/* Copyright 2022 - 2024 R. Thomas
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_ASM_X86_OPCODE_H
#define LIEF_ASM_X86_OPCODE_H

/* Generated from LLVM: 19.1.2 */

namespace LIEF {
namespace assembly {
namespace x86 {
enum class OPCODE {
  PHI = 0,
  INLINEASM = 1,
  INLINEASM_BR = 2,
  CFI_INSTRUCTION = 3,
  EH_LABEL = 4,
  GC_LABEL = 5,
  ANNOTATION_LABEL = 6,
  KILL = 7,
  EXTRACT_SUBREG = 8,
  INSERT_SUBREG = 9,
  IMPLICIT_DEF = 10,
  SUBREG_TO_REG = 11,
  COPY_TO_REGCLASS = 12,
  DBG_VALUE = 13,
  DBG_VALUE_LIST = 14,
  DBG_INSTR_REF = 15,
  DBG_PHI = 16,
  DBG_LABEL = 17,
  REG_SEQUENCE = 18,
  COPY = 19,
  BUNDLE = 20,
  LIFETIME_START = 21,
  LIFETIME_END = 22,
  PSEUDO_PROBE = 23,
  ARITH_FENCE = 24,
  STACKMAP = 25,
  FENTRY_CALL = 26,
  PATCHPOINT = 27,
  LOAD_STACK_GUARD = 28,
  PREALLOCATED_SETUP = 29,
  PREALLOCATED_ARG = 30,
  STATEPOINT = 31,
  LOCAL_ESCAPE = 32,
  FAULTING_OP = 33,
  PATCHABLE_OP = 34,
  PATCHABLE_FUNCTION_ENTER = 35,
  PATCHABLE_RET = 36,
  PATCHABLE_FUNCTION_EXIT = 37,
  PATCHABLE_TAIL_CALL = 38,
  PATCHABLE_EVENT_CALL = 39,
  PATCHABLE_TYPED_EVENT_CALL = 40,
  ICALL_BRANCH_FUNNEL = 41,
  MEMBARRIER = 42,
  JUMP_TABLE_DEBUG_INFO = 43,
  CONVERGENCECTRL_ENTRY = 44,
  CONVERGENCECTRL_ANCHOR = 45,
  CONVERGENCECTRL_LOOP = 46,
  CONVERGENCECTRL_GLUE = 47,
  G_ASSERT_SEXT = 48,
  G_ASSERT_ZEXT = 49,
  G_ASSERT_ALIGN = 50,
  G_ADD = 51,
  G_SUB = 52,
  G_MUL = 53,
  G_SDIV = 54,
  G_UDIV = 55,
  G_SREM = 56,
  G_UREM = 57,
  G_SDIVREM = 58,
  G_UDIVREM = 59,
  G_AND = 60,
  G_OR = 61,
  G_XOR = 62,
  G_IMPLICIT_DEF = 63,
  G_PHI = 64,
  G_FRAME_INDEX = 65,
  G_GLOBAL_VALUE = 66,
  G_PTRAUTH_GLOBAL_VALUE = 67,
  G_CONSTANT_POOL = 68,
  G_EXTRACT = 69,
  G_UNMERGE_VALUES = 70,
  G_INSERT = 71,
  G_MERGE_VALUES = 72,
  G_BUILD_VECTOR = 73,
  G_BUILD_VECTOR_TRUNC = 74,
  G_CONCAT_VECTORS = 75,
  G_PTRTOINT = 76,
  G_INTTOPTR = 77,
  G_BITCAST = 78,
  G_FREEZE = 79,
  G_CONSTANT_FOLD_BARRIER = 80,
  G_INTRINSIC_FPTRUNC_ROUND = 81,
  G_INTRINSIC_TRUNC = 82,
  G_INTRINSIC_ROUND = 83,
  G_INTRINSIC_LRINT = 84,
  G_INTRINSIC_LLRINT = 85,
  G_INTRINSIC_ROUNDEVEN = 86,
  G_READCYCLECOUNTER = 87,
  G_READSTEADYCOUNTER = 88,
  G_LOAD = 89,
  G_SEXTLOAD = 90,
  G_ZEXTLOAD = 91,
  G_INDEXED_LOAD = 92,
  G_INDEXED_SEXTLOAD = 93,
  G_INDEXED_ZEXTLOAD = 94,
  G_STORE = 95,
  G_INDEXED_STORE = 96,
  G_ATOMIC_CMPXCHG_WITH_SUCCESS = 97,
  G_ATOMIC_CMPXCHG = 98,
  G_ATOMICRMW_XCHG = 99,
  G_ATOMICRMW_ADD = 100,
  G_ATOMICRMW_SUB = 101,
  G_ATOMICRMW_AND = 102,
  G_ATOMICRMW_NAND = 103,
  G_ATOMICRMW_OR = 104,
  G_ATOMICRMW_XOR = 105,
  G_ATOMICRMW_MAX = 106,
  G_ATOMICRMW_MIN = 107,
  G_ATOMICRMW_UMAX = 108,
  G_ATOMICRMW_UMIN = 109,
  G_ATOMICRMW_FADD = 110,
  G_ATOMICRMW_FSUB = 111,
  G_ATOMICRMW_FMAX = 112,
  G_ATOMICRMW_FMIN = 113,
  G_ATOMICRMW_UINC_WRAP = 114,
  G_ATOMICRMW_UDEC_WRAP = 115,
  G_FENCE = 116,
  G_PREFETCH = 117,
  G_BRCOND = 118,
  G_BRINDIRECT = 119,
  G_INVOKE_REGION_START = 120,
  G_INTRINSIC = 121,
  G_INTRINSIC_W_SIDE_EFFECTS = 122,
  G_INTRINSIC_CONVERGENT = 123,
  G_INTRINSIC_CONVERGENT_W_SIDE_EFFECTS = 124,
  G_ANYEXT = 125,
  G_TRUNC = 126,
  G_CONSTANT = 127,
  G_FCONSTANT = 128,
  G_VASTART = 129,
  G_VAARG = 130,
  G_SEXT = 131,
  G_SEXT_INREG = 132,
  G_ZEXT = 133,
  G_SHL = 134,
  G_LSHR = 135,
  G_ASHR = 136,
  G_FSHL = 137,
  G_FSHR = 138,
  G_ROTR = 139,
  G_ROTL = 140,
  G_ICMP = 141,
  G_FCMP = 142,
  G_SCMP = 143,
  G_UCMP = 144,
  G_SELECT = 145,
  G_UADDO = 146,
  G_UADDE = 147,
  G_USUBO = 148,
  G_USUBE = 149,
  G_SADDO = 150,
  G_SADDE = 151,
  G_SSUBO = 152,
  G_SSUBE = 153,
  G_UMULO = 154,
  G_SMULO = 155,
  G_UMULH = 156,
  G_SMULH = 157,
  G_UADDSAT = 158,
  G_SADDSAT = 159,
  G_USUBSAT = 160,
  G_SSUBSAT = 161,
  G_USHLSAT = 162,
  G_SSHLSAT = 163,
  G_SMULFIX = 164,
  G_UMULFIX = 165,
  G_SMULFIXSAT = 166,
  G_UMULFIXSAT = 167,
  G_SDIVFIX = 168,
  G_UDIVFIX = 169,
  G_SDIVFIXSAT = 170,
  G_UDIVFIXSAT = 171,
  G_FADD = 172,
  G_FSUB = 173,
  G_FMUL = 174,
  G_FMA = 175,
  G_FMAD = 176,
  G_FDIV = 177,
  G_FREM = 178,
  G_FPOW = 179,
  G_FPOWI = 180,
  G_FEXP = 181,
  G_FEXP2 = 182,
  G_FEXP10 = 183,
  G_FLOG = 184,
  G_FLOG2 = 185,
  G_FLOG10 = 186,
  G_FLDEXP = 187,
  G_FFREXP = 188,
  G_FNEG = 189,
  G_FPEXT = 190,
  G_FPTRUNC = 191,
  G_FPTOSI = 192,
  G_FPTOUI = 193,
  G_SITOFP = 194,
  G_UITOFP = 195,
  G_FABS = 196,
  G_FCOPYSIGN = 197,
  G_IS_FPCLASS = 198,
  G_FCANONICALIZE = 199,
  G_FMINNUM = 200,
  G_FMAXNUM = 201,
  G_FMINNUM_IEEE = 202,
  G_FMAXNUM_IEEE = 203,
  G_FMINIMUM = 204,
  G_FMAXIMUM = 205,
  G_GET_FPENV = 206,
  G_SET_FPENV = 207,
  G_RESET_FPENV = 208,
  G_GET_FPMODE = 209,
  G_SET_FPMODE = 210,
  G_RESET_FPMODE = 211,
  G_PTR_ADD = 212,
  G_PTRMASK = 213,
  G_SMIN = 214,
  G_SMAX = 215,
  G_UMIN = 216,
  G_UMAX = 217,
  G_ABS = 218,
  G_LROUND = 219,
  G_LLROUND = 220,
  G_BR = 221,
  G_BRJT = 222,
  G_VSCALE = 223,
  G_INSERT_SUBVECTOR = 224,
  G_EXTRACT_SUBVECTOR = 225,
  G_INSERT_VECTOR_ELT = 226,
  G_EXTRACT_VECTOR_ELT = 227,
  G_SHUFFLE_VECTOR = 228,
  G_SPLAT_VECTOR = 229,
  G_VECTOR_COMPRESS = 230,
  G_CTTZ = 231,
  G_CTTZ_ZERO_UNDEF = 232,
  G_CTLZ = 233,
  G_CTLZ_ZERO_UNDEF = 234,
  G_CTPOP = 235,
  G_BSWAP = 236,
  G_BITREVERSE = 237,
  G_FCEIL = 238,
  G_FCOS = 239,
  G_FSIN = 240,
  G_FTAN = 241,
  G_FACOS = 242,
  G_FASIN = 243,
  G_FATAN = 244,
  G_FCOSH = 245,
  G_FSINH = 246,
  G_FTANH = 247,
  G_FSQRT = 248,
  G_FFLOOR = 249,
  G_FRINT = 250,
  G_FNEARBYINT = 251,
  G_ADDRSPACE_CAST = 252,
  G_BLOCK_ADDR = 253,
  G_JUMP_TABLE = 254,
  G_DYN_STACKALLOC = 255,
  G_STACKSAVE = 256,
  G_STACKRESTORE = 257,
  G_STRICT_FADD = 258,
  G_STRICT_FSUB = 259,
  G_STRICT_FMUL = 260,
  G_STRICT_FDIV = 261,
  G_STRICT_FREM = 262,
  G_STRICT_FMA = 263,
  G_STRICT_FSQRT = 264,
  G_STRICT_FLDEXP = 265,
  G_READ_REGISTER = 266,
  G_WRITE_REGISTER = 267,
  G_MEMCPY = 268,
  G_MEMCPY_INLINE = 269,
  G_MEMMOVE = 270,
  G_MEMSET = 271,
  G_BZERO = 272,
  G_TRAP = 273,
  G_DEBUGTRAP = 274,
  G_UBSANTRAP = 275,
  G_VECREDUCE_SEQ_FADD = 276,
  G_VECREDUCE_SEQ_FMUL = 277,
  G_VECREDUCE_FADD = 278,
  G_VECREDUCE_FMUL = 279,
  G_VECREDUCE_FMAX = 280,
  G_VECREDUCE_FMIN = 281,
  G_VECREDUCE_FMAXIMUM = 282,
  G_VECREDUCE_FMINIMUM = 283,
  G_VECREDUCE_ADD = 284,
  G_VECREDUCE_MUL = 285,
  G_VECREDUCE_AND = 286,
  G_VECREDUCE_OR = 287,
  G_VECREDUCE_XOR = 288,
  G_VECREDUCE_SMAX = 289,
  G_VECREDUCE_SMIN = 290,
  G_VECREDUCE_UMAX = 291,
  G_VECREDUCE_UMIN = 292,
  G_SBFX = 293,
  G_UBFX = 294,
  ADD16ri_DB = 295,
  ADD16rr_DB = 296,
  ADD32ri_DB = 297,
  ADD32rr_DB = 298,
  ADD64ri32_DB = 299,
  ADD64rr_DB = 300,
  ADD8ri_DB = 301,
  ADD8rr_DB = 302,
  AVX1_SETALLONES = 303,
  AVX2_SETALLONES = 304,
  AVX512_128_SET0 = 305,
  AVX512_256_SET0 = 306,
  AVX512_512_SET0 = 307,
  AVX512_512_SETALLONES = 308,
  AVX512_512_SEXT_MASK_32 = 309,
  AVX512_512_SEXT_MASK_64 = 310,
  AVX512_FsFLD0F128 = 311,
  AVX512_FsFLD0SD = 312,
  AVX512_FsFLD0SH = 313,
  AVX512_FsFLD0SS = 314,
  AVX_SET0 = 315,
  CALL64m_RVMARKER = 316,
  CALL64pcrel32_RVMARKER = 317,
  CALL64r_RVMARKER = 318,
  FsFLD0F128 = 319,
  FsFLD0SD = 320,
  FsFLD0SH = 321,
  FsFLD0SS = 322,
  INDIRECT_THUNK_CALL32 = 323,
  INDIRECT_THUNK_CALL64 = 324,
  INDIRECT_THUNK_TCRETURN32 = 325,
  INDIRECT_THUNK_TCRETURN64 = 326,
  KSET0D = 327,
  KSET0Q = 328,
  KSET0W = 329,
  KSET1D = 330,
  KSET1Q = 331,
  KSET1W = 332,
  LCMPXCHG16B_NO_RBX = 333,
  LCMPXCHG16B_SAVE_RBX = 334,
  MMX_SET0 = 335,
  MORESTACK_RET = 336,
  MORESTACK_RET_RESTORE_R10 = 337,
  MOV32ImmSExti8 = 338,
  MOV32r0 = 339,
  MOV32r1 = 340,
  MOV32r_1 = 341,
  MOV32ri64 = 342,
  MOV64ImmSExti8 = 343,
  MWAITX = 344,
  MWAITX_SAVE_RBX = 345,
  PLDTILECFGV = 346,
  PLEA32r = 347,
  PLEA64r = 348,
  PTDPBF16PSV = 349,
  PTDPBSSDV = 350,
  PTDPBSUDV = 351,
  PTDPBUSDV = 352,
  PTDPBUUDV = 353,
  PTDPFP16PSV = 354,
  PTILELOADDT1V = 355,
  PTILELOADDV = 356,
  PTILESTOREDV = 357,
  PTILEZEROV = 358,
  RDFLAGS32 = 359,
  RDFLAGS64 = 360,
  SEH_EndPrologue = 361,
  SEH_Epilogue = 362,
  SEH_PushFrame = 363,
  SEH_PushReg = 364,
  SEH_SaveReg = 365,
  SEH_SaveXMM = 366,
  SEH_SetFrame = 367,
  SEH_StackAlign = 368,
  SEH_StackAlloc = 369,
  SETB_C32r = 370,
  SETB_C64r = 371,
  SHLDROT32ri = 372,
  SHLDROT64ri = 373,
  SHRDROT32ri = 374,
  SHRDROT64ri = 375,
  VMOVAPSZ128mr_NOVLX = 376,
  VMOVAPSZ128rm_NOVLX = 377,
  VMOVAPSZ256mr_NOVLX = 378,
  VMOVAPSZ256rm_NOVLX = 379,
  VMOVUPSZ128mr_NOVLX = 380,
  VMOVUPSZ128rm_NOVLX = 381,
  VMOVUPSZ256mr_NOVLX = 382,
  VMOVUPSZ256rm_NOVLX = 383,
  V_SET0 = 384,
  V_SETALLONES = 385,
  WRFLAGS32 = 386,
  WRFLAGS64 = 387,
  XABORT_DEF = 388,
  XOR32_FP = 389,
  XOR64_FP = 390,
  AAA = 391,
  AAD8i8 = 392,
  AADD32mr = 393,
  AADD32mr_EVEX = 394,
  AADD64mr = 395,
  AADD64mr_EVEX = 396,
  AAM8i8 = 397,
  AAND32mr = 398,
  AAND32mr_EVEX = 399,
  AAND64mr = 400,
  AAND64mr_EVEX = 401,
  AAS = 402,
  ABS_F = 403,
  ABS_Fp32 = 404,
  ABS_Fp64 = 405,
  ABS_Fp80 = 406,
  ADC16i16 = 407,
  ADC16mi = 408,
  ADC16mi8 = 409,
  ADC16mi8_EVEX = 410,
  ADC16mi8_ND = 411,
  ADC16mi_EVEX = 412,
  ADC16mi_ND = 413,
  ADC16mr = 414,
  ADC16mr_EVEX = 415,
  ADC16mr_ND = 416,
  ADC16ri = 417,
  ADC16ri8 = 418,
  ADC16ri8_EVEX = 419,
  ADC16ri8_ND = 420,
  ADC16ri_EVEX = 421,
  ADC16ri_ND = 422,
  ADC16rm = 423,
  ADC16rm_EVEX = 424,
  ADC16rm_ND = 425,
  ADC16rr = 426,
  ADC16rr_EVEX = 427,
  ADC16rr_EVEX_REV = 428,
  ADC16rr_ND = 429,
  ADC16rr_ND_REV = 430,
  ADC16rr_REV = 431,
  ADC32i32 = 432,
  ADC32mi = 433,
  ADC32mi8 = 434,
  ADC32mi8_EVEX = 435,
  ADC32mi8_ND = 436,
  ADC32mi_EVEX = 437,
  ADC32mi_ND = 438,
  ADC32mr = 439,
  ADC32mr_EVEX = 440,
  ADC32mr_ND = 441,
  ADC32ri = 442,
  ADC32ri8 = 443,
  ADC32ri8_EVEX = 444,
  ADC32ri8_ND = 445,
  ADC32ri_EVEX = 446,
  ADC32ri_ND = 447,
  ADC32rm = 448,
  ADC32rm_EVEX = 449,
  ADC32rm_ND = 450,
  ADC32rr = 451,
  ADC32rr_EVEX = 452,
  ADC32rr_EVEX_REV = 453,
  ADC32rr_ND = 454,
  ADC32rr_ND_REV = 455,
  ADC32rr_REV = 456,
  ADC64i32 = 457,
  ADC64mi32 = 458,
  ADC64mi32_EVEX = 459,
  ADC64mi32_ND = 460,
  ADC64mi8 = 461,
  ADC64mi8_EVEX = 462,
  ADC64mi8_ND = 463,
  ADC64mr = 464,
  ADC64mr_EVEX = 465,
  ADC64mr_ND = 466,
  ADC64ri32 = 467,
  ADC64ri32_EVEX = 468,
  ADC64ri32_ND = 469,
  ADC64ri8 = 470,
  ADC64ri8_EVEX = 471,
  ADC64ri8_ND = 472,
  ADC64rm = 473,
  ADC64rm_EVEX = 474,
  ADC64rm_ND = 475,
  ADC64rr = 476,
  ADC64rr_EVEX = 477,
  ADC64rr_EVEX_REV = 478,
  ADC64rr_ND = 479,
  ADC64rr_ND_REV = 480,
  ADC64rr_REV = 481,
  ADC8i8 = 482,
  ADC8mi = 483,
  ADC8mi8 = 484,
  ADC8mi_EVEX = 485,
  ADC8mi_ND = 486,
  ADC8mr = 487,
  ADC8mr_EVEX = 488,
  ADC8mr_ND = 489,
  ADC8ri = 490,
  ADC8ri8 = 491,
  ADC8ri_EVEX = 492,
  ADC8ri_ND = 493,
  ADC8rm = 494,
  ADC8rm_EVEX = 495,
  ADC8rm_ND = 496,
  ADC8rr = 497,
  ADC8rr_EVEX = 498,
  ADC8rr_EVEX_REV = 499,
  ADC8rr_ND = 500,
  ADC8rr_ND_REV = 501,
  ADC8rr_REV = 502,
  ADCX32rm = 503,
  ADCX32rm_EVEX = 504,
  ADCX32rm_ND = 505,
  ADCX32rr = 506,
  ADCX32rr_EVEX = 507,
  ADCX32rr_ND = 508,
  ADCX64rm = 509,
  ADCX64rm_EVEX = 510,
  ADCX64rm_ND = 511,
  ADCX64rr = 512,
  ADCX64rr_EVEX = 513,
  ADCX64rr_ND = 514,
  ADD16i16 = 515,
  ADD16mi = 516,
  ADD16mi8 = 517,
  ADD16mi8_EVEX = 518,
  ADD16mi8_ND = 519,
  ADD16mi8_NF = 520,
  ADD16mi8_NF_ND = 521,
  ADD16mi_EVEX = 522,
  ADD16mi_ND = 523,
  ADD16mi_NF = 524,
  ADD16mi_NF_ND = 525,
  ADD16mr = 526,
  ADD16mr_EVEX = 527,
  ADD16mr_ND = 528,
  ADD16mr_NF = 529,
  ADD16mr_NF_ND = 530,
  ADD16ri = 531,
  ADD16ri8 = 532,
  ADD16ri8_EVEX = 533,
  ADD16ri8_ND = 534,
  ADD16ri8_NF = 535,
  ADD16ri8_NF_ND = 536,
  ADD16ri_EVEX = 537,
  ADD16ri_ND = 538,
  ADD16ri_NF = 539,
  ADD16ri_NF_ND = 540,
  ADD16rm = 541,
  ADD16rm_EVEX = 542,
  ADD16rm_ND = 543,
  ADD16rm_NF = 544,
  ADD16rm_NF_ND = 545,
  ADD16rr = 546,
  ADD16rr_EVEX = 547,
  ADD16rr_EVEX_REV = 548,
  ADD16rr_ND = 549,
  ADD16rr_ND_REV = 550,
  ADD16rr_NF = 551,
  ADD16rr_NF_ND = 552,
  ADD16rr_NF_ND_REV = 553,
  ADD16rr_NF_REV = 554,
  ADD16rr_REV = 555,
  ADD32i32 = 556,
  ADD32mi = 557,
  ADD32mi8 = 558,
  ADD32mi8_EVEX = 559,
  ADD32mi8_ND = 560,
  ADD32mi8_NF = 561,
  ADD32mi8_NF_ND = 562,
  ADD32mi_EVEX = 563,
  ADD32mi_ND = 564,
  ADD32mi_NF = 565,
  ADD32mi_NF_ND = 566,
  ADD32mr = 567,
  ADD32mr_EVEX = 568,
  ADD32mr_ND = 569,
  ADD32mr_NF = 570,
  ADD32mr_NF_ND = 571,
  ADD32ri = 572,
  ADD32ri8 = 573,
  ADD32ri8_EVEX = 574,
  ADD32ri8_ND = 575,
  ADD32ri8_NF = 576,
  ADD32ri8_NF_ND = 577,
  ADD32ri_EVEX = 578,
  ADD32ri_ND = 579,
  ADD32ri_NF = 580,
  ADD32ri_NF_ND = 581,
  ADD32rm = 582,
  ADD32rm_EVEX = 583,
  ADD32rm_ND = 584,
  ADD32rm_NF = 585,
  ADD32rm_NF_ND = 586,
  ADD32rr = 587,
  ADD32rr_EVEX = 588,
  ADD32rr_EVEX_REV = 589,
  ADD32rr_ND = 590,
  ADD32rr_ND_REV = 591,
  ADD32rr_NF = 592,
  ADD32rr_NF_ND = 593,
  ADD32rr_NF_ND_REV = 594,
  ADD32rr_NF_REV = 595,
  ADD32rr_REV = 596,
  ADD64i32 = 597,
  ADD64mi32 = 598,
  ADD64mi32_EVEX = 599,
  ADD64mi32_ND = 600,
  ADD64mi32_NF = 601,
  ADD64mi32_NF_ND = 602,
  ADD64mi8 = 603,
  ADD64mi8_EVEX = 604,
  ADD64mi8_ND = 605,
  ADD64mi8_NF = 606,
  ADD64mi8_NF_ND = 607,
  ADD64mr = 608,
  ADD64mr_EVEX = 609,
  ADD64mr_ND = 610,
  ADD64mr_NF = 611,
  ADD64mr_NF_ND = 612,
  ADD64ri32 = 613,
  ADD64ri32_EVEX = 614,
  ADD64ri32_ND = 615,
  ADD64ri32_NF = 616,
  ADD64ri32_NF_ND = 617,
  ADD64ri8 = 618,
  ADD64ri8_EVEX = 619,
  ADD64ri8_ND = 620,
  ADD64ri8_NF = 621,
  ADD64ri8_NF_ND = 622,
  ADD64rm = 623,
  ADD64rm_EVEX = 624,
  ADD64rm_ND = 625,
  ADD64rm_NF = 626,
  ADD64rm_NF_ND = 627,
  ADD64rr = 628,
  ADD64rr_EVEX = 629,
  ADD64rr_EVEX_REV = 630,
  ADD64rr_ND = 631,
  ADD64rr_ND_REV = 632,
  ADD64rr_NF = 633,
  ADD64rr_NF_ND = 634,
  ADD64rr_NF_ND_REV = 635,
  ADD64rr_NF_REV = 636,
  ADD64rr_REV = 637,
  ADD8i8 = 638,
  ADD8mi = 639,
  ADD8mi8 = 640,
  ADD8mi_EVEX = 641,
  ADD8mi_ND = 642,
  ADD8mi_NF = 643,
  ADD8mi_NF_ND = 644,
  ADD8mr = 645,
  ADD8mr_EVEX = 646,
  ADD8mr_ND = 647,
  ADD8mr_NF = 648,
  ADD8mr_NF_ND = 649,
  ADD8ri = 650,
  ADD8ri8 = 651,
  ADD8ri_EVEX = 652,
  ADD8ri_ND = 653,
  ADD8ri_NF = 654,
  ADD8ri_NF_ND = 655,
  ADD8rm = 656,
  ADD8rm_EVEX = 657,
  ADD8rm_ND = 658,
  ADD8rm_NF = 659,
  ADD8rm_NF_ND = 660,
  ADD8rr = 661,
  ADD8rr_EVEX = 662,
  ADD8rr_EVEX_REV = 663,
  ADD8rr_ND = 664,
  ADD8rr_ND_REV = 665,
  ADD8rr_NF = 666,
  ADD8rr_NF_ND = 667,
  ADD8rr_NF_ND_REV = 668,
  ADD8rr_NF_REV = 669,
  ADD8rr_REV = 670,
  ADDPDrm = 671,
  ADDPDrr = 672,
  ADDPSrm = 673,
  ADDPSrr = 674,
  ADDR16_PREFIX = 675,
  ADDR32_PREFIX = 676,
  ADDSDrm = 677,
  ADDSDrm_Int = 678,
  ADDSDrr = 679,
  ADDSDrr_Int = 680,
  ADDSSrm = 681,
  ADDSSrm_Int = 682,
  ADDSSrr = 683,
  ADDSSrr_Int = 684,
  ADDSUBPDrm = 685,
  ADDSUBPDrr = 686,
  ADDSUBPSrm = 687,
  ADDSUBPSrr = 688,
  ADD_F32m = 689,
  ADD_F64m = 690,
  ADD_FI16m = 691,
  ADD_FI32m = 692,
  ADD_FPrST0 = 693,
  ADD_FST0r = 694,
  ADD_Fp32 = 695,
  ADD_Fp32m = 696,
  ADD_Fp64 = 697,
  ADD_Fp64m = 698,
  ADD_Fp64m32 = 699,
  ADD_Fp80 = 700,
  ADD_Fp80m32 = 701,
  ADD_Fp80m64 = 702,
  ADD_FpI16m32 = 703,
  ADD_FpI16m64 = 704,
  ADD_FpI16m80 = 705,
  ADD_FpI32m32 = 706,
  ADD_FpI32m64 = 707,
  ADD_FpI32m80 = 708,
  ADD_FrST0 = 709,
  ADJCALLSTACKDOWN32 = 710,
  ADJCALLSTACKDOWN64 = 711,
  ADJCALLSTACKUP32 = 712,
  ADJCALLSTACKUP64 = 713,
  ADOX32rm = 714,
  ADOX32rm_EVEX = 715,
  ADOX32rm_ND = 716,
  ADOX32rr = 717,
  ADOX32rr_EVEX = 718,
  ADOX32rr_ND = 719,
  ADOX64rm = 720,
  ADOX64rm_EVEX = 721,
  ADOX64rm_ND = 722,
  ADOX64rr = 723,
  ADOX64rr_EVEX = 724,
  ADOX64rr_ND = 725,
  AESDEC128KL = 726,
  AESDEC256KL = 727,
  AESDECLASTrm = 728,
  AESDECLASTrr = 729,
  AESDECWIDE128KL = 730,
  AESDECWIDE256KL = 731,
  AESDECrm = 732,
  AESDECrr = 733,
  AESENC128KL = 734,
  AESENC256KL = 735,
  AESENCLASTrm = 736,
  AESENCLASTrr = 737,
  AESENCWIDE128KL = 738,
  AESENCWIDE256KL = 739,
  AESENCrm = 740,
  AESENCrr = 741,
  AESIMCrm = 742,
  AESIMCrr = 743,
  AESKEYGENASSIST128rm = 744,
  AESKEYGENASSIST128rr = 745,
  AND16i16 = 746,
  AND16mi = 747,
  AND16mi8 = 748,
  AND16mi8_EVEX = 749,
  AND16mi8_ND = 750,
  AND16mi8_NF = 751,
  AND16mi8_NF_ND = 752,
  AND16mi_EVEX = 753,
  AND16mi_ND = 754,
  AND16mi_NF = 755,
  AND16mi_NF_ND = 756,
  AND16mr = 757,
  AND16mr_EVEX = 758,
  AND16mr_ND = 759,
  AND16mr_NF = 760,
  AND16mr_NF_ND = 761,
  AND16ri = 762,
  AND16ri8 = 763,
  AND16ri8_EVEX = 764,
  AND16ri8_ND = 765,
  AND16ri8_NF = 766,
  AND16ri8_NF_ND = 767,
  AND16ri_EVEX = 768,
  AND16ri_ND = 769,
  AND16ri_NF = 770,
  AND16ri_NF_ND = 771,
  AND16rm = 772,
  AND16rm_EVEX = 773,
  AND16rm_ND = 774,
  AND16rm_NF = 775,
  AND16rm_NF_ND = 776,
  AND16rr = 777,
  AND16rr_EVEX = 778,
  AND16rr_EVEX_REV = 779,
  AND16rr_ND = 780,
  AND16rr_ND_REV = 781,
  AND16rr_NF = 782,
  AND16rr_NF_ND = 783,
  AND16rr_NF_ND_REV = 784,
  AND16rr_NF_REV = 785,
  AND16rr_REV = 786,
  AND32i32 = 787,
  AND32mi = 788,
  AND32mi8 = 789,
  AND32mi8_EVEX = 790,
  AND32mi8_ND = 791,
  AND32mi8_NF = 792,
  AND32mi8_NF_ND = 793,
  AND32mi_EVEX = 794,
  AND32mi_ND = 795,
  AND32mi_NF = 796,
  AND32mi_NF_ND = 797,
  AND32mr = 798,
  AND32mr_EVEX = 799,
  AND32mr_ND = 800,
  AND32mr_NF = 801,
  AND32mr_NF_ND = 802,
  AND32ri = 803,
  AND32ri8 = 804,
  AND32ri8_EVEX = 805,
  AND32ri8_ND = 806,
  AND32ri8_NF = 807,
  AND32ri8_NF_ND = 808,
  AND32ri_EVEX = 809,
  AND32ri_ND = 810,
  AND32ri_NF = 811,
  AND32ri_NF_ND = 812,
  AND32rm = 813,
  AND32rm_EVEX = 814,
  AND32rm_ND = 815,
  AND32rm_NF = 816,
  AND32rm_NF_ND = 817,
  AND32rr = 818,
  AND32rr_EVEX = 819,
  AND32rr_EVEX_REV = 820,
  AND32rr_ND = 821,
  AND32rr_ND_REV = 822,
  AND32rr_NF = 823,
  AND32rr_NF_ND = 824,
  AND32rr_NF_ND_REV = 825,
  AND32rr_NF_REV = 826,
  AND32rr_REV = 827,
  AND64i32 = 828,
  AND64mi32 = 829,
  AND64mi32_EVEX = 830,
  AND64mi32_ND = 831,
  AND64mi32_NF = 832,
  AND64mi32_NF_ND = 833,
  AND64mi8 = 834,
  AND64mi8_EVEX = 835,
  AND64mi8_ND = 836,
  AND64mi8_NF = 837,
  AND64mi8_NF_ND = 838,
  AND64mr = 839,
  AND64mr_EVEX = 840,
  AND64mr_ND = 841,
  AND64mr_NF = 842,
  AND64mr_NF_ND = 843,
  AND64ri32 = 844,
  AND64ri32_EVEX = 845,
  AND64ri32_ND = 846,
  AND64ri32_NF = 847,
  AND64ri32_NF_ND = 848,
  AND64ri8 = 849,
  AND64ri8_EVEX = 850,
  AND64ri8_ND = 851,
  AND64ri8_NF = 852,
  AND64ri8_NF_ND = 853,
  AND64rm = 854,
  AND64rm_EVEX = 855,
  AND64rm_ND = 856,
  AND64rm_NF = 857,
  AND64rm_NF_ND = 858,
  AND64rr = 859,
  AND64rr_EVEX = 860,
  AND64rr_EVEX_REV = 861,
  AND64rr_ND = 862,
  AND64rr_ND_REV = 863,
  AND64rr_NF = 864,
  AND64rr_NF_ND = 865,
  AND64rr_NF_ND_REV = 866,
  AND64rr_NF_REV = 867,
  AND64rr_REV = 868,
  AND8i8 = 869,
  AND8mi = 870,
  AND8mi8 = 871,
  AND8mi_EVEX = 872,
  AND8mi_ND = 873,
  AND8mi_NF = 874,
  AND8mi_NF_ND = 875,
  AND8mr = 876,
  AND8mr_EVEX = 877,
  AND8mr_ND = 878,
  AND8mr_NF = 879,
  AND8mr_NF_ND = 880,
  AND8ri = 881,
  AND8ri8 = 882,
  AND8ri_EVEX = 883,
  AND8ri_ND = 884,
  AND8ri_NF = 885,
  AND8ri_NF_ND = 886,
  AND8rm = 887,
  AND8rm_EVEX = 888,
  AND8rm_ND = 889,
  AND8rm_NF = 890,
  AND8rm_NF_ND = 891,
  AND8rr = 892,
  AND8rr_EVEX = 893,
  AND8rr_EVEX_REV = 894,
  AND8rr_ND = 895,
  AND8rr_ND_REV = 896,
  AND8rr_NF = 897,
  AND8rr_NF_ND = 898,
  AND8rr_NF_ND_REV = 899,
  AND8rr_NF_REV = 900,
  AND8rr_REV = 901,
  ANDN32rm = 902,
  ANDN32rm_EVEX = 903,
  ANDN32rm_NF = 904,
  ANDN32rr = 905,
  ANDN32rr_EVEX = 906,
  ANDN32rr_NF = 907,
  ANDN64rm = 908,
  ANDN64rm_EVEX = 909,
  ANDN64rm_NF = 910,
  ANDN64rr = 911,
  ANDN64rr_EVEX = 912,
  ANDN64rr_NF = 913,
  ANDNPDrm = 914,
  ANDNPDrr = 915,
  ANDNPSrm = 916,
  ANDNPSrr = 917,
  ANDPDrm = 918,
  ANDPDrr = 919,
  ANDPSrm = 920,
  ANDPSrr = 921,
  AOR32mr = 922,
  AOR32mr_EVEX = 923,
  AOR64mr = 924,
  AOR64mr_EVEX = 925,
  ARPL16mr = 926,
  ARPL16rr = 927,
  ASAN_CHECK_MEMACCESS = 928,
  AXOR32mr = 929,
  AXOR32mr_EVEX = 930,
  AXOR64mr = 931,
  AXOR64mr_EVEX = 932,
  BEXTR32rm = 933,
  BEXTR32rm_EVEX = 934,
  BEXTR32rm_NF = 935,
  BEXTR32rr = 936,
  BEXTR32rr_EVEX = 937,
  BEXTR32rr_NF = 938,
  BEXTR64rm = 939,
  BEXTR64rm_EVEX = 940,
  BEXTR64rm_NF = 941,
  BEXTR64rr = 942,
  BEXTR64rr_EVEX = 943,
  BEXTR64rr_NF = 944,
  BEXTRI32mi = 945,
  BEXTRI32ri = 946,
  BEXTRI64mi = 947,
  BEXTRI64ri = 948,
  BLCFILL32rm = 949,
  BLCFILL32rr = 950,
  BLCFILL64rm = 951,
  BLCFILL64rr = 952,
  BLCI32rm = 953,
  BLCI32rr = 954,
  BLCI64rm = 955,
  BLCI64rr = 956,
  BLCIC32rm = 957,
  BLCIC32rr = 958,
  BLCIC64rm = 959,
  BLCIC64rr = 960,
  BLCMSK32rm = 961,
  BLCMSK32rr = 962,
  BLCMSK64rm = 963,
  BLCMSK64rr = 964,
  BLCS32rm = 965,
  BLCS32rr = 966,
  BLCS64rm = 967,
  BLCS64rr = 968,
  BLENDPDrmi = 969,
  BLENDPDrri = 970,
  BLENDPSrmi = 971,
  BLENDPSrri = 972,
  BLENDVPDrm0 = 973,
  BLENDVPDrr0 = 974,
  BLENDVPSrm0 = 975,
  BLENDVPSrr0 = 976,
  BLSFILL32rm = 977,
  BLSFILL32rr = 978,
  BLSFILL64rm = 979,
  BLSFILL64rr = 980,
  BLSI32rm = 981,
  BLSI32rm_EVEX = 982,
  BLSI32rm_NF = 983,
  BLSI32rr = 984,
  BLSI32rr_EVEX = 985,
  BLSI32rr_NF = 986,
  BLSI64rm = 987,
  BLSI64rm_EVEX = 988,
  BLSI64rm_NF = 989,
  BLSI64rr = 990,
  BLSI64rr_EVEX = 991,
  BLSI64rr_NF = 992,
  BLSIC32rm = 993,
  BLSIC32rr = 994,
  BLSIC64rm = 995,
  BLSIC64rr = 996,
  BLSMSK32rm = 997,
  BLSMSK32rm_EVEX = 998,
  BLSMSK32rm_NF = 999,
  BLSMSK32rr = 1000,
  BLSMSK32rr_EVEX = 1001,
  BLSMSK32rr_NF = 1002,
  BLSMSK64rm = 1003,
  BLSMSK64rm_EVEX = 1004,
  BLSMSK64rm_NF = 1005,
  BLSMSK64rr = 1006,
  BLSMSK64rr_EVEX = 1007,
  BLSMSK64rr_NF = 1008,
  BLSR32rm = 1009,
  BLSR32rm_EVEX = 1010,
  BLSR32rm_NF = 1011,
  BLSR32rr = 1012,
  BLSR32rr_EVEX = 1013,
  BLSR32rr_NF = 1014,
  BLSR64rm = 1015,
  BLSR64rm_EVEX = 1016,
  BLSR64rm_NF = 1017,
  BLSR64rr = 1018,
  BLSR64rr_EVEX = 1019,
  BLSR64rr_NF = 1020,
  BOUNDS16rm = 1021,
  BOUNDS32rm = 1022,
  BSF16rm = 1023,
  BSF16rr = 1024,
  BSF32rm = 1025,
  BSF32rr = 1026,
  BSF64rm = 1027,
  BSF64rr = 1028,
  BSR16rm = 1029,
  BSR16rr = 1030,
  BSR32rm = 1031,
  BSR32rr = 1032,
  BSR64rm = 1033,
  BSR64rr = 1034,
  BSWAP16r_BAD = 1035,
  BSWAP32r = 1036,
  BSWAP64r = 1037,
  BT16mi8 = 1038,
  BT16mr = 1039,
  BT16ri8 = 1040,
  BT16rr = 1041,
  BT32mi8 = 1042,
  BT32mr = 1043,
  BT32ri8 = 1044,
  BT32rr = 1045,
  BT64mi8 = 1046,
  BT64mr = 1047,
  BT64ri8 = 1048,
  BT64rr = 1049,
  BTC16mi8 = 1050,
  BTC16mr = 1051,
  BTC16ri8 = 1052,
  BTC16rr = 1053,
  BTC32mi8 = 1054,
  BTC32mr = 1055,
  BTC32ri8 = 1056,
  BTC32rr = 1057,
  BTC64mi8 = 1058,
  BTC64mr = 1059,
  BTC64ri8 = 1060,
  BTC64rr = 1061,
  BTR16mi8 = 1062,
  BTR16mr = 1063,
  BTR16ri8 = 1064,
  BTR16rr = 1065,
  BTR32mi8 = 1066,
  BTR32mr = 1067,
  BTR32ri8 = 1068,
  BTR32rr = 1069,
  BTR64mi8 = 1070,
  BTR64mr = 1071,
  BTR64ri8 = 1072,
  BTR64rr = 1073,
  BTS16mi8 = 1074,
  BTS16mr = 1075,
  BTS16ri8 = 1076,
  BTS16rr = 1077,
  BTS32mi8 = 1078,
  BTS32mr = 1079,
  BTS32ri8 = 1080,
  BTS32rr = 1081,
  BTS64mi8 = 1082,
  BTS64mr = 1083,
  BTS64ri8 = 1084,
  BTS64rr = 1085,
  BZHI32rm = 1086,
  BZHI32rm_EVEX = 1087,
  BZHI32rm_NF = 1088,
  BZHI32rr = 1089,
  BZHI32rr_EVEX = 1090,
  BZHI32rr_NF = 1091,
  BZHI64rm = 1092,
  BZHI64rm_EVEX = 1093,
  BZHI64rm_NF = 1094,
  BZHI64rr = 1095,
  BZHI64rr_EVEX = 1096,
  BZHI64rr_NF = 1097,
  CALL16m = 1098,
  CALL16m_NT = 1099,
  CALL16r = 1100,
  CALL16r_NT = 1101,
  CALL32m = 1102,
  CALL32m_NT = 1103,
  CALL32r = 1104,
  CALL32r_NT = 1105,
  CALL64m = 1106,
  CALL64m_NT = 1107,
  CALL64pcrel32 = 1108,
  CALL64r = 1109,
  CALL64r_NT = 1110,
  CALLpcrel16 = 1111,
  CALLpcrel32 = 1112,
  CATCHRET = 1113,
  CBW = 1114,
  CCMP16mi = 1115,
  CCMP16mi8 = 1116,
  CCMP16mr = 1117,
  CCMP16ri = 1118,
  CCMP16ri8 = 1119,
  CCMP16rm = 1120,
  CCMP16rr = 1121,
  CCMP16rr_REV = 1122,
  CCMP32mi = 1123,
  CCMP32mi8 = 1124,
  CCMP32mr = 1125,
  CCMP32ri = 1126,
  CCMP32ri8 = 1127,
  CCMP32rm = 1128,
  CCMP32rr = 1129,
  CCMP32rr_REV = 1130,
  CCMP64mi32 = 1131,
  CCMP64mi8 = 1132,
  CCMP64mr = 1133,
  CCMP64ri32 = 1134,
  CCMP64ri8 = 1135,
  CCMP64rm = 1136,
  CCMP64rr = 1137,
  CCMP64rr_REV = 1138,
  CCMP8mi = 1139,
  CCMP8mr = 1140,
  CCMP8ri = 1141,
  CCMP8rm = 1142,
  CCMP8rr = 1143,
  CCMP8rr_REV = 1144,
  CDQ = 1145,
  CDQE = 1146,
  CFCMOV16mr = 1147,
  CFCMOV16rm = 1148,
  CFCMOV16rm_ND = 1149,
  CFCMOV16rr = 1150,
  CFCMOV16rr_ND = 1151,
  CFCMOV16rr_REV = 1152,
  CFCMOV32mr = 1153,
  CFCMOV32rm = 1154,
  CFCMOV32rm_ND = 1155,
  CFCMOV32rr = 1156,
  CFCMOV32rr_ND = 1157,
  CFCMOV32rr_REV = 1158,
  CFCMOV64mr = 1159,
  CFCMOV64rm = 1160,
  CFCMOV64rm_ND = 1161,
  CFCMOV64rr = 1162,
  CFCMOV64rr_ND = 1163,
  CFCMOV64rr_REV = 1164,
  CHS_F = 1165,
  CHS_Fp32 = 1166,
  CHS_Fp64 = 1167,
  CHS_Fp80 = 1168,
  CLAC = 1169,
  CLC = 1170,
  CLD = 1171,
  CLDEMOTE = 1172,
  CLEANUPRET = 1173,
  CLFLUSH = 1174,
  CLFLUSHOPT = 1175,
  CLGI = 1176,
  CLI = 1177,
  CLRSSBSY = 1178,
  CLTS = 1179,
  CLUI = 1180,
  CLWB = 1181,
  CLZERO32r = 1182,
  CLZERO64r = 1183,
  CMC = 1184,
  CMOV16rm = 1185,
  CMOV16rm_ND = 1186,
  CMOV16rr = 1187,
  CMOV16rr_ND = 1188,
  CMOV32rm = 1189,
  CMOV32rm_ND = 1190,
  CMOV32rr = 1191,
  CMOV32rr_ND = 1192,
  CMOV64rm = 1193,
  CMOV64rm_ND = 1194,
  CMOV64rr = 1195,
  CMOV64rr_ND = 1196,
  CMOVBE_F = 1197,
  CMOVBE_Fp32 = 1198,
  CMOVBE_Fp64 = 1199,
  CMOVBE_Fp80 = 1200,
  CMOVB_F = 1201,
  CMOVB_Fp32 = 1202,
  CMOVB_Fp64 = 1203,
  CMOVB_Fp80 = 1204,
  CMOVE_F = 1205,
  CMOVE_Fp32 = 1206,
  CMOVE_Fp64 = 1207,
  CMOVE_Fp80 = 1208,
  CMOVNBE_F = 1209,
  CMOVNBE_Fp32 = 1210,
  CMOVNBE_Fp64 = 1211,
  CMOVNBE_Fp80 = 1212,
  CMOVNB_F = 1213,
  CMOVNB_Fp32 = 1214,
  CMOVNB_Fp64 = 1215,
  CMOVNB_Fp80 = 1216,
  CMOVNE_F = 1217,
  CMOVNE_Fp32 = 1218,
  CMOVNE_Fp64 = 1219,
  CMOVNE_Fp80 = 1220,
  CMOVNP_F = 1221,
  CMOVNP_Fp32 = 1222,
  CMOVNP_Fp64 = 1223,
  CMOVNP_Fp80 = 1224,
  CMOVP_F = 1225,
  CMOVP_Fp32 = 1226,
  CMOVP_Fp64 = 1227,
  CMOVP_Fp80 = 1228,
  CMOV_FR16 = 1229,
  CMOV_FR16X = 1230,
  CMOV_FR32 = 1231,
  CMOV_FR32X = 1232,
  CMOV_FR64 = 1233,
  CMOV_FR64X = 1234,
  CMOV_GR16 = 1235,
  CMOV_GR32 = 1236,
  CMOV_GR8 = 1237,
  CMOV_RFP32 = 1238,
  CMOV_RFP64 = 1239,
  CMOV_RFP80 = 1240,
  CMOV_VK1 = 1241,
  CMOV_VK16 = 1242,
  CMOV_VK2 = 1243,
  CMOV_VK32 = 1244,
  CMOV_VK4 = 1245,
  CMOV_VK64 = 1246,
  CMOV_VK8 = 1247,
  CMOV_VR128 = 1248,
  CMOV_VR128X = 1249,
  CMOV_VR256 = 1250,
  CMOV_VR256X = 1251,
  CMOV_VR512 = 1252,
  CMOV_VR64 = 1253,
  CMP16i16 = 1254,
  CMP16mi = 1255,
  CMP16mi8 = 1256,
  CMP16mr = 1257,
  CMP16ri = 1258,
  CMP16ri8 = 1259,
  CMP16rm = 1260,
  CMP16rr = 1261,
  CMP16rr_REV = 1262,
  CMP32i32 = 1263,
  CMP32mi = 1264,
  CMP32mi8 = 1265,
  CMP32mr = 1266,
  CMP32ri = 1267,
  CMP32ri8 = 1268,
  CMP32rm = 1269,
  CMP32rr = 1270,
  CMP32rr_REV = 1271,
  CMP64i32 = 1272,
  CMP64mi32 = 1273,
  CMP64mi8 = 1274,
  CMP64mr = 1275,
  CMP64ri32 = 1276,
  CMP64ri8 = 1277,
  CMP64rm = 1278,
  CMP64rr = 1279,
  CMP64rr_REV = 1280,
  CMP8i8 = 1281,
  CMP8mi = 1282,
  CMP8mi8 = 1283,
  CMP8mr = 1284,
  CMP8ri = 1285,
  CMP8ri8 = 1286,
  CMP8rm = 1287,
  CMP8rr = 1288,
  CMP8rr_REV = 1289,
  CMPCCXADDmr32 = 1290,
  CMPCCXADDmr32_EVEX = 1291,
  CMPCCXADDmr64 = 1292,
  CMPCCXADDmr64_EVEX = 1293,
  CMPPDrmi = 1294,
  CMPPDrri = 1295,
  CMPPSrmi = 1296,
  CMPPSrri = 1297,
  CMPSB = 1298,
  CMPSDrmi = 1299,
  CMPSDrmi_Int = 1300,
  CMPSDrri = 1301,
  CMPSDrri_Int = 1302,
  CMPSL = 1303,
  CMPSQ = 1304,
  CMPSSrmi = 1305,
  CMPSSrmi_Int = 1306,
  CMPSSrri = 1307,
  CMPSSrri_Int = 1308,
  CMPSW = 1309,
  CMPXCHG16B = 1310,
  CMPXCHG16rm = 1311,
  CMPXCHG16rr = 1312,
  CMPXCHG32rm = 1313,
  CMPXCHG32rr = 1314,
  CMPXCHG64rm = 1315,
  CMPXCHG64rr = 1316,
  CMPXCHG8B = 1317,
  CMPXCHG8rm = 1318,
  CMPXCHG8rr = 1319,
  COMISDrm = 1320,
  COMISDrm_Int = 1321,
  COMISDrr = 1322,
  COMISDrr_Int = 1323,
  COMISSrm = 1324,
  COMISSrm_Int = 1325,
  COMISSrr = 1326,
  COMISSrr_Int = 1327,
  COMP_FST0r = 1328,
  COM_FIPr = 1329,
  COM_FIr = 1330,
  COM_FST0r = 1331,
  COM_FpIr32 = 1332,
  COM_FpIr64 = 1333,
  COM_FpIr80 = 1334,
  COM_Fpr32 = 1335,
  COM_Fpr64 = 1336,
  COM_Fpr80 = 1337,
  CPUID = 1338,
  CQO = 1339,
  CRC32r32m16 = 1340,
  CRC32r32m16_EVEX = 1341,
  CRC32r32m32 = 1342,
  CRC32r32m32_EVEX = 1343,
  CRC32r32m8 = 1344,
  CRC32r32m8_EVEX = 1345,
  CRC32r32r16 = 1346,
  CRC32r32r16_EVEX = 1347,
  CRC32r32r32 = 1348,
  CRC32r32r32_EVEX = 1349,
  CRC32r32r8 = 1350,
  CRC32r32r8_EVEX = 1351,
  CRC32r64m64 = 1352,
  CRC32r64m64_EVEX = 1353,
  CRC32r64m8 = 1354,
  CRC32r64m8_EVEX = 1355,
  CRC32r64r64 = 1356,
  CRC32r64r64_EVEX = 1357,
  CRC32r64r8 = 1358,
  CRC32r64r8_EVEX = 1359,
  CS_PREFIX = 1360,
  CTEST16mi = 1361,
  CTEST16mr = 1362,
  CTEST16ri = 1363,
  CTEST16rr = 1364,
  CTEST32mi = 1365,
  CTEST32mr = 1366,
  CTEST32ri = 1367,
  CTEST32rr = 1368,
  CTEST64mi32 = 1369,
  CTEST64mr = 1370,
  CTEST64ri32 = 1371,
  CTEST64rr = 1372,
  CTEST8mi = 1373,
  CTEST8mr = 1374,
  CTEST8ri = 1375,
  CTEST8rr = 1376,
  CVTDQ2PDrm = 1377,
  CVTDQ2PDrr = 1378,
  CVTDQ2PSrm = 1379,
  CVTDQ2PSrr = 1380,
  CVTPD2DQrm = 1381,
  CVTPD2DQrr = 1382,
  CVTPD2PSrm = 1383,
  CVTPD2PSrr = 1384,
  CVTPS2DQrm = 1385,
  CVTPS2DQrr = 1386,
  CVTPS2PDrm = 1387,
  CVTPS2PDrr = 1388,
  CVTSD2SI64rm = 1389,
  CVTSD2SI64rm_Int = 1390,
  CVTSD2SI64rr = 1391,
  CVTSD2SI64rr_Int = 1392,
  CVTSD2SIrm = 1393,
  CVTSD2SIrm_Int = 1394,
  CVTSD2SIrr = 1395,
  CVTSD2SIrr_Int = 1396,
  CVTSD2SSrm = 1397,
  CVTSD2SSrm_Int = 1398,
  CVTSD2SSrr = 1399,
  CVTSD2SSrr_Int = 1400,
  CVTSI2SDrm = 1401,
  CVTSI2SDrm_Int = 1402,
  CVTSI2SDrr = 1403,
  CVTSI2SDrr_Int = 1404,
  CVTSI2SSrm = 1405,
  CVTSI2SSrm_Int = 1406,
  CVTSI2SSrr = 1407,
  CVTSI2SSrr_Int = 1408,
  CVTSI642SDrm = 1409,
  CVTSI642SDrm_Int = 1410,
  CVTSI642SDrr = 1411,
  CVTSI642SDrr_Int = 1412,
  CVTSI642SSrm = 1413,
  CVTSI642SSrm_Int = 1414,
  CVTSI642SSrr = 1415,
  CVTSI642SSrr_Int = 1416,
  CVTSS2SDrm = 1417,
  CVTSS2SDrm_Int = 1418,
  CVTSS2SDrr = 1419,
  CVTSS2SDrr_Int = 1420,
  CVTSS2SI64rm = 1421,
  CVTSS2SI64rm_Int = 1422,
  CVTSS2SI64rr = 1423,
  CVTSS2SI64rr_Int = 1424,
  CVTSS2SIrm = 1425,
  CVTSS2SIrm_Int = 1426,
  CVTSS2SIrr = 1427,
  CVTSS2SIrr_Int = 1428,
  CVTTPD2DQrm = 1429,
  CVTTPD2DQrr = 1430,
  CVTTPS2DQrm = 1431,
  CVTTPS2DQrr = 1432,
  CVTTSD2SI64rm = 1433,
  CVTTSD2SI64rm_Int = 1434,
  CVTTSD2SI64rr = 1435,
  CVTTSD2SI64rr_Int = 1436,
  CVTTSD2SIrm = 1437,
  CVTTSD2SIrm_Int = 1438,
  CVTTSD2SIrr = 1439,
  CVTTSD2SIrr_Int = 1440,
  CVTTSS2SI64rm = 1441,
  CVTTSS2SI64rm_Int = 1442,
  CVTTSS2SI64rr = 1443,
  CVTTSS2SI64rr_Int = 1444,
  CVTTSS2SIrm = 1445,
  CVTTSS2SIrm_Int = 1446,
  CVTTSS2SIrr = 1447,
  CVTTSS2SIrr_Int = 1448,
  CWD = 1449,
  CWDE = 1450,
  DAA = 1451,
  DAS = 1452,
  DATA16_PREFIX = 1453,
  DEC16m = 1454,
  DEC16m_EVEX = 1455,
  DEC16m_ND = 1456,
  DEC16m_NF = 1457,
  DEC16m_NF_ND = 1458,
  DEC16r = 1459,
  DEC16r_EVEX = 1460,
  DEC16r_ND = 1461,
  DEC16r_NF = 1462,
  DEC16r_NF_ND = 1463,
  DEC16r_alt = 1464,
  DEC32m = 1465,
  DEC32m_EVEX = 1466,
  DEC32m_ND = 1467,
  DEC32m_NF = 1468,
  DEC32m_NF_ND = 1469,
  DEC32r = 1470,
  DEC32r_EVEX = 1471,
  DEC32r_ND = 1472,
  DEC32r_NF = 1473,
  DEC32r_NF_ND = 1474,
  DEC32r_alt = 1475,
  DEC64m = 1476,
  DEC64m_EVEX = 1477,
  DEC64m_ND = 1478,
  DEC64m_NF = 1479,
  DEC64m_NF_ND = 1480,
  DEC64r = 1481,
  DEC64r_EVEX = 1482,
  DEC64r_ND = 1483,
  DEC64r_NF = 1484,
  DEC64r_NF_ND = 1485,
  DEC8m = 1486,
  DEC8m_EVEX = 1487,
  DEC8m_ND = 1488,
  DEC8m_NF = 1489,
  DEC8m_NF_ND = 1490,
  DEC8r = 1491,
  DEC8r_EVEX = 1492,
  DEC8r_ND = 1493,
  DEC8r_NF = 1494,
  DEC8r_NF_ND = 1495,
  DIV16m = 1496,
  DIV16m_EVEX = 1497,
  DIV16m_NF = 1498,
  DIV16r = 1499,
  DIV16r_EVEX = 1500,
  DIV16r_NF = 1501,
  DIV32m = 1502,
  DIV32m_EVEX = 1503,
  DIV32m_NF = 1504,
  DIV32r = 1505,
  DIV32r_EVEX = 1506,
  DIV32r_NF = 1507,
  DIV64m = 1508,
  DIV64m_EVEX = 1509,
  DIV64m_NF = 1510,
  DIV64r = 1511,
  DIV64r_EVEX = 1512,
  DIV64r_NF = 1513,
  DIV8m = 1514,
  DIV8m_EVEX = 1515,
  DIV8m_NF = 1516,
  DIV8r = 1517,
  DIV8r_EVEX = 1518,
  DIV8r_NF = 1519,
  DIVPDrm = 1520,
  DIVPDrr = 1521,
  DIVPSrm = 1522,
  DIVPSrr = 1523,
  DIVR_F32m = 1524,
  DIVR_F64m = 1525,
  DIVR_FI16m = 1526,
  DIVR_FI32m = 1527,
  DIVR_FPrST0 = 1528,
  DIVR_FST0r = 1529,
  DIVR_Fp32m = 1530,
  DIVR_Fp64m = 1531,
  DIVR_Fp64m32 = 1532,
  DIVR_Fp80m32 = 1533,
  DIVR_Fp80m64 = 1534,
  DIVR_FpI16m32 = 1535,
  DIVR_FpI16m64 = 1536,
  DIVR_FpI16m80 = 1537,
  DIVR_FpI32m32 = 1538,
  DIVR_FpI32m64 = 1539,
  DIVR_FpI32m80 = 1540,
  DIVR_FrST0 = 1541,
  DIVSDrm = 1542,
  DIVSDrm_Int = 1543,
  DIVSDrr = 1544,
  DIVSDrr_Int = 1545,
  DIVSSrm = 1546,
  DIVSSrm_Int = 1547,
  DIVSSrr = 1548,
  DIVSSrr_Int = 1549,
  DIV_F32m = 1550,
  DIV_F64m = 1551,
  DIV_FI16m = 1552,
  DIV_FI32m = 1553,
  DIV_FPrST0 = 1554,
  DIV_FST0r = 1555,
  DIV_Fp32 = 1556,
  DIV_Fp32m = 1557,
  DIV_Fp64 = 1558,
  DIV_Fp64m = 1559,
  DIV_Fp64m32 = 1560,
  DIV_Fp80 = 1561,
  DIV_Fp80m32 = 1562,
  DIV_Fp80m64 = 1563,
  DIV_FpI16m32 = 1564,
  DIV_FpI16m64 = 1565,
  DIV_FpI16m80 = 1566,
  DIV_FpI32m32 = 1567,
  DIV_FpI32m64 = 1568,
  DIV_FpI32m80 = 1569,
  DIV_FrST0 = 1570,
  DPPDrmi = 1571,
  DPPDrri = 1572,
  DPPSrmi = 1573,
  DPPSrri = 1574,
  DS_PREFIX = 1575,
  DYN_ALLOCA_32 = 1576,
  DYN_ALLOCA_64 = 1577,
  EH_RETURN = 1578,
  EH_RETURN64 = 1579,
  EH_SjLj_LongJmp32 = 1580,
  EH_SjLj_LongJmp64 = 1581,
  EH_SjLj_SetJmp32 = 1582,
  EH_SjLj_SetJmp64 = 1583,
  EH_SjLj_Setup = 1584,
  ENCLS = 1585,
  ENCLU = 1586,
  ENCLV = 1587,
  ENCODEKEY128 = 1588,
  ENCODEKEY256 = 1589,
  ENDBR32 = 1590,
  ENDBR64 = 1591,
  ENQCMD16 = 1592,
  ENQCMD32 = 1593,
  ENQCMD32_EVEX = 1594,
  ENQCMD64 = 1595,
  ENQCMD64_EVEX = 1596,
  ENQCMDS16 = 1597,
  ENQCMDS32 = 1598,
  ENQCMDS32_EVEX = 1599,
  ENQCMDS64 = 1600,
  ENQCMDS64_EVEX = 1601,
  ENTER = 1602,
  ERETS = 1603,
  ERETU = 1604,
  ES_PREFIX = 1605,
  EXTRACTPSmr = 1606,
  EXTRACTPSrr = 1607,
  EXTRQ = 1608,
  EXTRQI = 1609,
  F2XM1 = 1610,
  FARCALL16i = 1611,
  FARCALL16m = 1612,
  FARCALL32i = 1613,
  FARCALL32m = 1614,
  FARCALL64m = 1615,
  FARJMP16i = 1616,
  FARJMP16m = 1617,
  FARJMP32i = 1618,
  FARJMP32m = 1619,
  FARJMP64m = 1620,
  FBLDm = 1621,
  FBSTPm = 1622,
  FCOM32m = 1623,
  FCOM64m = 1624,
  FCOMP32m = 1625,
  FCOMP64m = 1626,
  FCOMPP = 1627,
  FCOS = 1628,
  FDECSTP = 1629,
  FEMMS = 1630,
  FFREE = 1631,
  FFREEP = 1632,
  FICOM16m = 1633,
  FICOM32m = 1634,
  FICOMP16m = 1635,
  FICOMP32m = 1636,
  FINCSTP = 1637,
  FLDCW16m = 1638,
  FLDENVm = 1639,
  FLDL2E = 1640,
  FLDL2T = 1641,
  FLDLG2 = 1642,
  FLDLN2 = 1643,
  FLDPI = 1644,
  FNCLEX = 1645,
  FNINIT = 1646,
  FNOP = 1647,
  FNSTCW16m = 1648,
  FNSTSW16r = 1649,
  FNSTSWm = 1650,
  FP32_TO_INT16_IN_MEM = 1651,
  FP32_TO_INT32_IN_MEM = 1652,
  FP32_TO_INT64_IN_MEM = 1653,
  FP64_TO_INT16_IN_MEM = 1654,
  FP64_TO_INT32_IN_MEM = 1655,
  FP64_TO_INT64_IN_MEM = 1656,
  FP80_ADDm32 = 1657,
  FP80_ADDr = 1658,
  FP80_TO_INT16_IN_MEM = 1659,
  FP80_TO_INT32_IN_MEM = 1660,
  FP80_TO_INT64_IN_MEM = 1661,
  FPATAN = 1662,
  FPREM = 1663,
  FPREM1 = 1664,
  FPTAN = 1665,
  FRNDINT = 1666,
  FRSTORm = 1667,
  FSAVEm = 1668,
  FSCALE = 1669,
  FSIN = 1670,
  FSINCOS = 1671,
  FSTENVm = 1672,
  FS_PREFIX = 1673,
  FXRSTOR = 1674,
  FXRSTOR64 = 1675,
  FXSAVE = 1676,
  FXSAVE64 = 1677,
  FXTRACT = 1678,
  FYL2X = 1679,
  FYL2XP1 = 1680,
  GETSEC = 1681,
  GF2P8AFFINEINVQBrmi = 1682,
  GF2P8AFFINEINVQBrri = 1683,
  GF2P8AFFINEQBrmi = 1684,
  GF2P8AFFINEQBrri = 1685,
  GF2P8MULBrm = 1686,
  GF2P8MULBrr = 1687,
  GS_PREFIX = 1688,
  HADDPDrm = 1689,
  HADDPDrr = 1690,
  HADDPSrm = 1691,
  HADDPSrr = 1692,
  HLT = 1693,
  HRESET = 1694,
  HSUBPDrm = 1695,
  HSUBPDrr = 1696,
  HSUBPSrm = 1697,
  HSUBPSrr = 1698,
  IDIV16m = 1699,
  IDIV16m_EVEX = 1700,
  IDIV16m_NF = 1701,
  IDIV16r = 1702,
  IDIV16r_EVEX = 1703,
  IDIV16r_NF = 1704,
  IDIV32m = 1705,
  IDIV32m_EVEX = 1706,
  IDIV32m_NF = 1707,
  IDIV32r = 1708,
  IDIV32r_EVEX = 1709,
  IDIV32r_NF = 1710,
  IDIV64m = 1711,
  IDIV64m_EVEX = 1712,
  IDIV64m_NF = 1713,
  IDIV64r = 1714,
  IDIV64r_EVEX = 1715,
  IDIV64r_NF = 1716,
  IDIV8m = 1717,
  IDIV8m_EVEX = 1718,
  IDIV8m_NF = 1719,
  IDIV8r = 1720,
  IDIV8r_EVEX = 1721,
  IDIV8r_NF = 1722,
  ILD_F16m = 1723,
  ILD_F32m = 1724,
  ILD_F64m = 1725,
  ILD_Fp16m32 = 1726,
  ILD_Fp16m64 = 1727,
  ILD_Fp16m80 = 1728,
  ILD_Fp32m32 = 1729,
  ILD_Fp32m64 = 1730,
  ILD_Fp32m80 = 1731,
  ILD_Fp64m32 = 1732,
  ILD_Fp64m64 = 1733,
  ILD_Fp64m80 = 1734,
  IMUL16m = 1735,
  IMUL16m_EVEX = 1736,
  IMUL16m_NF = 1737,
  IMUL16r = 1738,
  IMUL16r_EVEX = 1739,
  IMUL16r_NF = 1740,
  IMUL16rm = 1741,
  IMUL16rm_EVEX = 1742,
  IMUL16rm_ND = 1743,
  IMUL16rm_NF = 1744,
  IMUL16rm_NF_ND = 1745,
  IMUL16rmi = 1746,
  IMUL16rmi8 = 1747,
  IMUL16rmi8_EVEX = 1748,
  IMUL16rmi8_NF = 1749,
  IMUL16rmi_EVEX = 1750,
  IMUL16rmi_NF = 1751,
  IMUL16rr = 1752,
  IMUL16rr_EVEX = 1753,
  IMUL16rr_ND = 1754,
  IMUL16rr_NF = 1755,
  IMUL16rr_NF_ND = 1756,
  IMUL16rri = 1757,
  IMUL16rri8 = 1758,
  IMUL16rri8_EVEX = 1759,
  IMUL16rri8_NF = 1760,
  IMUL16rri_EVEX = 1761,
  IMUL16rri_NF = 1762,
  IMUL32m = 1763,
  IMUL32m_EVEX = 1764,
  IMUL32m_NF = 1765,
  IMUL32r = 1766,
  IMUL32r_EVEX = 1767,
  IMUL32r_NF = 1768,
  IMUL32rm = 1769,
  IMUL32rm_EVEX = 1770,
  IMUL32rm_ND = 1771,
  IMUL32rm_NF = 1772,
  IMUL32rm_NF_ND = 1773,
  IMUL32rmi = 1774,
  IMUL32rmi8 = 1775,
  IMUL32rmi8_EVEX = 1776,
  IMUL32rmi8_NF = 1777,
  IMUL32rmi_EVEX = 1778,
  IMUL32rmi_NF = 1779,
  IMUL32rr = 1780,
  IMUL32rr_EVEX = 1781,
  IMUL32rr_ND = 1782,
  IMUL32rr_NF = 1783,
  IMUL32rr_NF_ND = 1784,
  IMUL32rri = 1785,
  IMUL32rri8 = 1786,
  IMUL32rri8_EVEX = 1787,
  IMUL32rri8_NF = 1788,
  IMUL32rri_EVEX = 1789,
  IMUL32rri_NF = 1790,
  IMUL64m = 1791,
  IMUL64m_EVEX = 1792,
  IMUL64m_NF = 1793,
  IMUL64r = 1794,
  IMUL64r_EVEX = 1795,
  IMUL64r_NF = 1796,
  IMUL64rm = 1797,
  IMUL64rm_EVEX = 1798,
  IMUL64rm_ND = 1799,
  IMUL64rm_NF = 1800,
  IMUL64rm_NF_ND = 1801,
  IMUL64rmi32 = 1802,
  IMUL64rmi32_EVEX = 1803,
  IMUL64rmi32_NF = 1804,
  IMUL64rmi8 = 1805,
  IMUL64rmi8_EVEX = 1806,
  IMUL64rmi8_NF = 1807,
  IMUL64rr = 1808,
  IMUL64rr_EVEX = 1809,
  IMUL64rr_ND = 1810,
  IMUL64rr_NF = 1811,
  IMUL64rr_NF_ND = 1812,
  IMUL64rri32 = 1813,
  IMUL64rri32_EVEX = 1814,
  IMUL64rri32_NF = 1815,
  IMUL64rri8 = 1816,
  IMUL64rri8_EVEX = 1817,
  IMUL64rri8_NF = 1818,
  IMUL8m = 1819,
  IMUL8m_EVEX = 1820,
  IMUL8m_NF = 1821,
  IMUL8r = 1822,
  IMUL8r_EVEX = 1823,
  IMUL8r_NF = 1824,
  IMULZU16rmi = 1825,
  IMULZU16rmi8 = 1826,
  IMULZU16rri = 1827,
  IMULZU16rri8 = 1828,
  IMULZU32rmi = 1829,
  IMULZU32rmi8 = 1830,
  IMULZU32rri = 1831,
  IMULZU32rri8 = 1832,
  IMULZU64rmi32 = 1833,
  IMULZU64rmi8 = 1834,
  IMULZU64rri32 = 1835,
  IMULZU64rri8 = 1836,
  IN16ri = 1837,
  IN16rr = 1838,
  IN32ri = 1839,
  IN32rr = 1840,
  IN8ri = 1841,
  IN8rr = 1842,
  INC16m = 1843,
  INC16m_EVEX = 1844,
  INC16m_ND = 1845,
  INC16m_NF = 1846,
  INC16m_NF_ND = 1847,
  INC16r = 1848,
  INC16r_EVEX = 1849,
  INC16r_ND = 1850,
  INC16r_NF = 1851,
  INC16r_NF_ND = 1852,
  INC16r_alt = 1853,
  INC32m = 1854,
  INC32m_EVEX = 1855,
  INC32m_ND = 1856,
  INC32m_NF = 1857,
  INC32m_NF_ND = 1858,
  INC32r = 1859,
  INC32r_EVEX = 1860,
  INC32r_ND = 1861,
  INC32r_NF = 1862,
  INC32r_NF_ND = 1863,
  INC32r_alt = 1864,
  INC64m = 1865,
  INC64m_EVEX = 1866,
  INC64m_ND = 1867,
  INC64m_NF = 1868,
  INC64m_NF_ND = 1869,
  INC64r = 1870,
  INC64r_EVEX = 1871,
  INC64r_ND = 1872,
  INC64r_NF = 1873,
  INC64r_NF_ND = 1874,
  INC8m = 1875,
  INC8m_EVEX = 1876,
  INC8m_ND = 1877,
  INC8m_NF = 1878,
  INC8m_NF_ND = 1879,
  INC8r = 1880,
  INC8r_EVEX = 1881,
  INC8r_ND = 1882,
  INC8r_NF = 1883,
  INC8r_NF_ND = 1884,
  INCSSPD = 1885,
  INCSSPQ = 1886,
  INSB = 1887,
  INSERTPSrm = 1888,
  INSERTPSrr = 1889,
  INSERTQ = 1890,
  INSERTQI = 1891,
  INSL = 1892,
  INSW = 1893,
  INT = 1894,
  INT3 = 1895,
  INTO = 1896,
  INVD = 1897,
  INVEPT32 = 1898,
  INVEPT64 = 1899,
  INVEPT64_EVEX = 1900,
  INVLPG = 1901,
  INVLPGA32 = 1902,
  INVLPGA64 = 1903,
  INVLPGB32 = 1904,
  INVLPGB64 = 1905,
  INVPCID32 = 1906,
  INVPCID64 = 1907,
  INVPCID64_EVEX = 1908,
  INVVPID32 = 1909,
  INVVPID64 = 1910,
  INVVPID64_EVEX = 1911,
  IRET = 1912,
  IRET16 = 1913,
  IRET32 = 1914,
  IRET64 = 1915,
  ISTT_FP16m = 1916,
  ISTT_FP32m = 1917,
  ISTT_FP64m = 1918,
  ISTT_Fp16m32 = 1919,
  ISTT_Fp16m64 = 1920,
  ISTT_Fp16m80 = 1921,
  ISTT_Fp32m32 = 1922,
  ISTT_Fp32m64 = 1923,
  ISTT_Fp32m80 = 1924,
  ISTT_Fp64m32 = 1925,
  ISTT_Fp64m64 = 1926,
  ISTT_Fp64m80 = 1927,
  IST_F16m = 1928,
  IST_F32m = 1929,
  IST_FP16m = 1930,
  IST_FP32m = 1931,
  IST_FP64m = 1932,
  IST_Fp16m32 = 1933,
  IST_Fp16m64 = 1934,
  IST_Fp16m80 = 1935,
  IST_Fp32m32 = 1936,
  IST_Fp32m64 = 1937,
  IST_Fp32m80 = 1938,
  IST_Fp64m32 = 1939,
  IST_Fp64m64 = 1940,
  IST_Fp64m80 = 1941,
  Int_eh_sjlj_setup_dispatch = 1942,
  JCC_1 = 1943,
  JCC_2 = 1944,
  JCC_4 = 1945,
  JCXZ = 1946,
  JECXZ = 1947,
  JMP16m = 1948,
  JMP16m_NT = 1949,
  JMP16r = 1950,
  JMP16r_NT = 1951,
  JMP32m = 1952,
  JMP32m_NT = 1953,
  JMP32r = 1954,
  JMP32r_NT = 1955,
  JMP64m = 1956,
  JMP64m_NT = 1957,
  JMP64m_REX = 1958,
  JMP64r = 1959,
  JMP64r_NT = 1960,
  JMP64r_REX = 1961,
  JMPABS64i = 1962,
  JMP_1 = 1963,
  JMP_2 = 1964,
  JMP_4 = 1965,
  JRCXZ = 1966,
  KADDBrr = 1967,
  KADDDrr = 1968,
  KADDQrr = 1969,
  KADDWrr = 1970,
  KANDBrr = 1971,
  KANDDrr = 1972,
  KANDNBrr = 1973,
  KANDNDrr = 1974,
  KANDNQrr = 1975,
  KANDNWrr = 1976,
  KANDQrr = 1977,
  KANDWrr = 1978,
  KCFI_CHECK = 1979,
  KMOVBkk = 1980,
  KMOVBkk_EVEX = 1981,
  KMOVBkm = 1982,
  KMOVBkm_EVEX = 1983,
  KMOVBkr = 1984,
  KMOVBkr_EVEX = 1985,
  KMOVBmk = 1986,
  KMOVBmk_EVEX = 1987,
  KMOVBrk = 1988,
  KMOVBrk_EVEX = 1989,
  KMOVDkk = 1990,
  KMOVDkk_EVEX = 1991,
  KMOVDkm = 1992,
  KMOVDkm_EVEX = 1993,
  KMOVDkr = 1994,
  KMOVDkr_EVEX = 1995,
  KMOVDmk = 1996,
  KMOVDmk_EVEX = 1997,
  KMOVDrk = 1998,
  KMOVDrk_EVEX = 1999,
  KMOVQkk = 2000,
  KMOVQkk_EVEX = 2001,
  KMOVQkm = 2002,
  KMOVQkm_EVEX = 2003,
  KMOVQkr = 2004,
  KMOVQkr_EVEX = 2005,
  KMOVQmk = 2006,
  KMOVQmk_EVEX = 2007,
  KMOVQrk = 2008,
  KMOVQrk_EVEX = 2009,
  KMOVWkk = 2010,
  KMOVWkk_EVEX = 2011,
  KMOVWkm = 2012,
  KMOVWkm_EVEX = 2013,
  KMOVWkr = 2014,
  KMOVWkr_EVEX = 2015,
  KMOVWmk = 2016,
  KMOVWmk_EVEX = 2017,
  KMOVWrk = 2018,
  KMOVWrk_EVEX = 2019,
  KNOTBrr = 2020,
  KNOTDrr = 2021,
  KNOTQrr = 2022,
  KNOTWrr = 2023,
  KORBrr = 2024,
  KORDrr = 2025,
  KORQrr = 2026,
  KORTESTBrr = 2027,
  KORTESTDrr = 2028,
  KORTESTQrr = 2029,
  KORTESTWrr = 2030,
  KORWrr = 2031,
  KSHIFTLBri = 2032,
  KSHIFTLDri = 2033,
  KSHIFTLQri = 2034,
  KSHIFTLWri = 2035,
  KSHIFTRBri = 2036,
  KSHIFTRDri = 2037,
  KSHIFTRQri = 2038,
  KSHIFTRWri = 2039,
  KTESTBrr = 2040,
  KTESTDrr = 2041,
  KTESTQrr = 2042,
  KTESTWrr = 2043,
  KUNPCKBWrr = 2044,
  KUNPCKDQrr = 2045,
  KUNPCKWDrr = 2046,
  KXNORBrr = 2047,
  KXNORDrr = 2048,
  KXNORQrr = 2049,
  KXNORWrr = 2050,
  KXORBrr = 2051,
  KXORDrr = 2052,
  KXORQrr = 2053,
  KXORWrr = 2054,
  LAHF = 2055,
  LAR16rm = 2056,
  LAR16rr = 2057,
  LAR32rm = 2058,
  LAR32rr = 2059,
  LAR64rm = 2060,
  LAR64rr = 2061,
  LCMPXCHG16 = 2062,
  LCMPXCHG16B = 2063,
  LCMPXCHG32 = 2064,
  LCMPXCHG64 = 2065,
  LCMPXCHG8 = 2066,
  LCMPXCHG8B = 2067,
  LDDQUrm = 2068,
  LDMXCSR = 2069,
  LDS16rm = 2070,
  LDS32rm = 2071,
  LDTILECFG = 2072,
  LDTILECFG_EVEX = 2073,
  LD_F0 = 2074,
  LD_F1 = 2075,
  LD_F32m = 2076,
  LD_F64m = 2077,
  LD_F80m = 2078,
  LD_Fp032 = 2079,
  LD_Fp064 = 2080,
  LD_Fp080 = 2081,
  LD_Fp132 = 2082,
  LD_Fp164 = 2083,
  LD_Fp180 = 2084,
  LD_Fp32m = 2085,
  LD_Fp32m64 = 2086,
  LD_Fp32m80 = 2087,
  LD_Fp64m = 2088,
  LD_Fp64m80 = 2089,
  LD_Fp80m = 2090,
  LD_Frr = 2091,
  LEA16r = 2092,
  LEA32r = 2093,
  LEA64_32r = 2094,
  LEA64r = 2095,
  LEAVE = 2096,
  LEAVE64 = 2097,
  LES16rm = 2098,
  LES32rm = 2099,
  LFENCE = 2100,
  LFS16rm = 2101,
  LFS32rm = 2102,
  LFS64rm = 2103,
  LGDT16m = 2104,
  LGDT32m = 2105,
  LGDT64m = 2106,
  LGS16rm = 2107,
  LGS32rm = 2108,
  LGS64rm = 2109,
  LIDT16m = 2110,
  LIDT32m = 2111,
  LIDT64m = 2112,
  LKGS16m = 2113,
  LKGS16r = 2114,
  LLDT16m = 2115,
  LLDT16r = 2116,
  LLWPCB = 2117,
  LLWPCB64 = 2118,
  LMSW16m = 2119,
  LMSW16r = 2120,
  LOADIWKEY = 2121,
  LOCK_ADD16mi = 2122,
  LOCK_ADD16mi8 = 2123,
  LOCK_ADD16mr = 2124,
  LOCK_ADD32mi = 2125,
  LOCK_ADD32mi8 = 2126,
  LOCK_ADD32mr = 2127,
  LOCK_ADD64mi32 = 2128,
  LOCK_ADD64mi8 = 2129,
  LOCK_ADD64mr = 2130,
  LOCK_ADD8mi = 2131,
  LOCK_ADD8mr = 2132,
  LOCK_AND16mi = 2133,
  LOCK_AND16mi8 = 2134,
  LOCK_AND16mr = 2135,
  LOCK_AND32mi = 2136,
  LOCK_AND32mi8 = 2137,
  LOCK_AND32mr = 2138,
  LOCK_AND64mi32 = 2139,
  LOCK_AND64mi8 = 2140,
  LOCK_AND64mr = 2141,
  LOCK_AND8mi = 2142,
  LOCK_AND8mr = 2143,
  LOCK_BTC16m = 2144,
  LOCK_BTC32m = 2145,
  LOCK_BTC64m = 2146,
  LOCK_BTC_RM16rm = 2147,
  LOCK_BTC_RM32rm = 2148,
  LOCK_BTC_RM64rm = 2149,
  LOCK_BTR16m = 2150,
  LOCK_BTR32m = 2151,
  LOCK_BTR64m = 2152,
  LOCK_BTR_RM16rm = 2153,
  LOCK_BTR_RM32rm = 2154,
  LOCK_BTR_RM64rm = 2155,
  LOCK_BTS16m = 2156,
  LOCK_BTS32m = 2157,
  LOCK_BTS64m = 2158,
  LOCK_BTS_RM16rm = 2159,
  LOCK_BTS_RM32rm = 2160,
  LOCK_BTS_RM64rm = 2161,
  LOCK_DEC16m = 2162,
  LOCK_DEC32m = 2163,
  LOCK_DEC64m = 2164,
  LOCK_DEC8m = 2165,
  LOCK_INC16m = 2166,
  LOCK_INC32m = 2167,
  LOCK_INC64m = 2168,
  LOCK_INC8m = 2169,
  LOCK_OR16mi = 2170,
  LOCK_OR16mi8 = 2171,
  LOCK_OR16mr = 2172,
  LOCK_OR32mi = 2173,
  LOCK_OR32mi8 = 2174,
  LOCK_OR32mr = 2175,
  LOCK_OR64mi32 = 2176,
  LOCK_OR64mi8 = 2177,
  LOCK_OR64mr = 2178,
  LOCK_OR8mi = 2179,
  LOCK_OR8mr = 2180,
  LOCK_PREFIX = 2181,
  LOCK_SUB16mi = 2182,
  LOCK_SUB16mi8 = 2183,
  LOCK_SUB16mr = 2184,
  LOCK_SUB32mi = 2185,
  LOCK_SUB32mi8 = 2186,
  LOCK_SUB32mr = 2187,
  LOCK_SUB64mi32 = 2188,
  LOCK_SUB64mi8 = 2189,
  LOCK_SUB64mr = 2190,
  LOCK_SUB8mi = 2191,
  LOCK_SUB8mr = 2192,
  LOCK_XOR16mi = 2193,
  LOCK_XOR16mi8 = 2194,
  LOCK_XOR16mr = 2195,
  LOCK_XOR32mi = 2196,
  LOCK_XOR32mi8 = 2197,
  LOCK_XOR32mr = 2198,
  LOCK_XOR64mi32 = 2199,
  LOCK_XOR64mi8 = 2200,
  LOCK_XOR64mr = 2201,
  LOCK_XOR8mi = 2202,
  LOCK_XOR8mr = 2203,
  LODSB = 2204,
  LODSL = 2205,
  LODSQ = 2206,
  LODSW = 2207,
  LOOP = 2208,
  LOOPE = 2209,
  LOOPNE = 2210,
  LRET16 = 2211,
  LRET32 = 2212,
  LRET64 = 2213,
  LRETI16 = 2214,
  LRETI32 = 2215,
  LRETI64 = 2216,
  LSL16rm = 2217,
  LSL16rr = 2218,
  LSL32rm = 2219,
  LSL32rr = 2220,
  LSL64rm = 2221,
  LSL64rr = 2222,
  LSS16rm = 2223,
  LSS32rm = 2224,
  LSS64rm = 2225,
  LTRm = 2226,
  LTRr = 2227,
  LWPINS32rmi = 2228,
  LWPINS32rri = 2229,
  LWPINS64rmi = 2230,
  LWPINS64rri = 2231,
  LWPVAL32rmi = 2232,
  LWPVAL32rri = 2233,
  LWPVAL64rmi = 2234,
  LWPVAL64rri = 2235,
  LXADD16 = 2236,
  LXADD32 = 2237,
  LXADD64 = 2238,
  LXADD8 = 2239,
  LZCNT16rm = 2240,
  LZCNT16rm_EVEX = 2241,
  LZCNT16rm_NF = 2242,
  LZCNT16rr = 2243,
  LZCNT16rr_EVEX = 2244,
  LZCNT16rr_NF = 2245,
  LZCNT32rm = 2246,
  LZCNT32rm_EVEX = 2247,
  LZCNT32rm_NF = 2248,
  LZCNT32rr = 2249,
  LZCNT32rr_EVEX = 2250,
  LZCNT32rr_NF = 2251,
  LZCNT64rm = 2252,
  LZCNT64rm_EVEX = 2253,
  LZCNT64rm_NF = 2254,
  LZCNT64rr = 2255,
  LZCNT64rr_EVEX = 2256,
  LZCNT64rr_NF = 2257,
  MASKMOVDQU = 2258,
  MASKMOVDQU64 = 2259,
  MASKPAIR16LOAD = 2260,
  MASKPAIR16STORE = 2261,
  MAXCPDrm = 2262,
  MAXCPDrr = 2263,
  MAXCPSrm = 2264,
  MAXCPSrr = 2265,
  MAXCSDrm = 2266,
  MAXCSDrr = 2267,
  MAXCSSrm = 2268,
  MAXCSSrr = 2269,
  MAXPDrm = 2270,
  MAXPDrr = 2271,
  MAXPSrm = 2272,
  MAXPSrr = 2273,
  MAXSDrm = 2274,
  MAXSDrm_Int = 2275,
  MAXSDrr = 2276,
  MAXSDrr_Int = 2277,
  MAXSSrm = 2278,
  MAXSSrm_Int = 2279,
  MAXSSrr = 2280,
  MAXSSrr_Int = 2281,
  MFENCE = 2282,
  MINCPDrm = 2283,
  MINCPDrr = 2284,
  MINCPSrm = 2285,
  MINCPSrr = 2286,
  MINCSDrm = 2287,
  MINCSDrr = 2288,
  MINCSSrm = 2289,
  MINCSSrr = 2290,
  MINPDrm = 2291,
  MINPDrr = 2292,
  MINPSrm = 2293,
  MINPSrr = 2294,
  MINSDrm = 2295,
  MINSDrm_Int = 2296,
  MINSDrr = 2297,
  MINSDrr_Int = 2298,
  MINSSrm = 2299,
  MINSSrm_Int = 2300,
  MINSSrr = 2301,
  MINSSrr_Int = 2302,
  MMX_CVTPD2PIrm = 2303,
  MMX_CVTPD2PIrr = 2304,
  MMX_CVTPI2PDrm = 2305,
  MMX_CVTPI2PDrr = 2306,
  MMX_CVTPI2PSrm = 2307,
  MMX_CVTPI2PSrr = 2308,
  MMX_CVTPS2PIrm = 2309,
  MMX_CVTPS2PIrr = 2310,
  MMX_CVTTPD2PIrm = 2311,
  MMX_CVTTPD2PIrr = 2312,
  MMX_CVTTPS2PIrm = 2313,
  MMX_CVTTPS2PIrr = 2314,
  MMX_EMMS = 2315,
  MMX_MASKMOVQ = 2316,
  MMX_MASKMOVQ64 = 2317,
  MMX_MOVD64from64mr = 2318,
  MMX_MOVD64from64rr = 2319,
  MMX_MOVD64grr = 2320,
  MMX_MOVD64mr = 2321,
  MMX_MOVD64rm = 2322,
  MMX_MOVD64rr = 2323,
  MMX_MOVD64to64rm = 2324,
  MMX_MOVD64to64rr = 2325,
  MMX_MOVDQ2Qrr = 2326,
  MMX_MOVFR642Qrr = 2327,
  MMX_MOVNTQmr = 2328,
  MMX_MOVQ2DQrr = 2329,
  MMX_MOVQ2FR64rr = 2330,
  MMX_MOVQ64mr = 2331,
  MMX_MOVQ64rm = 2332,
  MMX_MOVQ64rr = 2333,
  MMX_MOVQ64rr_REV = 2334,
  MMX_PABSBrm = 2335,
  MMX_PABSBrr = 2336,
  MMX_PABSDrm = 2337,
  MMX_PABSDrr = 2338,
  MMX_PABSWrm = 2339,
  MMX_PABSWrr = 2340,
  MMX_PACKSSDWrm = 2341,
  MMX_PACKSSDWrr = 2342,
  MMX_PACKSSWBrm = 2343,
  MMX_PACKSSWBrr = 2344,
  MMX_PACKUSWBrm = 2345,
  MMX_PACKUSWBrr = 2346,
  MMX_PADDBrm = 2347,
  MMX_PADDBrr = 2348,
  MMX_PADDDrm = 2349,
  MMX_PADDDrr = 2350,
  MMX_PADDQrm = 2351,
  MMX_PADDQrr = 2352,
  MMX_PADDSBrm = 2353,
  MMX_PADDSBrr = 2354,
  MMX_PADDSWrm = 2355,
  MMX_PADDSWrr = 2356,
  MMX_PADDUSBrm = 2357,
  MMX_PADDUSBrr = 2358,
  MMX_PADDUSWrm = 2359,
  MMX_PADDUSWrr = 2360,
  MMX_PADDWrm = 2361,
  MMX_PADDWrr = 2362,
  MMX_PALIGNRrmi = 2363,
  MMX_PALIGNRrri = 2364,
  MMX_PANDNrm = 2365,
  MMX_PANDNrr = 2366,
  MMX_PANDrm = 2367,
  MMX_PANDrr = 2368,
  MMX_PAVGBrm = 2369,
  MMX_PAVGBrr = 2370,
  MMX_PAVGWrm = 2371,
  MMX_PAVGWrr = 2372,
  MMX_PCMPEQBrm = 2373,
  MMX_PCMPEQBrr = 2374,
  MMX_PCMPEQDrm = 2375,
  MMX_PCMPEQDrr = 2376,
  MMX_PCMPEQWrm = 2377,
  MMX_PCMPEQWrr = 2378,
  MMX_PCMPGTBrm = 2379,
  MMX_PCMPGTBrr = 2380,
  MMX_PCMPGTDrm = 2381,
  MMX_PCMPGTDrr = 2382,
  MMX_PCMPGTWrm = 2383,
  MMX_PCMPGTWrr = 2384,
  MMX_PEXTRWrr = 2385,
  MMX_PHADDDrm = 2386,
  MMX_PHADDDrr = 2387,
  MMX_PHADDSWrm = 2388,
  MMX_PHADDSWrr = 2389,
  MMX_PHADDWrm = 2390,
  MMX_PHADDWrr = 2391,
  MMX_PHSUBDrm = 2392,
  MMX_PHSUBDrr = 2393,
  MMX_PHSUBSWrm = 2394,
  MMX_PHSUBSWrr = 2395,
  MMX_PHSUBWrm = 2396,
  MMX_PHSUBWrr = 2397,
  MMX_PINSRWrm = 2398,
  MMX_PINSRWrr = 2399,
  MMX_PMADDUBSWrm = 2400,
  MMX_PMADDUBSWrr = 2401,
  MMX_PMADDWDrm = 2402,
  MMX_PMADDWDrr = 2403,
  MMX_PMAXSWrm = 2404,
  MMX_PMAXSWrr = 2405,
  MMX_PMAXUBrm = 2406,
  MMX_PMAXUBrr = 2407,
  MMX_PMINSWrm = 2408,
  MMX_PMINSWrr = 2409,
  MMX_PMINUBrm = 2410,
  MMX_PMINUBrr = 2411,
  MMX_PMOVMSKBrr = 2412,
  MMX_PMULHRSWrm = 2413,
  MMX_PMULHRSWrr = 2414,
  MMX_PMULHUWrm = 2415,
  MMX_PMULHUWrr = 2416,
  MMX_PMULHWrm = 2417,
  MMX_PMULHWrr = 2418,
  MMX_PMULLWrm = 2419,
  MMX_PMULLWrr = 2420,
  MMX_PMULUDQrm = 2421,
  MMX_PMULUDQrr = 2422,
  MMX_PORrm = 2423,
  MMX_PORrr = 2424,
  MMX_PSADBWrm = 2425,
  MMX_PSADBWrr = 2426,
  MMX_PSHUFBrm = 2427,
  MMX_PSHUFBrr = 2428,
  MMX_PSHUFWmi = 2429,
  MMX_PSHUFWri = 2430,
  MMX_PSIGNBrm = 2431,
  MMX_PSIGNBrr = 2432,
  MMX_PSIGNDrm = 2433,
  MMX_PSIGNDrr = 2434,
  MMX_PSIGNWrm = 2435,
  MMX_PSIGNWrr = 2436,
  MMX_PSLLDri = 2437,
  MMX_PSLLDrm = 2438,
  MMX_PSLLDrr = 2439,
  MMX_PSLLQri = 2440,
  MMX_PSLLQrm = 2441,
  MMX_PSLLQrr = 2442,
  MMX_PSLLWri = 2443,
  MMX_PSLLWrm = 2444,
  MMX_PSLLWrr = 2445,
  MMX_PSRADri = 2446,
  MMX_PSRADrm = 2447,
  MMX_PSRADrr = 2448,
  MMX_PSRAWri = 2449,
  MMX_PSRAWrm = 2450,
  MMX_PSRAWrr = 2451,
  MMX_PSRLDri = 2452,
  MMX_PSRLDrm = 2453,
  MMX_PSRLDrr = 2454,
  MMX_PSRLQri = 2455,
  MMX_PSRLQrm = 2456,
  MMX_PSRLQrr = 2457,
  MMX_PSRLWri = 2458,
  MMX_PSRLWrm = 2459,
  MMX_PSRLWrr = 2460,
  MMX_PSUBBrm = 2461,
  MMX_PSUBBrr = 2462,
  MMX_PSUBDrm = 2463,
  MMX_PSUBDrr = 2464,
  MMX_PSUBQrm = 2465,
  MMX_PSUBQrr = 2466,
  MMX_PSUBSBrm = 2467,
  MMX_PSUBSBrr = 2468,
  MMX_PSUBSWrm = 2469,
  MMX_PSUBSWrr = 2470,
  MMX_PSUBUSBrm = 2471,
  MMX_PSUBUSBrr = 2472,
  MMX_PSUBUSWrm = 2473,
  MMX_PSUBUSWrr = 2474,
  MMX_PSUBWrm = 2475,
  MMX_PSUBWrr = 2476,
  MMX_PUNPCKHBWrm = 2477,
  MMX_PUNPCKHBWrr = 2478,
  MMX_PUNPCKHDQrm = 2479,
  MMX_PUNPCKHDQrr = 2480,
  MMX_PUNPCKHWDrm = 2481,
  MMX_PUNPCKHWDrr = 2482,
  MMX_PUNPCKLBWrm = 2483,
  MMX_PUNPCKLBWrr = 2484,
  MMX_PUNPCKLDQrm = 2485,
  MMX_PUNPCKLDQrr = 2486,
  MMX_PUNPCKLWDrm = 2487,
  MMX_PUNPCKLWDrr = 2488,
  MMX_PXORrm = 2489,
  MMX_PXORrr = 2490,
  MONITOR32rrr = 2491,
  MONITOR64rrr = 2492,
  MONITORX32rrr = 2493,
  MONITORX64rrr = 2494,
  MONTMUL = 2495,
  MOV16ao16 = 2496,
  MOV16ao32 = 2497,
  MOV16ao64 = 2498,
  MOV16mi = 2499,
  MOV16mr = 2500,
  MOV16ms = 2501,
  MOV16o16a = 2502,
  MOV16o32a = 2503,
  MOV16o64a = 2504,
  MOV16ri = 2505,
  MOV16ri_alt = 2506,
  MOV16rm = 2507,
  MOV16rr = 2508,
  MOV16rr_REV = 2509,
  MOV16rs = 2510,
  MOV16sm = 2511,
  MOV16sr = 2512,
  MOV32ao16 = 2513,
  MOV32ao32 = 2514,
  MOV32ao64 = 2515,
  MOV32cr = 2516,
  MOV32dr = 2517,
  MOV32mi = 2518,
  MOV32mr = 2519,
  MOV32o16a = 2520,
  MOV32o32a = 2521,
  MOV32o64a = 2522,
  MOV32rc = 2523,
  MOV32rd = 2524,
  MOV32ri = 2525,
  MOV32ri_alt = 2526,
  MOV32rm = 2527,
  MOV32rr = 2528,
  MOV32rr_REV = 2529,
  MOV32rs = 2530,
  MOV32sr = 2531,
  MOV64ao32 = 2532,
  MOV64ao64 = 2533,
  MOV64cr = 2534,
  MOV64dr = 2535,
  MOV64mi32 = 2536,
  MOV64mr = 2537,
  MOV64o32a = 2538,
  MOV64o64a = 2539,
  MOV64rc = 2540,
  MOV64rd = 2541,
  MOV64ri = 2542,
  MOV64ri32 = 2543,
  MOV64rm = 2544,
  MOV64rr = 2545,
  MOV64rr_REV = 2546,
  MOV64rs = 2547,
  MOV64sr = 2548,
  MOV64toPQIrm = 2549,
  MOV64toPQIrr = 2550,
  MOV64toSDrr = 2551,
  MOV8ao16 = 2552,
  MOV8ao32 = 2553,
  MOV8ao64 = 2554,
  MOV8mi = 2555,
  MOV8mr = 2556,
  MOV8mr_NOREX = 2557,
  MOV8o16a = 2558,
  MOV8o32a = 2559,
  MOV8o64a = 2560,
  MOV8ri = 2561,
  MOV8ri_alt = 2562,
  MOV8rm = 2563,
  MOV8rm_NOREX = 2564,
  MOV8rr = 2565,
  MOV8rr_NOREX = 2566,
  MOV8rr_REV = 2567,
  MOVAPDmr = 2568,
  MOVAPDrm = 2569,
  MOVAPDrr = 2570,
  MOVAPDrr_REV = 2571,
  MOVAPSmr = 2572,
  MOVAPSrm = 2573,
  MOVAPSrr = 2574,
  MOVAPSrr_REV = 2575,
  MOVBE16mr = 2576,
  MOVBE16mr_EVEX = 2577,
  MOVBE16rm = 2578,
  MOVBE16rm_EVEX = 2579,
  MOVBE16rr = 2580,
  MOVBE16rr_REV = 2581,
  MOVBE32mr = 2582,
  MOVBE32mr_EVEX = 2583,
  MOVBE32rm = 2584,
  MOVBE32rm_EVEX = 2585,
  MOVBE32rr = 2586,
  MOVBE32rr_REV = 2587,
  MOVBE64mr = 2588,
  MOVBE64mr_EVEX = 2589,
  MOVBE64rm = 2590,
  MOVBE64rm_EVEX = 2591,
  MOVBE64rr = 2592,
  MOVBE64rr_REV = 2593,
  MOVDDUPrm = 2594,
  MOVDDUPrr = 2595,
  MOVDI2PDIrm = 2596,
  MOVDI2PDIrr = 2597,
  MOVDI2SSrr = 2598,
  MOVDIR64B16 = 2599,
  MOVDIR64B32 = 2600,
  MOVDIR64B32_EVEX = 2601,
  MOVDIR64B64 = 2602,
  MOVDIR64B64_EVEX = 2603,
  MOVDIRI32 = 2604,
  MOVDIRI32_EVEX = 2605,
  MOVDIRI64 = 2606,
  MOVDIRI64_EVEX = 2607,
  MOVDQAmr = 2608,
  MOVDQArm = 2609,
  MOVDQArr = 2610,
  MOVDQArr_REV = 2611,
  MOVDQUmr = 2612,
  MOVDQUrm = 2613,
  MOVDQUrr = 2614,
  MOVDQUrr_REV = 2615,
  MOVHLPSrr = 2616,
  MOVHPDmr = 2617,
  MOVHPDrm = 2618,
  MOVHPSmr = 2619,
  MOVHPSrm = 2620,
  MOVLHPSrr = 2621,
  MOVLPDmr = 2622,
  MOVLPDrm = 2623,
  MOVLPSmr = 2624,
  MOVLPSrm = 2625,
  MOVMSKPDrr = 2626,
  MOVMSKPSrr = 2627,
  MOVNTDQArm = 2628,
  MOVNTDQmr = 2629,
  MOVNTI_64mr = 2630,
  MOVNTImr = 2631,
  MOVNTPDmr = 2632,
  MOVNTPSmr = 2633,
  MOVNTSD = 2634,
  MOVNTSS = 2635,
  MOVPC32r = 2636,
  MOVPDI2DImr = 2637,
  MOVPDI2DIrr = 2638,
  MOVPQI2QImr = 2639,
  MOVPQI2QIrr = 2640,
  MOVPQIto64mr = 2641,
  MOVPQIto64rr = 2642,
  MOVQI2PQIrm = 2643,
  MOVSB = 2644,
  MOVSDmr = 2645,
  MOVSDrm = 2646,
  MOVSDrm_alt = 2647,
  MOVSDrr = 2648,
  MOVSDrr_REV = 2649,
  MOVSDto64rr = 2650,
  MOVSHDUPrm = 2651,
  MOVSHDUPrr = 2652,
  MOVSL = 2653,
  MOVSLDUPrm = 2654,
  MOVSLDUPrr = 2655,
  MOVSQ = 2656,
  MOVSS2DIrr = 2657,
  MOVSSmr = 2658,
  MOVSSrm = 2659,
  MOVSSrm_alt = 2660,
  MOVSSrr = 2661,
  MOVSSrr_REV = 2662,
  MOVSW = 2663,
  MOVSX16rm16 = 2664,
  MOVSX16rm32 = 2665,
  MOVSX16rm8 = 2666,
  MOVSX16rr16 = 2667,
  MOVSX16rr32 = 2668,
  MOVSX16rr8 = 2669,
  MOVSX32rm16 = 2670,
  MOVSX32rm32 = 2671,
  MOVSX32rm8 = 2672,
  MOVSX32rm8_NOREX = 2673,
  MOVSX32rr16 = 2674,
  MOVSX32rr32 = 2675,
  MOVSX32rr8 = 2676,
  MOVSX32rr8_NOREX = 2677,
  MOVSX64rm16 = 2678,
  MOVSX64rm32 = 2679,
  MOVSX64rm8 = 2680,
  MOVSX64rr16 = 2681,
  MOVSX64rr32 = 2682,
  MOVSX64rr8 = 2683,
  MOVUPDmr = 2684,
  MOVUPDrm = 2685,
  MOVUPDrr = 2686,
  MOVUPDrr_REV = 2687,
  MOVUPSmr = 2688,
  MOVUPSrm = 2689,
  MOVUPSrr = 2690,
  MOVUPSrr_REV = 2691,
  MOVZPQILo2PQIrr = 2692,
  MOVZX16rm16 = 2693,
  MOVZX16rm8 = 2694,
  MOVZX16rr16 = 2695,
  MOVZX16rr8 = 2696,
  MOVZX32rm16 = 2697,
  MOVZX32rm8 = 2698,
  MOVZX32rm8_NOREX = 2699,
  MOVZX32rr16 = 2700,
  MOVZX32rr8 = 2701,
  MOVZX32rr8_NOREX = 2702,
  MOVZX64rm16 = 2703,
  MOVZX64rm8 = 2704,
  MOVZX64rr16 = 2705,
  MOVZX64rr8 = 2706,
  MPSADBWrmi = 2707,
  MPSADBWrri = 2708,
  MUL16m = 2709,
  MUL16m_EVEX = 2710,
  MUL16m_NF = 2711,
  MUL16r = 2712,
  MUL16r_EVEX = 2713,
  MUL16r_NF = 2714,
  MUL32m = 2715,
  MUL32m_EVEX = 2716,
  MUL32m_NF = 2717,
  MUL32r = 2718,
  MUL32r_EVEX = 2719,
  MUL32r_NF = 2720,
  MUL64m = 2721,
  MUL64m_EVEX = 2722,
  MUL64m_NF = 2723,
  MUL64r = 2724,
  MUL64r_EVEX = 2725,
  MUL64r_NF = 2726,
  MUL8m = 2727,
  MUL8m_EVEX = 2728,
  MUL8m_NF = 2729,
  MUL8r = 2730,
  MUL8r_EVEX = 2731,
  MUL8r_NF = 2732,
  MULPDrm = 2733,
  MULPDrr = 2734,
  MULPSrm = 2735,
  MULPSrr = 2736,
  MULSDrm = 2737,
  MULSDrm_Int = 2738,
  MULSDrr = 2739,
  MULSDrr_Int = 2740,
  MULSSrm = 2741,
  MULSSrm_Int = 2742,
  MULSSrr = 2743,
  MULSSrr_Int = 2744,
  MULX32Hrm = 2745,
  MULX32Hrr = 2746,
  MULX32rm = 2747,
  MULX32rm_EVEX = 2748,
  MULX32rr = 2749,
  MULX32rr_EVEX = 2750,
  MULX64Hrm = 2751,
  MULX64Hrr = 2752,
  MULX64rm = 2753,
  MULX64rm_EVEX = 2754,
  MULX64rr = 2755,
  MULX64rr_EVEX = 2756,
  MUL_F32m = 2757,
  MUL_F64m = 2758,
  MUL_FI16m = 2759,
  MUL_FI32m = 2760,
  MUL_FPrST0 = 2761,
  MUL_FST0r = 2762,
  MUL_Fp32 = 2763,
  MUL_Fp32m = 2764,
  MUL_Fp64 = 2765,
  MUL_Fp64m = 2766,
  MUL_Fp64m32 = 2767,
  MUL_Fp80 = 2768,
  MUL_Fp80m32 = 2769,
  MUL_Fp80m64 = 2770,
  MUL_FpI16m32 = 2771,
  MUL_FpI16m64 = 2772,
  MUL_FpI16m80 = 2773,
  MUL_FpI32m32 = 2774,
  MUL_FpI32m64 = 2775,
  MUL_FpI32m80 = 2776,
  MUL_FrST0 = 2777,
  MWAITXrrr = 2778,
  MWAITrr = 2779,
  NEG16m = 2780,
  NEG16m_EVEX = 2781,
  NEG16m_ND = 2782,
  NEG16m_NF = 2783,
  NEG16m_NF_ND = 2784,
  NEG16r = 2785,
  NEG16r_EVEX = 2786,
  NEG16r_ND = 2787,
  NEG16r_NF = 2788,
  NEG16r_NF_ND = 2789,
  NEG32m = 2790,
  NEG32m_EVEX = 2791,
  NEG32m_ND = 2792,
  NEG32m_NF = 2793,
  NEG32m_NF_ND = 2794,
  NEG32r = 2795,
  NEG32r_EVEX = 2796,
  NEG32r_ND = 2797,
  NEG32r_NF = 2798,
  NEG32r_NF_ND = 2799,
  NEG64m = 2800,
  NEG64m_EVEX = 2801,
  NEG64m_ND = 2802,
  NEG64m_NF = 2803,
  NEG64m_NF_ND = 2804,
  NEG64r = 2805,
  NEG64r_EVEX = 2806,
  NEG64r_ND = 2807,
  NEG64r_NF = 2808,
  NEG64r_NF_ND = 2809,
  NEG8m = 2810,
  NEG8m_EVEX = 2811,
  NEG8m_ND = 2812,
  NEG8m_NF = 2813,
  NEG8m_NF_ND = 2814,
  NEG8r = 2815,
  NEG8r_EVEX = 2816,
  NEG8r_ND = 2817,
  NEG8r_NF = 2818,
  NEG8r_NF_ND = 2819,
  NOOP = 2820,
  NOOPL = 2821,
  NOOPLr = 2822,
  NOOPQ = 2823,
  NOOPQr = 2824,
  NOOPW = 2825,
  NOOPWr = 2826,
  NOT16m = 2827,
  NOT16m_EVEX = 2828,
  NOT16m_ND = 2829,
  NOT16r = 2830,
  NOT16r_EVEX = 2831,
  NOT16r_ND = 2832,
  NOT32m = 2833,
  NOT32m_EVEX = 2834,
  NOT32m_ND = 2835,
  NOT32r = 2836,
  NOT32r_EVEX = 2837,
  NOT32r_ND = 2838,
  NOT64m = 2839,
  NOT64m_EVEX = 2840,
  NOT64m_ND = 2841,
  NOT64r = 2842,
  NOT64r_EVEX = 2843,
  NOT64r_ND = 2844,
  NOT8m = 2845,
  NOT8m_EVEX = 2846,
  NOT8m_ND = 2847,
  NOT8r = 2848,
  NOT8r_EVEX = 2849,
  NOT8r_ND = 2850,
  OR16i16 = 2851,
  OR16mi = 2852,
  OR16mi8 = 2853,
  OR16mi8_EVEX = 2854,
  OR16mi8_ND = 2855,
  OR16mi8_NF = 2856,
  OR16mi8_NF_ND = 2857,
  OR16mi_EVEX = 2858,
  OR16mi_ND = 2859,
  OR16mi_NF = 2860,
  OR16mi_NF_ND = 2861,
  OR16mr = 2862,
  OR16mr_EVEX = 2863,
  OR16mr_ND = 2864,
  OR16mr_NF = 2865,
  OR16mr_NF_ND = 2866,
  OR16ri = 2867,
  OR16ri8 = 2868,
  OR16ri8_EVEX = 2869,
  OR16ri8_ND = 2870,
  OR16ri8_NF = 2871,
  OR16ri8_NF_ND = 2872,
  OR16ri_EVEX = 2873,
  OR16ri_ND = 2874,
  OR16ri_NF = 2875,
  OR16ri_NF_ND = 2876,
  OR16rm = 2877,
  OR16rm_EVEX = 2878,
  OR16rm_ND = 2879,
  OR16rm_NF = 2880,
  OR16rm_NF_ND = 2881,
  OR16rr = 2882,
  OR16rr_EVEX = 2883,
  OR16rr_EVEX_REV = 2884,
  OR16rr_ND = 2885,
  OR16rr_ND_REV = 2886,
  OR16rr_NF = 2887,
  OR16rr_NF_ND = 2888,
  OR16rr_NF_ND_REV = 2889,
  OR16rr_NF_REV = 2890,
  OR16rr_REV = 2891,
  OR32i32 = 2892,
  OR32mi = 2893,
  OR32mi8 = 2894,
  OR32mi8Locked = 2895,
  OR32mi8_EVEX = 2896,
  OR32mi8_ND = 2897,
  OR32mi8_NF = 2898,
  OR32mi8_NF_ND = 2899,
  OR32mi_EVEX = 2900,
  OR32mi_ND = 2901,
  OR32mi_NF = 2902,
  OR32mi_NF_ND = 2903,
  OR32mr = 2904,
  OR32mr_EVEX = 2905,
  OR32mr_ND = 2906,
  OR32mr_NF = 2907,
  OR32mr_NF_ND = 2908,
  OR32ri = 2909,
  OR32ri8 = 2910,
  OR32ri8_EVEX = 2911,
  OR32ri8_ND = 2912,
  OR32ri8_NF = 2913,
  OR32ri8_NF_ND = 2914,
  OR32ri_EVEX = 2915,
  OR32ri_ND = 2916,
  OR32ri_NF = 2917,
  OR32ri_NF_ND = 2918,
  OR32rm = 2919,
  OR32rm_EVEX = 2920,
  OR32rm_ND = 2921,
  OR32rm_NF = 2922,
  OR32rm_NF_ND = 2923,
  OR32rr = 2924,
  OR32rr_EVEX = 2925,
  OR32rr_EVEX_REV = 2926,
  OR32rr_ND = 2927,
  OR32rr_ND_REV = 2928,
  OR32rr_NF = 2929,
  OR32rr_NF_ND = 2930,
  OR32rr_NF_ND_REV = 2931,
  OR32rr_NF_REV = 2932,
  OR32rr_REV = 2933,
  OR64i32 = 2934,
  OR64mi32 = 2935,
  OR64mi32_EVEX = 2936,
  OR64mi32_ND = 2937,
  OR64mi32_NF = 2938,
  OR64mi32_NF_ND = 2939,
  OR64mi8 = 2940,
  OR64mi8_EVEX = 2941,
  OR64mi8_ND = 2942,
  OR64mi8_NF = 2943,
  OR64mi8_NF_ND = 2944,
  OR64mr = 2945,
  OR64mr_EVEX = 2946,
  OR64mr_ND = 2947,
  OR64mr_NF = 2948,
  OR64mr_NF_ND = 2949,
  OR64ri32 = 2950,
  OR64ri32_EVEX = 2951,
  OR64ri32_ND = 2952,
  OR64ri32_NF = 2953,
  OR64ri32_NF_ND = 2954,
  OR64ri8 = 2955,
  OR64ri8_EVEX = 2956,
  OR64ri8_ND = 2957,
  OR64ri8_NF = 2958,
  OR64ri8_NF_ND = 2959,
  OR64rm = 2960,
  OR64rm_EVEX = 2961,
  OR64rm_ND = 2962,
  OR64rm_NF = 2963,
  OR64rm_NF_ND = 2964,
  OR64rr = 2965,
  OR64rr_EVEX = 2966,
  OR64rr_EVEX_REV = 2967,
  OR64rr_ND = 2968,
  OR64rr_ND_REV = 2969,
  OR64rr_NF = 2970,
  OR64rr_NF_ND = 2971,
  OR64rr_NF_ND_REV = 2972,
  OR64rr_NF_REV = 2973,
  OR64rr_REV = 2974,
  OR8i8 = 2975,
  OR8mi = 2976,
  OR8mi8 = 2977,
  OR8mi_EVEX = 2978,
  OR8mi_ND = 2979,
  OR8mi_NF = 2980,
  OR8mi_NF_ND = 2981,
  OR8mr = 2982,
  OR8mr_EVEX = 2983,
  OR8mr_ND = 2984,
  OR8mr_NF = 2985,
  OR8mr_NF_ND = 2986,
  OR8ri = 2987,
  OR8ri8 = 2988,
  OR8ri_EVEX = 2989,
  OR8ri_ND = 2990,
  OR8ri_NF = 2991,
  OR8ri_NF_ND = 2992,
  OR8rm = 2993,
  OR8rm_EVEX = 2994,
  OR8rm_ND = 2995,
  OR8rm_NF = 2996,
  OR8rm_NF_ND = 2997,
  OR8rr = 2998,
  OR8rr_EVEX = 2999,
  OR8rr_EVEX_REV = 3000,
  OR8rr_ND = 3001,
  OR8rr_ND_REV = 3002,
  OR8rr_NF = 3003,
  OR8rr_NF_ND = 3004,
  OR8rr_NF_ND_REV = 3005,
  OR8rr_NF_REV = 3006,
  OR8rr_REV = 3007,
  ORPDrm = 3008,
  ORPDrr = 3009,
  ORPSrm = 3010,
  ORPSrr = 3011,
  OUT16ir = 3012,
  OUT16rr = 3013,
  OUT32ir = 3014,
  OUT32rr = 3015,
  OUT8ir = 3016,
  OUT8rr = 3017,
  OUTSB = 3018,
  OUTSL = 3019,
  OUTSW = 3020,
  PABSBrm = 3021,
  PABSBrr = 3022,
  PABSDrm = 3023,
  PABSDrr = 3024,
  PABSWrm = 3025,
  PABSWrr = 3026,
  PACKSSDWrm = 3027,
  PACKSSDWrr = 3028,
  PACKSSWBrm = 3029,
  PACKSSWBrr = 3030,
  PACKUSDWrm = 3031,
  PACKUSDWrr = 3032,
  PACKUSWBrm = 3033,
  PACKUSWBrr = 3034,
  PADDBrm = 3035,
  PADDBrr = 3036,
  PADDDrm = 3037,
  PADDDrr = 3038,
  PADDQrm = 3039,
  PADDQrr = 3040,
  PADDSBrm = 3041,
  PADDSBrr = 3042,
  PADDSWrm = 3043,
  PADDSWrr = 3044,
  PADDUSBrm = 3045,
  PADDUSBrr = 3046,
  PADDUSWrm = 3047,
  PADDUSWrr = 3048,
  PADDWrm = 3049,
  PADDWrr = 3050,
  PALIGNRrmi = 3051,
  PALIGNRrri = 3052,
  PANDNrm = 3053,
  PANDNrr = 3054,
  PANDrm = 3055,
  PANDrr = 3056,
  PAUSE = 3057,
  PAVGBrm = 3058,
  PAVGBrr = 3059,
  PAVGUSBrm = 3060,
  PAVGUSBrr = 3061,
  PAVGWrm = 3062,
  PAVGWrr = 3063,
  PBLENDVBrm0 = 3064,
  PBLENDVBrr0 = 3065,
  PBLENDWrmi = 3066,
  PBLENDWrri = 3067,
  PBNDKB = 3068,
  PCLMULQDQrmi = 3069,
  PCLMULQDQrri = 3070,
  PCMPEQBrm = 3071,
  PCMPEQBrr = 3072,
  PCMPEQDrm = 3073,
  PCMPEQDrr = 3074,
  PCMPEQQrm = 3075,
  PCMPEQQrr = 3076,
  PCMPEQWrm = 3077,
  PCMPEQWrr = 3078,
  PCMPESTRIrmi = 3079,
  PCMPESTRIrri = 3080,
  PCMPESTRMrmi = 3081,
  PCMPESTRMrri = 3082,
  PCMPGTBrm = 3083,
  PCMPGTBrr = 3084,
  PCMPGTDrm = 3085,
  PCMPGTDrr = 3086,
  PCMPGTQrm = 3087,
  PCMPGTQrr = 3088,
  PCMPGTWrm = 3089,
  PCMPGTWrr = 3090,
  PCMPISTRIrmi = 3091,
  PCMPISTRIrri = 3092,
  PCMPISTRMrmi = 3093,
  PCMPISTRMrri = 3094,
  PCONFIG = 3095,
  PDEP32rm = 3096,
  PDEP32rm_EVEX = 3097,
  PDEP32rr = 3098,
  PDEP32rr_EVEX = 3099,
  PDEP64rm = 3100,
  PDEP64rm_EVEX = 3101,
  PDEP64rr = 3102,
  PDEP64rr_EVEX = 3103,
  PEXT32rm = 3104,
  PEXT32rm_EVEX = 3105,
  PEXT32rr = 3106,
  PEXT32rr_EVEX = 3107,
  PEXT64rm = 3108,
  PEXT64rm_EVEX = 3109,
  PEXT64rr = 3110,
  PEXT64rr_EVEX = 3111,
  PEXTRBmr = 3112,
  PEXTRBrr = 3113,
  PEXTRDmr = 3114,
  PEXTRDrr = 3115,
  PEXTRQmr = 3116,
  PEXTRQrr = 3117,
  PEXTRWmr = 3118,
  PEXTRWrr = 3119,
  PEXTRWrr_REV = 3120,
  PF2IDrm = 3121,
  PF2IDrr = 3122,
  PF2IWrm = 3123,
  PF2IWrr = 3124,
  PFACCrm = 3125,
  PFACCrr = 3126,
  PFADDrm = 3127,
  PFADDrr = 3128,
  PFCMPEQrm = 3129,
  PFCMPEQrr = 3130,
  PFCMPGErm = 3131,
  PFCMPGErr = 3132,
  PFCMPGTrm = 3133,
  PFCMPGTrr = 3134,
  PFMAXrm = 3135,
  PFMAXrr = 3136,
  PFMINrm = 3137,
  PFMINrr = 3138,
  PFMULrm = 3139,
  PFMULrr = 3140,
  PFNACCrm = 3141,
  PFNACCrr = 3142,
  PFPNACCrm = 3143,
  PFPNACCrr = 3144,
  PFRCPIT1rm = 3145,
  PFRCPIT1rr = 3146,
  PFRCPIT2rm = 3147,
  PFRCPIT2rr = 3148,
  PFRCPrm = 3149,
  PFRCPrr = 3150,
  PFRSQIT1rm = 3151,
  PFRSQIT1rr = 3152,
  PFRSQRTrm = 3153,
  PFRSQRTrr = 3154,
  PFSUBRrm = 3155,
  PFSUBRrr = 3156,
  PFSUBrm = 3157,
  PFSUBrr = 3158,
  PHADDDrm = 3159,
  PHADDDrr = 3160,
  PHADDSWrm = 3161,
  PHADDSWrr = 3162,
  PHADDWrm = 3163,
  PHADDWrr = 3164,
  PHMINPOSUWrm = 3165,
  PHMINPOSUWrr = 3166,
  PHSUBDrm = 3167,
  PHSUBDrr = 3168,
  PHSUBSWrm = 3169,
  PHSUBSWrr = 3170,
  PHSUBWrm = 3171,
  PHSUBWrr = 3172,
  PI2FDrm = 3173,
  PI2FDrr = 3174,
  PI2FWrm = 3175,
  PI2FWrr = 3176,
  PINSRBrm = 3177,
  PINSRBrr = 3178,
  PINSRDrm = 3179,
  PINSRDrr = 3180,
  PINSRQrm = 3181,
  PINSRQrr = 3182,
  PINSRWrm = 3183,
  PINSRWrr = 3184,
  PMADDUBSWrm = 3185,
  PMADDUBSWrr = 3186,
  PMADDWDrm = 3187,
  PMADDWDrr = 3188,
  PMAXSBrm = 3189,
  PMAXSBrr = 3190,
  PMAXSDrm = 3191,
  PMAXSDrr = 3192,
  PMAXSWrm = 3193,
  PMAXSWrr = 3194,
  PMAXUBrm = 3195,
  PMAXUBrr = 3196,
  PMAXUDrm = 3197,
  PMAXUDrr = 3198,
  PMAXUWrm = 3199,
  PMAXUWrr = 3200,
  PMINSBrm = 3201,
  PMINSBrr = 3202,
  PMINSDrm = 3203,
  PMINSDrr = 3204,
  PMINSWrm = 3205,
  PMINSWrr = 3206,
  PMINUBrm = 3207,
  PMINUBrr = 3208,
  PMINUDrm = 3209,
  PMINUDrr = 3210,
  PMINUWrm = 3211,
  PMINUWrr = 3212,
  PMOVMSKBrr = 3213,
  PMOVSXBDrm = 3214,
  PMOVSXBDrr = 3215,
  PMOVSXBQrm = 3216,
  PMOVSXBQrr = 3217,
  PMOVSXBWrm = 3218,
  PMOVSXBWrr = 3219,
  PMOVSXDQrm = 3220,
  PMOVSXDQrr = 3221,
  PMOVSXWDrm = 3222,
  PMOVSXWDrr = 3223,
  PMOVSXWQrm = 3224,
  PMOVSXWQrr = 3225,
  PMOVZXBDrm = 3226,
  PMOVZXBDrr = 3227,
  PMOVZXBQrm = 3228,
  PMOVZXBQrr = 3229,
  PMOVZXBWrm = 3230,
  PMOVZXBWrr = 3231,
  PMOVZXDQrm = 3232,
  PMOVZXDQrr = 3233,
  PMOVZXWDrm = 3234,
  PMOVZXWDrr = 3235,
  PMOVZXWQrm = 3236,
  PMOVZXWQrr = 3237,
  PMULDQrm = 3238,
  PMULDQrr = 3239,
  PMULHRSWrm = 3240,
  PMULHRSWrr = 3241,
  PMULHRWrm = 3242,
  PMULHRWrr = 3243,
  PMULHUWrm = 3244,
  PMULHUWrr = 3245,
  PMULHWrm = 3246,
  PMULHWrr = 3247,
  PMULLDrm = 3248,
  PMULLDrr = 3249,
  PMULLWrm = 3250,
  PMULLWrr = 3251,
  PMULUDQrm = 3252,
  PMULUDQrr = 3253,
  POP16r = 3254,
  POP16rmm = 3255,
  POP16rmr = 3256,
  POP2 = 3257,
  POP2P = 3258,
  POP32r = 3259,
  POP32rmm = 3260,
  POP32rmr = 3261,
  POP64r = 3262,
  POP64rmm = 3263,
  POP64rmr = 3264,
  POPA16 = 3265,
  POPA32 = 3266,
  POPCNT16rm = 3267,
  POPCNT16rm_EVEX = 3268,
  POPCNT16rm_NF = 3269,
  POPCNT16rr = 3270,
  POPCNT16rr_EVEX = 3271,
  POPCNT16rr_NF = 3272,
  POPCNT32rm = 3273,
  POPCNT32rm_EVEX = 3274,
  POPCNT32rm_NF = 3275,
  POPCNT32rr = 3276,
  POPCNT32rr_EVEX = 3277,
  POPCNT32rr_NF = 3278,
  POPCNT64rm = 3279,
  POPCNT64rm_EVEX = 3280,
  POPCNT64rm_NF = 3281,
  POPCNT64rr = 3282,
  POPCNT64rr_EVEX = 3283,
  POPCNT64rr_NF = 3284,
  POPDS16 = 3285,
  POPDS32 = 3286,
  POPES16 = 3287,
  POPES32 = 3288,
  POPF16 = 3289,
  POPF32 = 3290,
  POPF64 = 3291,
  POPFS16 = 3292,
  POPFS32 = 3293,
  POPFS64 = 3294,
  POPGS16 = 3295,
  POPGS32 = 3296,
  POPGS64 = 3297,
  POPP64r = 3298,
  POPSS16 = 3299,
  POPSS32 = 3300,
  PORrm = 3301,
  PORrr = 3302,
  PREFETCH = 3303,
  PREFETCHIT0 = 3304,
  PREFETCHIT1 = 3305,
  PREFETCHNTA = 3306,
  PREFETCHT0 = 3307,
  PREFETCHT1 = 3308,
  PREFETCHT2 = 3309,
  PREFETCHW = 3310,
  PREFETCHWT1 = 3311,
  PROBED_ALLOCA_32 = 3312,
  PROBED_ALLOCA_64 = 3313,
  PSADBWrm = 3314,
  PSADBWrr = 3315,
  PSHUFBrm = 3316,
  PSHUFBrr = 3317,
  PSHUFDmi = 3318,
  PSHUFDri = 3319,
  PSHUFHWmi = 3320,
  PSHUFHWri = 3321,
  PSHUFLWmi = 3322,
  PSHUFLWri = 3323,
  PSIGNBrm = 3324,
  PSIGNBrr = 3325,
  PSIGNDrm = 3326,
  PSIGNDrr = 3327,
  PSIGNWrm = 3328,
  PSIGNWrr = 3329,
  PSLLDQri = 3330,
  PSLLDri = 3331,
  PSLLDrm = 3332,
  PSLLDrr = 3333,
  PSLLQri = 3334,
  PSLLQrm = 3335,
  PSLLQrr = 3336,
  PSLLWri = 3337,
  PSLLWrm = 3338,
  PSLLWrr = 3339,
  PSMASH = 3340,
  PSRADri = 3341,
  PSRADrm = 3342,
  PSRADrr = 3343,
  PSRAWri = 3344,
  PSRAWrm = 3345,
  PSRAWrr = 3346,
  PSRLDQri = 3347,
  PSRLDri = 3348,
  PSRLDrm = 3349,
  PSRLDrr = 3350,
  PSRLQri = 3351,
  PSRLQrm = 3352,
  PSRLQrr = 3353,
  PSRLWri = 3354,
  PSRLWrm = 3355,
  PSRLWrr = 3356,
  PSUBBrm = 3357,
  PSUBBrr = 3358,
  PSUBDrm = 3359,
  PSUBDrr = 3360,
  PSUBQrm = 3361,
  PSUBQrr = 3362,
  PSUBSBrm = 3363,
  PSUBSBrr = 3364,
  PSUBSWrm = 3365,
  PSUBSWrr = 3366,
  PSUBUSBrm = 3367,
  PSUBUSBrr = 3368,
  PSUBUSWrm = 3369,
  PSUBUSWrr = 3370,
  PSUBWrm = 3371,
  PSUBWrr = 3372,
  PSWAPDrm = 3373,
  PSWAPDrr = 3374,
  PTCMMIMFP16PS = 3375,
  PTCMMIMFP16PSV = 3376,
  PTCMMRLFP16PS = 3377,
  PTCMMRLFP16PSV = 3378,
  PTDPBF16PS = 3379,
  PTDPBSSD = 3380,
  PTDPBSUD = 3381,
  PTDPBUSD = 3382,
  PTDPBUUD = 3383,
  PTDPFP16PS = 3384,
  PTESTrm = 3385,
  PTESTrr = 3386,
  PTILELOADD = 3387,
  PTILELOADDT1 = 3388,
  PTILESTORED = 3389,
  PTILEZERO = 3390,
  PTWRITE64m = 3391,
  PTWRITE64r = 3392,
  PTWRITEm = 3393,
  PTWRITEr = 3394,
  PUNPCKHBWrm = 3395,
  PUNPCKHBWrr = 3396,
  PUNPCKHDQrm = 3397,
  PUNPCKHDQrr = 3398,
  PUNPCKHQDQrm = 3399,
  PUNPCKHQDQrr = 3400,
  PUNPCKHWDrm = 3401,
  PUNPCKHWDrr = 3402,
  PUNPCKLBWrm = 3403,
  PUNPCKLBWrr = 3404,
  PUNPCKLDQrm = 3405,
  PUNPCKLDQrr = 3406,
  PUNPCKLQDQrm = 3407,
  PUNPCKLQDQrr = 3408,
  PUNPCKLWDrm = 3409,
  PUNPCKLWDrr = 3410,
  PUSH16i = 3411,
  PUSH16i8 = 3412,
  PUSH16r = 3413,
  PUSH16rmm = 3414,
  PUSH16rmr = 3415,
  PUSH2 = 3416,
  PUSH2P = 3417,
  PUSH32i = 3418,
  PUSH32i8 = 3419,
  PUSH32r = 3420,
  PUSH32rmm = 3421,
  PUSH32rmr = 3422,
  PUSH64i32 = 3423,
  PUSH64i8 = 3424,
  PUSH64r = 3425,
  PUSH64rmm = 3426,
  PUSH64rmr = 3427,
  PUSHA16 = 3428,
  PUSHA32 = 3429,
  PUSHCS16 = 3430,
  PUSHCS32 = 3431,
  PUSHDS16 = 3432,
  PUSHDS32 = 3433,
  PUSHES16 = 3434,
  PUSHES32 = 3435,
  PUSHF16 = 3436,
  PUSHF32 = 3437,
  PUSHF64 = 3438,
  PUSHFS16 = 3439,
  PUSHFS32 = 3440,
  PUSHFS64 = 3441,
  PUSHGS16 = 3442,
  PUSHGS32 = 3443,
  PUSHGS64 = 3444,
  PUSHP64r = 3445,
  PUSHSS16 = 3446,
  PUSHSS32 = 3447,
  PVALIDATE32 = 3448,
  PVALIDATE64 = 3449,
  PXORrm = 3450,
  PXORrr = 3451,
  RCL16m1 = 3452,
  RCL16m1_EVEX = 3453,
  RCL16m1_ND = 3454,
  RCL16mCL = 3455,
  RCL16mCL_EVEX = 3456,
  RCL16mCL_ND = 3457,
  RCL16mi = 3458,
  RCL16mi_EVEX = 3459,
  RCL16mi_ND = 3460,
  RCL16r1 = 3461,
  RCL16r1_EVEX = 3462,
  RCL16r1_ND = 3463,
  RCL16rCL = 3464,
  RCL16rCL_EVEX = 3465,
  RCL16rCL_ND = 3466,
  RCL16ri = 3467,
  RCL16ri_EVEX = 3468,
  RCL16ri_ND = 3469,
  RCL32m1 = 3470,
  RCL32m1_EVEX = 3471,
  RCL32m1_ND = 3472,
  RCL32mCL = 3473,
  RCL32mCL_EVEX = 3474,
  RCL32mCL_ND = 3475,
  RCL32mi = 3476,
  RCL32mi_EVEX = 3477,
  RCL32mi_ND = 3478,
  RCL32r1 = 3479,
  RCL32r1_EVEX = 3480,
  RCL32r1_ND = 3481,
  RCL32rCL = 3482,
  RCL32rCL_EVEX = 3483,
  RCL32rCL_ND = 3484,
  RCL32ri = 3485,
  RCL32ri_EVEX = 3486,
  RCL32ri_ND = 3487,
  RCL64m1 = 3488,
  RCL64m1_EVEX = 3489,
  RCL64m1_ND = 3490,
  RCL64mCL = 3491,
  RCL64mCL_EVEX = 3492,
  RCL64mCL_ND = 3493,
  RCL64mi = 3494,
  RCL64mi_EVEX = 3495,
  RCL64mi_ND = 3496,
  RCL64r1 = 3497,
  RCL64r1_EVEX = 3498,
  RCL64r1_ND = 3499,
  RCL64rCL = 3500,
  RCL64rCL_EVEX = 3501,
  RCL64rCL_ND = 3502,
  RCL64ri = 3503,
  RCL64ri_EVEX = 3504,
  RCL64ri_ND = 3505,
  RCL8m1 = 3506,
  RCL8m1_EVEX = 3507,
  RCL8m1_ND = 3508,
  RCL8mCL = 3509,
  RCL8mCL_EVEX = 3510,
  RCL8mCL_ND = 3511,
  RCL8mi = 3512,
  RCL8mi_EVEX = 3513,
  RCL8mi_ND = 3514,
  RCL8r1 = 3515,
  RCL8r1_EVEX = 3516,
  RCL8r1_ND = 3517,
  RCL8rCL = 3518,
  RCL8rCL_EVEX = 3519,
  RCL8rCL_ND = 3520,
  RCL8ri = 3521,
  RCL8ri_EVEX = 3522,
  RCL8ri_ND = 3523,
  RCPPSm = 3524,
  RCPPSr = 3525,
  RCPSSm = 3526,
  RCPSSm_Int = 3527,
  RCPSSr = 3528,
  RCPSSr_Int = 3529,
  RCR16m1 = 3530,
  RCR16m1_EVEX = 3531,
  RCR16m1_ND = 3532,
  RCR16mCL = 3533,
  RCR16mCL_EVEX = 3534,
  RCR16mCL_ND = 3535,
  RCR16mi = 3536,
  RCR16mi_EVEX = 3537,
  RCR16mi_ND = 3538,
  RCR16r1 = 3539,
  RCR16r1_EVEX = 3540,
  RCR16r1_ND = 3541,
  RCR16rCL = 3542,
  RCR16rCL_EVEX = 3543,
  RCR16rCL_ND = 3544,
  RCR16ri = 3545,
  RCR16ri_EVEX = 3546,
  RCR16ri_ND = 3547,
  RCR32m1 = 3548,
  RCR32m1_EVEX = 3549,
  RCR32m1_ND = 3550,
  RCR32mCL = 3551,
  RCR32mCL_EVEX = 3552,
  RCR32mCL_ND = 3553,
  RCR32mi = 3554,
  RCR32mi_EVEX = 3555,
  RCR32mi_ND = 3556,
  RCR32r1 = 3557,
  RCR32r1_EVEX = 3558,
  RCR32r1_ND = 3559,
  RCR32rCL = 3560,
  RCR32rCL_EVEX = 3561,
  RCR32rCL_ND = 3562,
  RCR32ri = 3563,
  RCR32ri_EVEX = 3564,
  RCR32ri_ND = 3565,
  RCR64m1 = 3566,
  RCR64m1_EVEX = 3567,
  RCR64m1_ND = 3568,
  RCR64mCL = 3569,
  RCR64mCL_EVEX = 3570,
  RCR64mCL_ND = 3571,
  RCR64mi = 3572,
  RCR64mi_EVEX = 3573,
  RCR64mi_ND = 3574,
  RCR64r1 = 3575,
  RCR64r1_EVEX = 3576,
  RCR64r1_ND = 3577,
  RCR64rCL = 3578,
  RCR64rCL_EVEX = 3579,
  RCR64rCL_ND = 3580,
  RCR64ri = 3581,
  RCR64ri_EVEX = 3582,
  RCR64ri_ND = 3583,
  RCR8m1 = 3584,
  RCR8m1_EVEX = 3585,
  RCR8m1_ND = 3586,
  RCR8mCL = 3587,
  RCR8mCL_EVEX = 3588,
  RCR8mCL_ND = 3589,
  RCR8mi = 3590,
  RCR8mi_EVEX = 3591,
  RCR8mi_ND = 3592,
  RCR8r1 = 3593,
  RCR8r1_EVEX = 3594,
  RCR8r1_ND = 3595,
  RCR8rCL = 3596,
  RCR8rCL_EVEX = 3597,
  RCR8rCL_ND = 3598,
  RCR8ri = 3599,
  RCR8ri_EVEX = 3600,
  RCR8ri_ND = 3601,
  RDFSBASE = 3602,
  RDFSBASE64 = 3603,
  RDGSBASE = 3604,
  RDGSBASE64 = 3605,
  RDMSR = 3606,
  RDMSRLIST = 3607,
  RDPID32 = 3608,
  RDPID64 = 3609,
  RDPKRUr = 3610,
  RDPMC = 3611,
  RDPRU = 3612,
  RDRAND16r = 3613,
  RDRAND32r = 3614,
  RDRAND64r = 3615,
  RDSEED16r = 3616,
  RDSEED32r = 3617,
  RDSEED64r = 3618,
  RDSSPD = 3619,
  RDSSPQ = 3620,
  RDTSC = 3621,
  RDTSCP = 3622,
  REPNE_PREFIX = 3623,
  REP_MOVSB_32 = 3624,
  REP_MOVSB_64 = 3625,
  REP_MOVSD_32 = 3626,
  REP_MOVSD_64 = 3627,
  REP_MOVSQ_32 = 3628,
  REP_MOVSQ_64 = 3629,
  REP_MOVSW_32 = 3630,
  REP_MOVSW_64 = 3631,
  REP_PREFIX = 3632,
  REP_STOSB_32 = 3633,
  REP_STOSB_64 = 3634,
  REP_STOSD_32 = 3635,
  REP_STOSD_64 = 3636,
  REP_STOSQ_32 = 3637,
  REP_STOSQ_64 = 3638,
  REP_STOSW_32 = 3639,
  REP_STOSW_64 = 3640,
  RET = 3641,
  RET16 = 3642,
  RET32 = 3643,
  RET64 = 3644,
  RETI16 = 3645,
  RETI32 = 3646,
  RETI64 = 3647,
  REX64_PREFIX = 3648,
  RMPADJUST = 3649,
  RMPQUERY = 3650,
  RMPUPDATE = 3651,
  ROL16m1 = 3652,
  ROL16m1_EVEX = 3653,
  ROL16m1_ND = 3654,
  ROL16m1_NF = 3655,
  ROL16m1_NF_ND = 3656,
  ROL16mCL = 3657,
  ROL16mCL_EVEX = 3658,
  ROL16mCL_ND = 3659,
  ROL16mCL_NF = 3660,
  ROL16mCL_NF_ND = 3661,
  ROL16mi = 3662,
  ROL16mi_EVEX = 3663,
  ROL16mi_ND = 3664,
  ROL16mi_NF = 3665,
  ROL16mi_NF_ND = 3666,
  ROL16r1 = 3667,
  ROL16r1_EVEX = 3668,
  ROL16r1_ND = 3669,
  ROL16r1_NF = 3670,
  ROL16r1_NF_ND = 3671,
  ROL16rCL = 3672,
  ROL16rCL_EVEX = 3673,
  ROL16rCL_ND = 3674,
  ROL16rCL_NF = 3675,
  ROL16rCL_NF_ND = 3676,
  ROL16ri = 3677,
  ROL16ri_EVEX = 3678,
  ROL16ri_ND = 3679,
  ROL16ri_NF = 3680,
  ROL16ri_NF_ND = 3681,
  ROL32m1 = 3682,
  ROL32m1_EVEX = 3683,
  ROL32m1_ND = 3684,
  ROL32m1_NF = 3685,
  ROL32m1_NF_ND = 3686,
  ROL32mCL = 3687,
  ROL32mCL_EVEX = 3688,
  ROL32mCL_ND = 3689,
  ROL32mCL_NF = 3690,
  ROL32mCL_NF_ND = 3691,
  ROL32mi = 3692,
  ROL32mi_EVEX = 3693,
  ROL32mi_ND = 3694,
  ROL32mi_NF = 3695,
  ROL32mi_NF_ND = 3696,
  ROL32r1 = 3697,
  ROL32r1_EVEX = 3698,
  ROL32r1_ND = 3699,
  ROL32r1_NF = 3700,
  ROL32r1_NF_ND = 3701,
  ROL32rCL = 3702,
  ROL32rCL_EVEX = 3703,
  ROL32rCL_ND = 3704,
  ROL32rCL_NF = 3705,
  ROL32rCL_NF_ND = 3706,
  ROL32ri = 3707,
  ROL32ri_EVEX = 3708,
  ROL32ri_ND = 3709,
  ROL32ri_NF = 3710,
  ROL32ri_NF_ND = 3711,
  ROL64m1 = 3712,
  ROL64m1_EVEX = 3713,
  ROL64m1_ND = 3714,
  ROL64m1_NF = 3715,
  ROL64m1_NF_ND = 3716,
  ROL64mCL = 3717,
  ROL64mCL_EVEX = 3718,
  ROL64mCL_ND = 3719,
  ROL64mCL_NF = 3720,
  ROL64mCL_NF_ND = 3721,
  ROL64mi = 3722,
  ROL64mi_EVEX = 3723,
  ROL64mi_ND = 3724,
  ROL64mi_NF = 3725,
  ROL64mi_NF_ND = 3726,
  ROL64r1 = 3727,
  ROL64r1_EVEX = 3728,
  ROL64r1_ND = 3729,
  ROL64r1_NF = 3730,
  ROL64r1_NF_ND = 3731,
  ROL64rCL = 3732,
  ROL64rCL_EVEX = 3733,
  ROL64rCL_ND = 3734,
  ROL64rCL_NF = 3735,
  ROL64rCL_NF_ND = 3736,
  ROL64ri = 3737,
  ROL64ri_EVEX = 3738,
  ROL64ri_ND = 3739,
  ROL64ri_NF = 3740,
  ROL64ri_NF_ND = 3741,
  ROL8m1 = 3742,
  ROL8m1_EVEX = 3743,
  ROL8m1_ND = 3744,
  ROL8m1_NF = 3745,
  ROL8m1_NF_ND = 3746,
  ROL8mCL = 3747,
  ROL8mCL_EVEX = 3748,
  ROL8mCL_ND = 3749,
  ROL8mCL_NF = 3750,
  ROL8mCL_NF_ND = 3751,
  ROL8mi = 3752,
  ROL8mi_EVEX = 3753,
  ROL8mi_ND = 3754,
  ROL8mi_NF = 3755,
  ROL8mi_NF_ND = 3756,
  ROL8r1 = 3757,
  ROL8r1_EVEX = 3758,
  ROL8r1_ND = 3759,
  ROL8r1_NF = 3760,
  ROL8r1_NF_ND = 3761,
  ROL8rCL = 3762,
  ROL8rCL_EVEX = 3763,
  ROL8rCL_ND = 3764,
  ROL8rCL_NF = 3765,
  ROL8rCL_NF_ND = 3766,
  ROL8ri = 3767,
  ROL8ri_EVEX = 3768,
  ROL8ri_ND = 3769,
  ROL8ri_NF = 3770,
  ROL8ri_NF_ND = 3771,
  ROR16m1 = 3772,
  ROR16m1_EVEX = 3773,
  ROR16m1_ND = 3774,
  ROR16m1_NF = 3775,
  ROR16m1_NF_ND = 3776,
  ROR16mCL = 3777,
  ROR16mCL_EVEX = 3778,
  ROR16mCL_ND = 3779,
  ROR16mCL_NF = 3780,
  ROR16mCL_NF_ND = 3781,
  ROR16mi = 3782,
  ROR16mi_EVEX = 3783,
  ROR16mi_ND = 3784,
  ROR16mi_NF = 3785,
  ROR16mi_NF_ND = 3786,
  ROR16r1 = 3787,
  ROR16r1_EVEX = 3788,
  ROR16r1_ND = 3789,
  ROR16r1_NF = 3790,
  ROR16r1_NF_ND = 3791,
  ROR16rCL = 3792,
  ROR16rCL_EVEX = 3793,
  ROR16rCL_ND = 3794,
  ROR16rCL_NF = 3795,
  ROR16rCL_NF_ND = 3796,
  ROR16ri = 3797,
  ROR16ri_EVEX = 3798,
  ROR16ri_ND = 3799,
  ROR16ri_NF = 3800,
  ROR16ri_NF_ND = 3801,
  ROR32m1 = 3802,
  ROR32m1_EVEX = 3803,
  ROR32m1_ND = 3804,
  ROR32m1_NF = 3805,
  ROR32m1_NF_ND = 3806,
  ROR32mCL = 3807,
  ROR32mCL_EVEX = 3808,
  ROR32mCL_ND = 3809,
  ROR32mCL_NF = 3810,
  ROR32mCL_NF_ND = 3811,
  ROR32mi = 3812,
  ROR32mi_EVEX = 3813,
  ROR32mi_ND = 3814,
  ROR32mi_NF = 3815,
  ROR32mi_NF_ND = 3816,
  ROR32r1 = 3817,
  ROR32r1_EVEX = 3818,
  ROR32r1_ND = 3819,
  ROR32r1_NF = 3820,
  ROR32r1_NF_ND = 3821,
  ROR32rCL = 3822,
  ROR32rCL_EVEX = 3823,
  ROR32rCL_ND = 3824,
  ROR32rCL_NF = 3825,
  ROR32rCL_NF_ND = 3826,
  ROR32ri = 3827,
  ROR32ri_EVEX = 3828,
  ROR32ri_ND = 3829,
  ROR32ri_NF = 3830,
  ROR32ri_NF_ND = 3831,
  ROR64m1 = 3832,
  ROR64m1_EVEX = 3833,
  ROR64m1_ND = 3834,
  ROR64m1_NF = 3835,
  ROR64m1_NF_ND = 3836,
  ROR64mCL = 3837,
  ROR64mCL_EVEX = 3838,
  ROR64mCL_ND = 3839,
  ROR64mCL_NF = 3840,
  ROR64mCL_NF_ND = 3841,
  ROR64mi = 3842,
  ROR64mi_EVEX = 3843,
  ROR64mi_ND = 3844,
  ROR64mi_NF = 3845,
  ROR64mi_NF_ND = 3846,
  ROR64r1 = 3847,
  ROR64r1_EVEX = 3848,
  ROR64r1_ND = 3849,
  ROR64r1_NF = 3850,
  ROR64r1_NF_ND = 3851,
  ROR64rCL = 3852,
  ROR64rCL_EVEX = 3853,
  ROR64rCL_ND = 3854,
  ROR64rCL_NF = 3855,
  ROR64rCL_NF_ND = 3856,
  ROR64ri = 3857,
  ROR64ri_EVEX = 3858,
  ROR64ri_ND = 3859,
  ROR64ri_NF = 3860,
  ROR64ri_NF_ND = 3861,
  ROR8m1 = 3862,
  ROR8m1_EVEX = 3863,
  ROR8m1_ND = 3864,
  ROR8m1_NF = 3865,
  ROR8m1_NF_ND = 3866,
  ROR8mCL = 3867,
  ROR8mCL_EVEX = 3868,
  ROR8mCL_ND = 3869,
  ROR8mCL_NF = 3870,
  ROR8mCL_NF_ND = 3871,
  ROR8mi = 3872,
  ROR8mi_EVEX = 3873,
  ROR8mi_ND = 3874,
  ROR8mi_NF = 3875,
  ROR8mi_NF_ND = 3876,
  ROR8r1 = 3877,
  ROR8r1_EVEX = 3878,
  ROR8r1_ND = 3879,
  ROR8r1_NF = 3880,
  ROR8r1_NF_ND = 3881,
  ROR8rCL = 3882,
  ROR8rCL_EVEX = 3883,
  ROR8rCL_ND = 3884,
  ROR8rCL_NF = 3885,
  ROR8rCL_NF_ND = 3886,
  ROR8ri = 3887,
  ROR8ri_EVEX = 3888,
  ROR8ri_ND = 3889,
  ROR8ri_NF = 3890,
  ROR8ri_NF_ND = 3891,
  RORX32mi = 3892,
  RORX32mi_EVEX = 3893,
  RORX32ri = 3894,
  RORX32ri_EVEX = 3895,
  RORX64mi = 3896,
  RORX64mi_EVEX = 3897,
  RORX64ri = 3898,
  RORX64ri_EVEX = 3899,
  ROUNDPDmi = 3900,
  ROUNDPDri = 3901,
  ROUNDPSmi = 3902,
  ROUNDPSri = 3903,
  ROUNDSDmi = 3904,
  ROUNDSDmi_Int = 3905,
  ROUNDSDri = 3906,
  ROUNDSDri_Int = 3907,
  ROUNDSSmi = 3908,
  ROUNDSSmi_Int = 3909,
  ROUNDSSri = 3910,
  ROUNDSSri_Int = 3911,
  RSM = 3912,
  RSQRTPSm = 3913,
  RSQRTPSr = 3914,
  RSQRTSSm = 3915,
  RSQRTSSm_Int = 3916,
  RSQRTSSr = 3917,
  RSQRTSSr_Int = 3918,
  RSTORSSP = 3919,
  SAHF = 3920,
  SALC = 3921,
  SAR16m1 = 3922,
  SAR16m1_EVEX = 3923,
  SAR16m1_ND = 3924,
  SAR16m1_NF = 3925,
  SAR16m1_NF_ND = 3926,
  SAR16mCL = 3927,
  SAR16mCL_EVEX = 3928,
  SAR16mCL_ND = 3929,
  SAR16mCL_NF = 3930,
  SAR16mCL_NF_ND = 3931,
  SAR16mi = 3932,
  SAR16mi_EVEX = 3933,
  SAR16mi_ND = 3934,
  SAR16mi_NF = 3935,
  SAR16mi_NF_ND = 3936,
  SAR16r1 = 3937,
  SAR16r1_EVEX = 3938,
  SAR16r1_ND = 3939,
  SAR16r1_NF = 3940,
  SAR16r1_NF_ND = 3941,
  SAR16rCL = 3942,
  SAR16rCL_EVEX = 3943,
  SAR16rCL_ND = 3944,
  SAR16rCL_NF = 3945,
  SAR16rCL_NF_ND = 3946,
  SAR16ri = 3947,
  SAR16ri_EVEX = 3948,
  SAR16ri_ND = 3949,
  SAR16ri_NF = 3950,
  SAR16ri_NF_ND = 3951,
  SAR32m1 = 3952,
  SAR32m1_EVEX = 3953,
  SAR32m1_ND = 3954,
  SAR32m1_NF = 3955,
  SAR32m1_NF_ND = 3956,
  SAR32mCL = 3957,
  SAR32mCL_EVEX = 3958,
  SAR32mCL_ND = 3959,
  SAR32mCL_NF = 3960,
  SAR32mCL_NF_ND = 3961,
  SAR32mi = 3962,
  SAR32mi_EVEX = 3963,
  SAR32mi_ND = 3964,
  SAR32mi_NF = 3965,
  SAR32mi_NF_ND = 3966,
  SAR32r1 = 3967,
  SAR32r1_EVEX = 3968,
  SAR32r1_ND = 3969,
  SAR32r1_NF = 3970,
  SAR32r1_NF_ND = 3971,
  SAR32rCL = 3972,
  SAR32rCL_EVEX = 3973,
  SAR32rCL_ND = 3974,
  SAR32rCL_NF = 3975,
  SAR32rCL_NF_ND = 3976,
  SAR32ri = 3977,
  SAR32ri_EVEX = 3978,
  SAR32ri_ND = 3979,
  SAR32ri_NF = 3980,
  SAR32ri_NF_ND = 3981,
  SAR64m1 = 3982,
  SAR64m1_EVEX = 3983,
  SAR64m1_ND = 3984,
  SAR64m1_NF = 3985,
  SAR64m1_NF_ND = 3986,
  SAR64mCL = 3987,
  SAR64mCL_EVEX = 3988,
  SAR64mCL_ND = 3989,
  SAR64mCL_NF = 3990,
  SAR64mCL_NF_ND = 3991,
  SAR64mi = 3992,
  SAR64mi_EVEX = 3993,
  SAR64mi_ND = 3994,
  SAR64mi_NF = 3995,
  SAR64mi_NF_ND = 3996,
  SAR64r1 = 3997,
  SAR64r1_EVEX = 3998,
  SAR64r1_ND = 3999,
  SAR64r1_NF = 4000,
  SAR64r1_NF_ND = 4001,
  SAR64rCL = 4002,
  SAR64rCL_EVEX = 4003,
  SAR64rCL_ND = 4004,
  SAR64rCL_NF = 4005,
  SAR64rCL_NF_ND = 4006,
  SAR64ri = 4007,
  SAR64ri_EVEX = 4008,
  SAR64ri_ND = 4009,
  SAR64ri_NF = 4010,
  SAR64ri_NF_ND = 4011,
  SAR8m1 = 4012,
  SAR8m1_EVEX = 4013,
  SAR8m1_ND = 4014,
  SAR8m1_NF = 4015,
  SAR8m1_NF_ND = 4016,
  SAR8mCL = 4017,
  SAR8mCL_EVEX = 4018,
  SAR8mCL_ND = 4019,
  SAR8mCL_NF = 4020,
  SAR8mCL_NF_ND = 4021,
  SAR8mi = 4022,
  SAR8mi_EVEX = 4023,
  SAR8mi_ND = 4024,
  SAR8mi_NF = 4025,
  SAR8mi_NF_ND = 4026,
  SAR8r1 = 4027,
  SAR8r1_EVEX = 4028,
  SAR8r1_ND = 4029,
  SAR8r1_NF = 4030,
  SAR8r1_NF_ND = 4031,
  SAR8rCL = 4032,
  SAR8rCL_EVEX = 4033,
  SAR8rCL_ND = 4034,
  SAR8rCL_NF = 4035,
  SAR8rCL_NF_ND = 4036,
  SAR8ri = 4037,
  SAR8ri_EVEX = 4038,
  SAR8ri_ND = 4039,
  SAR8ri_NF = 4040,
  SAR8ri_NF_ND = 4041,
  SARX32rm = 4042,
  SARX32rm_EVEX = 4043,
  SARX32rr = 4044,
  SARX32rr_EVEX = 4045,
  SARX64rm = 4046,
  SARX64rm_EVEX = 4047,
  SARX64rr = 4048,
  SARX64rr_EVEX = 4049,
  SAVEPREVSSP = 4050,
  SBB16i16 = 4051,
  SBB16mi = 4052,
  SBB16mi8 = 4053,
  SBB16mi8_EVEX = 4054,
  SBB16mi8_ND = 4055,
  SBB16mi_EVEX = 4056,
  SBB16mi_ND = 4057,
  SBB16mr = 4058,
  SBB16mr_EVEX = 4059,
  SBB16mr_ND = 4060,
  SBB16ri = 4061,
  SBB16ri8 = 4062,
  SBB16ri8_EVEX = 4063,
  SBB16ri8_ND = 4064,
  SBB16ri_EVEX = 4065,
  SBB16ri_ND = 4066,
  SBB16rm = 4067,
  SBB16rm_EVEX = 4068,
  SBB16rm_ND = 4069,
  SBB16rr = 4070,
  SBB16rr_EVEX = 4071,
  SBB16rr_EVEX_REV = 4072,
  SBB16rr_ND = 4073,
  SBB16rr_ND_REV = 4074,
  SBB16rr_REV = 4075,
  SBB32i32 = 4076,
  SBB32mi = 4077,
  SBB32mi8 = 4078,
  SBB32mi8_EVEX = 4079,
  SBB32mi8_ND = 4080,
  SBB32mi_EVEX = 4081,
  SBB32mi_ND = 4082,
  SBB32mr = 4083,
  SBB32mr_EVEX = 4084,
  SBB32mr_ND = 4085,
  SBB32ri = 4086,
  SBB32ri8 = 4087,
  SBB32ri8_EVEX = 4088,
  SBB32ri8_ND = 4089,
  SBB32ri_EVEX = 4090,
  SBB32ri_ND = 4091,
  SBB32rm = 4092,
  SBB32rm_EVEX = 4093,
  SBB32rm_ND = 4094,
  SBB32rr = 4095,
  SBB32rr_EVEX = 4096,
  SBB32rr_EVEX_REV = 4097,
  SBB32rr_ND = 4098,
  SBB32rr_ND_REV = 4099,
  SBB32rr_REV = 4100,
  SBB64i32 = 4101,
  SBB64mi32 = 4102,
  SBB64mi32_EVEX = 4103,
  SBB64mi32_ND = 4104,
  SBB64mi8 = 4105,
  SBB64mi8_EVEX = 4106,
  SBB64mi8_ND = 4107,
  SBB64mr = 4108,
  SBB64mr_EVEX = 4109,
  SBB64mr_ND = 4110,
  SBB64ri32 = 4111,
  SBB64ri32_EVEX = 4112,
  SBB64ri32_ND = 4113,
  SBB64ri8 = 4114,
  SBB64ri8_EVEX = 4115,
  SBB64ri8_ND = 4116,
  SBB64rm = 4117,
  SBB64rm_EVEX = 4118,
  SBB64rm_ND = 4119,
  SBB64rr = 4120,
  SBB64rr_EVEX = 4121,
  SBB64rr_EVEX_REV = 4122,
  SBB64rr_ND = 4123,
  SBB64rr_ND_REV = 4124,
  SBB64rr_REV = 4125,
  SBB8i8 = 4126,
  SBB8mi = 4127,
  SBB8mi8 = 4128,
  SBB8mi_EVEX = 4129,
  SBB8mi_ND = 4130,
  SBB8mr = 4131,
  SBB8mr_EVEX = 4132,
  SBB8mr_ND = 4133,
  SBB8ri = 4134,
  SBB8ri8 = 4135,
  SBB8ri_EVEX = 4136,
  SBB8ri_ND = 4137,
  SBB8rm = 4138,
  SBB8rm_EVEX = 4139,
  SBB8rm_ND = 4140,
  SBB8rr = 4141,
  SBB8rr_EVEX = 4142,
  SBB8rr_EVEX_REV = 4143,
  SBB8rr_ND = 4144,
  SBB8rr_ND_REV = 4145,
  SBB8rr_REV = 4146,
  SCASB = 4147,
  SCASL = 4148,
  SCASQ = 4149,
  SCASW = 4150,
  SEAMCALL = 4151,
  SEAMOPS = 4152,
  SEAMRET = 4153,
  SEG_ALLOCA_32 = 4154,
  SEG_ALLOCA_64 = 4155,
  SENDUIPI = 4156,
  SERIALIZE = 4157,
  SETCCm = 4158,
  SETCCm_EVEX = 4159,
  SETCCr = 4160,
  SETCCr_EVEX = 4161,
  SETSSBSY = 4162,
  SETZUCCm = 4163,
  SETZUCCr = 4164,
  SFENCE = 4165,
  SGDT16m = 4166,
  SGDT32m = 4167,
  SGDT64m = 4168,
  SHA1MSG1rm = 4169,
  SHA1MSG1rr = 4170,
  SHA1MSG2rm = 4171,
  SHA1MSG2rr = 4172,
  SHA1NEXTErm = 4173,
  SHA1NEXTErr = 4174,
  SHA1RNDS4rmi = 4175,
  SHA1RNDS4rri = 4176,
  SHA256MSG1rm = 4177,
  SHA256MSG1rr = 4178,
  SHA256MSG2rm = 4179,
  SHA256MSG2rr = 4180,
  SHA256RNDS2rm = 4181,
  SHA256RNDS2rr = 4182,
  SHL16m1 = 4183,
  SHL16m1_EVEX = 4184,
  SHL16m1_ND = 4185,
  SHL16m1_NF = 4186,
  SHL16m1_NF_ND = 4187,
  SHL16mCL = 4188,
  SHL16mCL_EVEX = 4189,
  SHL16mCL_ND = 4190,
  SHL16mCL_NF = 4191,
  SHL16mCL_NF_ND = 4192,
  SHL16mi = 4193,
  SHL16mi_EVEX = 4194,
  SHL16mi_ND = 4195,
  SHL16mi_NF = 4196,
  SHL16mi_NF_ND = 4197,
  SHL16r1 = 4198,
  SHL16r1_EVEX = 4199,
  SHL16r1_ND = 4200,
  SHL16r1_NF = 4201,
  SHL16r1_NF_ND = 4202,
  SHL16rCL = 4203,
  SHL16rCL_EVEX = 4204,
  SHL16rCL_ND = 4205,
  SHL16rCL_NF = 4206,
  SHL16rCL_NF_ND = 4207,
  SHL16ri = 4208,
  SHL16ri_EVEX = 4209,
  SHL16ri_ND = 4210,
  SHL16ri_NF = 4211,
  SHL16ri_NF_ND = 4212,
  SHL32m1 = 4213,
  SHL32m1_EVEX = 4214,
  SHL32m1_ND = 4215,
  SHL32m1_NF = 4216,
  SHL32m1_NF_ND = 4217,
  SHL32mCL = 4218,
  SHL32mCL_EVEX = 4219,
  SHL32mCL_ND = 4220,
  SHL32mCL_NF = 4221,
  SHL32mCL_NF_ND = 4222,
  SHL32mi = 4223,
  SHL32mi_EVEX = 4224,
  SHL32mi_ND = 4225,
  SHL32mi_NF = 4226,
  SHL32mi_NF_ND = 4227,
  SHL32r1 = 4228,
  SHL32r1_EVEX = 4229,
  SHL32r1_ND = 4230,
  SHL32r1_NF = 4231,
  SHL32r1_NF_ND = 4232,
  SHL32rCL = 4233,
  SHL32rCL_EVEX = 4234,
  SHL32rCL_ND = 4235,
  SHL32rCL_NF = 4236,
  SHL32rCL_NF_ND = 4237,
  SHL32ri = 4238,
  SHL32ri_EVEX = 4239,
  SHL32ri_ND = 4240,
  SHL32ri_NF = 4241,
  SHL32ri_NF_ND = 4242,
  SHL64m1 = 4243,
  SHL64m1_EVEX = 4244,
  SHL64m1_ND = 4245,
  SHL64m1_NF = 4246,
  SHL64m1_NF_ND = 4247,
  SHL64mCL = 4248,
  SHL64mCL_EVEX = 4249,
  SHL64mCL_ND = 4250,
  SHL64mCL_NF = 4251,
  SHL64mCL_NF_ND = 4252,
  SHL64mi = 4253,
  SHL64mi_EVEX = 4254,
  SHL64mi_ND = 4255,
  SHL64mi_NF = 4256,
  SHL64mi_NF_ND = 4257,
  SHL64r1 = 4258,
  SHL64r1_EVEX = 4259,
  SHL64r1_ND = 4260,
  SHL64r1_NF = 4261,
  SHL64r1_NF_ND = 4262,
  SHL64rCL = 4263,
  SHL64rCL_EVEX = 4264,
  SHL64rCL_ND = 4265,
  SHL64rCL_NF = 4266,
  SHL64rCL_NF_ND = 4267,
  SHL64ri = 4268,
  SHL64ri_EVEX = 4269,
  SHL64ri_ND = 4270,
  SHL64ri_NF = 4271,
  SHL64ri_NF_ND = 4272,
  SHL8m1 = 4273,
  SHL8m1_EVEX = 4274,
  SHL8m1_ND = 4275,
  SHL8m1_NF = 4276,
  SHL8m1_NF_ND = 4277,
  SHL8mCL = 4278,
  SHL8mCL_EVEX = 4279,
  SHL8mCL_ND = 4280,
  SHL8mCL_NF = 4281,
  SHL8mCL_NF_ND = 4282,
  SHL8mi = 4283,
  SHL8mi_EVEX = 4284,
  SHL8mi_ND = 4285,
  SHL8mi_NF = 4286,
  SHL8mi_NF_ND = 4287,
  SHL8r1 = 4288,
  SHL8r1_EVEX = 4289,
  SHL8r1_ND = 4290,
  SHL8r1_NF = 4291,
  SHL8r1_NF_ND = 4292,
  SHL8rCL = 4293,
  SHL8rCL_EVEX = 4294,
  SHL8rCL_ND = 4295,
  SHL8rCL_NF = 4296,
  SHL8rCL_NF_ND = 4297,
  SHL8ri = 4298,
  SHL8ri_EVEX = 4299,
  SHL8ri_ND = 4300,
  SHL8ri_NF = 4301,
  SHL8ri_NF_ND = 4302,
  SHLD16mrCL = 4303,
  SHLD16mrCL_EVEX = 4304,
  SHLD16mrCL_ND = 4305,
  SHLD16mrCL_NF = 4306,
  SHLD16mrCL_NF_ND = 4307,
  SHLD16mri8 = 4308,
  SHLD16mri8_EVEX = 4309,
  SHLD16mri8_ND = 4310,
  SHLD16mri8_NF = 4311,
  SHLD16mri8_NF_ND = 4312,
  SHLD16rrCL = 4313,
  SHLD16rrCL_EVEX = 4314,
  SHLD16rrCL_ND = 4315,
  SHLD16rrCL_NF = 4316,
  SHLD16rrCL_NF_ND = 4317,
  SHLD16rri8 = 4318,
  SHLD16rri8_EVEX = 4319,
  SHLD16rri8_ND = 4320,
  SHLD16rri8_NF = 4321,
  SHLD16rri8_NF_ND = 4322,
  SHLD32mrCL = 4323,
  SHLD32mrCL_EVEX = 4324,
  SHLD32mrCL_ND = 4325,
  SHLD32mrCL_NF = 4326,
  SHLD32mrCL_NF_ND = 4327,
  SHLD32mri8 = 4328,
  SHLD32mri8_EVEX = 4329,
  SHLD32mri8_ND = 4330,
  SHLD32mri8_NF = 4331,
  SHLD32mri8_NF_ND = 4332,
  SHLD32rrCL = 4333,
  SHLD32rrCL_EVEX = 4334,
  SHLD32rrCL_ND = 4335,
  SHLD32rrCL_NF = 4336,
  SHLD32rrCL_NF_ND = 4337,
  SHLD32rri8 = 4338,
  SHLD32rri8_EVEX = 4339,
  SHLD32rri8_ND = 4340,
  SHLD32rri8_NF = 4341,
  SHLD32rri8_NF_ND = 4342,
  SHLD64mrCL = 4343,
  SHLD64mrCL_EVEX = 4344,
  SHLD64mrCL_ND = 4345,
  SHLD64mrCL_NF = 4346,
  SHLD64mrCL_NF_ND = 4347,
  SHLD64mri8 = 4348,
  SHLD64mri8_EVEX = 4349,
  SHLD64mri8_ND = 4350,
  SHLD64mri8_NF = 4351,
  SHLD64mri8_NF_ND = 4352,
  SHLD64rrCL = 4353,
  SHLD64rrCL_EVEX = 4354,
  SHLD64rrCL_ND = 4355,
  SHLD64rrCL_NF = 4356,
  SHLD64rrCL_NF_ND = 4357,
  SHLD64rri8 = 4358,
  SHLD64rri8_EVEX = 4359,
  SHLD64rri8_ND = 4360,
  SHLD64rri8_NF = 4361,
  SHLD64rri8_NF_ND = 4362,
  SHLX32rm = 4363,
  SHLX32rm_EVEX = 4364,
  SHLX32rr = 4365,
  SHLX32rr_EVEX = 4366,
  SHLX64rm = 4367,
  SHLX64rm_EVEX = 4368,
  SHLX64rr = 4369,
  SHLX64rr_EVEX = 4370,
  SHR16m1 = 4371,
  SHR16m1_EVEX = 4372,
  SHR16m1_ND = 4373,
  SHR16m1_NF = 4374,
  SHR16m1_NF_ND = 4375,
  SHR16mCL = 4376,
  SHR16mCL_EVEX = 4377,
  SHR16mCL_ND = 4378,
  SHR16mCL_NF = 4379,
  SHR16mCL_NF_ND = 4380,
  SHR16mi = 4381,
  SHR16mi_EVEX = 4382,
  SHR16mi_ND = 4383,
  SHR16mi_NF = 4384,
  SHR16mi_NF_ND = 4385,
  SHR16r1 = 4386,
  SHR16r1_EVEX = 4387,
  SHR16r1_ND = 4388,
  SHR16r1_NF = 4389,
  SHR16r1_NF_ND = 4390,
  SHR16rCL = 4391,
  SHR16rCL_EVEX = 4392,
  SHR16rCL_ND = 4393,
  SHR16rCL_NF = 4394,
  SHR16rCL_NF_ND = 4395,
  SHR16ri = 4396,
  SHR16ri_EVEX = 4397,
  SHR16ri_ND = 4398,
  SHR16ri_NF = 4399,
  SHR16ri_NF_ND = 4400,
  SHR32m1 = 4401,
  SHR32m1_EVEX = 4402,
  SHR32m1_ND = 4403,
  SHR32m1_NF = 4404,
  SHR32m1_NF_ND = 4405,
  SHR32mCL = 4406,
  SHR32mCL_EVEX = 4407,
  SHR32mCL_ND = 4408,
  SHR32mCL_NF = 4409,
  SHR32mCL_NF_ND = 4410,
  SHR32mi = 4411,
  SHR32mi_EVEX = 4412,
  SHR32mi_ND = 4413,
  SHR32mi_NF = 4414,
  SHR32mi_NF_ND = 4415,
  SHR32r1 = 4416,
  SHR32r1_EVEX = 4417,
  SHR32r1_ND = 4418,
  SHR32r1_NF = 4419,
  SHR32r1_NF_ND = 4420,
  SHR32rCL = 4421,
  SHR32rCL_EVEX = 4422,
  SHR32rCL_ND = 4423,
  SHR32rCL_NF = 4424,
  SHR32rCL_NF_ND = 4425,
  SHR32ri = 4426,
  SHR32ri_EVEX = 4427,
  SHR32ri_ND = 4428,
  SHR32ri_NF = 4429,
  SHR32ri_NF_ND = 4430,
  SHR64m1 = 4431,
  SHR64m1_EVEX = 4432,
  SHR64m1_ND = 4433,
  SHR64m1_NF = 4434,
  SHR64m1_NF_ND = 4435,
  SHR64mCL = 4436,
  SHR64mCL_EVEX = 4437,
  SHR64mCL_ND = 4438,
  SHR64mCL_NF = 4439,
  SHR64mCL_NF_ND = 4440,
  SHR64mi = 4441,
  SHR64mi_EVEX = 4442,
  SHR64mi_ND = 4443,
  SHR64mi_NF = 4444,
  SHR64mi_NF_ND = 4445,
  SHR64r1 = 4446,
  SHR64r1_EVEX = 4447,
  SHR64r1_ND = 4448,
  SHR64r1_NF = 4449,
  SHR64r1_NF_ND = 4450,
  SHR64rCL = 4451,
  SHR64rCL_EVEX = 4452,
  SHR64rCL_ND = 4453,
  SHR64rCL_NF = 4454,
  SHR64rCL_NF_ND = 4455,
  SHR64ri = 4456,
  SHR64ri_EVEX = 4457,
  SHR64ri_ND = 4458,
  SHR64ri_NF = 4459,
  SHR64ri_NF_ND = 4460,
  SHR8m1 = 4461,
  SHR8m1_EVEX = 4462,
  SHR8m1_ND = 4463,
  SHR8m1_NF = 4464,
  SHR8m1_NF_ND = 4465,
  SHR8mCL = 4466,
  SHR8mCL_EVEX = 4467,
  SHR8mCL_ND = 4468,
  SHR8mCL_NF = 4469,
  SHR8mCL_NF_ND = 4470,
  SHR8mi = 4471,
  SHR8mi_EVEX = 4472,
  SHR8mi_ND = 4473,
  SHR8mi_NF = 4474,
  SHR8mi_NF_ND = 4475,
  SHR8r1 = 4476,
  SHR8r1_EVEX = 4477,
  SHR8r1_ND = 4478,
  SHR8r1_NF = 4479,
  SHR8r1_NF_ND = 4480,
  SHR8rCL = 4481,
  SHR8rCL_EVEX = 4482,
  SHR8rCL_ND = 4483,
  SHR8rCL_NF = 4484,
  SHR8rCL_NF_ND = 4485,
  SHR8ri = 4486,
  SHR8ri_EVEX = 4487,
  SHR8ri_ND = 4488,
  SHR8ri_NF = 4489,
  SHR8ri_NF_ND = 4490,
  SHRD16mrCL = 4491,
  SHRD16mrCL_EVEX = 4492,
  SHRD16mrCL_ND = 4493,
  SHRD16mrCL_NF = 4494,
  SHRD16mrCL_NF_ND = 4495,
  SHRD16mri8 = 4496,
  SHRD16mri8_EVEX = 4497,
  SHRD16mri8_ND = 4498,
  SHRD16mri8_NF = 4499,
  SHRD16mri8_NF_ND = 4500,
  SHRD16rrCL = 4501,
  SHRD16rrCL_EVEX = 4502,
  SHRD16rrCL_ND = 4503,
  SHRD16rrCL_NF = 4504,
  SHRD16rrCL_NF_ND = 4505,
  SHRD16rri8 = 4506,
  SHRD16rri8_EVEX = 4507,
  SHRD16rri8_ND = 4508,
  SHRD16rri8_NF = 4509,
  SHRD16rri8_NF_ND = 4510,
  SHRD32mrCL = 4511,
  SHRD32mrCL_EVEX = 4512,
  SHRD32mrCL_ND = 4513,
  SHRD32mrCL_NF = 4514,
  SHRD32mrCL_NF_ND = 4515,
  SHRD32mri8 = 4516,
  SHRD32mri8_EVEX = 4517,
  SHRD32mri8_ND = 4518,
  SHRD32mri8_NF = 4519,
  SHRD32mri8_NF_ND = 4520,
  SHRD32rrCL = 4521,
  SHRD32rrCL_EVEX = 4522,
  SHRD32rrCL_ND = 4523,
  SHRD32rrCL_NF = 4524,
  SHRD32rrCL_NF_ND = 4525,
  SHRD32rri8 = 4526,
  SHRD32rri8_EVEX = 4527,
  SHRD32rri8_ND = 4528,
  SHRD32rri8_NF = 4529,
  SHRD32rri8_NF_ND = 4530,
  SHRD64mrCL = 4531,
  SHRD64mrCL_EVEX = 4532,
  SHRD64mrCL_ND = 4533,
  SHRD64mrCL_NF = 4534,
  SHRD64mrCL_NF_ND = 4535,
  SHRD64mri8 = 4536,
  SHRD64mri8_EVEX = 4537,
  SHRD64mri8_ND = 4538,
  SHRD64mri8_NF = 4539,
  SHRD64mri8_NF_ND = 4540,
  SHRD64rrCL = 4541,
  SHRD64rrCL_EVEX = 4542,
  SHRD64rrCL_ND = 4543,
  SHRD64rrCL_NF = 4544,
  SHRD64rrCL_NF_ND = 4545,
  SHRD64rri8 = 4546,
  SHRD64rri8_EVEX = 4547,
  SHRD64rri8_ND = 4548,
  SHRD64rri8_NF = 4549,
  SHRD64rri8_NF_ND = 4550,
  SHRX32rm = 4551,
  SHRX32rm_EVEX = 4552,
  SHRX32rr = 4553,
  SHRX32rr_EVEX = 4554,
  SHRX64rm = 4555,
  SHRX64rm_EVEX = 4556,
  SHRX64rr = 4557,
  SHRX64rr_EVEX = 4558,
  SHUFPDrmi = 4559,
  SHUFPDrri = 4560,
  SHUFPSrmi = 4561,
  SHUFPSrri = 4562,
  SIDT16m = 4563,
  SIDT32m = 4564,
  SIDT64m = 4565,
  SKINIT = 4566,
  SLDT16m = 4567,
  SLDT16r = 4568,
  SLDT32r = 4569,
  SLDT64r = 4570,
  SLWPCB = 4571,
  SLWPCB64 = 4572,
  SMSW16m = 4573,
  SMSW16r = 4574,
  SMSW32r = 4575,
  SMSW64r = 4576,
  SQRTPDm = 4577,
  SQRTPDr = 4578,
  SQRTPSm = 4579,
  SQRTPSr = 4580,
  SQRTSDm = 4581,
  SQRTSDm_Int = 4582,
  SQRTSDr = 4583,
  SQRTSDr_Int = 4584,
  SQRTSSm = 4585,
  SQRTSSm_Int = 4586,
  SQRTSSr = 4587,
  SQRTSSr_Int = 4588,
  SQRT_F = 4589,
  SQRT_Fp32 = 4590,
  SQRT_Fp64 = 4591,
  SQRT_Fp80 = 4592,
  SS_PREFIX = 4593,
  STAC = 4594,
  STACKALLOC_W_PROBING = 4595,
  STC = 4596,
  STD = 4597,
  STGI = 4598,
  STI = 4599,
  STMXCSR = 4600,
  STOSB = 4601,
  STOSL = 4602,
  STOSQ = 4603,
  STOSW = 4604,
  STR16r = 4605,
  STR32r = 4606,
  STR64r = 4607,
  STRm = 4608,
  STTILECFG = 4609,
  STTILECFG_EVEX = 4610,
  STUI = 4611,
  ST_F32m = 4612,
  ST_F64m = 4613,
  ST_FP32m = 4614,
  ST_FP64m = 4615,
  ST_FP80m = 4616,
  ST_FPrr = 4617,
  ST_Fp32m = 4618,
  ST_Fp64m = 4619,
  ST_Fp64m32 = 4620,
  ST_Fp80m32 = 4621,
  ST_Fp80m64 = 4622,
  ST_FpP32m = 4623,
  ST_FpP64m = 4624,
  ST_FpP64m32 = 4625,
  ST_FpP80m = 4626,
  ST_FpP80m32 = 4627,
  ST_FpP80m64 = 4628,
  ST_Frr = 4629,
  SUB16i16 = 4630,
  SUB16mi = 4631,
  SUB16mi8 = 4632,
  SUB16mi8_EVEX = 4633,
  SUB16mi8_ND = 4634,
  SUB16mi8_NF = 4635,
  SUB16mi8_NF_ND = 4636,
  SUB16mi_EVEX = 4637,
  SUB16mi_ND = 4638,
  SUB16mi_NF = 4639,
  SUB16mi_NF_ND = 4640,
  SUB16mr = 4641,
  SUB16mr_EVEX = 4642,
  SUB16mr_ND = 4643,
  SUB16mr_NF = 4644,
  SUB16mr_NF_ND = 4645,
  SUB16ri = 4646,
  SUB16ri8 = 4647,
  SUB16ri8_EVEX = 4648,
  SUB16ri8_ND = 4649,
  SUB16ri8_NF = 4650,
  SUB16ri8_NF_ND = 4651,
  SUB16ri_EVEX = 4652,
  SUB16ri_ND = 4653,
  SUB16ri_NF = 4654,
  SUB16ri_NF_ND = 4655,
  SUB16rm = 4656,
  SUB16rm_EVEX = 4657,
  SUB16rm_ND = 4658,
  SUB16rm_NF = 4659,
  SUB16rm_NF_ND = 4660,
  SUB16rr = 4661,
  SUB16rr_EVEX = 4662,
  SUB16rr_EVEX_REV = 4663,
  SUB16rr_ND = 4664,
  SUB16rr_ND_REV = 4665,
  SUB16rr_NF = 4666,
  SUB16rr_NF_ND = 4667,
  SUB16rr_NF_ND_REV = 4668,
  SUB16rr_NF_REV = 4669,
  SUB16rr_REV = 4670,
  SUB32i32 = 4671,
  SUB32mi = 4672,
  SUB32mi8 = 4673,
  SUB32mi8_EVEX = 4674,
  SUB32mi8_ND = 4675,
  SUB32mi8_NF = 4676,
  SUB32mi8_NF_ND = 4677,
  SUB32mi_EVEX = 4678,
  SUB32mi_ND = 4679,
  SUB32mi_NF = 4680,
  SUB32mi_NF_ND = 4681,
  SUB32mr = 4682,
  SUB32mr_EVEX = 4683,
  SUB32mr_ND = 4684,
  SUB32mr_NF = 4685,
  SUB32mr_NF_ND = 4686,
  SUB32ri = 4687,
  SUB32ri8 = 4688,
  SUB32ri8_EVEX = 4689,
  SUB32ri8_ND = 4690,
  SUB32ri8_NF = 4691,
  SUB32ri8_NF_ND = 4692,
  SUB32ri_EVEX = 4693,
  SUB32ri_ND = 4694,
  SUB32ri_NF = 4695,
  SUB32ri_NF_ND = 4696,
  SUB32rm = 4697,
  SUB32rm_EVEX = 4698,
  SUB32rm_ND = 4699,
  SUB32rm_NF = 4700,
  SUB32rm_NF_ND = 4701,
  SUB32rr = 4702,
  SUB32rr_EVEX = 4703,
  SUB32rr_EVEX_REV = 4704,
  SUB32rr_ND = 4705,
  SUB32rr_ND_REV = 4706,
  SUB32rr_NF = 4707,
  SUB32rr_NF_ND = 4708,
  SUB32rr_NF_ND_REV = 4709,
  SUB32rr_NF_REV = 4710,
  SUB32rr_REV = 4711,
  SUB64i32 = 4712,
  SUB64mi32 = 4713,
  SUB64mi32_EVEX = 4714,
  SUB64mi32_ND = 4715,
  SUB64mi32_NF = 4716,
  SUB64mi32_NF_ND = 4717,
  SUB64mi8 = 4718,
  SUB64mi8_EVEX = 4719,
  SUB64mi8_ND = 4720,
  SUB64mi8_NF = 4721,
  SUB64mi8_NF_ND = 4722,
  SUB64mr = 4723,
  SUB64mr_EVEX = 4724,
  SUB64mr_ND = 4725,
  SUB64mr_NF = 4726,
  SUB64mr_NF_ND = 4727,
  SUB64ri32 = 4728,
  SUB64ri32_EVEX = 4729,
  SUB64ri32_ND = 4730,
  SUB64ri32_NF = 4731,
  SUB64ri32_NF_ND = 4732,
  SUB64ri8 = 4733,
  SUB64ri8_EVEX = 4734,
  SUB64ri8_ND = 4735,
  SUB64ri8_NF = 4736,
  SUB64ri8_NF_ND = 4737,
  SUB64rm = 4738,
  SUB64rm_EVEX = 4739,
  SUB64rm_ND = 4740,
  SUB64rm_NF = 4741,
  SUB64rm_NF_ND = 4742,
  SUB64rr = 4743,
  SUB64rr_EVEX = 4744,
  SUB64rr_EVEX_REV = 4745,
  SUB64rr_ND = 4746,
  SUB64rr_ND_REV = 4747,
  SUB64rr_NF = 4748,
  SUB64rr_NF_ND = 4749,
  SUB64rr_NF_ND_REV = 4750,
  SUB64rr_NF_REV = 4751,
  SUB64rr_REV = 4752,
  SUB8i8 = 4753,
  SUB8mi = 4754,
  SUB8mi8 = 4755,
  SUB8mi_EVEX = 4756,
  SUB8mi_ND = 4757,
  SUB8mi_NF = 4758,
  SUB8mi_NF_ND = 4759,
  SUB8mr = 4760,
  SUB8mr_EVEX = 4761,
  SUB8mr_ND = 4762,
  SUB8mr_NF = 4763,
  SUB8mr_NF_ND = 4764,
  SUB8ri = 4765,
  SUB8ri8 = 4766,
  SUB8ri_EVEX = 4767,
  SUB8ri_ND = 4768,
  SUB8ri_NF = 4769,
  SUB8ri_NF_ND = 4770,
  SUB8rm = 4771,
  SUB8rm_EVEX = 4772,
  SUB8rm_ND = 4773,
  SUB8rm_NF = 4774,
  SUB8rm_NF_ND = 4775,
  SUB8rr = 4776,
  SUB8rr_EVEX = 4777,
  SUB8rr_EVEX_REV = 4778,
  SUB8rr_ND = 4779,
  SUB8rr_ND_REV = 4780,
  SUB8rr_NF = 4781,
  SUB8rr_NF_ND = 4782,
  SUB8rr_NF_ND_REV = 4783,
  SUB8rr_NF_REV = 4784,
  SUB8rr_REV = 4785,
  SUBPDrm = 4786,
  SUBPDrr = 4787,
  SUBPSrm = 4788,
  SUBPSrr = 4789,
  SUBR_F32m = 4790,
  SUBR_F64m = 4791,
  SUBR_FI16m = 4792,
  SUBR_FI32m = 4793,
  SUBR_FPrST0 = 4794,
  SUBR_FST0r = 4795,
  SUBR_Fp32m = 4796,
  SUBR_Fp64m = 4797,
  SUBR_Fp64m32 = 4798,
  SUBR_Fp80m32 = 4799,
  SUBR_Fp80m64 = 4800,
  SUBR_FpI16m32 = 4801,
  SUBR_FpI16m64 = 4802,
  SUBR_FpI16m80 = 4803,
  SUBR_FpI32m32 = 4804,
  SUBR_FpI32m64 = 4805,
  SUBR_FpI32m80 = 4806,
  SUBR_FrST0 = 4807,
  SUBSDrm = 4808,
  SUBSDrm_Int = 4809,
  SUBSDrr = 4810,
  SUBSDrr_Int = 4811,
  SUBSSrm = 4812,
  SUBSSrm_Int = 4813,
  SUBSSrr = 4814,
  SUBSSrr_Int = 4815,
  SUB_F32m = 4816,
  SUB_F64m = 4817,
  SUB_FI16m = 4818,
  SUB_FI32m = 4819,
  SUB_FPrST0 = 4820,
  SUB_FST0r = 4821,
  SUB_Fp32 = 4822,
  SUB_Fp32m = 4823,
  SUB_Fp64 = 4824,
  SUB_Fp64m = 4825,
  SUB_Fp64m32 = 4826,
  SUB_Fp80 = 4827,
  SUB_Fp80m32 = 4828,
  SUB_Fp80m64 = 4829,
  SUB_FpI16m32 = 4830,
  SUB_FpI16m64 = 4831,
  SUB_FpI16m80 = 4832,
  SUB_FpI32m32 = 4833,
  SUB_FpI32m64 = 4834,
  SUB_FpI32m80 = 4835,
  SUB_FrST0 = 4836,
  SWAPGS = 4837,
  SYSCALL = 4838,
  SYSENTER = 4839,
  SYSEXIT = 4840,
  SYSEXIT64 = 4841,
  SYSRET = 4842,
  SYSRET64 = 4843,
  T1MSKC32rm = 4844,
  T1MSKC32rr = 4845,
  T1MSKC64rm = 4846,
  T1MSKC64rr = 4847,
  TAILJMPd = 4848,
  TAILJMPd64 = 4849,
  TAILJMPd64_CC = 4850,
  TAILJMPd_CC = 4851,
  TAILJMPm = 4852,
  TAILJMPm64 = 4853,
  TAILJMPm64_REX = 4854,
  TAILJMPr = 4855,
  TAILJMPr64 = 4856,
  TAILJMPr64_REX = 4857,
  TCMMIMFP16PS = 4858,
  TCMMRLFP16PS = 4859,
  TCRETURNdi = 4860,
  TCRETURNdi64 = 4861,
  TCRETURNdi64cc = 4862,
  TCRETURNdicc = 4863,
  TCRETURNmi = 4864,
  TCRETURNmi64 = 4865,
  TCRETURNri = 4866,
  TCRETURNri64 = 4867,
  TDCALL = 4868,
  TDPBF16PS = 4869,
  TDPBSSD = 4870,
  TDPBSUD = 4871,
  TDPBUSD = 4872,
  TDPBUUD = 4873,
  TDPFP16PS = 4874,
  TEST16i16 = 4875,
  TEST16mi = 4876,
  TEST16mr = 4877,
  TEST16ri = 4878,
  TEST16rr = 4879,
  TEST32i32 = 4880,
  TEST32mi = 4881,
  TEST32mr = 4882,
  TEST32ri = 4883,
  TEST32rr = 4884,
  TEST64i32 = 4885,
  TEST64mi32 = 4886,
  TEST64mr = 4887,
  TEST64ri32 = 4888,
  TEST64rr = 4889,
  TEST8i8 = 4890,
  TEST8mi = 4891,
  TEST8mr = 4892,
  TEST8ri = 4893,
  TEST8rr = 4894,
  TESTUI = 4895,
  TILELOADD = 4896,
  TILELOADDT1 = 4897,
  TILELOADDT1_EVEX = 4898,
  TILELOADD_EVEX = 4899,
  TILERELEASE = 4900,
  TILESTORED = 4901,
  TILESTORED_EVEX = 4902,
  TILEZERO = 4903,
  TLBSYNC = 4904,
  TLSCall_32 = 4905,
  TLSCall_64 = 4906,
  TLS_addr32 = 4907,
  TLS_addr64 = 4908,
  TLS_addrX32 = 4909,
  TLS_base_addr32 = 4910,
  TLS_base_addr64 = 4911,
  TLS_base_addrX32 = 4912,
  TLS_desc32 = 4913,
  TLS_desc64 = 4914,
  TPAUSE = 4915,
  TRAP = 4916,
  TST_F = 4917,
  TST_Fp32 = 4918,
  TST_Fp64 = 4919,
  TST_Fp80 = 4920,
  TZCNT16rm = 4921,
  TZCNT16rm_EVEX = 4922,
  TZCNT16rm_NF = 4923,
  TZCNT16rr = 4924,
  TZCNT16rr_EVEX = 4925,
  TZCNT16rr_NF = 4926,
  TZCNT32rm = 4927,
  TZCNT32rm_EVEX = 4928,
  TZCNT32rm_NF = 4929,
  TZCNT32rr = 4930,
  TZCNT32rr_EVEX = 4931,
  TZCNT32rr_NF = 4932,
  TZCNT64rm = 4933,
  TZCNT64rm_EVEX = 4934,
  TZCNT64rm_NF = 4935,
  TZCNT64rr = 4936,
  TZCNT64rr_EVEX = 4937,
  TZCNT64rr_NF = 4938,
  TZMSK32rm = 4939,
  TZMSK32rr = 4940,
  TZMSK64rm = 4941,
  TZMSK64rr = 4942,
  UBSAN_UD1 = 4943,
  UCOMISDrm = 4944,
  UCOMISDrm_Int = 4945,
  UCOMISDrr = 4946,
  UCOMISDrr_Int = 4947,
  UCOMISSrm = 4948,
  UCOMISSrm_Int = 4949,
  UCOMISSrr = 4950,
  UCOMISSrr_Int = 4951,
  UCOM_FIPr = 4952,
  UCOM_FIr = 4953,
  UCOM_FPPr = 4954,
  UCOM_FPr = 4955,
  UCOM_FpIr32 = 4956,
  UCOM_FpIr64 = 4957,
  UCOM_FpIr80 = 4958,
  UCOM_Fpr32 = 4959,
  UCOM_Fpr64 = 4960,
  UCOM_Fpr80 = 4961,
  UCOM_Fr = 4962,
  UD1Lm = 4963,
  UD1Lr = 4964,
  UD1Qm = 4965,
  UD1Qr = 4966,
  UD1Wm = 4967,
  UD1Wr = 4968,
  UIRET = 4969,
  UMONITOR16 = 4970,
  UMONITOR32 = 4971,
  UMONITOR64 = 4972,
  UMWAIT = 4973,
  UNPCKHPDrm = 4974,
  UNPCKHPDrr = 4975,
  UNPCKHPSrm = 4976,
  UNPCKHPSrr = 4977,
  UNPCKLPDrm = 4978,
  UNPCKLPDrr = 4979,
  UNPCKLPSrm = 4980,
  UNPCKLPSrr = 4981,
  URDMSRri = 4982,
  URDMSRri_EVEX = 4983,
  URDMSRrr = 4984,
  URDMSRrr_EVEX = 4985,
  UWRMSRir = 4986,
  UWRMSRir_EVEX = 4987,
  UWRMSRrr = 4988,
  UWRMSRrr_EVEX = 4989,
  V4FMADDPSrm = 4990,
  V4FMADDPSrmk = 4991,
  V4FMADDPSrmkz = 4992,
  V4FMADDSSrm = 4993,
  V4FMADDSSrmk = 4994,
  V4FMADDSSrmkz = 4995,
  V4FNMADDPSrm = 4996,
  V4FNMADDPSrmk = 4997,
  V4FNMADDPSrmkz = 4998,
  V4FNMADDSSrm = 4999,
  V4FNMADDSSrmk = 5000,
  V4FNMADDSSrmkz = 5001,
  VAARG_64 = 5002,
  VAARG_X32 = 5003,
  VADDPDYrm = 5004,
  VADDPDYrr = 5005,
  VADDPDZ128rm = 5006,
  VADDPDZ128rmb = 5007,
  VADDPDZ128rmbk = 5008,
  VADDPDZ128rmbkz = 5009,
  VADDPDZ128rmk = 5010,
  VADDPDZ128rmkz = 5011,
  VADDPDZ128rr = 5012,
  VADDPDZ128rrk = 5013,
  VADDPDZ128rrkz = 5014,
  VADDPDZ256rm = 5015,
  VADDPDZ256rmb = 5016,
  VADDPDZ256rmbk = 5017,
  VADDPDZ256rmbkz = 5018,
  VADDPDZ256rmk = 5019,
  VADDPDZ256rmkz = 5020,
  VADDPDZ256rr = 5021,
  VADDPDZ256rrk = 5022,
  VADDPDZ256rrkz = 5023,
  VADDPDZrm = 5024,
  VADDPDZrmb = 5025,
  VADDPDZrmbk = 5026,
  VADDPDZrmbkz = 5027,
  VADDPDZrmk = 5028,
  VADDPDZrmkz = 5029,
  VADDPDZrr = 5030,
  VADDPDZrrb = 5031,
  VADDPDZrrbk = 5032,
  VADDPDZrrbkz = 5033,
  VADDPDZrrk = 5034,
  VADDPDZrrkz = 5035,
  VADDPDrm = 5036,
  VADDPDrr = 5037,
  VADDPHZ128rm = 5038,
  VADDPHZ128rmb = 5039,
  VADDPHZ128rmbk = 5040,
  VADDPHZ128rmbkz = 5041,
  VADDPHZ128rmk = 5042,
  VADDPHZ128rmkz = 5043,
  VADDPHZ128rr = 5044,
  VADDPHZ128rrk = 5045,
  VADDPHZ128rrkz = 5046,
  VADDPHZ256rm = 5047,
  VADDPHZ256rmb = 5048,
  VADDPHZ256rmbk = 5049,
  VADDPHZ256rmbkz = 5050,
  VADDPHZ256rmk = 5051,
  VADDPHZ256rmkz = 5052,
  VADDPHZ256rr = 5053,
  VADDPHZ256rrk = 5054,
  VADDPHZ256rrkz = 5055,
  VADDPHZrm = 5056,
  VADDPHZrmb = 5057,
  VADDPHZrmbk = 5058,
  VADDPHZrmbkz = 5059,
  VADDPHZrmk = 5060,
  VADDPHZrmkz = 5061,
  VADDPHZrr = 5062,
  VADDPHZrrb = 5063,
  VADDPHZrrbk = 5064,
  VADDPHZrrbkz = 5065,
  VADDPHZrrk = 5066,
  VADDPHZrrkz = 5067,
  VADDPSYrm = 5068,
  VADDPSYrr = 5069,
  VADDPSZ128rm = 5070,
  VADDPSZ128rmb = 5071,
  VADDPSZ128rmbk = 5072,
  VADDPSZ128rmbkz = 5073,
  VADDPSZ128rmk = 5074,
  VADDPSZ128rmkz = 5075,
  VADDPSZ128rr = 5076,
  VADDPSZ128rrk = 5077,
  VADDPSZ128rrkz = 5078,
  VADDPSZ256rm = 5079,
  VADDPSZ256rmb = 5080,
  VADDPSZ256rmbk = 5081,
  VADDPSZ256rmbkz = 5082,
  VADDPSZ256rmk = 5083,
  VADDPSZ256rmkz = 5084,
  VADDPSZ256rr = 5085,
  VADDPSZ256rrk = 5086,
  VADDPSZ256rrkz = 5087,
  VADDPSZrm = 5088,
  VADDPSZrmb = 5089,
  VADDPSZrmbk = 5090,
  VADDPSZrmbkz = 5091,
  VADDPSZrmk = 5092,
  VADDPSZrmkz = 5093,
  VADDPSZrr = 5094,
  VADDPSZrrb = 5095,
  VADDPSZrrbk = 5096,
  VADDPSZrrbkz = 5097,
  VADDPSZrrk = 5098,
  VADDPSZrrkz = 5099,
  VADDPSrm = 5100,
  VADDPSrr = 5101,
  VADDSDZrm = 5102,
  VADDSDZrm_Int = 5103,
  VADDSDZrm_Intk = 5104,
  VADDSDZrm_Intkz = 5105,
  VADDSDZrr = 5106,
  VADDSDZrr_Int = 5107,
  VADDSDZrr_Intk = 5108,
  VADDSDZrr_Intkz = 5109,
  VADDSDZrrb_Int = 5110,
  VADDSDZrrb_Intk = 5111,
  VADDSDZrrb_Intkz = 5112,
  VADDSDrm = 5113,
  VADDSDrm_Int = 5114,
  VADDSDrr = 5115,
  VADDSDrr_Int = 5116,
  VADDSHZrm = 5117,
  VADDSHZrm_Int = 5118,
  VADDSHZrm_Intk = 5119,
  VADDSHZrm_Intkz = 5120,
  VADDSHZrr = 5121,
  VADDSHZrr_Int = 5122,
  VADDSHZrr_Intk = 5123,
  VADDSHZrr_Intkz = 5124,
  VADDSHZrrb_Int = 5125,
  VADDSHZrrb_Intk = 5126,
  VADDSHZrrb_Intkz = 5127,
  VADDSSZrm = 5128,
  VADDSSZrm_Int = 5129,
  VADDSSZrm_Intk = 5130,
  VADDSSZrm_Intkz = 5131,
  VADDSSZrr = 5132,
  VADDSSZrr_Int = 5133,
  VADDSSZrr_Intk = 5134,
  VADDSSZrr_Intkz = 5135,
  VADDSSZrrb_Int = 5136,
  VADDSSZrrb_Intk = 5137,
  VADDSSZrrb_Intkz = 5138,
  VADDSSrm = 5139,
  VADDSSrm_Int = 5140,
  VADDSSrr = 5141,
  VADDSSrr_Int = 5142,
  VADDSUBPDYrm = 5143,
  VADDSUBPDYrr = 5144,
  VADDSUBPDrm = 5145,
  VADDSUBPDrr = 5146,
  VADDSUBPSYrm = 5147,
  VADDSUBPSYrr = 5148,
  VADDSUBPSrm = 5149,
  VADDSUBPSrr = 5150,
  VAESDECLASTYrm = 5151,
  VAESDECLASTYrr = 5152,
  VAESDECLASTZ128rm = 5153,
  VAESDECLASTZ128rr = 5154,
  VAESDECLASTZ256rm = 5155,
  VAESDECLASTZ256rr = 5156,
  VAESDECLASTZrm = 5157,
  VAESDECLASTZrr = 5158,
  VAESDECLASTrm = 5159,
  VAESDECLASTrr = 5160,
  VAESDECYrm = 5161,
  VAESDECYrr = 5162,
  VAESDECZ128rm = 5163,
  VAESDECZ128rr = 5164,
  VAESDECZ256rm = 5165,
  VAESDECZ256rr = 5166,
  VAESDECZrm = 5167,
  VAESDECZrr = 5168,
  VAESDECrm = 5169,
  VAESDECrr = 5170,
  VAESENCLASTYrm = 5171,
  VAESENCLASTYrr = 5172,
  VAESENCLASTZ128rm = 5173,
  VAESENCLASTZ128rr = 5174,
  VAESENCLASTZ256rm = 5175,
  VAESENCLASTZ256rr = 5176,
  VAESENCLASTZrm = 5177,
  VAESENCLASTZrr = 5178,
  VAESENCLASTrm = 5179,
  VAESENCLASTrr = 5180,
  VAESENCYrm = 5181,
  VAESENCYrr = 5182,
  VAESENCZ128rm = 5183,
  VAESENCZ128rr = 5184,
  VAESENCZ256rm = 5185,
  VAESENCZ256rr = 5186,
  VAESENCZrm = 5187,
  VAESENCZrr = 5188,
  VAESENCrm = 5189,
  VAESENCrr = 5190,
  VAESIMCrm = 5191,
  VAESIMCrr = 5192,
  VAESKEYGENASSIST128rm = 5193,
  VAESKEYGENASSIST128rr = 5194,
  VALIGNDZ128rmbi = 5195,
  VALIGNDZ128rmbik = 5196,
  VALIGNDZ128rmbikz = 5197,
  VALIGNDZ128rmi = 5198,
  VALIGNDZ128rmik = 5199,
  VALIGNDZ128rmikz = 5200,
  VALIGNDZ128rri = 5201,
  VALIGNDZ128rrik = 5202,
  VALIGNDZ128rrikz = 5203,
  VALIGNDZ256rmbi = 5204,
  VALIGNDZ256rmbik = 5205,
  VALIGNDZ256rmbikz = 5206,
  VALIGNDZ256rmi = 5207,
  VALIGNDZ256rmik = 5208,
  VALIGNDZ256rmikz = 5209,
  VALIGNDZ256rri = 5210,
  VALIGNDZ256rrik = 5211,
  VALIGNDZ256rrikz = 5212,
  VALIGNDZrmbi = 5213,
  VALIGNDZrmbik = 5214,
  VALIGNDZrmbikz = 5215,
  VALIGNDZrmi = 5216,
  VALIGNDZrmik = 5217,
  VALIGNDZrmikz = 5218,
  VALIGNDZrri = 5219,
  VALIGNDZrrik = 5220,
  VALIGNDZrrikz = 5221,
  VALIGNQZ128rmbi = 5222,
  VALIGNQZ128rmbik = 5223,
  VALIGNQZ128rmbikz = 5224,
  VALIGNQZ128rmi = 5225,
  VALIGNQZ128rmik = 5226,
  VALIGNQZ128rmikz = 5227,
  VALIGNQZ128rri = 5228,
  VALIGNQZ128rrik = 5229,
  VALIGNQZ128rrikz = 5230,
  VALIGNQZ256rmbi = 5231,
  VALIGNQZ256rmbik = 5232,
  VALIGNQZ256rmbikz = 5233,
  VALIGNQZ256rmi = 5234,
  VALIGNQZ256rmik = 5235,
  VALIGNQZ256rmikz = 5236,
  VALIGNQZ256rri = 5237,
  VALIGNQZ256rrik = 5238,
  VALIGNQZ256rrikz = 5239,
  VALIGNQZrmbi = 5240,
  VALIGNQZrmbik = 5241,
  VALIGNQZrmbikz = 5242,
  VALIGNQZrmi = 5243,
  VALIGNQZrmik = 5244,
  VALIGNQZrmikz = 5245,
  VALIGNQZrri = 5246,
  VALIGNQZrrik = 5247,
  VALIGNQZrrikz = 5248,
  VANDNPDYrm = 5249,
  VANDNPDYrr = 5250,
  VANDNPDZ128rm = 5251,
  VANDNPDZ128rmb = 5252,
  VANDNPDZ128rmbk = 5253,
  VANDNPDZ128rmbkz = 5254,
  VANDNPDZ128rmk = 5255,
  VANDNPDZ128rmkz = 5256,
  VANDNPDZ128rr = 5257,
  VANDNPDZ128rrk = 5258,
  VANDNPDZ128rrkz = 5259,
  VANDNPDZ256rm = 5260,
  VANDNPDZ256rmb = 5261,
  VANDNPDZ256rmbk = 5262,
  VANDNPDZ256rmbkz = 5263,
  VANDNPDZ256rmk = 5264,
  VANDNPDZ256rmkz = 5265,
  VANDNPDZ256rr = 5266,
  VANDNPDZ256rrk = 5267,
  VANDNPDZ256rrkz = 5268,
  VANDNPDZrm = 5269,
  VANDNPDZrmb = 5270,
  VANDNPDZrmbk = 5271,
  VANDNPDZrmbkz = 5272,
  VANDNPDZrmk = 5273,
  VANDNPDZrmkz = 5274,
  VANDNPDZrr = 5275,
  VANDNPDZrrk = 5276,
  VANDNPDZrrkz = 5277,
  VANDNPDrm = 5278,
  VANDNPDrr = 5279,
  VANDNPSYrm = 5280,
  VANDNPSYrr = 5281,
  VANDNPSZ128rm = 5282,
  VANDNPSZ128rmb = 5283,
  VANDNPSZ128rmbk = 5284,
  VANDNPSZ128rmbkz = 5285,
  VANDNPSZ128rmk = 5286,
  VANDNPSZ128rmkz = 5287,
  VANDNPSZ128rr = 5288,
  VANDNPSZ128rrk = 5289,
  VANDNPSZ128rrkz = 5290,
  VANDNPSZ256rm = 5291,
  VANDNPSZ256rmb = 5292,
  VANDNPSZ256rmbk = 5293,
  VANDNPSZ256rmbkz = 5294,
  VANDNPSZ256rmk = 5295,
  VANDNPSZ256rmkz = 5296,
  VANDNPSZ256rr = 5297,
  VANDNPSZ256rrk = 5298,
  VANDNPSZ256rrkz = 5299,
  VANDNPSZrm = 5300,
  VANDNPSZrmb = 5301,
  VANDNPSZrmbk = 5302,
  VANDNPSZrmbkz = 5303,
  VANDNPSZrmk = 5304,
  VANDNPSZrmkz = 5305,
  VANDNPSZrr = 5306,
  VANDNPSZrrk = 5307,
  VANDNPSZrrkz = 5308,
  VANDNPSrm = 5309,
  VANDNPSrr = 5310,
  VANDPDYrm = 5311,
  VANDPDYrr = 5312,
  VANDPDZ128rm = 5313,
  VANDPDZ128rmb = 5314,
  VANDPDZ128rmbk = 5315,
  VANDPDZ128rmbkz = 5316,
  VANDPDZ128rmk = 5317,
  VANDPDZ128rmkz = 5318,
  VANDPDZ128rr = 5319,
  VANDPDZ128rrk = 5320,
  VANDPDZ128rrkz = 5321,
  VANDPDZ256rm = 5322,
  VANDPDZ256rmb = 5323,
  VANDPDZ256rmbk = 5324,
  VANDPDZ256rmbkz = 5325,
  VANDPDZ256rmk = 5326,
  VANDPDZ256rmkz = 5327,
  VANDPDZ256rr = 5328,
  VANDPDZ256rrk = 5329,
  VANDPDZ256rrkz = 5330,
  VANDPDZrm = 5331,
  VANDPDZrmb = 5332,
  VANDPDZrmbk = 5333,
  VANDPDZrmbkz = 5334,
  VANDPDZrmk = 5335,
  VANDPDZrmkz = 5336,
  VANDPDZrr = 5337,
  VANDPDZrrk = 5338,
  VANDPDZrrkz = 5339,
  VANDPDrm = 5340,
  VANDPDrr = 5341,
  VANDPSYrm = 5342,
  VANDPSYrr = 5343,
  VANDPSZ128rm = 5344,
  VANDPSZ128rmb = 5345,
  VANDPSZ128rmbk = 5346,
  VANDPSZ128rmbkz = 5347,
  VANDPSZ128rmk = 5348,
  VANDPSZ128rmkz = 5349,
  VANDPSZ128rr = 5350,
  VANDPSZ128rrk = 5351,
  VANDPSZ128rrkz = 5352,
  VANDPSZ256rm = 5353,
  VANDPSZ256rmb = 5354,
  VANDPSZ256rmbk = 5355,
  VANDPSZ256rmbkz = 5356,
  VANDPSZ256rmk = 5357,
  VANDPSZ256rmkz = 5358,
  VANDPSZ256rr = 5359,
  VANDPSZ256rrk = 5360,
  VANDPSZ256rrkz = 5361,
  VANDPSZrm = 5362,
  VANDPSZrmb = 5363,
  VANDPSZrmbk = 5364,
  VANDPSZrmbkz = 5365,
  VANDPSZrmk = 5366,
  VANDPSZrmkz = 5367,
  VANDPSZrr = 5368,
  VANDPSZrrk = 5369,
  VANDPSZrrkz = 5370,
  VANDPSrm = 5371,
  VANDPSrr = 5372,
  VASTART_SAVE_XMM_REGS = 5373,
  VBCSTNEBF162PSYrm = 5374,
  VBCSTNEBF162PSrm = 5375,
  VBCSTNESH2PSYrm = 5376,
  VBCSTNESH2PSrm = 5377,
  VBLENDMPDZ128rm = 5378,
  VBLENDMPDZ128rmb = 5379,
  VBLENDMPDZ128rmbk = 5380,
  VBLENDMPDZ128rmbkz = 5381,
  VBLENDMPDZ128rmk = 5382,
  VBLENDMPDZ128rmkz = 5383,
  VBLENDMPDZ128rr = 5384,
  VBLENDMPDZ128rrk = 5385,
  VBLENDMPDZ128rrkz = 5386,
  VBLENDMPDZ256rm = 5387,
  VBLENDMPDZ256rmb = 5388,
  VBLENDMPDZ256rmbk = 5389,
  VBLENDMPDZ256rmbkz = 5390,
  VBLENDMPDZ256rmk = 5391,
  VBLENDMPDZ256rmkz = 5392,
  VBLENDMPDZ256rr = 5393,
  VBLENDMPDZ256rrk = 5394,
  VBLENDMPDZ256rrkz = 5395,
  VBLENDMPDZrm = 5396,
  VBLENDMPDZrmb = 5397,
  VBLENDMPDZrmbk = 5398,
  VBLENDMPDZrmbkz = 5399,
  VBLENDMPDZrmk = 5400,
  VBLENDMPDZrmkz = 5401,
  VBLENDMPDZrr = 5402,
  VBLENDMPDZrrk = 5403,
  VBLENDMPDZrrkz = 5404,
  VBLENDMPSZ128rm = 5405,
  VBLENDMPSZ128rmb = 5406,
  VBLENDMPSZ128rmbk = 5407,
  VBLENDMPSZ128rmbkz = 5408,
  VBLENDMPSZ128rmk = 5409,
  VBLENDMPSZ128rmkz = 5410,
  VBLENDMPSZ128rr = 5411,
  VBLENDMPSZ128rrk = 5412,
  VBLENDMPSZ128rrkz = 5413,
  VBLENDMPSZ256rm = 5414,
  VBLENDMPSZ256rmb = 5415,
  VBLENDMPSZ256rmbk = 5416,
  VBLENDMPSZ256rmbkz = 5417,
  VBLENDMPSZ256rmk = 5418,
  VBLENDMPSZ256rmkz = 5419,
  VBLENDMPSZ256rr = 5420,
  VBLENDMPSZ256rrk = 5421,
  VBLENDMPSZ256rrkz = 5422,
  VBLENDMPSZrm = 5423,
  VBLENDMPSZrmb = 5424,
  VBLENDMPSZrmbk = 5425,
  VBLENDMPSZrmbkz = 5426,
  VBLENDMPSZrmk = 5427,
  VBLENDMPSZrmkz = 5428,
  VBLENDMPSZrr = 5429,
  VBLENDMPSZrrk = 5430,
  VBLENDMPSZrrkz = 5431,
  VBLENDPDYrmi = 5432,
  VBLENDPDYrri = 5433,
  VBLENDPDrmi = 5434,
  VBLENDPDrri = 5435,
  VBLENDPSYrmi = 5436,
  VBLENDPSYrri = 5437,
  VBLENDPSrmi = 5438,
  VBLENDPSrri = 5439,
  VBLENDVPDYrmr = 5440,
  VBLENDVPDYrrr = 5441,
  VBLENDVPDrmr = 5442,
  VBLENDVPDrrr = 5443,
  VBLENDVPSYrmr = 5444,
  VBLENDVPSYrrr = 5445,
  VBLENDVPSrmr = 5446,
  VBLENDVPSrrr = 5447,
  VBROADCASTF128rm = 5448,
  VBROADCASTF32X2Z256rm = 5449,
  VBROADCASTF32X2Z256rmk = 5450,
  VBROADCASTF32X2Z256rmkz = 5451,
  VBROADCASTF32X2Z256rr = 5452,
  VBROADCASTF32X2Z256rrk = 5453,
  VBROADCASTF32X2Z256rrkz = 5454,
  VBROADCASTF32X2Zrm = 5455,
  VBROADCASTF32X2Zrmk = 5456,
  VBROADCASTF32X2Zrmkz = 5457,
  VBROADCASTF32X2Zrr = 5458,
  VBROADCASTF32X2Zrrk = 5459,
  VBROADCASTF32X2Zrrkz = 5460,
  VBROADCASTF32X4Z256rm = 5461,
  VBROADCASTF32X4Z256rmk = 5462,
  VBROADCASTF32X4Z256rmkz = 5463,
  VBROADCASTF32X4rm = 5464,
  VBROADCASTF32X4rmk = 5465,
  VBROADCASTF32X4rmkz = 5466,
  VBROADCASTF32X8rm = 5467,
  VBROADCASTF32X8rmk = 5468,
  VBROADCASTF32X8rmkz = 5469,
  VBROADCASTF64X2Z128rm = 5470,
  VBROADCASTF64X2Z128rmk = 5471,
  VBROADCASTF64X2Z128rmkz = 5472,
  VBROADCASTF64X2rm = 5473,
  VBROADCASTF64X2rmk = 5474,
  VBROADCASTF64X2rmkz = 5475,
  VBROADCASTF64X4rm = 5476,
  VBROADCASTF64X4rmk = 5477,
  VBROADCASTF64X4rmkz = 5478,
  VBROADCASTI128rm = 5479,
  VBROADCASTI32X2Z128rm = 5480,
  VBROADCASTI32X2Z128rmk = 5481,
  VBROADCASTI32X2Z128rmkz = 5482,
  VBROADCASTI32X2Z128rr = 5483,
  VBROADCASTI32X2Z128rrk = 5484,
  VBROADCASTI32X2Z128rrkz = 5485,
  VBROADCASTI32X2Z256rm = 5486,
  VBROADCASTI32X2Z256rmk = 5487,
  VBROADCASTI32X2Z256rmkz = 5488,
  VBROADCASTI32X2Z256rr = 5489,
  VBROADCASTI32X2Z256rrk = 5490,
  VBROADCASTI32X2Z256rrkz = 5491,
  VBROADCASTI32X2Zrm = 5492,
  VBROADCASTI32X2Zrmk = 5493,
  VBROADCASTI32X2Zrmkz = 5494,
  VBROADCASTI32X2Zrr = 5495,
  VBROADCASTI32X2Zrrk = 5496,
  VBROADCASTI32X2Zrrkz = 5497,
  VBROADCASTI32X4Z256rm = 5498,
  VBROADCASTI32X4Z256rmk = 5499,
  VBROADCASTI32X4Z256rmkz = 5500,
  VBROADCASTI32X4rm = 5501,
  VBROADCASTI32X4rmk = 5502,
  VBROADCASTI32X4rmkz = 5503,
  VBROADCASTI32X8rm = 5504,
  VBROADCASTI32X8rmk = 5505,
  VBROADCASTI32X8rmkz = 5506,
  VBROADCASTI64X2Z128rm = 5507,
  VBROADCASTI64X2Z128rmk = 5508,
  VBROADCASTI64X2Z128rmkz = 5509,
  VBROADCASTI64X2rm = 5510,
  VBROADCASTI64X2rmk = 5511,
  VBROADCASTI64X2rmkz = 5512,
  VBROADCASTI64X4rm = 5513,
  VBROADCASTI64X4rmk = 5514,
  VBROADCASTI64X4rmkz = 5515,
  VBROADCASTSDYrm = 5516,
  VBROADCASTSDYrr = 5517,
  VBROADCASTSDZ256rm = 5518,
  VBROADCASTSDZ256rmk = 5519,
  VBROADCASTSDZ256rmkz = 5520,
  VBROADCASTSDZ256rr = 5521,
  VBROADCASTSDZ256rrk = 5522,
  VBROADCASTSDZ256rrkz = 5523,
  VBROADCASTSDZrm = 5524,
  VBROADCASTSDZrmk = 5525,
  VBROADCASTSDZrmkz = 5526,
  VBROADCASTSDZrr = 5527,
  VBROADCASTSDZrrk = 5528,
  VBROADCASTSDZrrkz = 5529,
  VBROADCASTSSYrm = 5530,
  VBROADCASTSSYrr = 5531,
  VBROADCASTSSZ128rm = 5532,
  VBROADCASTSSZ128rmk = 5533,
  VBROADCASTSSZ128rmkz = 5534,
  VBROADCASTSSZ128rr = 5535,
  VBROADCASTSSZ128rrk = 5536,
  VBROADCASTSSZ128rrkz = 5537,
  VBROADCASTSSZ256rm = 5538,
  VBROADCASTSSZ256rmk = 5539,
  VBROADCASTSSZ256rmkz = 5540,
  VBROADCASTSSZ256rr = 5541,
  VBROADCASTSSZ256rrk = 5542,
  VBROADCASTSSZ256rrkz = 5543,
  VBROADCASTSSZrm = 5544,
  VBROADCASTSSZrmk = 5545,
  VBROADCASTSSZrmkz = 5546,
  VBROADCASTSSZrr = 5547,
  VBROADCASTSSZrrk = 5548,
  VBROADCASTSSZrrkz = 5549,
  VBROADCASTSSrm = 5550,
  VBROADCASTSSrr = 5551,
  VCMPPDYrmi = 5552,
  VCMPPDYrri = 5553,
  VCMPPDZ128rmbi = 5554,
  VCMPPDZ128rmbik = 5555,
  VCMPPDZ128rmi = 5556,
  VCMPPDZ128rmik = 5557,
  VCMPPDZ128rri = 5558,
  VCMPPDZ128rrik = 5559,
  VCMPPDZ256rmbi = 5560,
  VCMPPDZ256rmbik = 5561,
  VCMPPDZ256rmi = 5562,
  VCMPPDZ256rmik = 5563,
  VCMPPDZ256rri = 5564,
  VCMPPDZ256rrik = 5565,
  VCMPPDZrmbi = 5566,
  VCMPPDZrmbik = 5567,
  VCMPPDZrmi = 5568,
  VCMPPDZrmik = 5569,
  VCMPPDZrri = 5570,
  VCMPPDZrrib = 5571,
  VCMPPDZrribk = 5572,
  VCMPPDZrrik = 5573,
  VCMPPDrmi = 5574,
  VCMPPDrri = 5575,
  VCMPPHZ128rmbi = 5576,
  VCMPPHZ128rmbik = 5577,
  VCMPPHZ128rmi = 5578,
  VCMPPHZ128rmik = 5579,
  VCMPPHZ128rri = 5580,
  VCMPPHZ128rrik = 5581,
  VCMPPHZ256rmbi = 5582,
  VCMPPHZ256rmbik = 5583,
  VCMPPHZ256rmi = 5584,
  VCMPPHZ256rmik = 5585,
  VCMPPHZ256rri = 5586,
  VCMPPHZ256rrik = 5587,
  VCMPPHZrmbi = 5588,
  VCMPPHZrmbik = 5589,
  VCMPPHZrmi = 5590,
  VCMPPHZrmik = 5591,
  VCMPPHZrri = 5592,
  VCMPPHZrrib = 5593,
  VCMPPHZrribk = 5594,
  VCMPPHZrrik = 5595,
  VCMPPSYrmi = 5596,
  VCMPPSYrri = 5597,
  VCMPPSZ128rmbi = 5598,
  VCMPPSZ128rmbik = 5599,
  VCMPPSZ128rmi = 5600,
  VCMPPSZ128rmik = 5601,
  VCMPPSZ128rri = 5602,
  VCMPPSZ128rrik = 5603,
  VCMPPSZ256rmbi = 5604,
  VCMPPSZ256rmbik = 5605,
  VCMPPSZ256rmi = 5606,
  VCMPPSZ256rmik = 5607,
  VCMPPSZ256rri = 5608,
  VCMPPSZ256rrik = 5609,
  VCMPPSZrmbi = 5610,
  VCMPPSZrmbik = 5611,
  VCMPPSZrmi = 5612,
  VCMPPSZrmik = 5613,
  VCMPPSZrri = 5614,
  VCMPPSZrrib = 5615,
  VCMPPSZrribk = 5616,
  VCMPPSZrrik = 5617,
  VCMPPSrmi = 5618,
  VCMPPSrri = 5619,
  VCMPSDZrmi = 5620,
  VCMPSDZrmi_Int = 5621,
  VCMPSDZrmi_Intk = 5622,
  VCMPSDZrri = 5623,
  VCMPSDZrri_Int = 5624,
  VCMPSDZrri_Intk = 5625,
  VCMPSDZrrib_Int = 5626,
  VCMPSDZrrib_Intk = 5627,
  VCMPSDrmi = 5628,
  VCMPSDrmi_Int = 5629,
  VCMPSDrri = 5630,
  VCMPSDrri_Int = 5631,
  VCMPSHZrmi = 5632,
  VCMPSHZrmi_Int = 5633,
  VCMPSHZrmi_Intk = 5634,
  VCMPSHZrri = 5635,
  VCMPSHZrri_Int = 5636,
  VCMPSHZrri_Intk = 5637,
  VCMPSHZrrib_Int = 5638,
  VCMPSHZrrib_Intk = 5639,
  VCMPSSZrmi = 5640,
  VCMPSSZrmi_Int = 5641,
  VCMPSSZrmi_Intk = 5642,
  VCMPSSZrri = 5643,
  VCMPSSZrri_Int = 5644,
  VCMPSSZrri_Intk = 5645,
  VCMPSSZrrib_Int = 5646,
  VCMPSSZrrib_Intk = 5647,
  VCMPSSrmi = 5648,
  VCMPSSrmi_Int = 5649,
  VCMPSSrri = 5650,
  VCMPSSrri_Int = 5651,
  VCOMISDZrm = 5652,
  VCOMISDZrm_Int = 5653,
  VCOMISDZrr = 5654,
  VCOMISDZrr_Int = 5655,
  VCOMISDZrrb = 5656,
  VCOMISDrm = 5657,
  VCOMISDrm_Int = 5658,
  VCOMISDrr = 5659,
  VCOMISDrr_Int = 5660,
  VCOMISHZrm = 5661,
  VCOMISHZrm_Int = 5662,
  VCOMISHZrr = 5663,
  VCOMISHZrr_Int = 5664,
  VCOMISHZrrb = 5665,
  VCOMISSZrm = 5666,
  VCOMISSZrm_Int = 5667,
  VCOMISSZrr = 5668,
  VCOMISSZrr_Int = 5669,
  VCOMISSZrrb = 5670,
  VCOMISSrm = 5671,
  VCOMISSrm_Int = 5672,
  VCOMISSrr = 5673,
  VCOMISSrr_Int = 5674,
  VCOMPRESSPDZ128mr = 5675,
  VCOMPRESSPDZ128mrk = 5676,
  VCOMPRESSPDZ128rr = 5677,
  VCOMPRESSPDZ128rrk = 5678,
  VCOMPRESSPDZ128rrkz = 5679,
  VCOMPRESSPDZ256mr = 5680,
  VCOMPRESSPDZ256mrk = 5681,
  VCOMPRESSPDZ256rr = 5682,
  VCOMPRESSPDZ256rrk = 5683,
  VCOMPRESSPDZ256rrkz = 5684,
  VCOMPRESSPDZmr = 5685,
  VCOMPRESSPDZmrk = 5686,
  VCOMPRESSPDZrr = 5687,
  VCOMPRESSPDZrrk = 5688,
  VCOMPRESSPDZrrkz = 5689,
  VCOMPRESSPSZ128mr = 5690,
  VCOMPRESSPSZ128mrk = 5691,
  VCOMPRESSPSZ128rr = 5692,
  VCOMPRESSPSZ128rrk = 5693,
  VCOMPRESSPSZ128rrkz = 5694,
  VCOMPRESSPSZ256mr = 5695,
  VCOMPRESSPSZ256mrk = 5696,
  VCOMPRESSPSZ256rr = 5697,
  VCOMPRESSPSZ256rrk = 5698,
  VCOMPRESSPSZ256rrkz = 5699,
  VCOMPRESSPSZmr = 5700,
  VCOMPRESSPSZmrk = 5701,
  VCOMPRESSPSZrr = 5702,
  VCOMPRESSPSZrrk = 5703,
  VCOMPRESSPSZrrkz = 5704,
  VCVTDQ2PDYrm = 5705,
  VCVTDQ2PDYrr = 5706,
  VCVTDQ2PDZ128rm = 5707,
  VCVTDQ2PDZ128rmb = 5708,
  VCVTDQ2PDZ128rmbk = 5709,
  VCVTDQ2PDZ128rmbkz = 5710,
  VCVTDQ2PDZ128rmk = 5711,
  VCVTDQ2PDZ128rmkz = 5712,
  VCVTDQ2PDZ128rr = 5713,
  VCVTDQ2PDZ128rrk = 5714,
  VCVTDQ2PDZ128rrkz = 5715,
  VCVTDQ2PDZ256rm = 5716,
  VCVTDQ2PDZ256rmb = 5717,
  VCVTDQ2PDZ256rmbk = 5718,
  VCVTDQ2PDZ256rmbkz = 5719,
  VCVTDQ2PDZ256rmk = 5720,
  VCVTDQ2PDZ256rmkz = 5721,
  VCVTDQ2PDZ256rr = 5722,
  VCVTDQ2PDZ256rrk = 5723,
  VCVTDQ2PDZ256rrkz = 5724,
  VCVTDQ2PDZrm = 5725,
  VCVTDQ2PDZrmb = 5726,
  VCVTDQ2PDZrmbk = 5727,
  VCVTDQ2PDZrmbkz = 5728,
  VCVTDQ2PDZrmk = 5729,
  VCVTDQ2PDZrmkz = 5730,
  VCVTDQ2PDZrr = 5731,
  VCVTDQ2PDZrrk = 5732,
  VCVTDQ2PDZrrkz = 5733,
  VCVTDQ2PDrm = 5734,
  VCVTDQ2PDrr = 5735,
  VCVTDQ2PHZ128rm = 5736,
  VCVTDQ2PHZ128rmb = 5737,
  VCVTDQ2PHZ128rmbk = 5738,
  VCVTDQ2PHZ128rmbkz = 5739,
  VCVTDQ2PHZ128rmk = 5740,
  VCVTDQ2PHZ128rmkz = 5741,
  VCVTDQ2PHZ128rr = 5742,
  VCVTDQ2PHZ128rrk = 5743,
  VCVTDQ2PHZ128rrkz = 5744,
  VCVTDQ2PHZ256rm = 5745,
  VCVTDQ2PHZ256rmb = 5746,
  VCVTDQ2PHZ256rmbk = 5747,
  VCVTDQ2PHZ256rmbkz = 5748,
  VCVTDQ2PHZ256rmk = 5749,
  VCVTDQ2PHZ256rmkz = 5750,
  VCVTDQ2PHZ256rr = 5751,
  VCVTDQ2PHZ256rrk = 5752,
  VCVTDQ2PHZ256rrkz = 5753,
  VCVTDQ2PHZrm = 5754,
  VCVTDQ2PHZrmb = 5755,
  VCVTDQ2PHZrmbk = 5756,
  VCVTDQ2PHZrmbkz = 5757,
  VCVTDQ2PHZrmk = 5758,
  VCVTDQ2PHZrmkz = 5759,
  VCVTDQ2PHZrr = 5760,
  VCVTDQ2PHZrrb = 5761,
  VCVTDQ2PHZrrbk = 5762,
  VCVTDQ2PHZrrbkz = 5763,
  VCVTDQ2PHZrrk = 5764,
  VCVTDQ2PHZrrkz = 5765,
  VCVTDQ2PSYrm = 5766,
  VCVTDQ2PSYrr = 5767,
  VCVTDQ2PSZ128rm = 5768,
  VCVTDQ2PSZ128rmb = 5769,
  VCVTDQ2PSZ128rmbk = 5770,
  VCVTDQ2PSZ128rmbkz = 5771,
  VCVTDQ2PSZ128rmk = 5772,
  VCVTDQ2PSZ128rmkz = 5773,
  VCVTDQ2PSZ128rr = 5774,
  VCVTDQ2PSZ128rrk = 5775,
  VCVTDQ2PSZ128rrkz = 5776,
  VCVTDQ2PSZ256rm = 5777,
  VCVTDQ2PSZ256rmb = 5778,
  VCVTDQ2PSZ256rmbk = 5779,
  VCVTDQ2PSZ256rmbkz = 5780,
  VCVTDQ2PSZ256rmk = 5781,
  VCVTDQ2PSZ256rmkz = 5782,
  VCVTDQ2PSZ256rr = 5783,
  VCVTDQ2PSZ256rrk = 5784,
  VCVTDQ2PSZ256rrkz = 5785,
  VCVTDQ2PSZrm = 5786,
  VCVTDQ2PSZrmb = 5787,
  VCVTDQ2PSZrmbk = 5788,
  VCVTDQ2PSZrmbkz = 5789,
  VCVTDQ2PSZrmk = 5790,
  VCVTDQ2PSZrmkz = 5791,
  VCVTDQ2PSZrr = 5792,
  VCVTDQ2PSZrrb = 5793,
  VCVTDQ2PSZrrbk = 5794,
  VCVTDQ2PSZrrbkz = 5795,
  VCVTDQ2PSZrrk = 5796,
  VCVTDQ2PSZrrkz = 5797,
  VCVTDQ2PSrm = 5798,
  VCVTDQ2PSrr = 5799,
  VCVTNE2PS2BF16Z128rm = 5800,
  VCVTNE2PS2BF16Z128rmb = 5801,
  VCVTNE2PS2BF16Z128rmbk = 5802,
  VCVTNE2PS2BF16Z128rmbkz = 5803,
  VCVTNE2PS2BF16Z128rmk = 5804,
  VCVTNE2PS2BF16Z128rmkz = 5805,
  VCVTNE2PS2BF16Z128rr = 5806,
  VCVTNE2PS2BF16Z128rrk = 5807,
  VCVTNE2PS2BF16Z128rrkz = 5808,
  VCVTNE2PS2BF16Z256rm = 5809,
  VCVTNE2PS2BF16Z256rmb = 5810,
  VCVTNE2PS2BF16Z256rmbk = 5811,
  VCVTNE2PS2BF16Z256rmbkz = 5812,
  VCVTNE2PS2BF16Z256rmk = 5813,
  VCVTNE2PS2BF16Z256rmkz = 5814,
  VCVTNE2PS2BF16Z256rr = 5815,
  VCVTNE2PS2BF16Z256rrk = 5816,
  VCVTNE2PS2BF16Z256rrkz = 5817,
  VCVTNE2PS2BF16Zrm = 5818,
  VCVTNE2PS2BF16Zrmb = 5819,
  VCVTNE2PS2BF16Zrmbk = 5820,
  VCVTNE2PS2BF16Zrmbkz = 5821,
  VCVTNE2PS2BF16Zrmk = 5822,
  VCVTNE2PS2BF16Zrmkz = 5823,
  VCVTNE2PS2BF16Zrr = 5824,
  VCVTNE2PS2BF16Zrrk = 5825,
  VCVTNE2PS2BF16Zrrkz = 5826,
  VCVTNEEBF162PSYrm = 5827,
  VCVTNEEBF162PSrm = 5828,
  VCVTNEEPH2PSYrm = 5829,
  VCVTNEEPH2PSrm = 5830,
  VCVTNEOBF162PSYrm = 5831,
  VCVTNEOBF162PSrm = 5832,
  VCVTNEOPH2PSYrm = 5833,
  VCVTNEOPH2PSrm = 5834,
  VCVTNEPS2BF16Yrm = 5835,
  VCVTNEPS2BF16Yrr = 5836,
  VCVTNEPS2BF16Z128rm = 5837,
  VCVTNEPS2BF16Z128rmb = 5838,
  VCVTNEPS2BF16Z128rmbk = 5839,
  VCVTNEPS2BF16Z128rmbkz = 5840,
  VCVTNEPS2BF16Z128rmk = 5841,
  VCVTNEPS2BF16Z128rmkz = 5842,
  VCVTNEPS2BF16Z128rr = 5843,
  VCVTNEPS2BF16Z128rrk = 5844,
  VCVTNEPS2BF16Z128rrkz = 5845,
  VCVTNEPS2BF16Z256rm = 5846,
  VCVTNEPS2BF16Z256rmb = 5847,
  VCVTNEPS2BF16Z256rmbk = 5848,
  VCVTNEPS2BF16Z256rmbkz = 5849,
  VCVTNEPS2BF16Z256rmk = 5850,
  VCVTNEPS2BF16Z256rmkz = 5851,
  VCVTNEPS2BF16Z256rr = 5852,
  VCVTNEPS2BF16Z256rrk = 5853,
  VCVTNEPS2BF16Z256rrkz = 5854,
  VCVTNEPS2BF16Zrm = 5855,
  VCVTNEPS2BF16Zrmb = 5856,
  VCVTNEPS2BF16Zrmbk = 5857,
  VCVTNEPS2BF16Zrmbkz = 5858,
  VCVTNEPS2BF16Zrmk = 5859,
  VCVTNEPS2BF16Zrmkz = 5860,
  VCVTNEPS2BF16Zrr = 5861,
  VCVTNEPS2BF16Zrrk = 5862,
  VCVTNEPS2BF16Zrrkz = 5863,
  VCVTNEPS2BF16rm = 5864,
  VCVTNEPS2BF16rr = 5865,
  VCVTPD2DQYrm = 5866,
  VCVTPD2DQYrr = 5867,
  VCVTPD2DQZ128rm = 5868,
  VCVTPD2DQZ128rmb = 5869,
  VCVTPD2DQZ128rmbk = 5870,
  VCVTPD2DQZ128rmbkz = 5871,
  VCVTPD2DQZ128rmk = 5872,
  VCVTPD2DQZ128rmkz = 5873,
  VCVTPD2DQZ128rr = 5874,
  VCVTPD2DQZ128rrk = 5875,
  VCVTPD2DQZ128rrkz = 5876,
  VCVTPD2DQZ256rm = 5877,
  VCVTPD2DQZ256rmb = 5878,
  VCVTPD2DQZ256rmbk = 5879,
  VCVTPD2DQZ256rmbkz = 5880,
  VCVTPD2DQZ256rmk = 5881,
  VCVTPD2DQZ256rmkz = 5882,
  VCVTPD2DQZ256rr = 5883,
  VCVTPD2DQZ256rrk = 5884,
  VCVTPD2DQZ256rrkz = 5885,
  VCVTPD2DQZrm = 5886,
  VCVTPD2DQZrmb = 5887,
  VCVTPD2DQZrmbk = 5888,
  VCVTPD2DQZrmbkz = 5889,
  VCVTPD2DQZrmk = 5890,
  VCVTPD2DQZrmkz = 5891,
  VCVTPD2DQZrr = 5892,
  VCVTPD2DQZrrb = 5893,
  VCVTPD2DQZrrbk = 5894,
  VCVTPD2DQZrrbkz = 5895,
  VCVTPD2DQZrrk = 5896,
  VCVTPD2DQZrrkz = 5897,
  VCVTPD2DQrm = 5898,
  VCVTPD2DQrr = 5899,
  VCVTPD2PHZ128rm = 5900,
  VCVTPD2PHZ128rmb = 5901,
  VCVTPD2PHZ128rmbk = 5902,
  VCVTPD2PHZ128rmbkz = 5903,
  VCVTPD2PHZ128rmk = 5904,
  VCVTPD2PHZ128rmkz = 5905,
  VCVTPD2PHZ128rr = 5906,
  VCVTPD2PHZ128rrk = 5907,
  VCVTPD2PHZ128rrkz = 5908,
  VCVTPD2PHZ256rm = 5909,
  VCVTPD2PHZ256rmb = 5910,
  VCVTPD2PHZ256rmbk = 5911,
  VCVTPD2PHZ256rmbkz = 5912,
  VCVTPD2PHZ256rmk = 5913,
  VCVTPD2PHZ256rmkz = 5914,
  VCVTPD2PHZ256rr = 5915,
  VCVTPD2PHZ256rrk = 5916,
  VCVTPD2PHZ256rrkz = 5917,
  VCVTPD2PHZrm = 5918,
  VCVTPD2PHZrmb = 5919,
  VCVTPD2PHZrmbk = 5920,
  VCVTPD2PHZrmbkz = 5921,
  VCVTPD2PHZrmk = 5922,
  VCVTPD2PHZrmkz = 5923,
  VCVTPD2PHZrr = 5924,
  VCVTPD2PHZrrb = 5925,
  VCVTPD2PHZrrbk = 5926,
  VCVTPD2PHZrrbkz = 5927,
  VCVTPD2PHZrrk = 5928,
  VCVTPD2PHZrrkz = 5929,
  VCVTPD2PSYrm = 5930,
  VCVTPD2PSYrr = 5931,
  VCVTPD2PSZ128rm = 5932,
  VCVTPD2PSZ128rmb = 5933,
  VCVTPD2PSZ128rmbk = 5934,
  VCVTPD2PSZ128rmbkz = 5935,
  VCVTPD2PSZ128rmk = 5936,
  VCVTPD2PSZ128rmkz = 5937,
  VCVTPD2PSZ128rr = 5938,
  VCVTPD2PSZ128rrk = 5939,
  VCVTPD2PSZ128rrkz = 5940,
  VCVTPD2PSZ256rm = 5941,
  VCVTPD2PSZ256rmb = 5942,
  VCVTPD2PSZ256rmbk = 5943,
  VCVTPD2PSZ256rmbkz = 5944,
  VCVTPD2PSZ256rmk = 5945,
  VCVTPD2PSZ256rmkz = 5946,
  VCVTPD2PSZ256rr = 5947,
  VCVTPD2PSZ256rrk = 5948,
  VCVTPD2PSZ256rrkz = 5949,
  VCVTPD2PSZrm = 5950,
  VCVTPD2PSZrmb = 5951,
  VCVTPD2PSZrmbk = 5952,
  VCVTPD2PSZrmbkz = 5953,
  VCVTPD2PSZrmk = 5954,
  VCVTPD2PSZrmkz = 5955,
  VCVTPD2PSZrr = 5956,
  VCVTPD2PSZrrb = 5957,
  VCVTPD2PSZrrbk = 5958,
  VCVTPD2PSZrrbkz = 5959,
  VCVTPD2PSZrrk = 5960,
  VCVTPD2PSZrrkz = 5961,
  VCVTPD2PSrm = 5962,
  VCVTPD2PSrr = 5963,
  VCVTPD2QQZ128rm = 5964,
  VCVTPD2QQZ128rmb = 5965,
  VCVTPD2QQZ128rmbk = 5966,
  VCVTPD2QQZ128rmbkz = 5967,
  VCVTPD2QQZ128rmk = 5968,
  VCVTPD2QQZ128rmkz = 5969,
  VCVTPD2QQZ128rr = 5970,
  VCVTPD2QQZ128rrk = 5971,
  VCVTPD2QQZ128rrkz = 5972,
  VCVTPD2QQZ256rm = 5973,
  VCVTPD2QQZ256rmb = 5974,
  VCVTPD2QQZ256rmbk = 5975,
  VCVTPD2QQZ256rmbkz = 5976,
  VCVTPD2QQZ256rmk = 5977,
  VCVTPD2QQZ256rmkz = 5978,
  VCVTPD2QQZ256rr = 5979,
  VCVTPD2QQZ256rrk = 5980,
  VCVTPD2QQZ256rrkz = 5981,
  VCVTPD2QQZrm = 5982,
  VCVTPD2QQZrmb = 5983,
  VCVTPD2QQZrmbk = 5984,
  VCVTPD2QQZrmbkz = 5985,
  VCVTPD2QQZrmk = 5986,
  VCVTPD2QQZrmkz = 5987,
  VCVTPD2QQZrr = 5988,
  VCVTPD2QQZrrb = 5989,
  VCVTPD2QQZrrbk = 5990,
  VCVTPD2QQZrrbkz = 5991,
  VCVTPD2QQZrrk = 5992,
  VCVTPD2QQZrrkz = 5993,
  VCVTPD2UDQZ128rm = 5994,
  VCVTPD2UDQZ128rmb = 5995,
  VCVTPD2UDQZ128rmbk = 5996,
  VCVTPD2UDQZ128rmbkz = 5997,
  VCVTPD2UDQZ128rmk = 5998,
  VCVTPD2UDQZ128rmkz = 5999,
  VCVTPD2UDQZ128rr = 6000,
  VCVTPD2UDQZ128rrk = 6001,
  VCVTPD2UDQZ128rrkz = 6002,
  VCVTPD2UDQZ256rm = 6003,
  VCVTPD2UDQZ256rmb = 6004,
  VCVTPD2UDQZ256rmbk = 6005,
  VCVTPD2UDQZ256rmbkz = 6006,
  VCVTPD2UDQZ256rmk = 6007,
  VCVTPD2UDQZ256rmkz = 6008,
  VCVTPD2UDQZ256rr = 6009,
  VCVTPD2UDQZ256rrk = 6010,
  VCVTPD2UDQZ256rrkz = 6011,
  VCVTPD2UDQZrm = 6012,
  VCVTPD2UDQZrmb = 6013,
  VCVTPD2UDQZrmbk = 6014,
  VCVTPD2UDQZrmbkz = 6015,
  VCVTPD2UDQZrmk = 6016,
  VCVTPD2UDQZrmkz = 6017,
  VCVTPD2UDQZrr = 6018,
  VCVTPD2UDQZrrb = 6019,
  VCVTPD2UDQZrrbk = 6020,
  VCVTPD2UDQZrrbkz = 6021,
  VCVTPD2UDQZrrk = 6022,
  VCVTPD2UDQZrrkz = 6023,
  VCVTPD2UQQZ128rm = 6024,
  VCVTPD2UQQZ128rmb = 6025,
  VCVTPD2UQQZ128rmbk = 6026,
  VCVTPD2UQQZ128rmbkz = 6027,
  VCVTPD2UQQZ128rmk = 6028,
  VCVTPD2UQQZ128rmkz = 6029,
  VCVTPD2UQQZ128rr = 6030,
  VCVTPD2UQQZ128rrk = 6031,
  VCVTPD2UQQZ128rrkz = 6032,
  VCVTPD2UQQZ256rm = 6033,
  VCVTPD2UQQZ256rmb = 6034,
  VCVTPD2UQQZ256rmbk = 6035,
  VCVTPD2UQQZ256rmbkz = 6036,
  VCVTPD2UQQZ256rmk = 6037,
  VCVTPD2UQQZ256rmkz = 6038,
  VCVTPD2UQQZ256rr = 6039,
  VCVTPD2UQQZ256rrk = 6040,
  VCVTPD2UQQZ256rrkz = 6041,
  VCVTPD2UQQZrm = 6042,
  VCVTPD2UQQZrmb = 6043,
  VCVTPD2UQQZrmbk = 6044,
  VCVTPD2UQQZrmbkz = 6045,
  VCVTPD2UQQZrmk = 6046,
  VCVTPD2UQQZrmkz = 6047,
  VCVTPD2UQQZrr = 6048,
  VCVTPD2UQQZrrb = 6049,
  VCVTPD2UQQZrrbk = 6050,
  VCVTPD2UQQZrrbkz = 6051,
  VCVTPD2UQQZrrk = 6052,
  VCVTPD2UQQZrrkz = 6053,
  VCVTPH2DQZ128rm = 6054,
  VCVTPH2DQZ128rmb = 6055,
  VCVTPH2DQZ128rmbk = 6056,
  VCVTPH2DQZ128rmbkz = 6057,
  VCVTPH2DQZ128rmk = 6058,
  VCVTPH2DQZ128rmkz = 6059,
  VCVTPH2DQZ128rr = 6060,
  VCVTPH2DQZ128rrk = 6061,
  VCVTPH2DQZ128rrkz = 6062,
  VCVTPH2DQZ256rm = 6063,
  VCVTPH2DQZ256rmb = 6064,
  VCVTPH2DQZ256rmbk = 6065,
  VCVTPH2DQZ256rmbkz = 6066,
  VCVTPH2DQZ256rmk = 6067,
  VCVTPH2DQZ256rmkz = 6068,
  VCVTPH2DQZ256rr = 6069,
  VCVTPH2DQZ256rrk = 6070,
  VCVTPH2DQZ256rrkz = 6071,
  VCVTPH2DQZrm = 6072,
  VCVTPH2DQZrmb = 6073,
  VCVTPH2DQZrmbk = 6074,
  VCVTPH2DQZrmbkz = 6075,
  VCVTPH2DQZrmk = 6076,
  VCVTPH2DQZrmkz = 6077,
  VCVTPH2DQZrr = 6078,
  VCVTPH2DQZrrb = 6079,
  VCVTPH2DQZrrbk = 6080,
  VCVTPH2DQZrrbkz = 6081,
  VCVTPH2DQZrrk = 6082,
  VCVTPH2DQZrrkz = 6083,
  VCVTPH2PDZ128rm = 6084,
  VCVTPH2PDZ128rmb = 6085,
  VCVTPH2PDZ128rmbk = 6086,
  VCVTPH2PDZ128rmbkz = 6087,
  VCVTPH2PDZ128rmk = 6088,
  VCVTPH2PDZ128rmkz = 6089,
  VCVTPH2PDZ128rr = 6090,
  VCVTPH2PDZ128rrk = 6091,
  VCVTPH2PDZ128rrkz = 6092,
  VCVTPH2PDZ256rm = 6093,
  VCVTPH2PDZ256rmb = 6094,
  VCVTPH2PDZ256rmbk = 6095,
  VCVTPH2PDZ256rmbkz = 6096,
  VCVTPH2PDZ256rmk = 6097,
  VCVTPH2PDZ256rmkz = 6098,
  VCVTPH2PDZ256rr = 6099,
  VCVTPH2PDZ256rrk = 6100,
  VCVTPH2PDZ256rrkz = 6101,
  VCVTPH2PDZrm = 6102,
  VCVTPH2PDZrmb = 6103,
  VCVTPH2PDZrmbk = 6104,
  VCVTPH2PDZrmbkz = 6105,
  VCVTPH2PDZrmk = 6106,
  VCVTPH2PDZrmkz = 6107,
  VCVTPH2PDZrr = 6108,
  VCVTPH2PDZrrb = 6109,
  VCVTPH2PDZrrbk = 6110,
  VCVTPH2PDZrrbkz = 6111,
  VCVTPH2PDZrrk = 6112,
  VCVTPH2PDZrrkz = 6113,
  VCVTPH2PSXZ128rm = 6114,
  VCVTPH2PSXZ128rmb = 6115,
  VCVTPH2PSXZ128rmbk = 6116,
  VCVTPH2PSXZ128rmbkz = 6117,
  VCVTPH2PSXZ128rmk = 6118,
  VCVTPH2PSXZ128rmkz = 6119,
  VCVTPH2PSXZ128rr = 6120,
  VCVTPH2PSXZ128rrk = 6121,
  VCVTPH2PSXZ128rrkz = 6122,
  VCVTPH2PSXZ256rm = 6123,
  VCVTPH2PSXZ256rmb = 6124,
  VCVTPH2PSXZ256rmbk = 6125,
  VCVTPH2PSXZ256rmbkz = 6126,
  VCVTPH2PSXZ256rmk = 6127,
  VCVTPH2PSXZ256rmkz = 6128,
  VCVTPH2PSXZ256rr = 6129,
  VCVTPH2PSXZ256rrk = 6130,
  VCVTPH2PSXZ256rrkz = 6131,
  VCVTPH2PSXZrm = 6132,
  VCVTPH2PSXZrmb = 6133,
  VCVTPH2PSXZrmbk = 6134,
  VCVTPH2PSXZrmbkz = 6135,
  VCVTPH2PSXZrmk = 6136,
  VCVTPH2PSXZrmkz = 6137,
  VCVTPH2PSXZrr = 6138,
  VCVTPH2PSXZrrb = 6139,
  VCVTPH2PSXZrrbk = 6140,
  VCVTPH2PSXZrrbkz = 6141,
  VCVTPH2PSXZrrk = 6142,
  VCVTPH2PSXZrrkz = 6143,
  VCVTPH2PSYrm = 6144,
  VCVTPH2PSYrr = 6145,
  VCVTPH2PSZ128rm = 6146,
  VCVTPH2PSZ128rmk = 6147,
  VCVTPH2PSZ128rmkz = 6148,
  VCVTPH2PSZ128rr = 6149,
  VCVTPH2PSZ128rrk = 6150,
  VCVTPH2PSZ128rrkz = 6151,
  VCVTPH2PSZ256rm = 6152,
  VCVTPH2PSZ256rmk = 6153,
  VCVTPH2PSZ256rmkz = 6154,
  VCVTPH2PSZ256rr = 6155,
  VCVTPH2PSZ256rrk = 6156,
  VCVTPH2PSZ256rrkz = 6157,
  VCVTPH2PSZrm = 6158,
  VCVTPH2PSZrmk = 6159,
  VCVTPH2PSZrmkz = 6160,
  VCVTPH2PSZrr = 6161,
  VCVTPH2PSZrrb = 6162,
  VCVTPH2PSZrrbk = 6163,
  VCVTPH2PSZrrbkz = 6164,
  VCVTPH2PSZrrk = 6165,
  VCVTPH2PSZrrkz = 6166,
  VCVTPH2PSrm = 6167,
  VCVTPH2PSrr = 6168,
  VCVTPH2QQZ128rm = 6169,
  VCVTPH2QQZ128rmb = 6170,
  VCVTPH2QQZ128rmbk = 6171,
  VCVTPH2QQZ128rmbkz = 6172,
  VCVTPH2QQZ128rmk = 6173,
  VCVTPH2QQZ128rmkz = 6174,
  VCVTPH2QQZ128rr = 6175,
  VCVTPH2QQZ128rrk = 6176,
  VCVTPH2QQZ128rrkz = 6177,
  VCVTPH2QQZ256rm = 6178,
  VCVTPH2QQZ256rmb = 6179,
  VCVTPH2QQZ256rmbk = 6180,
  VCVTPH2QQZ256rmbkz = 6181,
  VCVTPH2QQZ256rmk = 6182,
  VCVTPH2QQZ256rmkz = 6183,
  VCVTPH2QQZ256rr = 6184,
  VCVTPH2QQZ256rrk = 6185,
  VCVTPH2QQZ256rrkz = 6186,
  VCVTPH2QQZrm = 6187,
  VCVTPH2QQZrmb = 6188,
  VCVTPH2QQZrmbk = 6189,
  VCVTPH2QQZrmbkz = 6190,
  VCVTPH2QQZrmk = 6191,
  VCVTPH2QQZrmkz = 6192,
  VCVTPH2QQZrr = 6193,
  VCVTPH2QQZrrb = 6194,
  VCVTPH2QQZrrbk = 6195,
  VCVTPH2QQZrrbkz = 6196,
  VCVTPH2QQZrrk = 6197,
  VCVTPH2QQZrrkz = 6198,
  VCVTPH2UDQZ128rm = 6199,
  VCVTPH2UDQZ128rmb = 6200,
  VCVTPH2UDQZ128rmbk = 6201,
  VCVTPH2UDQZ128rmbkz = 6202,
  VCVTPH2UDQZ128rmk = 6203,
  VCVTPH2UDQZ128rmkz = 6204,
  VCVTPH2UDQZ128rr = 6205,
  VCVTPH2UDQZ128rrk = 6206,
  VCVTPH2UDQZ128rrkz = 6207,
  VCVTPH2UDQZ256rm = 6208,
  VCVTPH2UDQZ256rmb = 6209,
  VCVTPH2UDQZ256rmbk = 6210,
  VCVTPH2UDQZ256rmbkz = 6211,
  VCVTPH2UDQZ256rmk = 6212,
  VCVTPH2UDQZ256rmkz = 6213,
  VCVTPH2UDQZ256rr = 6214,
  VCVTPH2UDQZ256rrk = 6215,
  VCVTPH2UDQZ256rrkz = 6216,
  VCVTPH2UDQZrm = 6217,
  VCVTPH2UDQZrmb = 6218,
  VCVTPH2UDQZrmbk = 6219,
  VCVTPH2UDQZrmbkz = 6220,
  VCVTPH2UDQZrmk = 6221,
  VCVTPH2UDQZrmkz = 6222,
  VCVTPH2UDQZrr = 6223,
  VCVTPH2UDQZrrb = 6224,
  VCVTPH2UDQZrrbk = 6225,
  VCVTPH2UDQZrrbkz = 6226,
  VCVTPH2UDQZrrk = 6227,
  VCVTPH2UDQZrrkz = 6228,
  VCVTPH2UQQZ128rm = 6229,
  VCVTPH2UQQZ128rmb = 6230,
  VCVTPH2UQQZ128rmbk = 6231,
  VCVTPH2UQQZ128rmbkz = 6232,
  VCVTPH2UQQZ128rmk = 6233,
  VCVTPH2UQQZ128rmkz = 6234,
  VCVTPH2UQQZ128rr = 6235,
  VCVTPH2UQQZ128rrk = 6236,
  VCVTPH2UQQZ128rrkz = 6237,
  VCVTPH2UQQZ256rm = 6238,
  VCVTPH2UQQZ256rmb = 6239,
  VCVTPH2UQQZ256rmbk = 6240,
  VCVTPH2UQQZ256rmbkz = 6241,
  VCVTPH2UQQZ256rmk = 6242,
  VCVTPH2UQQZ256rmkz = 6243,
  VCVTPH2UQQZ256rr = 6244,
  VCVTPH2UQQZ256rrk = 6245,
  VCVTPH2UQQZ256rrkz = 6246,
  VCVTPH2UQQZrm = 6247,
  VCVTPH2UQQZrmb = 6248,
  VCVTPH2UQQZrmbk = 6249,
  VCVTPH2UQQZrmbkz = 6250,
  VCVTPH2UQQZrmk = 6251,
  VCVTPH2UQQZrmkz = 6252,
  VCVTPH2UQQZrr = 6253,
  VCVTPH2UQQZrrb = 6254,
  VCVTPH2UQQZrrbk = 6255,
  VCVTPH2UQQZrrbkz = 6256,
  VCVTPH2UQQZrrk = 6257,
  VCVTPH2UQQZrrkz = 6258,
  VCVTPH2UWZ128rm = 6259,
  VCVTPH2UWZ128rmb = 6260,
  VCVTPH2UWZ128rmbk = 6261,
  VCVTPH2UWZ128rmbkz = 6262,
  VCVTPH2UWZ128rmk = 6263,
  VCVTPH2UWZ128rmkz = 6264,
  VCVTPH2UWZ128rr = 6265,
  VCVTPH2UWZ128rrk = 6266,
  VCVTPH2UWZ128rrkz = 6267,
  VCVTPH2UWZ256rm = 6268,
  VCVTPH2UWZ256rmb = 6269,
  VCVTPH2UWZ256rmbk = 6270,
  VCVTPH2UWZ256rmbkz = 6271,
  VCVTPH2UWZ256rmk = 6272,
  VCVTPH2UWZ256rmkz = 6273,
  VCVTPH2UWZ256rr = 6274,
  VCVTPH2UWZ256rrk = 6275,
  VCVTPH2UWZ256rrkz = 6276,
  VCVTPH2UWZrm = 6277,
  VCVTPH2UWZrmb = 6278,
  VCVTPH2UWZrmbk = 6279,
  VCVTPH2UWZrmbkz = 6280,
  VCVTPH2UWZrmk = 6281,
  VCVTPH2UWZrmkz = 6282,
  VCVTPH2UWZrr = 6283,
  VCVTPH2UWZrrb = 6284,
  VCVTPH2UWZrrbk = 6285,
  VCVTPH2UWZrrbkz = 6286,
  VCVTPH2UWZrrk = 6287,
  VCVTPH2UWZrrkz = 6288,
  VCVTPH2WZ128rm = 6289,
  VCVTPH2WZ128rmb = 6290,
  VCVTPH2WZ128rmbk = 6291,
  VCVTPH2WZ128rmbkz = 6292,
  VCVTPH2WZ128rmk = 6293,
  VCVTPH2WZ128rmkz = 6294,
  VCVTPH2WZ128rr = 6295,
  VCVTPH2WZ128rrk = 6296,
  VCVTPH2WZ128rrkz = 6297,
  VCVTPH2WZ256rm = 6298,
  VCVTPH2WZ256rmb = 6299,
  VCVTPH2WZ256rmbk = 6300,
  VCVTPH2WZ256rmbkz = 6301,
  VCVTPH2WZ256rmk = 6302,
  VCVTPH2WZ256rmkz = 6303,
  VCVTPH2WZ256rr = 6304,
  VCVTPH2WZ256rrk = 6305,
  VCVTPH2WZ256rrkz = 6306,
  VCVTPH2WZrm = 6307,
  VCVTPH2WZrmb = 6308,
  VCVTPH2WZrmbk = 6309,
  VCVTPH2WZrmbkz = 6310,
  VCVTPH2WZrmk = 6311,
  VCVTPH2WZrmkz = 6312,
  VCVTPH2WZrr = 6313,
  VCVTPH2WZrrb = 6314,
  VCVTPH2WZrrbk = 6315,
  VCVTPH2WZrrbkz = 6316,
  VCVTPH2WZrrk = 6317,
  VCVTPH2WZrrkz = 6318,
  VCVTPS2DQYrm = 6319,
  VCVTPS2DQYrr = 6320,
  VCVTPS2DQZ128rm = 6321,
  VCVTPS2DQZ128rmb = 6322,
  VCVTPS2DQZ128rmbk = 6323,
  VCVTPS2DQZ128rmbkz = 6324,
  VCVTPS2DQZ128rmk = 6325,
  VCVTPS2DQZ128rmkz = 6326,
  VCVTPS2DQZ128rr = 6327,
  VCVTPS2DQZ128rrk = 6328,
  VCVTPS2DQZ128rrkz = 6329,
  VCVTPS2DQZ256rm = 6330,
  VCVTPS2DQZ256rmb = 6331,
  VCVTPS2DQZ256rmbk = 6332,
  VCVTPS2DQZ256rmbkz = 6333,
  VCVTPS2DQZ256rmk = 6334,
  VCVTPS2DQZ256rmkz = 6335,
  VCVTPS2DQZ256rr = 6336,
  VCVTPS2DQZ256rrk = 6337,
  VCVTPS2DQZ256rrkz = 6338,
  VCVTPS2DQZrm = 6339,
  VCVTPS2DQZrmb = 6340,
  VCVTPS2DQZrmbk = 6341,
  VCVTPS2DQZrmbkz = 6342,
  VCVTPS2DQZrmk = 6343,
  VCVTPS2DQZrmkz = 6344,
  VCVTPS2DQZrr = 6345,
  VCVTPS2DQZrrb = 6346,
  VCVTPS2DQZrrbk = 6347,
  VCVTPS2DQZrrbkz = 6348,
  VCVTPS2DQZrrk = 6349,
  VCVTPS2DQZrrkz = 6350,
  VCVTPS2DQrm = 6351,
  VCVTPS2DQrr = 6352,
  VCVTPS2PDYrm = 6353,
  VCVTPS2PDYrr = 6354,
  VCVTPS2PDZ128rm = 6355,
  VCVTPS2PDZ128rmb = 6356,
  VCVTPS2PDZ128rmbk = 6357,
  VCVTPS2PDZ128rmbkz = 6358,
  VCVTPS2PDZ128rmk = 6359,
  VCVTPS2PDZ128rmkz = 6360,
  VCVTPS2PDZ128rr = 6361,
  VCVTPS2PDZ128rrk = 6362,
  VCVTPS2PDZ128rrkz = 6363,
  VCVTPS2PDZ256rm = 6364,
  VCVTPS2PDZ256rmb = 6365,
  VCVTPS2PDZ256rmbk = 6366,
  VCVTPS2PDZ256rmbkz = 6367,
  VCVTPS2PDZ256rmk = 6368,
  VCVTPS2PDZ256rmkz = 6369,
  VCVTPS2PDZ256rr = 6370,
  VCVTPS2PDZ256rrk = 6371,
  VCVTPS2PDZ256rrkz = 6372,
  VCVTPS2PDZrm = 6373,
  VCVTPS2PDZrmb = 6374,
  VCVTPS2PDZrmbk = 6375,
  VCVTPS2PDZrmbkz = 6376,
  VCVTPS2PDZrmk = 6377,
  VCVTPS2PDZrmkz = 6378,
  VCVTPS2PDZrr = 6379,
  VCVTPS2PDZrrb = 6380,
  VCVTPS2PDZrrbk = 6381,
  VCVTPS2PDZrrbkz = 6382,
  VCVTPS2PDZrrk = 6383,
  VCVTPS2PDZrrkz = 6384,
  VCVTPS2PDrm = 6385,
  VCVTPS2PDrr = 6386,
  VCVTPS2PHXZ128rm = 6387,
  VCVTPS2PHXZ128rmb = 6388,
  VCVTPS2PHXZ128rmbk = 6389,
  VCVTPS2PHXZ128rmbkz = 6390,
  VCVTPS2PHXZ128rmk = 6391,
  VCVTPS2PHXZ128rmkz = 6392,
  VCVTPS2PHXZ128rr = 6393,
  VCVTPS2PHXZ128rrk = 6394,
  VCVTPS2PHXZ128rrkz = 6395,
  VCVTPS2PHXZ256rm = 6396,
  VCVTPS2PHXZ256rmb = 6397,
  VCVTPS2PHXZ256rmbk = 6398,
  VCVTPS2PHXZ256rmbkz = 6399,
  VCVTPS2PHXZ256rmk = 6400,
  VCVTPS2PHXZ256rmkz = 6401,
  VCVTPS2PHXZ256rr = 6402,
  VCVTPS2PHXZ256rrk = 6403,
  VCVTPS2PHXZ256rrkz = 6404,
  VCVTPS2PHXZrm = 6405,
  VCVTPS2PHXZrmb = 6406,
  VCVTPS2PHXZrmbk = 6407,
  VCVTPS2PHXZrmbkz = 6408,
  VCVTPS2PHXZrmk = 6409,
  VCVTPS2PHXZrmkz = 6410,
  VCVTPS2PHXZrr = 6411,
  VCVTPS2PHXZrrb = 6412,
  VCVTPS2PHXZrrbk = 6413,
  VCVTPS2PHXZrrbkz = 6414,
  VCVTPS2PHXZrrk = 6415,
  VCVTPS2PHXZrrkz = 6416,
  VCVTPS2PHYmr = 6417,
  VCVTPS2PHYrr = 6418,
  VCVTPS2PHZ128mr = 6419,
  VCVTPS2PHZ128mrk = 6420,
  VCVTPS2PHZ128rr = 6421,
  VCVTPS2PHZ128rrk = 6422,
  VCVTPS2PHZ128rrkz = 6423,
  VCVTPS2PHZ256mr = 6424,
  VCVTPS2PHZ256mrk = 6425,
  VCVTPS2PHZ256rr = 6426,
  VCVTPS2PHZ256rrk = 6427,
  VCVTPS2PHZ256rrkz = 6428,
  VCVTPS2PHZmr = 6429,
  VCVTPS2PHZmrk = 6430,
  VCVTPS2PHZrr = 6431,
  VCVTPS2PHZrrb = 6432,
  VCVTPS2PHZrrbk = 6433,
  VCVTPS2PHZrrbkz = 6434,
  VCVTPS2PHZrrk = 6435,
  VCVTPS2PHZrrkz = 6436,
  VCVTPS2PHmr = 6437,
  VCVTPS2PHrr = 6438,
  VCVTPS2QQZ128rm = 6439,
  VCVTPS2QQZ128rmb = 6440,
  VCVTPS2QQZ128rmbk = 6441,
  VCVTPS2QQZ128rmbkz = 6442,
  VCVTPS2QQZ128rmk = 6443,
  VCVTPS2QQZ128rmkz = 6444,
  VCVTPS2QQZ128rr = 6445,
  VCVTPS2QQZ128rrk = 6446,
  VCVTPS2QQZ128rrkz = 6447,
  VCVTPS2QQZ256rm = 6448,
  VCVTPS2QQZ256rmb = 6449,
  VCVTPS2QQZ256rmbk = 6450,
  VCVTPS2QQZ256rmbkz = 6451,
  VCVTPS2QQZ256rmk = 6452,
  VCVTPS2QQZ256rmkz = 6453,
  VCVTPS2QQZ256rr = 6454,
  VCVTPS2QQZ256rrk = 6455,
  VCVTPS2QQZ256rrkz = 6456,
  VCVTPS2QQZrm = 6457,
  VCVTPS2QQZrmb = 6458,
  VCVTPS2QQZrmbk = 6459,
  VCVTPS2QQZrmbkz = 6460,
  VCVTPS2QQZrmk = 6461,
  VCVTPS2QQZrmkz = 6462,
  VCVTPS2QQZrr = 6463,
  VCVTPS2QQZrrb = 6464,
  VCVTPS2QQZrrbk = 6465,
  VCVTPS2QQZrrbkz = 6466,
  VCVTPS2QQZrrk = 6467,
  VCVTPS2QQZrrkz = 6468,
  VCVTPS2UDQZ128rm = 6469,
  VCVTPS2UDQZ128rmb = 6470,
  VCVTPS2UDQZ128rmbk = 6471,
  VCVTPS2UDQZ128rmbkz = 6472,
  VCVTPS2UDQZ128rmk = 6473,
  VCVTPS2UDQZ128rmkz = 6474,
  VCVTPS2UDQZ128rr = 6475,
  VCVTPS2UDQZ128rrk = 6476,
  VCVTPS2UDQZ128rrkz = 6477,
  VCVTPS2UDQZ256rm = 6478,
  VCVTPS2UDQZ256rmb = 6479,
  VCVTPS2UDQZ256rmbk = 6480,
  VCVTPS2UDQZ256rmbkz = 6481,
  VCVTPS2UDQZ256rmk = 6482,
  VCVTPS2UDQZ256rmkz = 6483,
  VCVTPS2UDQZ256rr = 6484,
  VCVTPS2UDQZ256rrk = 6485,
  VCVTPS2UDQZ256rrkz = 6486,
  VCVTPS2UDQZrm = 6487,
  VCVTPS2UDQZrmb = 6488,
  VCVTPS2UDQZrmbk = 6489,
  VCVTPS2UDQZrmbkz = 6490,
  VCVTPS2UDQZrmk = 6491,
  VCVTPS2UDQZrmkz = 6492,
  VCVTPS2UDQZrr = 6493,
  VCVTPS2UDQZrrb = 6494,
  VCVTPS2UDQZrrbk = 6495,
  VCVTPS2UDQZrrbkz = 6496,
  VCVTPS2UDQZrrk = 6497,
  VCVTPS2UDQZrrkz = 6498,
  VCVTPS2UQQZ128rm = 6499,
  VCVTPS2UQQZ128rmb = 6500,
  VCVTPS2UQQZ128rmbk = 6501,
  VCVTPS2UQQZ128rmbkz = 6502,
  VCVTPS2UQQZ128rmk = 6503,
  VCVTPS2UQQZ128rmkz = 6504,
  VCVTPS2UQQZ128rr = 6505,
  VCVTPS2UQQZ128rrk = 6506,
  VCVTPS2UQQZ128rrkz = 6507,
  VCVTPS2UQQZ256rm = 6508,
  VCVTPS2UQQZ256rmb = 6509,
  VCVTPS2UQQZ256rmbk = 6510,
  VCVTPS2UQQZ256rmbkz = 6511,
  VCVTPS2UQQZ256rmk = 6512,
  VCVTPS2UQQZ256rmkz = 6513,
  VCVTPS2UQQZ256rr = 6514,
  VCVTPS2UQQZ256rrk = 6515,
  VCVTPS2UQQZ256rrkz = 6516,
  VCVTPS2UQQZrm = 6517,
  VCVTPS2UQQZrmb = 6518,
  VCVTPS2UQQZrmbk = 6519,
  VCVTPS2UQQZrmbkz = 6520,
  VCVTPS2UQQZrmk = 6521,
  VCVTPS2UQQZrmkz = 6522,
  VCVTPS2UQQZrr = 6523,
  VCVTPS2UQQZrrb = 6524,
  VCVTPS2UQQZrrbk = 6525,
  VCVTPS2UQQZrrbkz = 6526,
  VCVTPS2UQQZrrk = 6527,
  VCVTPS2UQQZrrkz = 6528,
  VCVTQQ2PDZ128rm = 6529,
  VCVTQQ2PDZ128rmb = 6530,
  VCVTQQ2PDZ128rmbk = 6531,
  VCVTQQ2PDZ128rmbkz = 6532,
  VCVTQQ2PDZ128rmk = 6533,
  VCVTQQ2PDZ128rmkz = 6534,
  VCVTQQ2PDZ128rr = 6535,
  VCVTQQ2PDZ128rrk = 6536,
  VCVTQQ2PDZ128rrkz = 6537,
  VCVTQQ2PDZ256rm = 6538,
  VCVTQQ2PDZ256rmb = 6539,
  VCVTQQ2PDZ256rmbk = 6540,
  VCVTQQ2PDZ256rmbkz = 6541,
  VCVTQQ2PDZ256rmk = 6542,
  VCVTQQ2PDZ256rmkz = 6543,
  VCVTQQ2PDZ256rr = 6544,
  VCVTQQ2PDZ256rrk = 6545,
  VCVTQQ2PDZ256rrkz = 6546,
  VCVTQQ2PDZrm = 6547,
  VCVTQQ2PDZrmb = 6548,
  VCVTQQ2PDZrmbk = 6549,
  VCVTQQ2PDZrmbkz = 6550,
  VCVTQQ2PDZrmk = 6551,
  VCVTQQ2PDZrmkz = 6552,
  VCVTQQ2PDZrr = 6553,
  VCVTQQ2PDZrrb = 6554,
  VCVTQQ2PDZrrbk = 6555,
  VCVTQQ2PDZrrbkz = 6556,
  VCVTQQ2PDZrrk = 6557,
  VCVTQQ2PDZrrkz = 6558,
  VCVTQQ2PHZ128rm = 6559,
  VCVTQQ2PHZ128rmb = 6560,
  VCVTQQ2PHZ128rmbk = 6561,
  VCVTQQ2PHZ128rmbkz = 6562,
  VCVTQQ2PHZ128rmk = 6563,
  VCVTQQ2PHZ128rmkz = 6564,
  VCVTQQ2PHZ128rr = 6565,
  VCVTQQ2PHZ128rrk = 6566,
  VCVTQQ2PHZ128rrkz = 6567,
  VCVTQQ2PHZ256rm = 6568,
  VCVTQQ2PHZ256rmb = 6569,
  VCVTQQ2PHZ256rmbk = 6570,
  VCVTQQ2PHZ256rmbkz = 6571,
  VCVTQQ2PHZ256rmk = 6572,
  VCVTQQ2PHZ256rmkz = 6573,
  VCVTQQ2PHZ256rr = 6574,
  VCVTQQ2PHZ256rrk = 6575,
  VCVTQQ2PHZ256rrkz = 6576,
  VCVTQQ2PHZrm = 6577,
  VCVTQQ2PHZrmb = 6578,
  VCVTQQ2PHZrmbk = 6579,
  VCVTQQ2PHZrmbkz = 6580,
  VCVTQQ2PHZrmk = 6581,
  VCVTQQ2PHZrmkz = 6582,
  VCVTQQ2PHZrr = 6583,
  VCVTQQ2PHZrrb = 6584,
  VCVTQQ2PHZrrbk = 6585,
  VCVTQQ2PHZrrbkz = 6586,
  VCVTQQ2PHZrrk = 6587,
  VCVTQQ2PHZrrkz = 6588,
  VCVTQQ2PSZ128rm = 6589,
  VCVTQQ2PSZ128rmb = 6590,
  VCVTQQ2PSZ128rmbk = 6591,
  VCVTQQ2PSZ128rmbkz = 6592,
  VCVTQQ2PSZ128rmk = 6593,
  VCVTQQ2PSZ128rmkz = 6594,
  VCVTQQ2PSZ128rr = 6595,
  VCVTQQ2PSZ128rrk = 6596,
  VCVTQQ2PSZ128rrkz = 6597,
  VCVTQQ2PSZ256rm = 6598,
  VCVTQQ2PSZ256rmb = 6599,
  VCVTQQ2PSZ256rmbk = 6600,
  VCVTQQ2PSZ256rmbkz = 6601,
  VCVTQQ2PSZ256rmk = 6602,
  VCVTQQ2PSZ256rmkz = 6603,
  VCVTQQ2PSZ256rr = 6604,
  VCVTQQ2PSZ256rrk = 6605,
  VCVTQQ2PSZ256rrkz = 6606,
  VCVTQQ2PSZrm = 6607,
  VCVTQQ2PSZrmb = 6608,
  VCVTQQ2PSZrmbk = 6609,
  VCVTQQ2PSZrmbkz = 6610,
  VCVTQQ2PSZrmk = 6611,
  VCVTQQ2PSZrmkz = 6612,
  VCVTQQ2PSZrr = 6613,
  VCVTQQ2PSZrrb = 6614,
  VCVTQQ2PSZrrbk = 6615,
  VCVTQQ2PSZrrbkz = 6616,
  VCVTQQ2PSZrrk = 6617,
  VCVTQQ2PSZrrkz = 6618,
  VCVTSD2SHZrm = 6619,
  VCVTSD2SHZrm_Int = 6620,
  VCVTSD2SHZrm_Intk = 6621,
  VCVTSD2SHZrm_Intkz = 6622,
  VCVTSD2SHZrr = 6623,
  VCVTSD2SHZrr_Int = 6624,
  VCVTSD2SHZrr_Intk = 6625,
  VCVTSD2SHZrr_Intkz = 6626,
  VCVTSD2SHZrrb_Int = 6627,
  VCVTSD2SHZrrb_Intk = 6628,
  VCVTSD2SHZrrb_Intkz = 6629,
  VCVTSD2SI64Zrm = 6630,
  VCVTSD2SI64Zrm_Int = 6631,
  VCVTSD2SI64Zrr = 6632,
  VCVTSD2SI64Zrr_Int = 6633,
  VCVTSD2SI64Zrrb_Int = 6634,
  VCVTSD2SI64rm = 6635,
  VCVTSD2SI64rm_Int = 6636,
  VCVTSD2SI64rr = 6637,
  VCVTSD2SI64rr_Int = 6638,
  VCVTSD2SIZrm = 6639,
  VCVTSD2SIZrm_Int = 6640,
  VCVTSD2SIZrr = 6641,
  VCVTSD2SIZrr_Int = 6642,
  VCVTSD2SIZrrb_Int = 6643,
  VCVTSD2SIrm = 6644,
  VCVTSD2SIrm_Int = 6645,
  VCVTSD2SIrr = 6646,
  VCVTSD2SIrr_Int = 6647,
  VCVTSD2SSZrm = 6648,
  VCVTSD2SSZrm_Int = 6649,
  VCVTSD2SSZrm_Intk = 6650,
  VCVTSD2SSZrm_Intkz = 6651,
  VCVTSD2SSZrr = 6652,
  VCVTSD2SSZrr_Int = 6653,
  VCVTSD2SSZrr_Intk = 6654,
  VCVTSD2SSZrr_Intkz = 6655,
  VCVTSD2SSZrrb_Int = 6656,
  VCVTSD2SSZrrb_Intk = 6657,
  VCVTSD2SSZrrb_Intkz = 6658,
  VCVTSD2SSrm = 6659,
  VCVTSD2SSrm_Int = 6660,
  VCVTSD2SSrr = 6661,
  VCVTSD2SSrr_Int = 6662,
  VCVTSD2USI64Zrm_Int = 6663,
  VCVTSD2USI64Zrr_Int = 6664,
  VCVTSD2USI64Zrrb_Int = 6665,
  VCVTSD2USIZrm_Int = 6666,
  VCVTSD2USIZrr_Int = 6667,
  VCVTSD2USIZrrb_Int = 6668,
  VCVTSH2SDZrm = 6669,
  VCVTSH2SDZrm_Int = 6670,
  VCVTSH2SDZrm_Intk = 6671,
  VCVTSH2SDZrm_Intkz = 6672,
  VCVTSH2SDZrr = 6673,
  VCVTSH2SDZrr_Int = 6674,
  VCVTSH2SDZrr_Intk = 6675,
  VCVTSH2SDZrr_Intkz = 6676,
  VCVTSH2SDZrrb_Int = 6677,
  VCVTSH2SDZrrb_Intk = 6678,
  VCVTSH2SDZrrb_Intkz = 6679,
  VCVTSH2SI64Zrm_Int = 6680,
  VCVTSH2SI64Zrr_Int = 6681,
  VCVTSH2SI64Zrrb_Int = 6682,
  VCVTSH2SIZrm_Int = 6683,
  VCVTSH2SIZrr_Int = 6684,
  VCVTSH2SIZrrb_Int = 6685,
  VCVTSH2SSZrm = 6686,
  VCVTSH2SSZrm_Int = 6687,
  VCVTSH2SSZrm_Intk = 6688,
  VCVTSH2SSZrm_Intkz = 6689,
  VCVTSH2SSZrr = 6690,
  VCVTSH2SSZrr_Int = 6691,
  VCVTSH2SSZrr_Intk = 6692,
  VCVTSH2SSZrr_Intkz = 6693,
  VCVTSH2SSZrrb_Int = 6694,
  VCVTSH2SSZrrb_Intk = 6695,
  VCVTSH2SSZrrb_Intkz = 6696,
  VCVTSH2USI64Zrm_Int = 6697,
  VCVTSH2USI64Zrr_Int = 6698,
  VCVTSH2USI64Zrrb_Int = 6699,
  VCVTSH2USIZrm_Int = 6700,
  VCVTSH2USIZrr_Int = 6701,
  VCVTSH2USIZrrb_Int = 6702,
  VCVTSI2SDZrm = 6703,
  VCVTSI2SDZrm_Int = 6704,
  VCVTSI2SDZrr = 6705,
  VCVTSI2SDZrr_Int = 6706,
  VCVTSI2SDrm = 6707,
  VCVTSI2SDrm_Int = 6708,
  VCVTSI2SDrr = 6709,
  VCVTSI2SDrr_Int = 6710,
  VCVTSI2SHZrm = 6711,
  VCVTSI2SHZrm_Int = 6712,
  VCVTSI2SHZrr = 6713,
  VCVTSI2SHZrr_Int = 6714,
  VCVTSI2SHZrrb_Int = 6715,
  VCVTSI2SSZrm = 6716,
  VCVTSI2SSZrm_Int = 6717,
  VCVTSI2SSZrr = 6718,
  VCVTSI2SSZrr_Int = 6719,
  VCVTSI2SSZrrb_Int = 6720,
  VCVTSI2SSrm = 6721,
  VCVTSI2SSrm_Int = 6722,
  VCVTSI2SSrr = 6723,
  VCVTSI2SSrr_Int = 6724,
  VCVTSI642SDZrm = 6725,
  VCVTSI642SDZrm_Int = 6726,
  VCVTSI642SDZrr = 6727,
  VCVTSI642SDZrr_Int = 6728,
  VCVTSI642SDZrrb_Int = 6729,
  VCVTSI642SDrm = 6730,
  VCVTSI642SDrm_Int = 6731,
  VCVTSI642SDrr = 6732,
  VCVTSI642SDrr_Int = 6733,
  VCVTSI642SHZrm = 6734,
  VCVTSI642SHZrm_Int = 6735,
  VCVTSI642SHZrr = 6736,
  VCVTSI642SHZrr_Int = 6737,
  VCVTSI642SHZrrb_Int = 6738,
  VCVTSI642SSZrm = 6739,
  VCVTSI642SSZrm_Int = 6740,
  VCVTSI642SSZrr = 6741,
  VCVTSI642SSZrr_Int = 6742,
  VCVTSI642SSZrrb_Int = 6743,
  VCVTSI642SSrm = 6744,
  VCVTSI642SSrm_Int = 6745,
  VCVTSI642SSrr = 6746,
  VCVTSI642SSrr_Int = 6747,
  VCVTSS2SDZrm = 6748,
  VCVTSS2SDZrm_Int = 6749,
  VCVTSS2SDZrm_Intk = 6750,
  VCVTSS2SDZrm_Intkz = 6751,
  VCVTSS2SDZrr = 6752,
  VCVTSS2SDZrr_Int = 6753,
  VCVTSS2SDZrr_Intk = 6754,
  VCVTSS2SDZrr_Intkz = 6755,
  VCVTSS2SDZrrb_Int = 6756,
  VCVTSS2SDZrrb_Intk = 6757,
  VCVTSS2SDZrrb_Intkz = 6758,
  VCVTSS2SDrm = 6759,
  VCVTSS2SDrm_Int = 6760,
  VCVTSS2SDrr = 6761,
  VCVTSS2SDrr_Int = 6762,
  VCVTSS2SHZrm = 6763,
  VCVTSS2SHZrm_Int = 6764,
  VCVTSS2SHZrm_Intk = 6765,
  VCVTSS2SHZrm_Intkz = 6766,
  VCVTSS2SHZrr = 6767,
  VCVTSS2SHZrr_Int = 6768,
  VCVTSS2SHZrr_Intk = 6769,
  VCVTSS2SHZrr_Intkz = 6770,
  VCVTSS2SHZrrb_Int = 6771,
  VCVTSS2SHZrrb_Intk = 6772,
  VCVTSS2SHZrrb_Intkz = 6773,
  VCVTSS2SI64Zrm = 6774,
  VCVTSS2SI64Zrm_Int = 6775,
  VCVTSS2SI64Zrr = 6776,
  VCVTSS2SI64Zrr_Int = 6777,
  VCVTSS2SI64Zrrb_Int = 6778,
  VCVTSS2SI64rm = 6779,
  VCVTSS2SI64rm_Int = 6780,
  VCVTSS2SI64rr = 6781,
  VCVTSS2SI64rr_Int = 6782,
  VCVTSS2SIZrm = 6783,
  VCVTSS2SIZrm_Int = 6784,
  VCVTSS2SIZrr = 6785,
  VCVTSS2SIZrr_Int = 6786,
  VCVTSS2SIZrrb_Int = 6787,
  VCVTSS2SIrm = 6788,
  VCVTSS2SIrm_Int = 6789,
  VCVTSS2SIrr = 6790,
  VCVTSS2SIrr_Int = 6791,
  VCVTSS2USI64Zrm_Int = 6792,
  VCVTSS2USI64Zrr_Int = 6793,
  VCVTSS2USI64Zrrb_Int = 6794,
  VCVTSS2USIZrm_Int = 6795,
  VCVTSS2USIZrr_Int = 6796,
  VCVTSS2USIZrrb_Int = 6797,
  VCVTTPD2DQYrm = 6798,
  VCVTTPD2DQYrr = 6799,
  VCVTTPD2DQZ128rm = 6800,
  VCVTTPD2DQZ128rmb = 6801,
  VCVTTPD2DQZ128rmbk = 6802,
  VCVTTPD2DQZ128rmbkz = 6803,
  VCVTTPD2DQZ128rmk = 6804,
  VCVTTPD2DQZ128rmkz = 6805,
  VCVTTPD2DQZ128rr = 6806,
  VCVTTPD2DQZ128rrk = 6807,
  VCVTTPD2DQZ128rrkz = 6808,
  VCVTTPD2DQZ256rm = 6809,
  VCVTTPD2DQZ256rmb = 6810,
  VCVTTPD2DQZ256rmbk = 6811,
  VCVTTPD2DQZ256rmbkz = 6812,
  VCVTTPD2DQZ256rmk = 6813,
  VCVTTPD2DQZ256rmkz = 6814,
  VCVTTPD2DQZ256rr = 6815,
  VCVTTPD2DQZ256rrk = 6816,
  VCVTTPD2DQZ256rrkz = 6817,
  VCVTTPD2DQZrm = 6818,
  VCVTTPD2DQZrmb = 6819,
  VCVTTPD2DQZrmbk = 6820,
  VCVTTPD2DQZrmbkz = 6821,
  VCVTTPD2DQZrmk = 6822,
  VCVTTPD2DQZrmkz = 6823,
  VCVTTPD2DQZrr = 6824,
  VCVTTPD2DQZrrb = 6825,
  VCVTTPD2DQZrrbk = 6826,
  VCVTTPD2DQZrrbkz = 6827,
  VCVTTPD2DQZrrk = 6828,
  VCVTTPD2DQZrrkz = 6829,
  VCVTTPD2DQrm = 6830,
  VCVTTPD2DQrr = 6831,
  VCVTTPD2QQZ128rm = 6832,
  VCVTTPD2QQZ128rmb = 6833,
  VCVTTPD2QQZ128rmbk = 6834,
  VCVTTPD2QQZ128rmbkz = 6835,
  VCVTTPD2QQZ128rmk = 6836,
  VCVTTPD2QQZ128rmkz = 6837,
  VCVTTPD2QQZ128rr = 6838,
  VCVTTPD2QQZ128rrk = 6839,
  VCVTTPD2QQZ128rrkz = 6840,
  VCVTTPD2QQZ256rm = 6841,
  VCVTTPD2QQZ256rmb = 6842,
  VCVTTPD2QQZ256rmbk = 6843,
  VCVTTPD2QQZ256rmbkz = 6844,
  VCVTTPD2QQZ256rmk = 6845,
  VCVTTPD2QQZ256rmkz = 6846,
  VCVTTPD2QQZ256rr = 6847,
  VCVTTPD2QQZ256rrk = 6848,
  VCVTTPD2QQZ256rrkz = 6849,
  VCVTTPD2QQZrm = 6850,
  VCVTTPD2QQZrmb = 6851,
  VCVTTPD2QQZrmbk = 6852,
  VCVTTPD2QQZrmbkz = 6853,
  VCVTTPD2QQZrmk = 6854,
  VCVTTPD2QQZrmkz = 6855,
  VCVTTPD2QQZrr = 6856,
  VCVTTPD2QQZrrb = 6857,
  VCVTTPD2QQZrrbk = 6858,
  VCVTTPD2QQZrrbkz = 6859,
  VCVTTPD2QQZrrk = 6860,
  VCVTTPD2QQZrrkz = 6861,
  VCVTTPD2UDQZ128rm = 6862,
  VCVTTPD2UDQZ128rmb = 6863,
  VCVTTPD2UDQZ128rmbk = 6864,
  VCVTTPD2UDQZ128rmbkz = 6865,
  VCVTTPD2UDQZ128rmk = 6866,
  VCVTTPD2UDQZ128rmkz = 6867,
  VCVTTPD2UDQZ128rr = 6868,
  VCVTTPD2UDQZ128rrk = 6869,
  VCVTTPD2UDQZ128rrkz = 6870,
  VCVTTPD2UDQZ256rm = 6871,
  VCVTTPD2UDQZ256rmb = 6872,
  VCVTTPD2UDQZ256rmbk = 6873,
  VCVTTPD2UDQZ256rmbkz = 6874,
  VCVTTPD2UDQZ256rmk = 6875,
  VCVTTPD2UDQZ256rmkz = 6876,
  VCVTTPD2UDQZ256rr = 6877,
  VCVTTPD2UDQZ256rrk = 6878,
  VCVTTPD2UDQZ256rrkz = 6879,
  VCVTTPD2UDQZrm = 6880,
  VCVTTPD2UDQZrmb = 6881,
  VCVTTPD2UDQZrmbk = 6882,
  VCVTTPD2UDQZrmbkz = 6883,
  VCVTTPD2UDQZrmk = 6884,
  VCVTTPD2UDQZrmkz = 6885,
  VCVTTPD2UDQZrr = 6886,
  VCVTTPD2UDQZrrb = 6887,
  VCVTTPD2UDQZrrbk = 6888,
  VCVTTPD2UDQZrrbkz = 6889,
  VCVTTPD2UDQZrrk = 6890,
  VCVTTPD2UDQZrrkz = 6891,
  VCVTTPD2UQQZ128rm = 6892,
  VCVTTPD2UQQZ128rmb = 6893,
  VCVTTPD2UQQZ128rmbk = 6894,
  VCVTTPD2UQQZ128rmbkz = 6895,
  VCVTTPD2UQQZ128rmk = 6896,
  VCVTTPD2UQQZ128rmkz = 6897,
  VCVTTPD2UQQZ128rr = 6898,
  VCVTTPD2UQQZ128rrk = 6899,
  VCVTTPD2UQQZ128rrkz = 6900,
  VCVTTPD2UQQZ256rm = 6901,
  VCVTTPD2UQQZ256rmb = 6902,
  VCVTTPD2UQQZ256rmbk = 6903,
  VCVTTPD2UQQZ256rmbkz = 6904,
  VCVTTPD2UQQZ256rmk = 6905,
  VCVTTPD2UQQZ256rmkz = 6906,
  VCVTTPD2UQQZ256rr = 6907,
  VCVTTPD2UQQZ256rrk = 6908,
  VCVTTPD2UQQZ256rrkz = 6909,
  VCVTTPD2UQQZrm = 6910,
  VCVTTPD2UQQZrmb = 6911,
  VCVTTPD2UQQZrmbk = 6912,
  VCVTTPD2UQQZrmbkz = 6913,
  VCVTTPD2UQQZrmk = 6914,
  VCVTTPD2UQQZrmkz = 6915,
  VCVTTPD2UQQZrr = 6916,
  VCVTTPD2UQQZrrb = 6917,
  VCVTTPD2UQQZrrbk = 6918,
  VCVTTPD2UQQZrrbkz = 6919,
  VCVTTPD2UQQZrrk = 6920,
  VCVTTPD2UQQZrrkz = 6921,
  VCVTTPH2DQZ128rm = 6922,
  VCVTTPH2DQZ128rmb = 6923,
  VCVTTPH2DQZ128rmbk = 6924,
  VCVTTPH2DQZ128rmbkz = 6925,
  VCVTTPH2DQZ128rmk = 6926,
  VCVTTPH2DQZ128rmkz = 6927,
  VCVTTPH2DQZ128rr = 6928,
  VCVTTPH2DQZ128rrk = 6929,
  VCVTTPH2DQZ128rrkz = 6930,
  VCVTTPH2DQZ256rm = 6931,
  VCVTTPH2DQZ256rmb = 6932,
  VCVTTPH2DQZ256rmbk = 6933,
  VCVTTPH2DQZ256rmbkz = 6934,
  VCVTTPH2DQZ256rmk = 6935,
  VCVTTPH2DQZ256rmkz = 6936,
  VCVTTPH2DQZ256rr = 6937,
  VCVTTPH2DQZ256rrk = 6938,
  VCVTTPH2DQZ256rrkz = 6939,
  VCVTTPH2DQZrm = 6940,
  VCVTTPH2DQZrmb = 6941,
  VCVTTPH2DQZrmbk = 6942,
  VCVTTPH2DQZrmbkz = 6943,
  VCVTTPH2DQZrmk = 6944,
  VCVTTPH2DQZrmkz = 6945,
  VCVTTPH2DQZrr = 6946,
  VCVTTPH2DQZrrb = 6947,
  VCVTTPH2DQZrrbk = 6948,
  VCVTTPH2DQZrrbkz = 6949,
  VCVTTPH2DQZrrk = 6950,
  VCVTTPH2DQZrrkz = 6951,
  VCVTTPH2QQZ128rm = 6952,
  VCVTTPH2QQZ128rmb = 6953,
  VCVTTPH2QQZ128rmbk = 6954,
  VCVTTPH2QQZ128rmbkz = 6955,
  VCVTTPH2QQZ128rmk = 6956,
  VCVTTPH2QQZ128rmkz = 6957,
  VCVTTPH2QQZ128rr = 6958,
  VCVTTPH2QQZ128rrk = 6959,
  VCVTTPH2QQZ128rrkz = 6960,
  VCVTTPH2QQZ256rm = 6961,
  VCVTTPH2QQZ256rmb = 6962,
  VCVTTPH2QQZ256rmbk = 6963,
  VCVTTPH2QQZ256rmbkz = 6964,
  VCVTTPH2QQZ256rmk = 6965,
  VCVTTPH2QQZ256rmkz = 6966,
  VCVTTPH2QQZ256rr = 6967,
  VCVTTPH2QQZ256rrk = 6968,
  VCVTTPH2QQZ256rrkz = 6969,
  VCVTTPH2QQZrm = 6970,
  VCVTTPH2QQZrmb = 6971,
  VCVTTPH2QQZrmbk = 6972,
  VCVTTPH2QQZrmbkz = 6973,
  VCVTTPH2QQZrmk = 6974,
  VCVTTPH2QQZrmkz = 6975,
  VCVTTPH2QQZrr = 6976,
  VCVTTPH2QQZrrb = 6977,
  VCVTTPH2QQZrrbk = 6978,
  VCVTTPH2QQZrrbkz = 6979,
  VCVTTPH2QQZrrk = 6980,
  VCVTTPH2QQZrrkz = 6981,
  VCVTTPH2UDQZ128rm = 6982,
  VCVTTPH2UDQZ128rmb = 6983,
  VCVTTPH2UDQZ128rmbk = 6984,
  VCVTTPH2UDQZ128rmbkz = 6985,
  VCVTTPH2UDQZ128rmk = 6986,
  VCVTTPH2UDQZ128rmkz = 6987,
  VCVTTPH2UDQZ128rr = 6988,
  VCVTTPH2UDQZ128rrk = 6989,
  VCVTTPH2UDQZ128rrkz = 6990,
  VCVTTPH2UDQZ256rm = 6991,
  VCVTTPH2UDQZ256rmb = 6992,
  VCVTTPH2UDQZ256rmbk = 6993,
  VCVTTPH2UDQZ256rmbkz = 6994,
  VCVTTPH2UDQZ256rmk = 6995,
  VCVTTPH2UDQZ256rmkz = 6996,
  VCVTTPH2UDQZ256rr = 6997,
  VCVTTPH2UDQZ256rrk = 6998,
  VCVTTPH2UDQZ256rrkz = 6999,
  VCVTTPH2UDQZrm = 7000,
  VCVTTPH2UDQZrmb = 7001,
  VCVTTPH2UDQZrmbk = 7002,
  VCVTTPH2UDQZrmbkz = 7003,
  VCVTTPH2UDQZrmk = 7004,
  VCVTTPH2UDQZrmkz = 7005,
  VCVTTPH2UDQZrr = 7006,
  VCVTTPH2UDQZrrb = 7007,
  VCVTTPH2UDQZrrbk = 7008,
  VCVTTPH2UDQZrrbkz = 7009,
  VCVTTPH2UDQZrrk = 7010,
  VCVTTPH2UDQZrrkz = 7011,
  VCVTTPH2UQQZ128rm = 7012,
  VCVTTPH2UQQZ128rmb = 7013,
  VCVTTPH2UQQZ128rmbk = 7014,
  VCVTTPH2UQQZ128rmbkz = 7015,
  VCVTTPH2UQQZ128rmk = 7016,
  VCVTTPH2UQQZ128rmkz = 7017,
  VCVTTPH2UQQZ128rr = 7018,
  VCVTTPH2UQQZ128rrk = 7019,
  VCVTTPH2UQQZ128rrkz = 7020,
  VCVTTPH2UQQZ256rm = 7021,
  VCVTTPH2UQQZ256rmb = 7022,
  VCVTTPH2UQQZ256rmbk = 7023,
  VCVTTPH2UQQZ256rmbkz = 7024,
  VCVTTPH2UQQZ256rmk = 7025,
  VCVTTPH2UQQZ256rmkz = 7026,
  VCVTTPH2UQQZ256rr = 7027,
  VCVTTPH2UQQZ256rrk = 7028,
  VCVTTPH2UQQZ256rrkz = 7029,
  VCVTTPH2UQQZrm = 7030,
  VCVTTPH2UQQZrmb = 7031,
  VCVTTPH2UQQZrmbk = 7032,
  VCVTTPH2UQQZrmbkz = 7033,
  VCVTTPH2UQQZrmk = 7034,
  VCVTTPH2UQQZrmkz = 7035,
  VCVTTPH2UQQZrr = 7036,
  VCVTTPH2UQQZrrb = 7037,
  VCVTTPH2UQQZrrbk = 7038,
  VCVTTPH2UQQZrrbkz = 7039,
  VCVTTPH2UQQZrrk = 7040,
  VCVTTPH2UQQZrrkz = 7041,
  VCVTTPH2UWZ128rm = 7042,
  VCVTTPH2UWZ128rmb = 7043,
  VCVTTPH2UWZ128rmbk = 7044,
  VCVTTPH2UWZ128rmbkz = 7045,
  VCVTTPH2UWZ128rmk = 7046,
  VCVTTPH2UWZ128rmkz = 7047,
  VCVTTPH2UWZ128rr = 7048,
  VCVTTPH2UWZ128rrk = 7049,
  VCVTTPH2UWZ128rrkz = 7050,
  VCVTTPH2UWZ256rm = 7051,
  VCVTTPH2UWZ256rmb = 7052,
  VCVTTPH2UWZ256rmbk = 7053,
  VCVTTPH2UWZ256rmbkz = 7054,
  VCVTTPH2UWZ256rmk = 7055,
  VCVTTPH2UWZ256rmkz = 7056,
  VCVTTPH2UWZ256rr = 7057,
  VCVTTPH2UWZ256rrk = 7058,
  VCVTTPH2UWZ256rrkz = 7059,
  VCVTTPH2UWZrm = 7060,
  VCVTTPH2UWZrmb = 7061,
  VCVTTPH2UWZrmbk = 7062,
  VCVTTPH2UWZrmbkz = 7063,
  VCVTTPH2UWZrmk = 7064,
  VCVTTPH2UWZrmkz = 7065,
  VCVTTPH2UWZrr = 7066,
  VCVTTPH2UWZrrb = 7067,
  VCVTTPH2UWZrrbk = 7068,
  VCVTTPH2UWZrrbkz = 7069,
  VCVTTPH2UWZrrk = 7070,
  VCVTTPH2UWZrrkz = 7071,
  VCVTTPH2WZ128rm = 7072,
  VCVTTPH2WZ128rmb = 7073,
  VCVTTPH2WZ128rmbk = 7074,
  VCVTTPH2WZ128rmbkz = 7075,
  VCVTTPH2WZ128rmk = 7076,
  VCVTTPH2WZ128rmkz = 7077,
  VCVTTPH2WZ128rr = 7078,
  VCVTTPH2WZ128rrk = 7079,
  VCVTTPH2WZ128rrkz = 7080,
  VCVTTPH2WZ256rm = 7081,
  VCVTTPH2WZ256rmb = 7082,
  VCVTTPH2WZ256rmbk = 7083,
  VCVTTPH2WZ256rmbkz = 7084,
  VCVTTPH2WZ256rmk = 7085,
  VCVTTPH2WZ256rmkz = 7086,
  VCVTTPH2WZ256rr = 7087,
  VCVTTPH2WZ256rrk = 7088,
  VCVTTPH2WZ256rrkz = 7089,
  VCVTTPH2WZrm = 7090,
  VCVTTPH2WZrmb = 7091,
  VCVTTPH2WZrmbk = 7092,
  VCVTTPH2WZrmbkz = 7093,
  VCVTTPH2WZrmk = 7094,
  VCVTTPH2WZrmkz = 7095,
  VCVTTPH2WZrr = 7096,
  VCVTTPH2WZrrb = 7097,
  VCVTTPH2WZrrbk = 7098,
  VCVTTPH2WZrrbkz = 7099,
  VCVTTPH2WZrrk = 7100,
  VCVTTPH2WZrrkz = 7101,
  VCVTTPS2DQYrm = 7102,
  VCVTTPS2DQYrr = 7103,
  VCVTTPS2DQZ128rm = 7104,
  VCVTTPS2DQZ128rmb = 7105,
  VCVTTPS2DQZ128rmbk = 7106,
  VCVTTPS2DQZ128rmbkz = 7107,
  VCVTTPS2DQZ128rmk = 7108,
  VCVTTPS2DQZ128rmkz = 7109,
  VCVTTPS2DQZ128rr = 7110,
  VCVTTPS2DQZ128rrk = 7111,
  VCVTTPS2DQZ128rrkz = 7112,
  VCVTTPS2DQZ256rm = 7113,
  VCVTTPS2DQZ256rmb = 7114,
  VCVTTPS2DQZ256rmbk = 7115,
  VCVTTPS2DQZ256rmbkz = 7116,
  VCVTTPS2DQZ256rmk = 7117,
  VCVTTPS2DQZ256rmkz = 7118,
  VCVTTPS2DQZ256rr = 7119,
  VCVTTPS2DQZ256rrk = 7120,
  VCVTTPS2DQZ256rrkz = 7121,
  VCVTTPS2DQZrm = 7122,
  VCVTTPS2DQZrmb = 7123,
  VCVTTPS2DQZrmbk = 7124,
  VCVTTPS2DQZrmbkz = 7125,
  VCVTTPS2DQZrmk = 7126,
  VCVTTPS2DQZrmkz = 7127,
  VCVTTPS2DQZrr = 7128,
  VCVTTPS2DQZrrb = 7129,
  VCVTTPS2DQZrrbk = 7130,
  VCVTTPS2DQZrrbkz = 7131,
  VCVTTPS2DQZrrk = 7132,
  VCVTTPS2DQZrrkz = 7133,
  VCVTTPS2DQrm = 7134,
  VCVTTPS2DQrr = 7135,
  VCVTTPS2QQZ128rm = 7136,
  VCVTTPS2QQZ128rmb = 7137,
  VCVTTPS2QQZ128rmbk = 7138,
  VCVTTPS2QQZ128rmbkz = 7139,
  VCVTTPS2QQZ128rmk = 7140,
  VCVTTPS2QQZ128rmkz = 7141,
  VCVTTPS2QQZ128rr = 7142,
  VCVTTPS2QQZ128rrk = 7143,
  VCVTTPS2QQZ128rrkz = 7144,
  VCVTTPS2QQZ256rm = 7145,
  VCVTTPS2QQZ256rmb = 7146,
  VCVTTPS2QQZ256rmbk = 7147,
  VCVTTPS2QQZ256rmbkz = 7148,
  VCVTTPS2QQZ256rmk = 7149,
  VCVTTPS2QQZ256rmkz = 7150,
  VCVTTPS2QQZ256rr = 7151,
  VCVTTPS2QQZ256rrk = 7152,
  VCVTTPS2QQZ256rrkz = 7153,
  VCVTTPS2QQZrm = 7154,
  VCVTTPS2QQZrmb = 7155,
  VCVTTPS2QQZrmbk = 7156,
  VCVTTPS2QQZrmbkz = 7157,
  VCVTTPS2QQZrmk = 7158,
  VCVTTPS2QQZrmkz = 7159,
  VCVTTPS2QQZrr = 7160,
  VCVTTPS2QQZrrb = 7161,
  VCVTTPS2QQZrrbk = 7162,
  VCVTTPS2QQZrrbkz = 7163,
  VCVTTPS2QQZrrk = 7164,
  VCVTTPS2QQZrrkz = 7165,
  VCVTTPS2UDQZ128rm = 7166,
  VCVTTPS2UDQZ128rmb = 7167,
  VCVTTPS2UDQZ128rmbk = 7168,
  VCVTTPS2UDQZ128rmbkz = 7169,
  VCVTTPS2UDQZ128rmk = 7170,
  VCVTTPS2UDQZ128rmkz = 7171,
  VCVTTPS2UDQZ128rr = 7172,
  VCVTTPS2UDQZ128rrk = 7173,
  VCVTTPS2UDQZ128rrkz = 7174,
  VCVTTPS2UDQZ256rm = 7175,
  VCVTTPS2UDQZ256rmb = 7176,
  VCVTTPS2UDQZ256rmbk = 7177,
  VCVTTPS2UDQZ256rmbkz = 7178,
  VCVTTPS2UDQZ256rmk = 7179,
  VCVTTPS2UDQZ256rmkz = 7180,
  VCVTTPS2UDQZ256rr = 7181,
  VCVTTPS2UDQZ256rrk = 7182,
  VCVTTPS2UDQZ256rrkz = 7183,
  VCVTTPS2UDQZrm = 7184,
  VCVTTPS2UDQZrmb = 7185,
  VCVTTPS2UDQZrmbk = 7186,
  VCVTTPS2UDQZrmbkz = 7187,
  VCVTTPS2UDQZrmk = 7188,
  VCVTTPS2UDQZrmkz = 7189,
  VCVTTPS2UDQZrr = 7190,
  VCVTTPS2UDQZrrb = 7191,
  VCVTTPS2UDQZrrbk = 7192,
  VCVTTPS2UDQZrrbkz = 7193,
  VCVTTPS2UDQZrrk = 7194,
  VCVTTPS2UDQZrrkz = 7195,
  VCVTTPS2UQQZ128rm = 7196,
  VCVTTPS2UQQZ128rmb = 7197,
  VCVTTPS2UQQZ128rmbk = 7198,
  VCVTTPS2UQQZ128rmbkz = 7199,
  VCVTTPS2UQQZ128rmk = 7200,
  VCVTTPS2UQQZ128rmkz = 7201,
  VCVTTPS2UQQZ128rr = 7202,
  VCVTTPS2UQQZ128rrk = 7203,
  VCVTTPS2UQQZ128rrkz = 7204,
  VCVTTPS2UQQZ256rm = 7205,
  VCVTTPS2UQQZ256rmb = 7206,
  VCVTTPS2UQQZ256rmbk = 7207,
  VCVTTPS2UQQZ256rmbkz = 7208,
  VCVTTPS2UQQZ256rmk = 7209,
  VCVTTPS2UQQZ256rmkz = 7210,
  VCVTTPS2UQQZ256rr = 7211,
  VCVTTPS2UQQZ256rrk = 7212,
  VCVTTPS2UQQZ256rrkz = 7213,
  VCVTTPS2UQQZrm = 7214,
  VCVTTPS2UQQZrmb = 7215,
  VCVTTPS2UQQZrmbk = 7216,
  VCVTTPS2UQQZrmbkz = 7217,
  VCVTTPS2UQQZrmk = 7218,
  VCVTTPS2UQQZrmkz = 7219,
  VCVTTPS2UQQZrr = 7220,
  VCVTTPS2UQQZrrb = 7221,
  VCVTTPS2UQQZrrbk = 7222,
  VCVTTPS2UQQZrrbkz = 7223,
  VCVTTPS2UQQZrrk = 7224,
  VCVTTPS2UQQZrrkz = 7225,
  VCVTTSD2SI64Zrm = 7226,
  VCVTTSD2SI64Zrm_Int = 7227,
  VCVTTSD2SI64Zrr = 7228,
  VCVTTSD2SI64Zrr_Int = 7229,
  VCVTTSD2SI64Zrrb_Int = 7230,
  VCVTTSD2SI64rm = 7231,
  VCVTTSD2SI64rm_Int = 7232,
  VCVTTSD2SI64rr = 7233,
  VCVTTSD2SI64rr_Int = 7234,
  VCVTTSD2SIZrm = 7235,
  VCVTTSD2SIZrm_Int = 7236,
  VCVTTSD2SIZrr = 7237,
  VCVTTSD2SIZrr_Int = 7238,
  VCVTTSD2SIZrrb_Int = 7239,
  VCVTTSD2SIrm = 7240,
  VCVTTSD2SIrm_Int = 7241,
  VCVTTSD2SIrr = 7242,
  VCVTTSD2SIrr_Int = 7243,
  VCVTTSD2USI64Zrm = 7244,
  VCVTTSD2USI64Zrm_Int = 7245,
  VCVTTSD2USI64Zrr = 7246,
  VCVTTSD2USI64Zrr_Int = 7247,
  VCVTTSD2USI64Zrrb_Int = 7248,
  VCVTTSD2USIZrm = 7249,
  VCVTTSD2USIZrm_Int = 7250,
  VCVTTSD2USIZrr = 7251,
  VCVTTSD2USIZrr_Int = 7252,
  VCVTTSD2USIZrrb_Int = 7253,
  VCVTTSH2SI64Zrm = 7254,
  VCVTTSH2SI64Zrm_Int = 7255,
  VCVTTSH2SI64Zrr = 7256,
  VCVTTSH2SI64Zrr_Int = 7257,
  VCVTTSH2SI64Zrrb_Int = 7258,
  VCVTTSH2SIZrm = 7259,
  VCVTTSH2SIZrm_Int = 7260,
  VCVTTSH2SIZrr = 7261,
  VCVTTSH2SIZrr_Int = 7262,
  VCVTTSH2SIZrrb_Int = 7263,
  VCVTTSH2USI64Zrm = 7264,
  VCVTTSH2USI64Zrm_Int = 7265,
  VCVTTSH2USI64Zrr = 7266,
  VCVTTSH2USI64Zrr_Int = 7267,
  VCVTTSH2USI64Zrrb_Int = 7268,
  VCVTTSH2USIZrm = 7269,
  VCVTTSH2USIZrm_Int = 7270,
  VCVTTSH2USIZrr = 7271,
  VCVTTSH2USIZrr_Int = 7272,
  VCVTTSH2USIZrrb_Int = 7273,
  VCVTTSS2SI64Zrm = 7274,
  VCVTTSS2SI64Zrm_Int = 7275,
  VCVTTSS2SI64Zrr = 7276,
  VCVTTSS2SI64Zrr_Int = 7277,
  VCVTTSS2SI64Zrrb_Int = 7278,
  VCVTTSS2SI64rm = 7279,
  VCVTTSS2SI64rm_Int = 7280,
  VCVTTSS2SI64rr = 7281,
  VCVTTSS2SI64rr_Int = 7282,
  VCVTTSS2SIZrm = 7283,
  VCVTTSS2SIZrm_Int = 7284,
  VCVTTSS2SIZrr = 7285,
  VCVTTSS2SIZrr_Int = 7286,
  VCVTTSS2SIZrrb_Int = 7287,
  VCVTTSS2SIrm = 7288,
  VCVTTSS2SIrm_Int = 7289,
  VCVTTSS2SIrr = 7290,
  VCVTTSS2SIrr_Int = 7291,
  VCVTTSS2USI64Zrm = 7292,
  VCVTTSS2USI64Zrm_Int = 7293,
  VCVTTSS2USI64Zrr = 7294,
  VCVTTSS2USI64Zrr_Int = 7295,
  VCVTTSS2USI64Zrrb_Int = 7296,
  VCVTTSS2USIZrm = 7297,
  VCVTTSS2USIZrm_Int = 7298,
  VCVTTSS2USIZrr = 7299,
  VCVTTSS2USIZrr_Int = 7300,
  VCVTTSS2USIZrrb_Int = 7301,
  VCVTUDQ2PDZ128rm = 7302,
  VCVTUDQ2PDZ128rmb = 7303,
  VCVTUDQ2PDZ128rmbk = 7304,
  VCVTUDQ2PDZ128rmbkz = 7305,
  VCVTUDQ2PDZ128rmk = 7306,
  VCVTUDQ2PDZ128rmkz = 7307,
  VCVTUDQ2PDZ128rr = 7308,
  VCVTUDQ2PDZ128rrk = 7309,
  VCVTUDQ2PDZ128rrkz = 7310,
  VCVTUDQ2PDZ256rm = 7311,
  VCVTUDQ2PDZ256rmb = 7312,
  VCVTUDQ2PDZ256rmbk = 7313,
  VCVTUDQ2PDZ256rmbkz = 7314,
  VCVTUDQ2PDZ256rmk = 7315,
  VCVTUDQ2PDZ256rmkz = 7316,
  VCVTUDQ2PDZ256rr = 7317,
  VCVTUDQ2PDZ256rrk = 7318,
  VCVTUDQ2PDZ256rrkz = 7319,
  VCVTUDQ2PDZrm = 7320,
  VCVTUDQ2PDZrmb = 7321,
  VCVTUDQ2PDZrmbk = 7322,
  VCVTUDQ2PDZrmbkz = 7323,
  VCVTUDQ2PDZrmk = 7324,
  VCVTUDQ2PDZrmkz = 7325,
  VCVTUDQ2PDZrr = 7326,
  VCVTUDQ2PDZrrk = 7327,
  VCVTUDQ2PDZrrkz = 7328,
  VCVTUDQ2PHZ128rm = 7329,
  VCVTUDQ2PHZ128rmb = 7330,
  VCVTUDQ2PHZ128rmbk = 7331,
  VCVTUDQ2PHZ128rmbkz = 7332,
  VCVTUDQ2PHZ128rmk = 7333,
  VCVTUDQ2PHZ128rmkz = 7334,
  VCVTUDQ2PHZ128rr = 7335,
  VCVTUDQ2PHZ128rrk = 7336,
  VCVTUDQ2PHZ128rrkz = 7337,
  VCVTUDQ2PHZ256rm = 7338,
  VCVTUDQ2PHZ256rmb = 7339,
  VCVTUDQ2PHZ256rmbk = 7340,
  VCVTUDQ2PHZ256rmbkz = 7341,
  VCVTUDQ2PHZ256rmk = 7342,
  VCVTUDQ2PHZ256rmkz = 7343,
  VCVTUDQ2PHZ256rr = 7344,
  VCVTUDQ2PHZ256rrk = 7345,
  VCVTUDQ2PHZ256rrkz = 7346,
  VCVTUDQ2PHZrm = 7347,
  VCVTUDQ2PHZrmb = 7348,
  VCVTUDQ2PHZrmbk = 7349,
  VCVTUDQ2PHZrmbkz = 7350,
  VCVTUDQ2PHZrmk = 7351,
  VCVTUDQ2PHZrmkz = 7352,
  VCVTUDQ2PHZrr = 7353,
  VCVTUDQ2PHZrrb = 7354,
  VCVTUDQ2PHZrrbk = 7355,
  VCVTUDQ2PHZrrbkz = 7356,
  VCVTUDQ2PHZrrk = 7357,
  VCVTUDQ2PHZrrkz = 7358,
  VCVTUDQ2PSZ128rm = 7359,
  VCVTUDQ2PSZ128rmb = 7360,
  VCVTUDQ2PSZ128rmbk = 7361,
  VCVTUDQ2PSZ128rmbkz = 7362,
  VCVTUDQ2PSZ128rmk = 7363,
  VCVTUDQ2PSZ128rmkz = 7364,
  VCVTUDQ2PSZ128rr = 7365,
  VCVTUDQ2PSZ128rrk = 7366,
  VCVTUDQ2PSZ128rrkz = 7367,
  VCVTUDQ2PSZ256rm = 7368,
  VCVTUDQ2PSZ256rmb = 7369,
  VCVTUDQ2PSZ256rmbk = 7370,
  VCVTUDQ2PSZ256rmbkz = 7371,
  VCVTUDQ2PSZ256rmk = 7372,
  VCVTUDQ2PSZ256rmkz = 7373,
  VCVTUDQ2PSZ256rr = 7374,
  VCVTUDQ2PSZ256rrk = 7375,
  VCVTUDQ2PSZ256rrkz = 7376,
  VCVTUDQ2PSZrm = 7377,
  VCVTUDQ2PSZrmb = 7378,
  VCVTUDQ2PSZrmbk = 7379,
  VCVTUDQ2PSZrmbkz = 7380,
  VCVTUDQ2PSZrmk = 7381,
  VCVTUDQ2PSZrmkz = 7382,
  VCVTUDQ2PSZrr = 7383,
  VCVTUDQ2PSZrrb = 7384,
  VCVTUDQ2PSZrrbk = 7385,
  VCVTUDQ2PSZrrbkz = 7386,
  VCVTUDQ2PSZrrk = 7387,
  VCVTUDQ2PSZrrkz = 7388,
  VCVTUQQ2PDZ128rm = 7389,
  VCVTUQQ2PDZ128rmb = 7390,
  VCVTUQQ2PDZ128rmbk = 7391,
  VCVTUQQ2PDZ128rmbkz = 7392,
  VCVTUQQ2PDZ128rmk = 7393,
  VCVTUQQ2PDZ128rmkz = 7394,
  VCVTUQQ2PDZ128rr = 7395,
  VCVTUQQ2PDZ128rrk = 7396,
  VCVTUQQ2PDZ128rrkz = 7397,
  VCVTUQQ2PDZ256rm = 7398,
  VCVTUQQ2PDZ256rmb = 7399,
  VCVTUQQ2PDZ256rmbk = 7400,
  VCVTUQQ2PDZ256rmbkz = 7401,
  VCVTUQQ2PDZ256rmk = 7402,
  VCVTUQQ2PDZ256rmkz = 7403,
  VCVTUQQ2PDZ256rr = 7404,
  VCVTUQQ2PDZ256rrk = 7405,
  VCVTUQQ2PDZ256rrkz = 7406,
  VCVTUQQ2PDZrm = 7407,
  VCVTUQQ2PDZrmb = 7408,
  VCVTUQQ2PDZrmbk = 7409,
  VCVTUQQ2PDZrmbkz = 7410,
  VCVTUQQ2PDZrmk = 7411,
  VCVTUQQ2PDZrmkz = 7412,
  VCVTUQQ2PDZrr = 7413,
  VCVTUQQ2PDZrrb = 7414,
  VCVTUQQ2PDZrrbk = 7415,
  VCVTUQQ2PDZrrbkz = 7416,
  VCVTUQQ2PDZrrk = 7417,
  VCVTUQQ2PDZrrkz = 7418,
  VCVTUQQ2PHZ128rm = 7419,
  VCVTUQQ2PHZ128rmb = 7420,
  VCVTUQQ2PHZ128rmbk = 7421,
  VCVTUQQ2PHZ128rmbkz = 7422,
  VCVTUQQ2PHZ128rmk = 7423,
  VCVTUQQ2PHZ128rmkz = 7424,
  VCVTUQQ2PHZ128rr = 7425,
  VCVTUQQ2PHZ128rrk = 7426,
  VCVTUQQ2PHZ128rrkz = 7427,
  VCVTUQQ2PHZ256rm = 7428,
  VCVTUQQ2PHZ256rmb = 7429,
  VCVTUQQ2PHZ256rmbk = 7430,
  VCVTUQQ2PHZ256rmbkz = 7431,
  VCVTUQQ2PHZ256rmk = 7432,
  VCVTUQQ2PHZ256rmkz = 7433,
  VCVTUQQ2PHZ256rr = 7434,
  VCVTUQQ2PHZ256rrk = 7435,
  VCVTUQQ2PHZ256rrkz = 7436,
  VCVTUQQ2PHZrm = 7437,
  VCVTUQQ2PHZrmb = 7438,
  VCVTUQQ2PHZrmbk = 7439,
  VCVTUQQ2PHZrmbkz = 7440,
  VCVTUQQ2PHZrmk = 7441,
  VCVTUQQ2PHZrmkz = 7442,
  VCVTUQQ2PHZrr = 7443,
  VCVTUQQ2PHZrrb = 7444,
  VCVTUQQ2PHZrrbk = 7445,
  VCVTUQQ2PHZrrbkz = 7446,
  VCVTUQQ2PHZrrk = 7447,
  VCVTUQQ2PHZrrkz = 7448,
  VCVTUQQ2PSZ128rm = 7449,
  VCVTUQQ2PSZ128rmb = 7450,
  VCVTUQQ2PSZ128rmbk = 7451,
  VCVTUQQ2PSZ128rmbkz = 7452,
  VCVTUQQ2PSZ128rmk = 7453,
  VCVTUQQ2PSZ128rmkz = 7454,
  VCVTUQQ2PSZ128rr = 7455,
  VCVTUQQ2PSZ128rrk = 7456,
  VCVTUQQ2PSZ128rrkz = 7457,
  VCVTUQQ2PSZ256rm = 7458,
  VCVTUQQ2PSZ256rmb = 7459,
  VCVTUQQ2PSZ256rmbk = 7460,
  VCVTUQQ2PSZ256rmbkz = 7461,
  VCVTUQQ2PSZ256rmk = 7462,
  VCVTUQQ2PSZ256rmkz = 7463,
  VCVTUQQ2PSZ256rr = 7464,
  VCVTUQQ2PSZ256rrk = 7465,
  VCVTUQQ2PSZ256rrkz = 7466,
  VCVTUQQ2PSZrm = 7467,
  VCVTUQQ2PSZrmb = 7468,
  VCVTUQQ2PSZrmbk = 7469,
  VCVTUQQ2PSZrmbkz = 7470,
  VCVTUQQ2PSZrmk = 7471,
  VCVTUQQ2PSZrmkz = 7472,
  VCVTUQQ2PSZrr = 7473,
  VCVTUQQ2PSZrrb = 7474,
  VCVTUQQ2PSZrrbk = 7475,
  VCVTUQQ2PSZrrbkz = 7476,
  VCVTUQQ2PSZrrk = 7477,
  VCVTUQQ2PSZrrkz = 7478,
  VCVTUSI2SDZrm = 7479,
  VCVTUSI2SDZrm_Int = 7480,
  VCVTUSI2SDZrr = 7481,
  VCVTUSI2SDZrr_Int = 7482,
  VCVTUSI2SHZrm = 7483,
  VCVTUSI2SHZrm_Int = 7484,
  VCVTUSI2SHZrr = 7485,
  VCVTUSI2SHZrr_Int = 7486,
  VCVTUSI2SHZrrb_Int = 7487,
  VCVTUSI2SSZrm = 7488,
  VCVTUSI2SSZrm_Int = 7489,
  VCVTUSI2SSZrr = 7490,
  VCVTUSI2SSZrr_Int = 7491,
  VCVTUSI2SSZrrb_Int = 7492,
  VCVTUSI642SDZrm = 7493,
  VCVTUSI642SDZrm_Int = 7494,
  VCVTUSI642SDZrr = 7495,
  VCVTUSI642SDZrr_Int = 7496,
  VCVTUSI642SDZrrb_Int = 7497,
  VCVTUSI642SHZrm = 7498,
  VCVTUSI642SHZrm_Int = 7499,
  VCVTUSI642SHZrr = 7500,
  VCVTUSI642SHZrr_Int = 7501,
  VCVTUSI642SHZrrb_Int = 7502,
  VCVTUSI642SSZrm = 7503,
  VCVTUSI642SSZrm_Int = 7504,
  VCVTUSI642SSZrr = 7505,
  VCVTUSI642SSZrr_Int = 7506,
  VCVTUSI642SSZrrb_Int = 7507,
  VCVTUW2PHZ128rm = 7508,
  VCVTUW2PHZ128rmb = 7509,
  VCVTUW2PHZ128rmbk = 7510,
  VCVTUW2PHZ128rmbkz = 7511,
  VCVTUW2PHZ128rmk = 7512,
  VCVTUW2PHZ128rmkz = 7513,
  VCVTUW2PHZ128rr = 7514,
  VCVTUW2PHZ128rrk = 7515,
  VCVTUW2PHZ128rrkz = 7516,
  VCVTUW2PHZ256rm = 7517,
  VCVTUW2PHZ256rmb = 7518,
  VCVTUW2PHZ256rmbk = 7519,
  VCVTUW2PHZ256rmbkz = 7520,
  VCVTUW2PHZ256rmk = 7521,
  VCVTUW2PHZ256rmkz = 7522,
  VCVTUW2PHZ256rr = 7523,
  VCVTUW2PHZ256rrk = 7524,
  VCVTUW2PHZ256rrkz = 7525,
  VCVTUW2PHZrm = 7526,
  VCVTUW2PHZrmb = 7527,
  VCVTUW2PHZrmbk = 7528,
  VCVTUW2PHZrmbkz = 7529,
  VCVTUW2PHZrmk = 7530,
  VCVTUW2PHZrmkz = 7531,
  VCVTUW2PHZrr = 7532,
  VCVTUW2PHZrrb = 7533,
  VCVTUW2PHZrrbk = 7534,
  VCVTUW2PHZrrbkz = 7535,
  VCVTUW2PHZrrk = 7536,
  VCVTUW2PHZrrkz = 7537,
  VCVTW2PHZ128rm = 7538,
  VCVTW2PHZ128rmb = 7539,
  VCVTW2PHZ128rmbk = 7540,
  VCVTW2PHZ128rmbkz = 7541,
  VCVTW2PHZ128rmk = 7542,
  VCVTW2PHZ128rmkz = 7543,
  VCVTW2PHZ128rr = 7544,
  VCVTW2PHZ128rrk = 7545,
  VCVTW2PHZ128rrkz = 7546,
  VCVTW2PHZ256rm = 7547,
  VCVTW2PHZ256rmb = 7548,
  VCVTW2PHZ256rmbk = 7549,
  VCVTW2PHZ256rmbkz = 7550,
  VCVTW2PHZ256rmk = 7551,
  VCVTW2PHZ256rmkz = 7552,
  VCVTW2PHZ256rr = 7553,
  VCVTW2PHZ256rrk = 7554,
  VCVTW2PHZ256rrkz = 7555,
  VCVTW2PHZrm = 7556,
  VCVTW2PHZrmb = 7557,
  VCVTW2PHZrmbk = 7558,
  VCVTW2PHZrmbkz = 7559,
  VCVTW2PHZrmk = 7560,
  VCVTW2PHZrmkz = 7561,
  VCVTW2PHZrr = 7562,
  VCVTW2PHZrrb = 7563,
  VCVTW2PHZrrbk = 7564,
  VCVTW2PHZrrbkz = 7565,
  VCVTW2PHZrrk = 7566,
  VCVTW2PHZrrkz = 7567,
  VDBPSADBWZ128rmi = 7568,
  VDBPSADBWZ128rmik = 7569,
  VDBPSADBWZ128rmikz = 7570,
  VDBPSADBWZ128rri = 7571,
  VDBPSADBWZ128rrik = 7572,
  VDBPSADBWZ128rrikz = 7573,
  VDBPSADBWZ256rmi = 7574,
  VDBPSADBWZ256rmik = 7575,
  VDBPSADBWZ256rmikz = 7576,
  VDBPSADBWZ256rri = 7577,
  VDBPSADBWZ256rrik = 7578,
  VDBPSADBWZ256rrikz = 7579,
  VDBPSADBWZrmi = 7580,
  VDBPSADBWZrmik = 7581,
  VDBPSADBWZrmikz = 7582,
  VDBPSADBWZrri = 7583,
  VDBPSADBWZrrik = 7584,
  VDBPSADBWZrrikz = 7585,
  VDIVPDYrm = 7586,
  VDIVPDYrr = 7587,
  VDIVPDZ128rm = 7588,
  VDIVPDZ128rmb = 7589,
  VDIVPDZ128rmbk = 7590,
  VDIVPDZ128rmbkz = 7591,
  VDIVPDZ128rmk = 7592,
  VDIVPDZ128rmkz = 7593,
  VDIVPDZ128rr = 7594,
  VDIVPDZ128rrk = 7595,
  VDIVPDZ128rrkz = 7596,
  VDIVPDZ256rm = 7597,
  VDIVPDZ256rmb = 7598,
  VDIVPDZ256rmbk = 7599,
  VDIVPDZ256rmbkz = 7600,
  VDIVPDZ256rmk = 7601,
  VDIVPDZ256rmkz = 7602,
  VDIVPDZ256rr = 7603,
  VDIVPDZ256rrk = 7604,
  VDIVPDZ256rrkz = 7605,
  VDIVPDZrm = 7606,
  VDIVPDZrmb = 7607,
  VDIVPDZrmbk = 7608,
  VDIVPDZrmbkz = 7609,
  VDIVPDZrmk = 7610,
  VDIVPDZrmkz = 7611,
  VDIVPDZrr = 7612,
  VDIVPDZrrb = 7613,
  VDIVPDZrrbk = 7614,
  VDIVPDZrrbkz = 7615,
  VDIVPDZrrk = 7616,
  VDIVPDZrrkz = 7617,
  VDIVPDrm = 7618,
  VDIVPDrr = 7619,
  VDIVPHZ128rm = 7620,
  VDIVPHZ128rmb = 7621,
  VDIVPHZ128rmbk = 7622,
  VDIVPHZ128rmbkz = 7623,
  VDIVPHZ128rmk = 7624,
  VDIVPHZ128rmkz = 7625,
  VDIVPHZ128rr = 7626,
  VDIVPHZ128rrk = 7627,
  VDIVPHZ128rrkz = 7628,
  VDIVPHZ256rm = 7629,
  VDIVPHZ256rmb = 7630,
  VDIVPHZ256rmbk = 7631,
  VDIVPHZ256rmbkz = 7632,
  VDIVPHZ256rmk = 7633,
  VDIVPHZ256rmkz = 7634,
  VDIVPHZ256rr = 7635,
  VDIVPHZ256rrk = 7636,
  VDIVPHZ256rrkz = 7637,
  VDIVPHZrm = 7638,
  VDIVPHZrmb = 7639,
  VDIVPHZrmbk = 7640,
  VDIVPHZrmbkz = 7641,
  VDIVPHZrmk = 7642,
  VDIVPHZrmkz = 7643,
  VDIVPHZrr = 7644,
  VDIVPHZrrb = 7645,
  VDIVPHZrrbk = 7646,
  VDIVPHZrrbkz = 7647,
  VDIVPHZrrk = 7648,
  VDIVPHZrrkz = 7649,
  VDIVPSYrm = 7650,
  VDIVPSYrr = 7651,
  VDIVPSZ128rm = 7652,
  VDIVPSZ128rmb = 7653,
  VDIVPSZ128rmbk = 7654,
  VDIVPSZ128rmbkz = 7655,
  VDIVPSZ128rmk = 7656,
  VDIVPSZ128rmkz = 7657,
  VDIVPSZ128rr = 7658,
  VDIVPSZ128rrk = 7659,
  VDIVPSZ128rrkz = 7660,
  VDIVPSZ256rm = 7661,
  VDIVPSZ256rmb = 7662,
  VDIVPSZ256rmbk = 7663,
  VDIVPSZ256rmbkz = 7664,
  VDIVPSZ256rmk = 7665,
  VDIVPSZ256rmkz = 7666,
  VDIVPSZ256rr = 7667,
  VDIVPSZ256rrk = 7668,
  VDIVPSZ256rrkz = 7669,
  VDIVPSZrm = 7670,
  VDIVPSZrmb = 7671,
  VDIVPSZrmbk = 7672,
  VDIVPSZrmbkz = 7673,
  VDIVPSZrmk = 7674,
  VDIVPSZrmkz = 7675,
  VDIVPSZrr = 7676,
  VDIVPSZrrb = 7677,
  VDIVPSZrrbk = 7678,
  VDIVPSZrrbkz = 7679,
  VDIVPSZrrk = 7680,
  VDIVPSZrrkz = 7681,
  VDIVPSrm = 7682,
  VDIVPSrr = 7683,
  VDIVSDZrm = 7684,
  VDIVSDZrm_Int = 7685,
  VDIVSDZrm_Intk = 7686,
  VDIVSDZrm_Intkz = 7687,
  VDIVSDZrr = 7688,
  VDIVSDZrr_Int = 7689,
  VDIVSDZrr_Intk = 7690,
  VDIVSDZrr_Intkz = 7691,
  VDIVSDZrrb_Int = 7692,
  VDIVSDZrrb_Intk = 7693,
  VDIVSDZrrb_Intkz = 7694,
  VDIVSDrm = 7695,
  VDIVSDrm_Int = 7696,
  VDIVSDrr = 7697,
  VDIVSDrr_Int = 7698,
  VDIVSHZrm = 7699,
  VDIVSHZrm_Int = 7700,
  VDIVSHZrm_Intk = 7701,
  VDIVSHZrm_Intkz = 7702,
  VDIVSHZrr = 7703,
  VDIVSHZrr_Int = 7704,
  VDIVSHZrr_Intk = 7705,
  VDIVSHZrr_Intkz = 7706,
  VDIVSHZrrb_Int = 7707,
  VDIVSHZrrb_Intk = 7708,
  VDIVSHZrrb_Intkz = 7709,
  VDIVSSZrm = 7710,
  VDIVSSZrm_Int = 7711,
  VDIVSSZrm_Intk = 7712,
  VDIVSSZrm_Intkz = 7713,
  VDIVSSZrr = 7714,
  VDIVSSZrr_Int = 7715,
  VDIVSSZrr_Intk = 7716,
  VDIVSSZrr_Intkz = 7717,
  VDIVSSZrrb_Int = 7718,
  VDIVSSZrrb_Intk = 7719,
  VDIVSSZrrb_Intkz = 7720,
  VDIVSSrm = 7721,
  VDIVSSrm_Int = 7722,
  VDIVSSrr = 7723,
  VDIVSSrr_Int = 7724,
  VDPBF16PSZ128m = 7725,
  VDPBF16PSZ128mb = 7726,
  VDPBF16PSZ128mbk = 7727,
  VDPBF16PSZ128mbkz = 7728,
  VDPBF16PSZ128mk = 7729,
  VDPBF16PSZ128mkz = 7730,
  VDPBF16PSZ128r = 7731,
  VDPBF16PSZ128rk = 7732,
  VDPBF16PSZ128rkz = 7733,
  VDPBF16PSZ256m = 7734,
  VDPBF16PSZ256mb = 7735,
  VDPBF16PSZ256mbk = 7736,
  VDPBF16PSZ256mbkz = 7737,
  VDPBF16PSZ256mk = 7738,
  VDPBF16PSZ256mkz = 7739,
  VDPBF16PSZ256r = 7740,
  VDPBF16PSZ256rk = 7741,
  VDPBF16PSZ256rkz = 7742,
  VDPBF16PSZm = 7743,
  VDPBF16PSZmb = 7744,
  VDPBF16PSZmbk = 7745,
  VDPBF16PSZmbkz = 7746,
  VDPBF16PSZmk = 7747,
  VDPBF16PSZmkz = 7748,
  VDPBF16PSZr = 7749,
  VDPBF16PSZrk = 7750,
  VDPBF16PSZrkz = 7751,
  VDPPDrmi = 7752,
  VDPPDrri = 7753,
  VDPPSYrmi = 7754,
  VDPPSYrri = 7755,
  VDPPSrmi = 7756,
  VDPPSrri = 7757,
  VERRm = 7758,
  VERRr = 7759,
  VERWm = 7760,
  VERWr = 7761,
  VEXP2PDZm = 7762,
  VEXP2PDZmb = 7763,
  VEXP2PDZmbk = 7764,
  VEXP2PDZmbkz = 7765,
  VEXP2PDZmk = 7766,
  VEXP2PDZmkz = 7767,
  VEXP2PDZr = 7768,
  VEXP2PDZrb = 7769,
  VEXP2PDZrbk = 7770,
  VEXP2PDZrbkz = 7771,
  VEXP2PDZrk = 7772,
  VEXP2PDZrkz = 7773,
  VEXP2PSZm = 7774,
  VEXP2PSZmb = 7775,
  VEXP2PSZmbk = 7776,
  VEXP2PSZmbkz = 7777,
  VEXP2PSZmk = 7778,
  VEXP2PSZmkz = 7779,
  VEXP2PSZr = 7780,
  VEXP2PSZrb = 7781,
  VEXP2PSZrbk = 7782,
  VEXP2PSZrbkz = 7783,
  VEXP2PSZrk = 7784,
  VEXP2PSZrkz = 7785,
  VEXPANDPDZ128rm = 7786,
  VEXPANDPDZ128rmk = 7787,
  VEXPANDPDZ128rmkz = 7788,
  VEXPANDPDZ128rr = 7789,
  VEXPANDPDZ128rrk = 7790,
  VEXPANDPDZ128rrkz = 7791,
  VEXPANDPDZ256rm = 7792,
  VEXPANDPDZ256rmk = 7793,
  VEXPANDPDZ256rmkz = 7794,
  VEXPANDPDZ256rr = 7795,
  VEXPANDPDZ256rrk = 7796,
  VEXPANDPDZ256rrkz = 7797,
  VEXPANDPDZrm = 7798,
  VEXPANDPDZrmk = 7799,
  VEXPANDPDZrmkz = 7800,
  VEXPANDPDZrr = 7801,
  VEXPANDPDZrrk = 7802,
  VEXPANDPDZrrkz = 7803,
  VEXPANDPSZ128rm = 7804,
  VEXPANDPSZ128rmk = 7805,
  VEXPANDPSZ128rmkz = 7806,
  VEXPANDPSZ128rr = 7807,
  VEXPANDPSZ128rrk = 7808,
  VEXPANDPSZ128rrkz = 7809,
  VEXPANDPSZ256rm = 7810,
  VEXPANDPSZ256rmk = 7811,
  VEXPANDPSZ256rmkz = 7812,
  VEXPANDPSZ256rr = 7813,
  VEXPANDPSZ256rrk = 7814,
  VEXPANDPSZ256rrkz = 7815,
  VEXPANDPSZrm = 7816,
  VEXPANDPSZrmk = 7817,
  VEXPANDPSZrmkz = 7818,
  VEXPANDPSZrr = 7819,
  VEXPANDPSZrrk = 7820,
  VEXPANDPSZrrkz = 7821,
  VEXTRACTF128mr = 7822,
  VEXTRACTF128rr = 7823,
  VEXTRACTF32x4Z256mr = 7824,
  VEXTRACTF32x4Z256mrk = 7825,
  VEXTRACTF32x4Z256rr = 7826,
  VEXTRACTF32x4Z256rrk = 7827,
  VEXTRACTF32x4Z256rrkz = 7828,
  VEXTRACTF32x4Zmr = 7829,
  VEXTRACTF32x4Zmrk = 7830,
  VEXTRACTF32x4Zrr = 7831,
  VEXTRACTF32x4Zrrk = 7832,
  VEXTRACTF32x4Zrrkz = 7833,
  VEXTRACTF32x8Zmr = 7834,
  VEXTRACTF32x8Zmrk = 7835,
  VEXTRACTF32x8Zrr = 7836,
  VEXTRACTF32x8Zrrk = 7837,
  VEXTRACTF32x8Zrrkz = 7838,
  VEXTRACTF64x2Z256mr = 7839,
  VEXTRACTF64x2Z256mrk = 7840,
  VEXTRACTF64x2Z256rr = 7841,
  VEXTRACTF64x2Z256rrk = 7842,
  VEXTRACTF64x2Z256rrkz = 7843,
  VEXTRACTF64x2Zmr = 7844,
  VEXTRACTF64x2Zmrk = 7845,
  VEXTRACTF64x2Zrr = 7846,
  VEXTRACTF64x2Zrrk = 7847,
  VEXTRACTF64x2Zrrkz = 7848,
  VEXTRACTF64x4Zmr = 7849,
  VEXTRACTF64x4Zmrk = 7850,
  VEXTRACTF64x4Zrr = 7851,
  VEXTRACTF64x4Zrrk = 7852,
  VEXTRACTF64x4Zrrkz = 7853,
  VEXTRACTI128mr = 7854,
  VEXTRACTI128rr = 7855,
  VEXTRACTI32x4Z256mr = 7856,
  VEXTRACTI32x4Z256mrk = 7857,
  VEXTRACTI32x4Z256rr = 7858,
  VEXTRACTI32x4Z256rrk = 7859,
  VEXTRACTI32x4Z256rrkz = 7860,
  VEXTRACTI32x4Zmr = 7861,
  VEXTRACTI32x4Zmrk = 7862,
  VEXTRACTI32x4Zrr = 7863,
  VEXTRACTI32x4Zrrk = 7864,
  VEXTRACTI32x4Zrrkz = 7865,
  VEXTRACTI32x8Zmr = 7866,
  VEXTRACTI32x8Zmrk = 7867,
  VEXTRACTI32x8Zrr = 7868,
  VEXTRACTI32x8Zrrk = 7869,
  VEXTRACTI32x8Zrrkz = 7870,
  VEXTRACTI64x2Z256mr = 7871,
  VEXTRACTI64x2Z256mrk = 7872,
  VEXTRACTI64x2Z256rr = 7873,
  VEXTRACTI64x2Z256rrk = 7874,
  VEXTRACTI64x2Z256rrkz = 7875,
  VEXTRACTI64x2Zmr = 7876,
  VEXTRACTI64x2Zmrk = 7877,
  VEXTRACTI64x2Zrr = 7878,
  VEXTRACTI64x2Zrrk = 7879,
  VEXTRACTI64x2Zrrkz = 7880,
  VEXTRACTI64x4Zmr = 7881,
  VEXTRACTI64x4Zmrk = 7882,
  VEXTRACTI64x4Zrr = 7883,
  VEXTRACTI64x4Zrrk = 7884,
  VEXTRACTI64x4Zrrkz = 7885,
  VEXTRACTPSZmr = 7886,
  VEXTRACTPSZrr = 7887,
  VEXTRACTPSmr = 7888,
  VEXTRACTPSrr = 7889,
  VFCMADDCPHZ128m = 7890,
  VFCMADDCPHZ128mb = 7891,
  VFCMADDCPHZ128mbk = 7892,
  VFCMADDCPHZ128mbkz = 7893,
  VFCMADDCPHZ128mk = 7894,
  VFCMADDCPHZ128mkz = 7895,
  VFCMADDCPHZ128r = 7896,
  VFCMADDCPHZ128rk = 7897,
  VFCMADDCPHZ128rkz = 7898,
  VFCMADDCPHZ256m = 7899,
  VFCMADDCPHZ256mb = 7900,
  VFCMADDCPHZ256mbk = 7901,
  VFCMADDCPHZ256mbkz = 7902,
  VFCMADDCPHZ256mk = 7903,
  VFCMADDCPHZ256mkz = 7904,
  VFCMADDCPHZ256r = 7905,
  VFCMADDCPHZ256rk = 7906,
  VFCMADDCPHZ256rkz = 7907,
  VFCMADDCPHZm = 7908,
  VFCMADDCPHZmb = 7909,
  VFCMADDCPHZmbk = 7910,
  VFCMADDCPHZmbkz = 7911,
  VFCMADDCPHZmk = 7912,
  VFCMADDCPHZmkz = 7913,
  VFCMADDCPHZr = 7914,
  VFCMADDCPHZrb = 7915,
  VFCMADDCPHZrbk = 7916,
  VFCMADDCPHZrbkz = 7917,
  VFCMADDCPHZrk = 7918,
  VFCMADDCPHZrkz = 7919,
  VFCMADDCSHZm = 7920,
  VFCMADDCSHZmk = 7921,
  VFCMADDCSHZmkz = 7922,
  VFCMADDCSHZr = 7923,
  VFCMADDCSHZrb = 7924,
  VFCMADDCSHZrbk = 7925,
  VFCMADDCSHZrbkz = 7926,
  VFCMADDCSHZrk = 7927,
  VFCMADDCSHZrkz = 7928,
  VFCMULCPHZ128rm = 7929,
  VFCMULCPHZ128rmb = 7930,
  VFCMULCPHZ128rmbk = 7931,
  VFCMULCPHZ128rmbkz = 7932,
  VFCMULCPHZ128rmk = 7933,
  VFCMULCPHZ128rmkz = 7934,
  VFCMULCPHZ128rr = 7935,
  VFCMULCPHZ128rrk = 7936,
  VFCMULCPHZ128rrkz = 7937,
  VFCMULCPHZ256rm = 7938,
  VFCMULCPHZ256rmb = 7939,
  VFCMULCPHZ256rmbk = 7940,
  VFCMULCPHZ256rmbkz = 7941,
  VFCMULCPHZ256rmk = 7942,
  VFCMULCPHZ256rmkz = 7943,
  VFCMULCPHZ256rr = 7944,
  VFCMULCPHZ256rrk = 7945,
  VFCMULCPHZ256rrkz = 7946,
  VFCMULCPHZrm = 7947,
  VFCMULCPHZrmb = 7948,
  VFCMULCPHZrmbk = 7949,
  VFCMULCPHZrmbkz = 7950,
  VFCMULCPHZrmk = 7951,
  VFCMULCPHZrmkz = 7952,
  VFCMULCPHZrr = 7953,
  VFCMULCPHZrrb = 7954,
  VFCMULCPHZrrbk = 7955,
  VFCMULCPHZrrbkz = 7956,
  VFCMULCPHZrrk = 7957,
  VFCMULCPHZrrkz = 7958,
  VFCMULCSHZrm = 7959,
  VFCMULCSHZrmk = 7960,
  VFCMULCSHZrmkz = 7961,
  VFCMULCSHZrr = 7962,
  VFCMULCSHZrrb = 7963,
  VFCMULCSHZrrbk = 7964,
  VFCMULCSHZrrbkz = 7965,
  VFCMULCSHZrrk = 7966,
  VFCMULCSHZrrkz = 7967,
  VFIXUPIMMPDZ128rmbi = 7968,
  VFIXUPIMMPDZ128rmbik = 7969,
  VFIXUPIMMPDZ128rmbikz = 7970,
  VFIXUPIMMPDZ128rmi = 7971,
  VFIXUPIMMPDZ128rmik = 7972,
  VFIXUPIMMPDZ128rmikz = 7973,
  VFIXUPIMMPDZ128rri = 7974,
  VFIXUPIMMPDZ128rrik = 7975,
  VFIXUPIMMPDZ128rrikz = 7976,
  VFIXUPIMMPDZ256rmbi = 7977,
  VFIXUPIMMPDZ256rmbik = 7978,
  VFIXUPIMMPDZ256rmbikz = 7979,
  VFIXUPIMMPDZ256rmi = 7980,
  VFIXUPIMMPDZ256rmik = 7981,
  VFIXUPIMMPDZ256rmikz = 7982,
  VFIXUPIMMPDZ256rri = 7983,
  VFIXUPIMMPDZ256rrik = 7984,
  VFIXUPIMMPDZ256rrikz = 7985,
  VFIXUPIMMPDZrmbi = 7986,
  VFIXUPIMMPDZrmbik = 7987,
  VFIXUPIMMPDZrmbikz = 7988,
  VFIXUPIMMPDZrmi = 7989,
  VFIXUPIMMPDZrmik = 7990,
  VFIXUPIMMPDZrmikz = 7991,
  VFIXUPIMMPDZrri = 7992,
  VFIXUPIMMPDZrrib = 7993,
  VFIXUPIMMPDZrribk = 7994,
  VFIXUPIMMPDZrribkz = 7995,
  VFIXUPIMMPDZrrik = 7996,
  VFIXUPIMMPDZrrikz = 7997,
  VFIXUPIMMPSZ128rmbi = 7998,
  VFIXUPIMMPSZ128rmbik = 7999,
  VFIXUPIMMPSZ128rmbikz = 8000,
  VFIXUPIMMPSZ128rmi = 8001,
  VFIXUPIMMPSZ128rmik = 8002,
  VFIXUPIMMPSZ128rmikz = 8003,
  VFIXUPIMMPSZ128rri = 8004,
  VFIXUPIMMPSZ128rrik = 8005,
  VFIXUPIMMPSZ128rrikz = 8006,
  VFIXUPIMMPSZ256rmbi = 8007,
  VFIXUPIMMPSZ256rmbik = 8008,
  VFIXUPIMMPSZ256rmbikz = 8009,
  VFIXUPIMMPSZ256rmi = 8010,
  VFIXUPIMMPSZ256rmik = 8011,
  VFIXUPIMMPSZ256rmikz = 8012,
  VFIXUPIMMPSZ256rri = 8013,
  VFIXUPIMMPSZ256rrik = 8014,
  VFIXUPIMMPSZ256rrikz = 8015,
  VFIXUPIMMPSZrmbi = 8016,
  VFIXUPIMMPSZrmbik = 8017,
  VFIXUPIMMPSZrmbikz = 8018,
  VFIXUPIMMPSZrmi = 8019,
  VFIXUPIMMPSZrmik = 8020,
  VFIXUPIMMPSZrmikz = 8021,
  VFIXUPIMMPSZrri = 8022,
  VFIXUPIMMPSZrrib = 8023,
  VFIXUPIMMPSZrribk = 8024,
  VFIXUPIMMPSZrribkz = 8025,
  VFIXUPIMMPSZrrik = 8026,
  VFIXUPIMMPSZrrikz = 8027,
  VFIXUPIMMSDZrmi = 8028,
  VFIXUPIMMSDZrmik = 8029,
  VFIXUPIMMSDZrmikz = 8030,
  VFIXUPIMMSDZrri = 8031,
  VFIXUPIMMSDZrrib = 8032,
  VFIXUPIMMSDZrribk = 8033,
  VFIXUPIMMSDZrribkz = 8034,
  VFIXUPIMMSDZrrik = 8035,
  VFIXUPIMMSDZrrikz = 8036,
  VFIXUPIMMSSZrmi = 8037,
  VFIXUPIMMSSZrmik = 8038,
  VFIXUPIMMSSZrmikz = 8039,
  VFIXUPIMMSSZrri = 8040,
  VFIXUPIMMSSZrrib = 8041,
  VFIXUPIMMSSZrribk = 8042,
  VFIXUPIMMSSZrribkz = 8043,
  VFIXUPIMMSSZrrik = 8044,
  VFIXUPIMMSSZrrikz = 8045,
  VFMADD132PDYm = 8046,
  VFMADD132PDYr = 8047,
  VFMADD132PDZ128m = 8048,
  VFMADD132PDZ128mb = 8049,
  VFMADD132PDZ128mbk = 8050,
  VFMADD132PDZ128mbkz = 8051,
  VFMADD132PDZ128mk = 8052,
  VFMADD132PDZ128mkz = 8053,
  VFMADD132PDZ128r = 8054,
  VFMADD132PDZ128rk = 8055,
  VFMADD132PDZ128rkz = 8056,
  VFMADD132PDZ256m = 8057,
  VFMADD132PDZ256mb = 8058,
  VFMADD132PDZ256mbk = 8059,
  VFMADD132PDZ256mbkz = 8060,
  VFMADD132PDZ256mk = 8061,
  VFMADD132PDZ256mkz = 8062,
  VFMADD132PDZ256r = 8063,
  VFMADD132PDZ256rk = 8064,
  VFMADD132PDZ256rkz = 8065,
  VFMADD132PDZm = 8066,
  VFMADD132PDZmb = 8067,
  VFMADD132PDZmbk = 8068,
  VFMADD132PDZmbkz = 8069,
  VFMADD132PDZmk = 8070,
  VFMADD132PDZmkz = 8071,
  VFMADD132PDZr = 8072,
  VFMADD132PDZrb = 8073,
  VFMADD132PDZrbk = 8074,
  VFMADD132PDZrbkz = 8075,
  VFMADD132PDZrk = 8076,
  VFMADD132PDZrkz = 8077,
  VFMADD132PDm = 8078,
  VFMADD132PDr = 8079,
  VFMADD132PHZ128m = 8080,
  VFMADD132PHZ128mb = 8081,
  VFMADD132PHZ128mbk = 8082,
  VFMADD132PHZ128mbkz = 8083,
  VFMADD132PHZ128mk = 8084,
  VFMADD132PHZ128mkz = 8085,
  VFMADD132PHZ128r = 8086,
  VFMADD132PHZ128rk = 8087,
  VFMADD132PHZ128rkz = 8088,
  VFMADD132PHZ256m = 8089,
  VFMADD132PHZ256mb = 8090,
  VFMADD132PHZ256mbk = 8091,
  VFMADD132PHZ256mbkz = 8092,
  VFMADD132PHZ256mk = 8093,
  VFMADD132PHZ256mkz = 8094,
  VFMADD132PHZ256r = 8095,
  VFMADD132PHZ256rk = 8096,
  VFMADD132PHZ256rkz = 8097,
  VFMADD132PHZm = 8098,
  VFMADD132PHZmb = 8099,
  VFMADD132PHZmbk = 8100,
  VFMADD132PHZmbkz = 8101,
  VFMADD132PHZmk = 8102,
  VFMADD132PHZmkz = 8103,
  VFMADD132PHZr = 8104,
  VFMADD132PHZrb = 8105,
  VFMADD132PHZrbk = 8106,
  VFMADD132PHZrbkz = 8107,
  VFMADD132PHZrk = 8108,
  VFMADD132PHZrkz = 8109,
  VFMADD132PSYm = 8110,
  VFMADD132PSYr = 8111,
  VFMADD132PSZ128m = 8112,
  VFMADD132PSZ128mb = 8113,
  VFMADD132PSZ128mbk = 8114,
  VFMADD132PSZ128mbkz = 8115,
  VFMADD132PSZ128mk = 8116,
  VFMADD132PSZ128mkz = 8117,
  VFMADD132PSZ128r = 8118,
  VFMADD132PSZ128rk = 8119,
  VFMADD132PSZ128rkz = 8120,
  VFMADD132PSZ256m = 8121,
  VFMADD132PSZ256mb = 8122,
  VFMADD132PSZ256mbk = 8123,
  VFMADD132PSZ256mbkz = 8124,
  VFMADD132PSZ256mk = 8125,
  VFMADD132PSZ256mkz = 8126,
  VFMADD132PSZ256r = 8127,
  VFMADD132PSZ256rk = 8128,
  VFMADD132PSZ256rkz = 8129,
  VFMADD132PSZm = 8130,
  VFMADD132PSZmb = 8131,
  VFMADD132PSZmbk = 8132,
  VFMADD132PSZmbkz = 8133,
  VFMADD132PSZmk = 8134,
  VFMADD132PSZmkz = 8135,
  VFMADD132PSZr = 8136,
  VFMADD132PSZrb = 8137,
  VFMADD132PSZrbk = 8138,
  VFMADD132PSZrbkz = 8139,
  VFMADD132PSZrk = 8140,
  VFMADD132PSZrkz = 8141,
  VFMADD132PSm = 8142,
  VFMADD132PSr = 8143,
  VFMADD132SDZm = 8144,
  VFMADD132SDZm_Int = 8145,
  VFMADD132SDZm_Intk = 8146,
  VFMADD132SDZm_Intkz = 8147,
  VFMADD132SDZr = 8148,
  VFMADD132SDZr_Int = 8149,
  VFMADD132SDZr_Intk = 8150,
  VFMADD132SDZr_Intkz = 8151,
  VFMADD132SDZrb = 8152,
  VFMADD132SDZrb_Int = 8153,
  VFMADD132SDZrb_Intk = 8154,
  VFMADD132SDZrb_Intkz = 8155,
  VFMADD132SDm = 8156,
  VFMADD132SDm_Int = 8157,
  VFMADD132SDr = 8158,
  VFMADD132SDr_Int = 8159,
  VFMADD132SHZm = 8160,
  VFMADD132SHZm_Int = 8161,
  VFMADD132SHZm_Intk = 8162,
  VFMADD132SHZm_Intkz = 8163,
  VFMADD132SHZr = 8164,
  VFMADD132SHZr_Int = 8165,
  VFMADD132SHZr_Intk = 8166,
  VFMADD132SHZr_Intkz = 8167,
  VFMADD132SHZrb = 8168,
  VFMADD132SHZrb_Int = 8169,
  VFMADD132SHZrb_Intk = 8170,
  VFMADD132SHZrb_Intkz = 8171,
  VFMADD132SSZm = 8172,
  VFMADD132SSZm_Int = 8173,
  VFMADD132SSZm_Intk = 8174,
  VFMADD132SSZm_Intkz = 8175,
  VFMADD132SSZr = 8176,
  VFMADD132SSZr_Int = 8177,
  VFMADD132SSZr_Intk = 8178,
  VFMADD132SSZr_Intkz = 8179,
  VFMADD132SSZrb = 8180,
  VFMADD132SSZrb_Int = 8181,
  VFMADD132SSZrb_Intk = 8182,
  VFMADD132SSZrb_Intkz = 8183,
  VFMADD132SSm = 8184,
  VFMADD132SSm_Int = 8185,
  VFMADD132SSr = 8186,
  VFMADD132SSr_Int = 8187,
  VFMADD213PDYm = 8188,
  VFMADD213PDYr = 8189,
  VFMADD213PDZ128m = 8190,
  VFMADD213PDZ128mb = 8191,
  VFMADD213PDZ128mbk = 8192,
  VFMADD213PDZ128mbkz = 8193,
  VFMADD213PDZ128mk = 8194,
  VFMADD213PDZ128mkz = 8195,
  VFMADD213PDZ128r = 8196,
  VFMADD213PDZ128rk = 8197,
  VFMADD213PDZ128rkz = 8198,
  VFMADD213PDZ256m = 8199,
  VFMADD213PDZ256mb = 8200,
  VFMADD213PDZ256mbk = 8201,
  VFMADD213PDZ256mbkz = 8202,
  VFMADD213PDZ256mk = 8203,
  VFMADD213PDZ256mkz = 8204,
  VFMADD213PDZ256r = 8205,
  VFMADD213PDZ256rk = 8206,
  VFMADD213PDZ256rkz = 8207,
  VFMADD213PDZm = 8208,
  VFMADD213PDZmb = 8209,
  VFMADD213PDZmbk = 8210,
  VFMADD213PDZmbkz = 8211,
  VFMADD213PDZmk = 8212,
  VFMADD213PDZmkz = 8213,
  VFMADD213PDZr = 8214,
  VFMADD213PDZrb = 8215,
  VFMADD213PDZrbk = 8216,
  VFMADD213PDZrbkz = 8217,
  VFMADD213PDZrk = 8218,
  VFMADD213PDZrkz = 8219,
  VFMADD213PDm = 8220,
  VFMADD213PDr = 8221,
  VFMADD213PHZ128m = 8222,
  VFMADD213PHZ128mb = 8223,
  VFMADD213PHZ128mbk = 8224,
  VFMADD213PHZ128mbkz = 8225,
  VFMADD213PHZ128mk = 8226,
  VFMADD213PHZ128mkz = 8227,
  VFMADD213PHZ128r = 8228,
  VFMADD213PHZ128rk = 8229,
  VFMADD213PHZ128rkz = 8230,
  VFMADD213PHZ256m = 8231,
  VFMADD213PHZ256mb = 8232,
  VFMADD213PHZ256mbk = 8233,
  VFMADD213PHZ256mbkz = 8234,
  VFMADD213PHZ256mk = 8235,
  VFMADD213PHZ256mkz = 8236,
  VFMADD213PHZ256r = 8237,
  VFMADD213PHZ256rk = 8238,
  VFMADD213PHZ256rkz = 8239,
  VFMADD213PHZm = 8240,
  VFMADD213PHZmb = 8241,
  VFMADD213PHZmbk = 8242,
  VFMADD213PHZmbkz = 8243,
  VFMADD213PHZmk = 8244,
  VFMADD213PHZmkz = 8245,
  VFMADD213PHZr = 8246,
  VFMADD213PHZrb = 8247,
  VFMADD213PHZrbk = 8248,
  VFMADD213PHZrbkz = 8249,
  VFMADD213PHZrk = 8250,
  VFMADD213PHZrkz = 8251,
  VFMADD213PSYm = 8252,
  VFMADD213PSYr = 8253,
  VFMADD213PSZ128m = 8254,
  VFMADD213PSZ128mb = 8255,
  VFMADD213PSZ128mbk = 8256,
  VFMADD213PSZ128mbkz = 8257,
  VFMADD213PSZ128mk = 8258,
  VFMADD213PSZ128mkz = 8259,
  VFMADD213PSZ128r = 8260,
  VFMADD213PSZ128rk = 8261,
  VFMADD213PSZ128rkz = 8262,
  VFMADD213PSZ256m = 8263,
  VFMADD213PSZ256mb = 8264,
  VFMADD213PSZ256mbk = 8265,
  VFMADD213PSZ256mbkz = 8266,
  VFMADD213PSZ256mk = 8267,
  VFMADD213PSZ256mkz = 8268,
  VFMADD213PSZ256r = 8269,
  VFMADD213PSZ256rk = 8270,
  VFMADD213PSZ256rkz = 8271,
  VFMADD213PSZm = 8272,
  VFMADD213PSZmb = 8273,
  VFMADD213PSZmbk = 8274,
  VFMADD213PSZmbkz = 8275,
  VFMADD213PSZmk = 8276,
  VFMADD213PSZmkz = 8277,
  VFMADD213PSZr = 8278,
  VFMADD213PSZrb = 8279,
  VFMADD213PSZrbk = 8280,
  VFMADD213PSZrbkz = 8281,
  VFMADD213PSZrk = 8282,
  VFMADD213PSZrkz = 8283,
  VFMADD213PSm = 8284,
  VFMADD213PSr = 8285,
  VFMADD213SDZm = 8286,
  VFMADD213SDZm_Int = 8287,
  VFMADD213SDZm_Intk = 8288,
  VFMADD213SDZm_Intkz = 8289,
  VFMADD213SDZr = 8290,
  VFMADD213SDZr_Int = 8291,
  VFMADD213SDZr_Intk = 8292,
  VFMADD213SDZr_Intkz = 8293,
  VFMADD213SDZrb = 8294,
  VFMADD213SDZrb_Int = 8295,
  VFMADD213SDZrb_Intk = 8296,
  VFMADD213SDZrb_Intkz = 8297,
  VFMADD213SDm = 8298,
  VFMADD213SDm_Int = 8299,
  VFMADD213SDr = 8300,
  VFMADD213SDr_Int = 8301,
  VFMADD213SHZm = 8302,
  VFMADD213SHZm_Int = 8303,
  VFMADD213SHZm_Intk = 8304,
  VFMADD213SHZm_Intkz = 8305,
  VFMADD213SHZr = 8306,
  VFMADD213SHZr_Int = 8307,
  VFMADD213SHZr_Intk = 8308,
  VFMADD213SHZr_Intkz = 8309,
  VFMADD213SHZrb = 8310,
  VFMADD213SHZrb_Int = 8311,
  VFMADD213SHZrb_Intk = 8312,
  VFMADD213SHZrb_Intkz = 8313,
  VFMADD213SSZm = 8314,
  VFMADD213SSZm_Int = 8315,
  VFMADD213SSZm_Intk = 8316,
  VFMADD213SSZm_Intkz = 8317,
  VFMADD213SSZr = 8318,
  VFMADD213SSZr_Int = 8319,
  VFMADD213SSZr_Intk = 8320,
  VFMADD213SSZr_Intkz = 8321,
  VFMADD213SSZrb = 8322,
  VFMADD213SSZrb_Int = 8323,
  VFMADD213SSZrb_Intk = 8324,
  VFMADD213SSZrb_Intkz = 8325,
  VFMADD213SSm = 8326,
  VFMADD213SSm_Int = 8327,
  VFMADD213SSr = 8328,
  VFMADD213SSr_Int = 8329,
  VFMADD231PDYm = 8330,
  VFMADD231PDYr = 8331,
  VFMADD231PDZ128m = 8332,
  VFMADD231PDZ128mb = 8333,
  VFMADD231PDZ128mbk = 8334,
  VFMADD231PDZ128mbkz = 8335,
  VFMADD231PDZ128mk = 8336,
  VFMADD231PDZ128mkz = 8337,
  VFMADD231PDZ128r = 8338,
  VFMADD231PDZ128rk = 8339,
  VFMADD231PDZ128rkz = 8340,
  VFMADD231PDZ256m = 8341,
  VFMADD231PDZ256mb = 8342,
  VFMADD231PDZ256mbk = 8343,
  VFMADD231PDZ256mbkz = 8344,
  VFMADD231PDZ256mk = 8345,
  VFMADD231PDZ256mkz = 8346,
  VFMADD231PDZ256r = 8347,
  VFMADD231PDZ256rk = 8348,
  VFMADD231PDZ256rkz = 8349,
  VFMADD231PDZm = 8350,
  VFMADD231PDZmb = 8351,
  VFMADD231PDZmbk = 8352,
  VFMADD231PDZmbkz = 8353,
  VFMADD231PDZmk = 8354,
  VFMADD231PDZmkz = 8355,
  VFMADD231PDZr = 8356,
  VFMADD231PDZrb = 8357,
  VFMADD231PDZrbk = 8358,
  VFMADD231PDZrbkz = 8359,
  VFMADD231PDZrk = 8360,
  VFMADD231PDZrkz = 8361,
  VFMADD231PDm = 8362,
  VFMADD231PDr = 8363,
  VFMADD231PHZ128m = 8364,
  VFMADD231PHZ128mb = 8365,
  VFMADD231PHZ128mbk = 8366,
  VFMADD231PHZ128mbkz = 8367,
  VFMADD231PHZ128mk = 8368,
  VFMADD231PHZ128mkz = 8369,
  VFMADD231PHZ128r = 8370,
  VFMADD231PHZ128rk = 8371,
  VFMADD231PHZ128rkz = 8372,
  VFMADD231PHZ256m = 8373,
  VFMADD231PHZ256mb = 8374,
  VFMADD231PHZ256mbk = 8375,
  VFMADD231PHZ256mbkz = 8376,
  VFMADD231PHZ256mk = 8377,
  VFMADD231PHZ256mkz = 8378,
  VFMADD231PHZ256r = 8379,
  VFMADD231PHZ256rk = 8380,
  VFMADD231PHZ256rkz = 8381,
  VFMADD231PHZm = 8382,
  VFMADD231PHZmb = 8383,
  VFMADD231PHZmbk = 8384,
  VFMADD231PHZmbkz = 8385,
  VFMADD231PHZmk = 8386,
  VFMADD231PHZmkz = 8387,
  VFMADD231PHZr = 8388,
  VFMADD231PHZrb = 8389,
  VFMADD231PHZrbk = 8390,
  VFMADD231PHZrbkz = 8391,
  VFMADD231PHZrk = 8392,
  VFMADD231PHZrkz = 8393,
  VFMADD231PSYm = 8394,
  VFMADD231PSYr = 8395,
  VFMADD231PSZ128m = 8396,
  VFMADD231PSZ128mb = 8397,
  VFMADD231PSZ128mbk = 8398,
  VFMADD231PSZ128mbkz = 8399,
  VFMADD231PSZ128mk = 8400,
  VFMADD231PSZ128mkz = 8401,
  VFMADD231PSZ128r = 8402,
  VFMADD231PSZ128rk = 8403,
  VFMADD231PSZ128rkz = 8404,
  VFMADD231PSZ256m = 8405,
  VFMADD231PSZ256mb = 8406,
  VFMADD231PSZ256mbk = 8407,
  VFMADD231PSZ256mbkz = 8408,
  VFMADD231PSZ256mk = 8409,
  VFMADD231PSZ256mkz = 8410,
  VFMADD231PSZ256r = 8411,
  VFMADD231PSZ256rk = 8412,
  VFMADD231PSZ256rkz = 8413,
  VFMADD231PSZm = 8414,
  VFMADD231PSZmb = 8415,
  VFMADD231PSZmbk = 8416,
  VFMADD231PSZmbkz = 8417,
  VFMADD231PSZmk = 8418,
  VFMADD231PSZmkz = 8419,
  VFMADD231PSZr = 8420,
  VFMADD231PSZrb = 8421,
  VFMADD231PSZrbk = 8422,
  VFMADD231PSZrbkz = 8423,
  VFMADD231PSZrk = 8424,
  VFMADD231PSZrkz = 8425,
  VFMADD231PSm = 8426,
  VFMADD231PSr = 8427,
  VFMADD231SDZm = 8428,
  VFMADD231SDZm_Int = 8429,
  VFMADD231SDZm_Intk = 8430,
  VFMADD231SDZm_Intkz = 8431,
  VFMADD231SDZr = 8432,
  VFMADD231SDZr_Int = 8433,
  VFMADD231SDZr_Intk = 8434,
  VFMADD231SDZr_Intkz = 8435,
  VFMADD231SDZrb = 8436,
  VFMADD231SDZrb_Int = 8437,
  VFMADD231SDZrb_Intk = 8438,
  VFMADD231SDZrb_Intkz = 8439,
  VFMADD231SDm = 8440,
  VFMADD231SDm_Int = 8441,
  VFMADD231SDr = 8442,
  VFMADD231SDr_Int = 8443,
  VFMADD231SHZm = 8444,
  VFMADD231SHZm_Int = 8445,
  VFMADD231SHZm_Intk = 8446,
  VFMADD231SHZm_Intkz = 8447,
  VFMADD231SHZr = 8448,
  VFMADD231SHZr_Int = 8449,
  VFMADD231SHZr_Intk = 8450,
  VFMADD231SHZr_Intkz = 8451,
  VFMADD231SHZrb = 8452,
  VFMADD231SHZrb_Int = 8453,
  VFMADD231SHZrb_Intk = 8454,
  VFMADD231SHZrb_Intkz = 8455,
  VFMADD231SSZm = 8456,
  VFMADD231SSZm_Int = 8457,
  VFMADD231SSZm_Intk = 8458,
  VFMADD231SSZm_Intkz = 8459,
  VFMADD231SSZr = 8460,
  VFMADD231SSZr_Int = 8461,
  VFMADD231SSZr_Intk = 8462,
  VFMADD231SSZr_Intkz = 8463,
  VFMADD231SSZrb = 8464,
  VFMADD231SSZrb_Int = 8465,
  VFMADD231SSZrb_Intk = 8466,
  VFMADD231SSZrb_Intkz = 8467,
  VFMADD231SSm = 8468,
  VFMADD231SSm_Int = 8469,
  VFMADD231SSr = 8470,
  VFMADD231SSr_Int = 8471,
  VFMADDCPHZ128m = 8472,
  VFMADDCPHZ128mb = 8473,
  VFMADDCPHZ128mbk = 8474,
  VFMADDCPHZ128mbkz = 8475,
  VFMADDCPHZ128mk = 8476,
  VFMADDCPHZ128mkz = 8477,
  VFMADDCPHZ128r = 8478,
  VFMADDCPHZ128rk = 8479,
  VFMADDCPHZ128rkz = 8480,
  VFMADDCPHZ256m = 8481,
  VFMADDCPHZ256mb = 8482,
  VFMADDCPHZ256mbk = 8483,
  VFMADDCPHZ256mbkz = 8484,
  VFMADDCPHZ256mk = 8485,
  VFMADDCPHZ256mkz = 8486,
  VFMADDCPHZ256r = 8487,
  VFMADDCPHZ256rk = 8488,
  VFMADDCPHZ256rkz = 8489,
  VFMADDCPHZm = 8490,
  VFMADDCPHZmb = 8491,
  VFMADDCPHZmbk = 8492,
  VFMADDCPHZmbkz = 8493,
  VFMADDCPHZmk = 8494,
  VFMADDCPHZmkz = 8495,
  VFMADDCPHZr = 8496,
  VFMADDCPHZrb = 8497,
  VFMADDCPHZrbk = 8498,
  VFMADDCPHZrbkz = 8499,
  VFMADDCPHZrk = 8500,
  VFMADDCPHZrkz = 8501,
  VFMADDCSHZm = 8502,
  VFMADDCSHZmk = 8503,
  VFMADDCSHZmkz = 8504,
  VFMADDCSHZr = 8505,
  VFMADDCSHZrb = 8506,
  VFMADDCSHZrbk = 8507,
  VFMADDCSHZrbkz = 8508,
  VFMADDCSHZrk = 8509,
  VFMADDCSHZrkz = 8510,
  VFMADDPD4Ymr = 8511,
  VFMADDPD4Yrm = 8512,
  VFMADDPD4Yrr = 8513,
  VFMADDPD4Yrr_REV = 8514,
  VFMADDPD4mr = 8515,
  VFMADDPD4rm = 8516,
  VFMADDPD4rr = 8517,
  VFMADDPD4rr_REV = 8518,
  VFMADDPS4Ymr = 8519,
  VFMADDPS4Yrm = 8520,
  VFMADDPS4Yrr = 8521,
  VFMADDPS4Yrr_REV = 8522,
  VFMADDPS4mr = 8523,
  VFMADDPS4rm = 8524,
  VFMADDPS4rr = 8525,
  VFMADDPS4rr_REV = 8526,
  VFMADDSD4mr = 8527,
  VFMADDSD4mr_Int = 8528,
  VFMADDSD4rm = 8529,
  VFMADDSD4rm_Int = 8530,
  VFMADDSD4rr = 8531,
  VFMADDSD4rr_Int = 8532,
  VFMADDSD4rr_Int_REV = 8533,
  VFMADDSD4rr_REV = 8534,
  VFMADDSS4mr = 8535,
  VFMADDSS4mr_Int = 8536,
  VFMADDSS4rm = 8537,
  VFMADDSS4rm_Int = 8538,
  VFMADDSS4rr = 8539,
  VFMADDSS4rr_Int = 8540,
  VFMADDSS4rr_Int_REV = 8541,
  VFMADDSS4rr_REV = 8542,
  VFMADDSUB132PDYm = 8543,
  VFMADDSUB132PDYr = 8544,
  VFMADDSUB132PDZ128m = 8545,
  VFMADDSUB132PDZ128mb = 8546,
  VFMADDSUB132PDZ128mbk = 8547,
  VFMADDSUB132PDZ128mbkz = 8548,
  VFMADDSUB132PDZ128mk = 8549,
  VFMADDSUB132PDZ128mkz = 8550,
  VFMADDSUB132PDZ128r = 8551,
  VFMADDSUB132PDZ128rk = 8552,
  VFMADDSUB132PDZ128rkz = 8553,
  VFMADDSUB132PDZ256m = 8554,
  VFMADDSUB132PDZ256mb = 8555,
  VFMADDSUB132PDZ256mbk = 8556,
  VFMADDSUB132PDZ256mbkz = 8557,
  VFMADDSUB132PDZ256mk = 8558,
  VFMADDSUB132PDZ256mkz = 8559,
  VFMADDSUB132PDZ256r = 8560,
  VFMADDSUB132PDZ256rk = 8561,
  VFMADDSUB132PDZ256rkz = 8562,
  VFMADDSUB132PDZm = 8563,
  VFMADDSUB132PDZmb = 8564,
  VFMADDSUB132PDZmbk = 8565,
  VFMADDSUB132PDZmbkz = 8566,
  VFMADDSUB132PDZmk = 8567,
  VFMADDSUB132PDZmkz = 8568,
  VFMADDSUB132PDZr = 8569,
  VFMADDSUB132PDZrb = 8570,
  VFMADDSUB132PDZrbk = 8571,
  VFMADDSUB132PDZrbkz = 8572,
  VFMADDSUB132PDZrk = 8573,
  VFMADDSUB132PDZrkz = 8574,
  VFMADDSUB132PDm = 8575,
  VFMADDSUB132PDr = 8576,
  VFMADDSUB132PHZ128m = 8577,
  VFMADDSUB132PHZ128mb = 8578,
  VFMADDSUB132PHZ128mbk = 8579,
  VFMADDSUB132PHZ128mbkz = 8580,
  VFMADDSUB132PHZ128mk = 8581,
  VFMADDSUB132PHZ128mkz = 8582,
  VFMADDSUB132PHZ128r = 8583,
  VFMADDSUB132PHZ128rk = 8584,
  VFMADDSUB132PHZ128rkz = 8585,
  VFMADDSUB132PHZ256m = 8586,
  VFMADDSUB132PHZ256mb = 8587,
  VFMADDSUB132PHZ256mbk = 8588,
  VFMADDSUB132PHZ256mbkz = 8589,
  VFMADDSUB132PHZ256mk = 8590,
  VFMADDSUB132PHZ256mkz = 8591,
  VFMADDSUB132PHZ256r = 8592,
  VFMADDSUB132PHZ256rk = 8593,
  VFMADDSUB132PHZ256rkz = 8594,
  VFMADDSUB132PHZm = 8595,
  VFMADDSUB132PHZmb = 8596,
  VFMADDSUB132PHZmbk = 8597,
  VFMADDSUB132PHZmbkz = 8598,
  VFMADDSUB132PHZmk = 8599,
  VFMADDSUB132PHZmkz = 8600,
  VFMADDSUB132PHZr = 8601,
  VFMADDSUB132PHZrb = 8602,
  VFMADDSUB132PHZrbk = 8603,
  VFMADDSUB132PHZrbkz = 8604,
  VFMADDSUB132PHZrk = 8605,
  VFMADDSUB132PHZrkz = 8606,
  VFMADDSUB132PSYm = 8607,
  VFMADDSUB132PSYr = 8608,
  VFMADDSUB132PSZ128m = 8609,
  VFMADDSUB132PSZ128mb = 8610,
  VFMADDSUB132PSZ128mbk = 8611,
  VFMADDSUB132PSZ128mbkz = 8612,
  VFMADDSUB132PSZ128mk = 8613,
  VFMADDSUB132PSZ128mkz = 8614,
  VFMADDSUB132PSZ128r = 8615,
  VFMADDSUB132PSZ128rk = 8616,
  VFMADDSUB132PSZ128rkz = 8617,
  VFMADDSUB132PSZ256m = 8618,
  VFMADDSUB132PSZ256mb = 8619,
  VFMADDSUB132PSZ256mbk = 8620,
  VFMADDSUB132PSZ256mbkz = 8621,
  VFMADDSUB132PSZ256mk = 8622,
  VFMADDSUB132PSZ256mkz = 8623,
  VFMADDSUB132PSZ256r = 8624,
  VFMADDSUB132PSZ256rk = 8625,
  VFMADDSUB132PSZ256rkz = 8626,
  VFMADDSUB132PSZm = 8627,
  VFMADDSUB132PSZmb = 8628,
  VFMADDSUB132PSZmbk = 8629,
  VFMADDSUB132PSZmbkz = 8630,
  VFMADDSUB132PSZmk = 8631,
  VFMADDSUB132PSZmkz = 8632,
  VFMADDSUB132PSZr = 8633,
  VFMADDSUB132PSZrb = 8634,
  VFMADDSUB132PSZrbk = 8635,
  VFMADDSUB132PSZrbkz = 8636,
  VFMADDSUB132PSZrk = 8637,
  VFMADDSUB132PSZrkz = 8638,
  VFMADDSUB132PSm = 8639,
  VFMADDSUB132PSr = 8640,
  VFMADDSUB213PDYm = 8641,
  VFMADDSUB213PDYr = 8642,
  VFMADDSUB213PDZ128m = 8643,
  VFMADDSUB213PDZ128mb = 8644,
  VFMADDSUB213PDZ128mbk = 8645,
  VFMADDSUB213PDZ128mbkz = 8646,
  VFMADDSUB213PDZ128mk = 8647,
  VFMADDSUB213PDZ128mkz = 8648,
  VFMADDSUB213PDZ128r = 8649,
  VFMADDSUB213PDZ128rk = 8650,
  VFMADDSUB213PDZ128rkz = 8651,
  VFMADDSUB213PDZ256m = 8652,
  VFMADDSUB213PDZ256mb = 8653,
  VFMADDSUB213PDZ256mbk = 8654,
  VFMADDSUB213PDZ256mbkz = 8655,
  VFMADDSUB213PDZ256mk = 8656,
  VFMADDSUB213PDZ256mkz = 8657,
  VFMADDSUB213PDZ256r = 8658,
  VFMADDSUB213PDZ256rk = 8659,
  VFMADDSUB213PDZ256rkz = 8660,
  VFMADDSUB213PDZm = 8661,
  VFMADDSUB213PDZmb = 8662,
  VFMADDSUB213PDZmbk = 8663,
  VFMADDSUB213PDZmbkz = 8664,
  VFMADDSUB213PDZmk = 8665,
  VFMADDSUB213PDZmkz = 8666,
  VFMADDSUB213PDZr = 8667,
  VFMADDSUB213PDZrb = 8668,
  VFMADDSUB213PDZrbk = 8669,
  VFMADDSUB213PDZrbkz = 8670,
  VFMADDSUB213PDZrk = 8671,
  VFMADDSUB213PDZrkz = 8672,
  VFMADDSUB213PDm = 8673,
  VFMADDSUB213PDr = 8674,
  VFMADDSUB213PHZ128m = 8675,
  VFMADDSUB213PHZ128mb = 8676,
  VFMADDSUB213PHZ128mbk = 8677,
  VFMADDSUB213PHZ128mbkz = 8678,
  VFMADDSUB213PHZ128mk = 8679,
  VFMADDSUB213PHZ128mkz = 8680,
  VFMADDSUB213PHZ128r = 8681,
  VFMADDSUB213PHZ128rk = 8682,
  VFMADDSUB213PHZ128rkz = 8683,
  VFMADDSUB213PHZ256m = 8684,
  VFMADDSUB213PHZ256mb = 8685,
  VFMADDSUB213PHZ256mbk = 8686,
  VFMADDSUB213PHZ256mbkz = 8687,
  VFMADDSUB213PHZ256mk = 8688,
  VFMADDSUB213PHZ256mkz = 8689,
  VFMADDSUB213PHZ256r = 8690,
  VFMADDSUB213PHZ256rk = 8691,
  VFMADDSUB213PHZ256rkz = 8692,
  VFMADDSUB213PHZm = 8693,
  VFMADDSUB213PHZmb = 8694,
  VFMADDSUB213PHZmbk = 8695,
  VFMADDSUB213PHZmbkz = 8696,
  VFMADDSUB213PHZmk = 8697,
  VFMADDSUB213PHZmkz = 8698,
  VFMADDSUB213PHZr = 8699,
  VFMADDSUB213PHZrb = 8700,
  VFMADDSUB213PHZrbk = 8701,
  VFMADDSUB213PHZrbkz = 8702,
  VFMADDSUB213PHZrk = 8703,
  VFMADDSUB213PHZrkz = 8704,
  VFMADDSUB213PSYm = 8705,
  VFMADDSUB213PSYr = 8706,
  VFMADDSUB213PSZ128m = 8707,
  VFMADDSUB213PSZ128mb = 8708,
  VFMADDSUB213PSZ128mbk = 8709,
  VFMADDSUB213PSZ128mbkz = 8710,
  VFMADDSUB213PSZ128mk = 8711,
  VFMADDSUB213PSZ128mkz = 8712,
  VFMADDSUB213PSZ128r = 8713,
  VFMADDSUB213PSZ128rk = 8714,
  VFMADDSUB213PSZ128rkz = 8715,
  VFMADDSUB213PSZ256m = 8716,
  VFMADDSUB213PSZ256mb = 8717,
  VFMADDSUB213PSZ256mbk = 8718,
  VFMADDSUB213PSZ256mbkz = 8719,
  VFMADDSUB213PSZ256mk = 8720,
  VFMADDSUB213PSZ256mkz = 8721,
  VFMADDSUB213PSZ256r = 8722,
  VFMADDSUB213PSZ256rk = 8723,
  VFMADDSUB213PSZ256rkz = 8724,
  VFMADDSUB213PSZm = 8725,
  VFMADDSUB213PSZmb = 8726,
  VFMADDSUB213PSZmbk = 8727,
  VFMADDSUB213PSZmbkz = 8728,
  VFMADDSUB213PSZmk = 8729,
  VFMADDSUB213PSZmkz = 8730,
  VFMADDSUB213PSZr = 8731,
  VFMADDSUB213PSZrb = 8732,
  VFMADDSUB213PSZrbk = 8733,
  VFMADDSUB213PSZrbkz = 8734,
  VFMADDSUB213PSZrk = 8735,
  VFMADDSUB213PSZrkz = 8736,
  VFMADDSUB213PSm = 8737,
  VFMADDSUB213PSr = 8738,
  VFMADDSUB231PDYm = 8739,
  VFMADDSUB231PDYr = 8740,
  VFMADDSUB231PDZ128m = 8741,
  VFMADDSUB231PDZ128mb = 8742,
  VFMADDSUB231PDZ128mbk = 8743,
  VFMADDSUB231PDZ128mbkz = 8744,
  VFMADDSUB231PDZ128mk = 8745,
  VFMADDSUB231PDZ128mkz = 8746,
  VFMADDSUB231PDZ128r = 8747,
  VFMADDSUB231PDZ128rk = 8748,
  VFMADDSUB231PDZ128rkz = 8749,
  VFMADDSUB231PDZ256m = 8750,
  VFMADDSUB231PDZ256mb = 8751,
  VFMADDSUB231PDZ256mbk = 8752,
  VFMADDSUB231PDZ256mbkz = 8753,
  VFMADDSUB231PDZ256mk = 8754,
  VFMADDSUB231PDZ256mkz = 8755,
  VFMADDSUB231PDZ256r = 8756,
  VFMADDSUB231PDZ256rk = 8757,
  VFMADDSUB231PDZ256rkz = 8758,
  VFMADDSUB231PDZm = 8759,
  VFMADDSUB231PDZmb = 8760,
  VFMADDSUB231PDZmbk = 8761,
  VFMADDSUB231PDZmbkz = 8762,
  VFMADDSUB231PDZmk = 8763,
  VFMADDSUB231PDZmkz = 8764,
  VFMADDSUB231PDZr = 8765,
  VFMADDSUB231PDZrb = 8766,
  VFMADDSUB231PDZrbk = 8767,
  VFMADDSUB231PDZrbkz = 8768,
  VFMADDSUB231PDZrk = 8769,
  VFMADDSUB231PDZrkz = 8770,
  VFMADDSUB231PDm = 8771,
  VFMADDSUB231PDr = 8772,
  VFMADDSUB231PHZ128m = 8773,
  VFMADDSUB231PHZ128mb = 8774,
  VFMADDSUB231PHZ128mbk = 8775,
  VFMADDSUB231PHZ128mbkz = 8776,
  VFMADDSUB231PHZ128mk = 8777,
  VFMADDSUB231PHZ128mkz = 8778,
  VFMADDSUB231PHZ128r = 8779,
  VFMADDSUB231PHZ128rk = 8780,
  VFMADDSUB231PHZ128rkz = 8781,
  VFMADDSUB231PHZ256m = 8782,
  VFMADDSUB231PHZ256mb = 8783,
  VFMADDSUB231PHZ256mbk = 8784,
  VFMADDSUB231PHZ256mbkz = 8785,
  VFMADDSUB231PHZ256mk = 8786,
  VFMADDSUB231PHZ256mkz = 8787,
  VFMADDSUB231PHZ256r = 8788,
  VFMADDSUB231PHZ256rk = 8789,
  VFMADDSUB231PHZ256rkz = 8790,
  VFMADDSUB231PHZm = 8791,
  VFMADDSUB231PHZmb = 8792,
  VFMADDSUB231PHZmbk = 8793,
  VFMADDSUB231PHZmbkz = 8794,
  VFMADDSUB231PHZmk = 8795,
  VFMADDSUB231PHZmkz = 8796,
  VFMADDSUB231PHZr = 8797,
  VFMADDSUB231PHZrb = 8798,
  VFMADDSUB231PHZrbk = 8799,
  VFMADDSUB231PHZrbkz = 8800,
  VFMADDSUB231PHZrk = 8801,
  VFMADDSUB231PHZrkz = 8802,
  VFMADDSUB231PSYm = 8803,
  VFMADDSUB231PSYr = 8804,
  VFMADDSUB231PSZ128m = 8805,
  VFMADDSUB231PSZ128mb = 8806,
  VFMADDSUB231PSZ128mbk = 8807,
  VFMADDSUB231PSZ128mbkz = 8808,
  VFMADDSUB231PSZ128mk = 8809,
  VFMADDSUB231PSZ128mkz = 8810,
  VFMADDSUB231PSZ128r = 8811,
  VFMADDSUB231PSZ128rk = 8812,
  VFMADDSUB231PSZ128rkz = 8813,
  VFMADDSUB231PSZ256m = 8814,
  VFMADDSUB231PSZ256mb = 8815,
  VFMADDSUB231PSZ256mbk = 8816,
  VFMADDSUB231PSZ256mbkz = 8817,
  VFMADDSUB231PSZ256mk = 8818,
  VFMADDSUB231PSZ256mkz = 8819,
  VFMADDSUB231PSZ256r = 8820,
  VFMADDSUB231PSZ256rk = 8821,
  VFMADDSUB231PSZ256rkz = 8822,
  VFMADDSUB231PSZm = 8823,
  VFMADDSUB231PSZmb = 8824,
  VFMADDSUB231PSZmbk = 8825,
  VFMADDSUB231PSZmbkz = 8826,
  VFMADDSUB231PSZmk = 8827,
  VFMADDSUB231PSZmkz = 8828,
  VFMADDSUB231PSZr = 8829,
  VFMADDSUB231PSZrb = 8830,
  VFMADDSUB231PSZrbk = 8831,
  VFMADDSUB231PSZrbkz = 8832,
  VFMADDSUB231PSZrk = 8833,
  VFMADDSUB231PSZrkz = 8834,
  VFMADDSUB231PSm = 8835,
  VFMADDSUB231PSr = 8836,
  VFMADDSUBPD4Ymr = 8837,
  VFMADDSUBPD4Yrm = 8838,
  VFMADDSUBPD4Yrr = 8839,
  VFMADDSUBPD4Yrr_REV = 8840,
  VFMADDSUBPD4mr = 8841,
  VFMADDSUBPD4rm = 8842,
  VFMADDSUBPD4rr = 8843,
  VFMADDSUBPD4rr_REV = 8844,
  VFMADDSUBPS4Ymr = 8845,
  VFMADDSUBPS4Yrm = 8846,
  VFMADDSUBPS4Yrr = 8847,
  VFMADDSUBPS4Yrr_REV = 8848,
  VFMADDSUBPS4mr = 8849,
  VFMADDSUBPS4rm = 8850,
  VFMADDSUBPS4rr = 8851,
  VFMADDSUBPS4rr_REV = 8852,
  VFMSUB132PDYm = 8853,
  VFMSUB132PDYr = 8854,
  VFMSUB132PDZ128m = 8855,
  VFMSUB132PDZ128mb = 8856,
  VFMSUB132PDZ128mbk = 8857,
  VFMSUB132PDZ128mbkz = 8858,
  VFMSUB132PDZ128mk = 8859,
  VFMSUB132PDZ128mkz = 8860,
  VFMSUB132PDZ128r = 8861,
  VFMSUB132PDZ128rk = 8862,
  VFMSUB132PDZ128rkz = 8863,
  VFMSUB132PDZ256m = 8864,
  VFMSUB132PDZ256mb = 8865,
  VFMSUB132PDZ256mbk = 8866,
  VFMSUB132PDZ256mbkz = 8867,
  VFMSUB132PDZ256mk = 8868,
  VFMSUB132PDZ256mkz = 8869,
  VFMSUB132PDZ256r = 8870,
  VFMSUB132PDZ256rk = 8871,
  VFMSUB132PDZ256rkz = 8872,
  VFMSUB132PDZm = 8873,
  VFMSUB132PDZmb = 8874,
  VFMSUB132PDZmbk = 8875,
  VFMSUB132PDZmbkz = 8876,
  VFMSUB132PDZmk = 8877,
  VFMSUB132PDZmkz = 8878,
  VFMSUB132PDZr = 8879,
  VFMSUB132PDZrb = 8880,
  VFMSUB132PDZrbk = 8881,
  VFMSUB132PDZrbkz = 8882,
  VFMSUB132PDZrk = 8883,
  VFMSUB132PDZrkz = 8884,
  VFMSUB132PDm = 8885,
  VFMSUB132PDr = 8886,
  VFMSUB132PHZ128m = 8887,
  VFMSUB132PHZ128mb = 8888,
  VFMSUB132PHZ128mbk = 8889,
  VFMSUB132PHZ128mbkz = 8890,
  VFMSUB132PHZ128mk = 8891,
  VFMSUB132PHZ128mkz = 8892,
  VFMSUB132PHZ128r = 8893,
  VFMSUB132PHZ128rk = 8894,
  VFMSUB132PHZ128rkz = 8895,
  VFMSUB132PHZ256m = 8896,
  VFMSUB132PHZ256mb = 8897,
  VFMSUB132PHZ256mbk = 8898,
  VFMSUB132PHZ256mbkz = 8899,
  VFMSUB132PHZ256mk = 8900,
  VFMSUB132PHZ256mkz = 8901,
  VFMSUB132PHZ256r = 8902,
  VFMSUB132PHZ256rk = 8903,
  VFMSUB132PHZ256rkz = 8904,
  VFMSUB132PHZm = 8905,
  VFMSUB132PHZmb = 8906,
  VFMSUB132PHZmbk = 8907,
  VFMSUB132PHZmbkz = 8908,
  VFMSUB132PHZmk = 8909,
  VFMSUB132PHZmkz = 8910,
  VFMSUB132PHZr = 8911,
  VFMSUB132PHZrb = 8912,
  VFMSUB132PHZrbk = 8913,
  VFMSUB132PHZrbkz = 8914,
  VFMSUB132PHZrk = 8915,
  VFMSUB132PHZrkz = 8916,
  VFMSUB132PSYm = 8917,
  VFMSUB132PSYr = 8918,
  VFMSUB132PSZ128m = 8919,
  VFMSUB132PSZ128mb = 8920,
  VFMSUB132PSZ128mbk = 8921,
  VFMSUB132PSZ128mbkz = 8922,
  VFMSUB132PSZ128mk = 8923,
  VFMSUB132PSZ128mkz = 8924,
  VFMSUB132PSZ128r = 8925,
  VFMSUB132PSZ128rk = 8926,
  VFMSUB132PSZ128rkz = 8927,
  VFMSUB132PSZ256m = 8928,
  VFMSUB132PSZ256mb = 8929,
  VFMSUB132PSZ256mbk = 8930,
  VFMSUB132PSZ256mbkz = 8931,
  VFMSUB132PSZ256mk = 8932,
  VFMSUB132PSZ256mkz = 8933,
  VFMSUB132PSZ256r = 8934,
  VFMSUB132PSZ256rk = 8935,
  VFMSUB132PSZ256rkz = 8936,
  VFMSUB132PSZm = 8937,
  VFMSUB132PSZmb = 8938,
  VFMSUB132PSZmbk = 8939,
  VFMSUB132PSZmbkz = 8940,
  VFMSUB132PSZmk = 8941,
  VFMSUB132PSZmkz = 8942,
  VFMSUB132PSZr = 8943,
  VFMSUB132PSZrb = 8944,
  VFMSUB132PSZrbk = 8945,
  VFMSUB132PSZrbkz = 8946,
  VFMSUB132PSZrk = 8947,
  VFMSUB132PSZrkz = 8948,
  VFMSUB132PSm = 8949,
  VFMSUB132PSr = 8950,
  VFMSUB132SDZm = 8951,
  VFMSUB132SDZm_Int = 8952,
  VFMSUB132SDZm_Intk = 8953,
  VFMSUB132SDZm_Intkz = 8954,
  VFMSUB132SDZr = 8955,
  VFMSUB132SDZr_Int = 8956,
  VFMSUB132SDZr_Intk = 8957,
  VFMSUB132SDZr_Intkz = 8958,
  VFMSUB132SDZrb = 8959,
  VFMSUB132SDZrb_Int = 8960,
  VFMSUB132SDZrb_Intk = 8961,
  VFMSUB132SDZrb_Intkz = 8962,
  VFMSUB132SDm = 8963,
  VFMSUB132SDm_Int = 8964,
  VFMSUB132SDr = 8965,
  VFMSUB132SDr_Int = 8966,
  VFMSUB132SHZm = 8967,
  VFMSUB132SHZm_Int = 8968,
  VFMSUB132SHZm_Intk = 8969,
  VFMSUB132SHZm_Intkz = 8970,
  VFMSUB132SHZr = 8971,
  VFMSUB132SHZr_Int = 8972,
  VFMSUB132SHZr_Intk = 8973,
  VFMSUB132SHZr_Intkz = 8974,
  VFMSUB132SHZrb = 8975,
  VFMSUB132SHZrb_Int = 8976,
  VFMSUB132SHZrb_Intk = 8977,
  VFMSUB132SHZrb_Intkz = 8978,
  VFMSUB132SSZm = 8979,
  VFMSUB132SSZm_Int = 8980,
  VFMSUB132SSZm_Intk = 8981,
  VFMSUB132SSZm_Intkz = 8982,
  VFMSUB132SSZr = 8983,
  VFMSUB132SSZr_Int = 8984,
  VFMSUB132SSZr_Intk = 8985,
  VFMSUB132SSZr_Intkz = 8986,
  VFMSUB132SSZrb = 8987,
  VFMSUB132SSZrb_Int = 8988,
  VFMSUB132SSZrb_Intk = 8989,
  VFMSUB132SSZrb_Intkz = 8990,
  VFMSUB132SSm = 8991,
  VFMSUB132SSm_Int = 8992,
  VFMSUB132SSr = 8993,
  VFMSUB132SSr_Int = 8994,
  VFMSUB213PDYm = 8995,
  VFMSUB213PDYr = 8996,
  VFMSUB213PDZ128m = 8997,
  VFMSUB213PDZ128mb = 8998,
  VFMSUB213PDZ128mbk = 8999,
  VFMSUB213PDZ128mbkz = 9000,
  VFMSUB213PDZ128mk = 9001,
  VFMSUB213PDZ128mkz = 9002,
  VFMSUB213PDZ128r = 9003,
  VFMSUB213PDZ128rk = 9004,
  VFMSUB213PDZ128rkz = 9005,
  VFMSUB213PDZ256m = 9006,
  VFMSUB213PDZ256mb = 9007,
  VFMSUB213PDZ256mbk = 9008,
  VFMSUB213PDZ256mbkz = 9009,
  VFMSUB213PDZ256mk = 9010,
  VFMSUB213PDZ256mkz = 9011,
  VFMSUB213PDZ256r = 9012,
  VFMSUB213PDZ256rk = 9013,
  VFMSUB213PDZ256rkz = 9014,
  VFMSUB213PDZm = 9015,
  VFMSUB213PDZmb = 9016,
  VFMSUB213PDZmbk = 9017,
  VFMSUB213PDZmbkz = 9018,
  VFMSUB213PDZmk = 9019,
  VFMSUB213PDZmkz = 9020,
  VFMSUB213PDZr = 9021,
  VFMSUB213PDZrb = 9022,
  VFMSUB213PDZrbk = 9023,
  VFMSUB213PDZrbkz = 9024,
  VFMSUB213PDZrk = 9025,
  VFMSUB213PDZrkz = 9026,
  VFMSUB213PDm = 9027,
  VFMSUB213PDr = 9028,
  VFMSUB213PHZ128m = 9029,
  VFMSUB213PHZ128mb = 9030,
  VFMSUB213PHZ128mbk = 9031,
  VFMSUB213PHZ128mbkz = 9032,
  VFMSUB213PHZ128mk = 9033,
  VFMSUB213PHZ128mkz = 9034,
  VFMSUB213PHZ128r = 9035,
  VFMSUB213PHZ128rk = 9036,
  VFMSUB213PHZ128rkz = 9037,
  VFMSUB213PHZ256m = 9038,
  VFMSUB213PHZ256mb = 9039,
  VFMSUB213PHZ256mbk = 9040,
  VFMSUB213PHZ256mbkz = 9041,
  VFMSUB213PHZ256mk = 9042,
  VFMSUB213PHZ256mkz = 9043,
  VFMSUB213PHZ256r = 9044,
  VFMSUB213PHZ256rk = 9045,
  VFMSUB213PHZ256rkz = 9046,
  VFMSUB213PHZm = 9047,
  VFMSUB213PHZmb = 9048,
  VFMSUB213PHZmbk = 9049,
  VFMSUB213PHZmbkz = 9050,
  VFMSUB213PHZmk = 9051,
  VFMSUB213PHZmkz = 9052,
  VFMSUB213PHZr = 9053,
  VFMSUB213PHZrb = 9054,
  VFMSUB213PHZrbk = 9055,
  VFMSUB213PHZrbkz = 9056,
  VFMSUB213PHZrk = 9057,
  VFMSUB213PHZrkz = 9058,
  VFMSUB213PSYm = 9059,
  VFMSUB213PSYr = 9060,
  VFMSUB213PSZ128m = 9061,
  VFMSUB213PSZ128mb = 9062,
  VFMSUB213PSZ128mbk = 9063,
  VFMSUB213PSZ128mbkz = 9064,
  VFMSUB213PSZ128mk = 9065,
  VFMSUB213PSZ128mkz = 9066,
  VFMSUB213PSZ128r = 9067,
  VFMSUB213PSZ128rk = 9068,
  VFMSUB213PSZ128rkz = 9069,
  VFMSUB213PSZ256m = 9070,
  VFMSUB213PSZ256mb = 9071,
  VFMSUB213PSZ256mbk = 9072,
  VFMSUB213PSZ256mbkz = 9073,
  VFMSUB213PSZ256mk = 9074,
  VFMSUB213PSZ256mkz = 9075,
  VFMSUB213PSZ256r = 9076,
  VFMSUB213PSZ256rk = 9077,
  VFMSUB213PSZ256rkz = 9078,
  VFMSUB213PSZm = 9079,
  VFMSUB213PSZmb = 9080,
  VFMSUB213PSZmbk = 9081,
  VFMSUB213PSZmbkz = 9082,
  VFMSUB213PSZmk = 9083,
  VFMSUB213PSZmkz = 9084,
  VFMSUB213PSZr = 9085,
  VFMSUB213PSZrb = 9086,
  VFMSUB213PSZrbk = 9087,
  VFMSUB213PSZrbkz = 9088,
  VFMSUB213PSZrk = 9089,
  VFMSUB213PSZrkz = 9090,
  VFMSUB213PSm = 9091,
  VFMSUB213PSr = 9092,
  VFMSUB213SDZm = 9093,
  VFMSUB213SDZm_Int = 9094,
  VFMSUB213SDZm_Intk = 9095,
  VFMSUB213SDZm_Intkz = 9096,
  VFMSUB213SDZr = 9097,
  VFMSUB213SDZr_Int = 9098,
  VFMSUB213SDZr_Intk = 9099,
  VFMSUB213SDZr_Intkz = 9100,
  VFMSUB213SDZrb = 9101,
  VFMSUB213SDZrb_Int = 9102,
  VFMSUB213SDZrb_Intk = 9103,
  VFMSUB213SDZrb_Intkz = 9104,
  VFMSUB213SDm = 9105,
  VFMSUB213SDm_Int = 9106,
  VFMSUB213SDr = 9107,
  VFMSUB213SDr_Int = 9108,
  VFMSUB213SHZm = 9109,
  VFMSUB213SHZm_Int = 9110,
  VFMSUB213SHZm_Intk = 9111,
  VFMSUB213SHZm_Intkz = 9112,
  VFMSUB213SHZr = 9113,
  VFMSUB213SHZr_Int = 9114,
  VFMSUB213SHZr_Intk = 9115,
  VFMSUB213SHZr_Intkz = 9116,
  VFMSUB213SHZrb = 9117,
  VFMSUB213SHZrb_Int = 9118,
  VFMSUB213SHZrb_Intk = 9119,
  VFMSUB213SHZrb_Intkz = 9120,
  VFMSUB213SSZm = 9121,
  VFMSUB213SSZm_Int = 9122,
  VFMSUB213SSZm_Intk = 9123,
  VFMSUB213SSZm_Intkz = 9124,
  VFMSUB213SSZr = 9125,
  VFMSUB213SSZr_Int = 9126,
  VFMSUB213SSZr_Intk = 9127,
  VFMSUB213SSZr_Intkz = 9128,
  VFMSUB213SSZrb = 9129,
  VFMSUB213SSZrb_Int = 9130,
  VFMSUB213SSZrb_Intk = 9131,
  VFMSUB213SSZrb_Intkz = 9132,
  VFMSUB213SSm = 9133,
  VFMSUB213SSm_Int = 9134,
  VFMSUB213SSr = 9135,
  VFMSUB213SSr_Int = 9136,
  VFMSUB231PDYm = 9137,
  VFMSUB231PDYr = 9138,
  VFMSUB231PDZ128m = 9139,
  VFMSUB231PDZ128mb = 9140,
  VFMSUB231PDZ128mbk = 9141,
  VFMSUB231PDZ128mbkz = 9142,
  VFMSUB231PDZ128mk = 9143,
  VFMSUB231PDZ128mkz = 9144,
  VFMSUB231PDZ128r = 9145,
  VFMSUB231PDZ128rk = 9146,
  VFMSUB231PDZ128rkz = 9147,
  VFMSUB231PDZ256m = 9148,
  VFMSUB231PDZ256mb = 9149,
  VFMSUB231PDZ256mbk = 9150,
  VFMSUB231PDZ256mbkz = 9151,
  VFMSUB231PDZ256mk = 9152,
  VFMSUB231PDZ256mkz = 9153,
  VFMSUB231PDZ256r = 9154,
  VFMSUB231PDZ256rk = 9155,
  VFMSUB231PDZ256rkz = 9156,
  VFMSUB231PDZm = 9157,
  VFMSUB231PDZmb = 9158,
  VFMSUB231PDZmbk = 9159,
  VFMSUB231PDZmbkz = 9160,
  VFMSUB231PDZmk = 9161,
  VFMSUB231PDZmkz = 9162,
  VFMSUB231PDZr = 9163,
  VFMSUB231PDZrb = 9164,
  VFMSUB231PDZrbk = 9165,
  VFMSUB231PDZrbkz = 9166,
  VFMSUB231PDZrk = 9167,
  VFMSUB231PDZrkz = 9168,
  VFMSUB231PDm = 9169,
  VFMSUB231PDr = 9170,
  VFMSUB231PHZ128m = 9171,
  VFMSUB231PHZ128mb = 9172,
  VFMSUB231PHZ128mbk = 9173,
  VFMSUB231PHZ128mbkz = 9174,
  VFMSUB231PHZ128mk = 9175,
  VFMSUB231PHZ128mkz = 9176,
  VFMSUB231PHZ128r = 9177,
  VFMSUB231PHZ128rk = 9178,
  VFMSUB231PHZ128rkz = 9179,
  VFMSUB231PHZ256m = 9180,
  VFMSUB231PHZ256mb = 9181,
  VFMSUB231PHZ256mbk = 9182,
  VFMSUB231PHZ256mbkz = 9183,
  VFMSUB231PHZ256mk = 9184,
  VFMSUB231PHZ256mkz = 9185,
  VFMSUB231PHZ256r = 9186,
  VFMSUB231PHZ256rk = 9187,
  VFMSUB231PHZ256rkz = 9188,
  VFMSUB231PHZm = 9189,
  VFMSUB231PHZmb = 9190,
  VFMSUB231PHZmbk = 9191,
  VFMSUB231PHZmbkz = 9192,
  VFMSUB231PHZmk = 9193,
  VFMSUB231PHZmkz = 9194,
  VFMSUB231PHZr = 9195,
  VFMSUB231PHZrb = 9196,
  VFMSUB231PHZrbk = 9197,
  VFMSUB231PHZrbkz = 9198,
  VFMSUB231PHZrk = 9199,
  VFMSUB231PHZrkz = 9200,
  VFMSUB231PSYm = 9201,
  VFMSUB231PSYr = 9202,
  VFMSUB231PSZ128m = 9203,
  VFMSUB231PSZ128mb = 9204,
  VFMSUB231PSZ128mbk = 9205,
  VFMSUB231PSZ128mbkz = 9206,
  VFMSUB231PSZ128mk = 9207,
  VFMSUB231PSZ128mkz = 9208,
  VFMSUB231PSZ128r = 9209,
  VFMSUB231PSZ128rk = 9210,
  VFMSUB231PSZ128rkz = 9211,
  VFMSUB231PSZ256m = 9212,
  VFMSUB231PSZ256mb = 9213,
  VFMSUB231PSZ256mbk = 9214,
  VFMSUB231PSZ256mbkz = 9215,
  VFMSUB231PSZ256mk = 9216,
  VFMSUB231PSZ256mkz = 9217,
  VFMSUB231PSZ256r = 9218,
  VFMSUB231PSZ256rk = 9219,
  VFMSUB231PSZ256rkz = 9220,
  VFMSUB231PSZm = 9221,
  VFMSUB231PSZmb = 9222,
  VFMSUB231PSZmbk = 9223,
  VFMSUB231PSZmbkz = 9224,
  VFMSUB231PSZmk = 9225,
  VFMSUB231PSZmkz = 9226,
  VFMSUB231PSZr = 9227,
  VFMSUB231PSZrb = 9228,
  VFMSUB231PSZrbk = 9229,
  VFMSUB231PSZrbkz = 9230,
  VFMSUB231PSZrk = 9231,
  VFMSUB231PSZrkz = 9232,
  VFMSUB231PSm = 9233,
  VFMSUB231PSr = 9234,
  VFMSUB231SDZm = 9235,
  VFMSUB231SDZm_Int = 9236,
  VFMSUB231SDZm_Intk = 9237,
  VFMSUB231SDZm_Intkz = 9238,
  VFMSUB231SDZr = 9239,
  VFMSUB231SDZr_Int = 9240,
  VFMSUB231SDZr_Intk = 9241,
  VFMSUB231SDZr_Intkz = 9242,
  VFMSUB231SDZrb = 9243,
  VFMSUB231SDZrb_Int = 9244,
  VFMSUB231SDZrb_Intk = 9245,
  VFMSUB231SDZrb_Intkz = 9246,
  VFMSUB231SDm = 9247,
  VFMSUB231SDm_Int = 9248,
  VFMSUB231SDr = 9249,
  VFMSUB231SDr_Int = 9250,
  VFMSUB231SHZm = 9251,
  VFMSUB231SHZm_Int = 9252,
  VFMSUB231SHZm_Intk = 9253,
  VFMSUB231SHZm_Intkz = 9254,
  VFMSUB231SHZr = 9255,
  VFMSUB231SHZr_Int = 9256,
  VFMSUB231SHZr_Intk = 9257,
  VFMSUB231SHZr_Intkz = 9258,
  VFMSUB231SHZrb = 9259,
  VFMSUB231SHZrb_Int = 9260,
  VFMSUB231SHZrb_Intk = 9261,
  VFMSUB231SHZrb_Intkz = 9262,
  VFMSUB231SSZm = 9263,
  VFMSUB231SSZm_Int = 9264,
  VFMSUB231SSZm_Intk = 9265,
  VFMSUB231SSZm_Intkz = 9266,
  VFMSUB231SSZr = 9267,
  VFMSUB231SSZr_Int = 9268,
  VFMSUB231SSZr_Intk = 9269,
  VFMSUB231SSZr_Intkz = 9270,
  VFMSUB231SSZrb = 9271,
  VFMSUB231SSZrb_Int = 9272,
  VFMSUB231SSZrb_Intk = 9273,
  VFMSUB231SSZrb_Intkz = 9274,
  VFMSUB231SSm = 9275,
  VFMSUB231SSm_Int = 9276,
  VFMSUB231SSr = 9277,
  VFMSUB231SSr_Int = 9278,
  VFMSUBADD132PDYm = 9279,
  VFMSUBADD132PDYr = 9280,
  VFMSUBADD132PDZ128m = 9281,
  VFMSUBADD132PDZ128mb = 9282,
  VFMSUBADD132PDZ128mbk = 9283,
  VFMSUBADD132PDZ128mbkz = 9284,
  VFMSUBADD132PDZ128mk = 9285,
  VFMSUBADD132PDZ128mkz = 9286,
  VFMSUBADD132PDZ128r = 9287,
  VFMSUBADD132PDZ128rk = 9288,
  VFMSUBADD132PDZ128rkz = 9289,
  VFMSUBADD132PDZ256m = 9290,
  VFMSUBADD132PDZ256mb = 9291,
  VFMSUBADD132PDZ256mbk = 9292,
  VFMSUBADD132PDZ256mbkz = 9293,
  VFMSUBADD132PDZ256mk = 9294,
  VFMSUBADD132PDZ256mkz = 9295,
  VFMSUBADD132PDZ256r = 9296,
  VFMSUBADD132PDZ256rk = 9297,
  VFMSUBADD132PDZ256rkz = 9298,
  VFMSUBADD132PDZm = 9299,
  VFMSUBADD132PDZmb = 9300,
  VFMSUBADD132PDZmbk = 9301,
  VFMSUBADD132PDZmbkz = 9302,
  VFMSUBADD132PDZmk = 9303,
  VFMSUBADD132PDZmkz = 9304,
  VFMSUBADD132PDZr = 9305,
  VFMSUBADD132PDZrb = 9306,
  VFMSUBADD132PDZrbk = 9307,
  VFMSUBADD132PDZrbkz = 9308,
  VFMSUBADD132PDZrk = 9309,
  VFMSUBADD132PDZrkz = 9310,
  VFMSUBADD132PDm = 9311,
  VFMSUBADD132PDr = 9312,
  VFMSUBADD132PHZ128m = 9313,
  VFMSUBADD132PHZ128mb = 9314,
  VFMSUBADD132PHZ128mbk = 9315,
  VFMSUBADD132PHZ128mbkz = 9316,
  VFMSUBADD132PHZ128mk = 9317,
  VFMSUBADD132PHZ128mkz = 9318,
  VFMSUBADD132PHZ128r = 9319,
  VFMSUBADD132PHZ128rk = 9320,
  VFMSUBADD132PHZ128rkz = 9321,
  VFMSUBADD132PHZ256m = 9322,
  VFMSUBADD132PHZ256mb = 9323,
  VFMSUBADD132PHZ256mbk = 9324,
  VFMSUBADD132PHZ256mbkz = 9325,
  VFMSUBADD132PHZ256mk = 9326,
  VFMSUBADD132PHZ256mkz = 9327,
  VFMSUBADD132PHZ256r = 9328,
  VFMSUBADD132PHZ256rk = 9329,
  VFMSUBADD132PHZ256rkz = 9330,
  VFMSUBADD132PHZm = 9331,
  VFMSUBADD132PHZmb = 9332,
  VFMSUBADD132PHZmbk = 9333,
  VFMSUBADD132PHZmbkz = 9334,
  VFMSUBADD132PHZmk = 9335,
  VFMSUBADD132PHZmkz = 9336,
  VFMSUBADD132PHZr = 9337,
  VFMSUBADD132PHZrb = 9338,
  VFMSUBADD132PHZrbk = 9339,
  VFMSUBADD132PHZrbkz = 9340,
  VFMSUBADD132PHZrk = 9341,
  VFMSUBADD132PHZrkz = 9342,
  VFMSUBADD132PSYm = 9343,
  VFMSUBADD132PSYr = 9344,
  VFMSUBADD132PSZ128m = 9345,
  VFMSUBADD132PSZ128mb = 9346,
  VFMSUBADD132PSZ128mbk = 9347,
  VFMSUBADD132PSZ128mbkz = 9348,
  VFMSUBADD132PSZ128mk = 9349,
  VFMSUBADD132PSZ128mkz = 9350,
  VFMSUBADD132PSZ128r = 9351,
  VFMSUBADD132PSZ128rk = 9352,
  VFMSUBADD132PSZ128rkz = 9353,
  VFMSUBADD132PSZ256m = 9354,
  VFMSUBADD132PSZ256mb = 9355,
  VFMSUBADD132PSZ256mbk = 9356,
  VFMSUBADD132PSZ256mbkz = 9357,
  VFMSUBADD132PSZ256mk = 9358,
  VFMSUBADD132PSZ256mkz = 9359,
  VFMSUBADD132PSZ256r = 9360,
  VFMSUBADD132PSZ256rk = 9361,
  VFMSUBADD132PSZ256rkz = 9362,
  VFMSUBADD132PSZm = 9363,
  VFMSUBADD132PSZmb = 9364,
  VFMSUBADD132PSZmbk = 9365,
  VFMSUBADD132PSZmbkz = 9366,
  VFMSUBADD132PSZmk = 9367,
  VFMSUBADD132PSZmkz = 9368,
  VFMSUBADD132PSZr = 9369,
  VFMSUBADD132PSZrb = 9370,
  VFMSUBADD132PSZrbk = 9371,
  VFMSUBADD132PSZrbkz = 9372,
  VFMSUBADD132PSZrk = 9373,
  VFMSUBADD132PSZrkz = 9374,
  VFMSUBADD132PSm = 9375,
  VFMSUBADD132PSr = 9376,
  VFMSUBADD213PDYm = 9377,
  VFMSUBADD213PDYr = 9378,
  VFMSUBADD213PDZ128m = 9379,
  VFMSUBADD213PDZ128mb = 9380,
  VFMSUBADD213PDZ128mbk = 9381,
  VFMSUBADD213PDZ128mbkz = 9382,
  VFMSUBADD213PDZ128mk = 9383,
  VFMSUBADD213PDZ128mkz = 9384,
  VFMSUBADD213PDZ128r = 9385,
  VFMSUBADD213PDZ128rk = 9386,
  VFMSUBADD213PDZ128rkz = 9387,
  VFMSUBADD213PDZ256m = 9388,
  VFMSUBADD213PDZ256mb = 9389,
  VFMSUBADD213PDZ256mbk = 9390,
  VFMSUBADD213PDZ256mbkz = 9391,
  VFMSUBADD213PDZ256mk = 9392,
  VFMSUBADD213PDZ256mkz = 9393,
  VFMSUBADD213PDZ256r = 9394,
  VFMSUBADD213PDZ256rk = 9395,
  VFMSUBADD213PDZ256rkz = 9396,
  VFMSUBADD213PDZm = 9397,
  VFMSUBADD213PDZmb = 9398,
  VFMSUBADD213PDZmbk = 9399,
  VFMSUBADD213PDZmbkz = 9400,
  VFMSUBADD213PDZmk = 9401,
  VFMSUBADD213PDZmkz = 9402,
  VFMSUBADD213PDZr = 9403,
  VFMSUBADD213PDZrb = 9404,
  VFMSUBADD213PDZrbk = 9405,
  VFMSUBADD213PDZrbkz = 9406,
  VFMSUBADD213PDZrk = 9407,
  VFMSUBADD213PDZrkz = 9408,
  VFMSUBADD213PDm = 9409,
  VFMSUBADD213PDr = 9410,
  VFMSUBADD213PHZ128m = 9411,
  VFMSUBADD213PHZ128mb = 9412,
  VFMSUBADD213PHZ128mbk = 9413,
  VFMSUBADD213PHZ128mbkz = 9414,
  VFMSUBADD213PHZ128mk = 9415,
  VFMSUBADD213PHZ128mkz = 9416,
  VFMSUBADD213PHZ128r = 9417,
  VFMSUBADD213PHZ128rk = 9418,
  VFMSUBADD213PHZ128rkz = 9419,
  VFMSUBADD213PHZ256m = 9420,
  VFMSUBADD213PHZ256mb = 9421,
  VFMSUBADD213PHZ256mbk = 9422,
  VFMSUBADD213PHZ256mbkz = 9423,
  VFMSUBADD213PHZ256mk = 9424,
  VFMSUBADD213PHZ256mkz = 9425,
  VFMSUBADD213PHZ256r = 9426,
  VFMSUBADD213PHZ256rk = 9427,
  VFMSUBADD213PHZ256rkz = 9428,
  VFMSUBADD213PHZm = 9429,
  VFMSUBADD213PHZmb = 9430,
  VFMSUBADD213PHZmbk = 9431,
  VFMSUBADD213PHZmbkz = 9432,
  VFMSUBADD213PHZmk = 9433,
  VFMSUBADD213PHZmkz = 9434,
  VFMSUBADD213PHZr = 9435,
  VFMSUBADD213PHZrb = 9436,
  VFMSUBADD213PHZrbk = 9437,
  VFMSUBADD213PHZrbkz = 9438,
  VFMSUBADD213PHZrk = 9439,
  VFMSUBADD213PHZrkz = 9440,
  VFMSUBADD213PSYm = 9441,
  VFMSUBADD213PSYr = 9442,
  VFMSUBADD213PSZ128m = 9443,
  VFMSUBADD213PSZ128mb = 9444,
  VFMSUBADD213PSZ128mbk = 9445,
  VFMSUBADD213PSZ128mbkz = 9446,
  VFMSUBADD213PSZ128mk = 9447,
  VFMSUBADD213PSZ128mkz = 9448,
  VFMSUBADD213PSZ128r = 9449,
  VFMSUBADD213PSZ128rk = 9450,
  VFMSUBADD213PSZ128rkz = 9451,
  VFMSUBADD213PSZ256m = 9452,
  VFMSUBADD213PSZ256mb = 9453,
  VFMSUBADD213PSZ256mbk = 9454,
  VFMSUBADD213PSZ256mbkz = 9455,
  VFMSUBADD213PSZ256mk = 9456,
  VFMSUBADD213PSZ256mkz = 9457,
  VFMSUBADD213PSZ256r = 9458,
  VFMSUBADD213PSZ256rk = 9459,
  VFMSUBADD213PSZ256rkz = 9460,
  VFMSUBADD213PSZm = 9461,
  VFMSUBADD213PSZmb = 9462,
  VFMSUBADD213PSZmbk = 9463,
  VFMSUBADD213PSZmbkz = 9464,
  VFMSUBADD213PSZmk = 9465,
  VFMSUBADD213PSZmkz = 9466,
  VFMSUBADD213PSZr = 9467,
  VFMSUBADD213PSZrb = 9468,
  VFMSUBADD213PSZrbk = 9469,
  VFMSUBADD213PSZrbkz = 9470,
  VFMSUBADD213PSZrk = 9471,
  VFMSUBADD213PSZrkz = 9472,
  VFMSUBADD213PSm = 9473,
  VFMSUBADD213PSr = 9474,
  VFMSUBADD231PDYm = 9475,
  VFMSUBADD231PDYr = 9476,
  VFMSUBADD231PDZ128m = 9477,
  VFMSUBADD231PDZ128mb = 9478,
  VFMSUBADD231PDZ128mbk = 9479,
  VFMSUBADD231PDZ128mbkz = 9480,
  VFMSUBADD231PDZ128mk = 9481,
  VFMSUBADD231PDZ128mkz = 9482,
  VFMSUBADD231PDZ128r = 9483,
  VFMSUBADD231PDZ128rk = 9484,
  VFMSUBADD231PDZ128rkz = 9485,
  VFMSUBADD231PDZ256m = 9486,
  VFMSUBADD231PDZ256mb = 9487,
  VFMSUBADD231PDZ256mbk = 9488,
  VFMSUBADD231PDZ256mbkz = 9489,
  VFMSUBADD231PDZ256mk = 9490,
  VFMSUBADD231PDZ256mkz = 9491,
  VFMSUBADD231PDZ256r = 9492,
  VFMSUBADD231PDZ256rk = 9493,
  VFMSUBADD231PDZ256rkz = 9494,
  VFMSUBADD231PDZm = 9495,
  VFMSUBADD231PDZmb = 9496,
  VFMSUBADD231PDZmbk = 9497,
  VFMSUBADD231PDZmbkz = 9498,
  VFMSUBADD231PDZmk = 9499,
  VFMSUBADD231PDZmkz = 9500,
  VFMSUBADD231PDZr = 9501,
  VFMSUBADD231PDZrb = 9502,
  VFMSUBADD231PDZrbk = 9503,
  VFMSUBADD231PDZrbkz = 9504,
  VFMSUBADD231PDZrk = 9505,
  VFMSUBADD231PDZrkz = 9506,
  VFMSUBADD231PDm = 9507,
  VFMSUBADD231PDr = 9508,
  VFMSUBADD231PHZ128m = 9509,
  VFMSUBADD231PHZ128mb = 9510,
  VFMSUBADD231PHZ128mbk = 9511,
  VFMSUBADD231PHZ128mbkz = 9512,
  VFMSUBADD231PHZ128mk = 9513,
  VFMSUBADD231PHZ128mkz = 9514,
  VFMSUBADD231PHZ128r = 9515,
  VFMSUBADD231PHZ128rk = 9516,
  VFMSUBADD231PHZ128rkz = 9517,
  VFMSUBADD231PHZ256m = 9518,
  VFMSUBADD231PHZ256mb = 9519,
  VFMSUBADD231PHZ256mbk = 9520,
  VFMSUBADD231PHZ256mbkz = 9521,
  VFMSUBADD231PHZ256mk = 9522,
  VFMSUBADD231PHZ256mkz = 9523,
  VFMSUBADD231PHZ256r = 9524,
  VFMSUBADD231PHZ256rk = 9525,
  VFMSUBADD231PHZ256rkz = 9526,
  VFMSUBADD231PHZm = 9527,
  VFMSUBADD231PHZmb = 9528,
  VFMSUBADD231PHZmbk = 9529,
  VFMSUBADD231PHZmbkz = 9530,
  VFMSUBADD231PHZmk = 9531,
  VFMSUBADD231PHZmkz = 9532,
  VFMSUBADD231PHZr = 9533,
  VFMSUBADD231PHZrb = 9534,
  VFMSUBADD231PHZrbk = 9535,
  VFMSUBADD231PHZrbkz = 9536,
  VFMSUBADD231PHZrk = 9537,
  VFMSUBADD231PHZrkz = 9538,
  VFMSUBADD231PSYm = 9539,
  VFMSUBADD231PSYr = 9540,
  VFMSUBADD231PSZ128m = 9541,
  VFMSUBADD231PSZ128mb = 9542,
  VFMSUBADD231PSZ128mbk = 9543,
  VFMSUBADD231PSZ128mbkz = 9544,
  VFMSUBADD231PSZ128mk = 9545,
  VFMSUBADD231PSZ128mkz = 9546,
  VFMSUBADD231PSZ128r = 9547,
  VFMSUBADD231PSZ128rk = 9548,
  VFMSUBADD231PSZ128rkz = 9549,
  VFMSUBADD231PSZ256m = 9550,
  VFMSUBADD231PSZ256mb = 9551,
  VFMSUBADD231PSZ256mbk = 9552,
  VFMSUBADD231PSZ256mbkz = 9553,
  VFMSUBADD231PSZ256mk = 9554,
  VFMSUBADD231PSZ256mkz = 9555,
  VFMSUBADD231PSZ256r = 9556,
  VFMSUBADD231PSZ256rk = 9557,
  VFMSUBADD231PSZ256rkz = 9558,
  VFMSUBADD231PSZm = 9559,
  VFMSUBADD231PSZmb = 9560,
  VFMSUBADD231PSZmbk = 9561,
  VFMSUBADD231PSZmbkz = 9562,
  VFMSUBADD231PSZmk = 9563,
  VFMSUBADD231PSZmkz = 9564,
  VFMSUBADD231PSZr = 9565,
  VFMSUBADD231PSZrb = 9566,
  VFMSUBADD231PSZrbk = 9567,
  VFMSUBADD231PSZrbkz = 9568,
  VFMSUBADD231PSZrk = 9569,
  VFMSUBADD231PSZrkz = 9570,
  VFMSUBADD231PSm = 9571,
  VFMSUBADD231PSr = 9572,
  VFMSUBADDPD4Ymr = 9573,
  VFMSUBADDPD4Yrm = 9574,
  VFMSUBADDPD4Yrr = 9575,
  VFMSUBADDPD4Yrr_REV = 9576,
  VFMSUBADDPD4mr = 9577,
  VFMSUBADDPD4rm = 9578,
  VFMSUBADDPD4rr = 9579,
  VFMSUBADDPD4rr_REV = 9580,
  VFMSUBADDPS4Ymr = 9581,
  VFMSUBADDPS4Yrm = 9582,
  VFMSUBADDPS4Yrr = 9583,
  VFMSUBADDPS4Yrr_REV = 9584,
  VFMSUBADDPS4mr = 9585,
  VFMSUBADDPS4rm = 9586,
  VFMSUBADDPS4rr = 9587,
  VFMSUBADDPS4rr_REV = 9588,
  VFMSUBPD4Ymr = 9589,
  VFMSUBPD4Yrm = 9590,
  VFMSUBPD4Yrr = 9591,
  VFMSUBPD4Yrr_REV = 9592,
  VFMSUBPD4mr = 9593,
  VFMSUBPD4rm = 9594,
  VFMSUBPD4rr = 9595,
  VFMSUBPD4rr_REV = 9596,
  VFMSUBPS4Ymr = 9597,
  VFMSUBPS4Yrm = 9598,
  VFMSUBPS4Yrr = 9599,
  VFMSUBPS4Yrr_REV = 9600,
  VFMSUBPS4mr = 9601,
  VFMSUBPS4rm = 9602,
  VFMSUBPS4rr = 9603,
  VFMSUBPS4rr_REV = 9604,
  VFMSUBSD4mr = 9605,
  VFMSUBSD4mr_Int = 9606,
  VFMSUBSD4rm = 9607,
  VFMSUBSD4rm_Int = 9608,
  VFMSUBSD4rr = 9609,
  VFMSUBSD4rr_Int = 9610,
  VFMSUBSD4rr_Int_REV = 9611,
  VFMSUBSD4rr_REV = 9612,
  VFMSUBSS4mr = 9613,
  VFMSUBSS4mr_Int = 9614,
  VFMSUBSS4rm = 9615,
  VFMSUBSS4rm_Int = 9616,
  VFMSUBSS4rr = 9617,
  VFMSUBSS4rr_Int = 9618,
  VFMSUBSS4rr_Int_REV = 9619,
  VFMSUBSS4rr_REV = 9620,
  VFMULCPHZ128rm = 9621,
  VFMULCPHZ128rmb = 9622,
  VFMULCPHZ128rmbk = 9623,
  VFMULCPHZ128rmbkz = 9624,
  VFMULCPHZ128rmk = 9625,
  VFMULCPHZ128rmkz = 9626,
  VFMULCPHZ128rr = 9627,
  VFMULCPHZ128rrk = 9628,
  VFMULCPHZ128rrkz = 9629,
  VFMULCPHZ256rm = 9630,
  VFMULCPHZ256rmb = 9631,
  VFMULCPHZ256rmbk = 9632,
  VFMULCPHZ256rmbkz = 9633,
  VFMULCPHZ256rmk = 9634,
  VFMULCPHZ256rmkz = 9635,
  VFMULCPHZ256rr = 9636,
  VFMULCPHZ256rrk = 9637,
  VFMULCPHZ256rrkz = 9638,
  VFMULCPHZrm = 9639,
  VFMULCPHZrmb = 9640,
  VFMULCPHZrmbk = 9641,
  VFMULCPHZrmbkz = 9642,
  VFMULCPHZrmk = 9643,
  VFMULCPHZrmkz = 9644,
  VFMULCPHZrr = 9645,
  VFMULCPHZrrb = 9646,
  VFMULCPHZrrbk = 9647,
  VFMULCPHZrrbkz = 9648,
  VFMULCPHZrrk = 9649,
  VFMULCPHZrrkz = 9650,
  VFMULCSHZrm = 9651,
  VFMULCSHZrmk = 9652,
  VFMULCSHZrmkz = 9653,
  VFMULCSHZrr = 9654,
  VFMULCSHZrrb = 9655,
  VFMULCSHZrrbk = 9656,
  VFMULCSHZrrbkz = 9657,
  VFMULCSHZrrk = 9658,
  VFMULCSHZrrkz = 9659,
  VFNMADD132PDYm = 9660,
  VFNMADD132PDYr = 9661,
  VFNMADD132PDZ128m = 9662,
  VFNMADD132PDZ128mb = 9663,
  VFNMADD132PDZ128mbk = 9664,
  VFNMADD132PDZ128mbkz = 9665,
  VFNMADD132PDZ128mk = 9666,
  VFNMADD132PDZ128mkz = 9667,
  VFNMADD132PDZ128r = 9668,
  VFNMADD132PDZ128rk = 9669,
  VFNMADD132PDZ128rkz = 9670,
  VFNMADD132PDZ256m = 9671,
  VFNMADD132PDZ256mb = 9672,
  VFNMADD132PDZ256mbk = 9673,
  VFNMADD132PDZ256mbkz = 9674,
  VFNMADD132PDZ256mk = 9675,
  VFNMADD132PDZ256mkz = 9676,
  VFNMADD132PDZ256r = 9677,
  VFNMADD132PDZ256rk = 9678,
  VFNMADD132PDZ256rkz = 9679,
  VFNMADD132PDZm = 9680,
  VFNMADD132PDZmb = 9681,
  VFNMADD132PDZmbk = 9682,
  VFNMADD132PDZmbkz = 9683,
  VFNMADD132PDZmk = 9684,
  VFNMADD132PDZmkz = 9685,
  VFNMADD132PDZr = 9686,
  VFNMADD132PDZrb = 9687,
  VFNMADD132PDZrbk = 9688,
  VFNMADD132PDZrbkz = 9689,
  VFNMADD132PDZrk = 9690,
  VFNMADD132PDZrkz = 9691,
  VFNMADD132PDm = 9692,
  VFNMADD132PDr = 9693,
  VFNMADD132PHZ128m = 9694,
  VFNMADD132PHZ128mb = 9695,
  VFNMADD132PHZ128mbk = 9696,
  VFNMADD132PHZ128mbkz = 9697,
  VFNMADD132PHZ128mk = 9698,
  VFNMADD132PHZ128mkz = 9699,
  VFNMADD132PHZ128r = 9700,
  VFNMADD132PHZ128rk = 9701,
  VFNMADD132PHZ128rkz = 9702,
  VFNMADD132PHZ256m = 9703,
  VFNMADD132PHZ256mb = 9704,
  VFNMADD132PHZ256mbk = 9705,
  VFNMADD132PHZ256mbkz = 9706,
  VFNMADD132PHZ256mk = 9707,
  VFNMADD132PHZ256mkz = 9708,
  VFNMADD132PHZ256r = 9709,
  VFNMADD132PHZ256rk = 9710,
  VFNMADD132PHZ256rkz = 9711,
  VFNMADD132PHZm = 9712,
  VFNMADD132PHZmb = 9713,
  VFNMADD132PHZmbk = 9714,
  VFNMADD132PHZmbkz = 9715,
  VFNMADD132PHZmk = 9716,
  VFNMADD132PHZmkz = 9717,
  VFNMADD132PHZr = 9718,
  VFNMADD132PHZrb = 9719,
  VFNMADD132PHZrbk = 9720,
  VFNMADD132PHZrbkz = 9721,
  VFNMADD132PHZrk = 9722,
  VFNMADD132PHZrkz = 9723,
  VFNMADD132PSYm = 9724,
  VFNMADD132PSYr = 9725,
  VFNMADD132PSZ128m = 9726,
  VFNMADD132PSZ128mb = 9727,
  VFNMADD132PSZ128mbk = 9728,
  VFNMADD132PSZ128mbkz = 9729,
  VFNMADD132PSZ128mk = 9730,
  VFNMADD132PSZ128mkz = 9731,
  VFNMADD132PSZ128r = 9732,
  VFNMADD132PSZ128rk = 9733,
  VFNMADD132PSZ128rkz = 9734,
  VFNMADD132PSZ256m = 9735,
  VFNMADD132PSZ256mb = 9736,
  VFNMADD132PSZ256mbk = 9737,
  VFNMADD132PSZ256mbkz = 9738,
  VFNMADD132PSZ256mk = 9739,
  VFNMADD132PSZ256mkz = 9740,
  VFNMADD132PSZ256r = 9741,
  VFNMADD132PSZ256rk = 9742,
  VFNMADD132PSZ256rkz = 9743,
  VFNMADD132PSZm = 9744,
  VFNMADD132PSZmb = 9745,
  VFNMADD132PSZmbk = 9746,
  VFNMADD132PSZmbkz = 9747,
  VFNMADD132PSZmk = 9748,
  VFNMADD132PSZmkz = 9749,
  VFNMADD132PSZr = 9750,
  VFNMADD132PSZrb = 9751,
  VFNMADD132PSZrbk = 9752,
  VFNMADD132PSZrbkz = 9753,
  VFNMADD132PSZrk = 9754,
  VFNMADD132PSZrkz = 9755,
  VFNMADD132PSm = 9756,
  VFNMADD132PSr = 9757,
  VFNMADD132SDZm = 9758,
  VFNMADD132SDZm_Int = 9759,
  VFNMADD132SDZm_Intk = 9760,
  VFNMADD132SDZm_Intkz = 9761,
  VFNMADD132SDZr = 9762,
  VFNMADD132SDZr_Int = 9763,
  VFNMADD132SDZr_Intk = 9764,
  VFNMADD132SDZr_Intkz = 9765,
  VFNMADD132SDZrb = 9766,
  VFNMADD132SDZrb_Int = 9767,
  VFNMADD132SDZrb_Intk = 9768,
  VFNMADD132SDZrb_Intkz = 9769,
  VFNMADD132SDm = 9770,
  VFNMADD132SDm_Int = 9771,
  VFNMADD132SDr = 9772,
  VFNMADD132SDr_Int = 9773,
  VFNMADD132SHZm = 9774,
  VFNMADD132SHZm_Int = 9775,
  VFNMADD132SHZm_Intk = 9776,
  VFNMADD132SHZm_Intkz = 9777,
  VFNMADD132SHZr = 9778,
  VFNMADD132SHZr_Int = 9779,
  VFNMADD132SHZr_Intk = 9780,
  VFNMADD132SHZr_Intkz = 9781,
  VFNMADD132SHZrb = 9782,
  VFNMADD132SHZrb_Int = 9783,
  VFNMADD132SHZrb_Intk = 9784,
  VFNMADD132SHZrb_Intkz = 9785,
  VFNMADD132SSZm = 9786,
  VFNMADD132SSZm_Int = 9787,
  VFNMADD132SSZm_Intk = 9788,
  VFNMADD132SSZm_Intkz = 9789,
  VFNMADD132SSZr = 9790,
  VFNMADD132SSZr_Int = 9791,
  VFNMADD132SSZr_Intk = 9792,
  VFNMADD132SSZr_Intkz = 9793,
  VFNMADD132SSZrb = 9794,
  VFNMADD132SSZrb_Int = 9795,
  VFNMADD132SSZrb_Intk = 9796,
  VFNMADD132SSZrb_Intkz = 9797,
  VFNMADD132SSm = 9798,
  VFNMADD132SSm_Int = 9799,
  VFNMADD132SSr = 9800,
  VFNMADD132SSr_Int = 9801,
  VFNMADD213PDYm = 9802,
  VFNMADD213PDYr = 9803,
  VFNMADD213PDZ128m = 9804,
  VFNMADD213PDZ128mb = 9805,
  VFNMADD213PDZ128mbk = 9806,
  VFNMADD213PDZ128mbkz = 9807,
  VFNMADD213PDZ128mk = 9808,
  VFNMADD213PDZ128mkz = 9809,
  VFNMADD213PDZ128r = 9810,
  VFNMADD213PDZ128rk = 9811,
  VFNMADD213PDZ128rkz = 9812,
  VFNMADD213PDZ256m = 9813,
  VFNMADD213PDZ256mb = 9814,
  VFNMADD213PDZ256mbk = 9815,
  VFNMADD213PDZ256mbkz = 9816,
  VFNMADD213PDZ256mk = 9817,
  VFNMADD213PDZ256mkz = 9818,
  VFNMADD213PDZ256r = 9819,
  VFNMADD213PDZ256rk = 9820,
  VFNMADD213PDZ256rkz = 9821,
  VFNMADD213PDZm = 9822,
  VFNMADD213PDZmb = 9823,
  VFNMADD213PDZmbk = 9824,
  VFNMADD213PDZmbkz = 9825,
  VFNMADD213PDZmk = 9826,
  VFNMADD213PDZmkz = 9827,
  VFNMADD213PDZr = 9828,
  VFNMADD213PDZrb = 9829,
  VFNMADD213PDZrbk = 9830,
  VFNMADD213PDZrbkz = 9831,
  VFNMADD213PDZrk = 9832,
  VFNMADD213PDZrkz = 9833,
  VFNMADD213PDm = 9834,
  VFNMADD213PDr = 9835,
  VFNMADD213PHZ128m = 9836,
  VFNMADD213PHZ128mb = 9837,
  VFNMADD213PHZ128mbk = 9838,
  VFNMADD213PHZ128mbkz = 9839,
  VFNMADD213PHZ128mk = 9840,
  VFNMADD213PHZ128mkz = 9841,
  VFNMADD213PHZ128r = 9842,
  VFNMADD213PHZ128rk = 9843,
  VFNMADD213PHZ128rkz = 9844,
  VFNMADD213PHZ256m = 9845,
  VFNMADD213PHZ256mb = 9846,
  VFNMADD213PHZ256mbk = 9847,
  VFNMADD213PHZ256mbkz = 9848,
  VFNMADD213PHZ256mk = 9849,
  VFNMADD213PHZ256mkz = 9850,
  VFNMADD213PHZ256r = 9851,
  VFNMADD213PHZ256rk = 9852,
  VFNMADD213PHZ256rkz = 9853,
  VFNMADD213PHZm = 9854,
  VFNMADD213PHZmb = 9855,
  VFNMADD213PHZmbk = 9856,
  VFNMADD213PHZmbkz = 9857,
  VFNMADD213PHZmk = 9858,
  VFNMADD213PHZmkz = 9859,
  VFNMADD213PHZr = 9860,
  VFNMADD213PHZrb = 9861,
  VFNMADD213PHZrbk = 9862,
  VFNMADD213PHZrbkz = 9863,
  VFNMADD213PHZrk = 9864,
  VFNMADD213PHZrkz = 9865,
  VFNMADD213PSYm = 9866,
  VFNMADD213PSYr = 9867,
  VFNMADD213PSZ128m = 9868,
  VFNMADD213PSZ128mb = 9869,
  VFNMADD213PSZ128mbk = 9870,
  VFNMADD213PSZ128mbkz = 9871,
  VFNMADD213PSZ128mk = 9872,
  VFNMADD213PSZ128mkz = 9873,
  VFNMADD213PSZ128r = 9874,
  VFNMADD213PSZ128rk = 9875,
  VFNMADD213PSZ128rkz = 9876,
  VFNMADD213PSZ256m = 9877,
  VFNMADD213PSZ256mb = 9878,
  VFNMADD213PSZ256mbk = 9879,
  VFNMADD213PSZ256mbkz = 9880,
  VFNMADD213PSZ256mk = 9881,
  VFNMADD213PSZ256mkz = 9882,
  VFNMADD213PSZ256r = 9883,
  VFNMADD213PSZ256rk = 9884,
  VFNMADD213PSZ256rkz = 9885,
  VFNMADD213PSZm = 9886,
  VFNMADD213PSZmb = 9887,
  VFNMADD213PSZmbk = 9888,
  VFNMADD213PSZmbkz = 9889,
  VFNMADD213PSZmk = 9890,
  VFNMADD213PSZmkz = 9891,
  VFNMADD213PSZr = 9892,
  VFNMADD213PSZrb = 9893,
  VFNMADD213PSZrbk = 9894,
  VFNMADD213PSZrbkz = 9895,
  VFNMADD213PSZrk = 9896,
  VFNMADD213PSZrkz = 9897,
  VFNMADD213PSm = 9898,
  VFNMADD213PSr = 9899,
  VFNMADD213SDZm = 9900,
  VFNMADD213SDZm_Int = 9901,
  VFNMADD213SDZm_Intk = 9902,
  VFNMADD213SDZm_Intkz = 9903,
  VFNMADD213SDZr = 9904,
  VFNMADD213SDZr_Int = 9905,
  VFNMADD213SDZr_Intk = 9906,
  VFNMADD213SDZr_Intkz = 9907,
  VFNMADD213SDZrb = 9908,
  VFNMADD213SDZrb_Int = 9909,
  VFNMADD213SDZrb_Intk = 9910,
  VFNMADD213SDZrb_Intkz = 9911,
  VFNMADD213SDm = 9912,
  VFNMADD213SDm_Int = 9913,
  VFNMADD213SDr = 9914,
  VFNMADD213SDr_Int = 9915,
  VFNMADD213SHZm = 9916,
  VFNMADD213SHZm_Int = 9917,
  VFNMADD213SHZm_Intk = 9918,
  VFNMADD213SHZm_Intkz = 9919,
  VFNMADD213SHZr = 9920,
  VFNMADD213SHZr_Int = 9921,
  VFNMADD213SHZr_Intk = 9922,
  VFNMADD213SHZr_Intkz = 9923,
  VFNMADD213SHZrb = 9924,
  VFNMADD213SHZrb_Int = 9925,
  VFNMADD213SHZrb_Intk = 9926,
  VFNMADD213SHZrb_Intkz = 9927,
  VFNMADD213SSZm = 9928,
  VFNMADD213SSZm_Int = 9929,
  VFNMADD213SSZm_Intk = 9930,
  VFNMADD213SSZm_Intkz = 9931,
  VFNMADD213SSZr = 9932,
  VFNMADD213SSZr_Int = 9933,
  VFNMADD213SSZr_Intk = 9934,
  VFNMADD213SSZr_Intkz = 9935,
  VFNMADD213SSZrb = 9936,
  VFNMADD213SSZrb_Int = 9937,
  VFNMADD213SSZrb_Intk = 9938,
  VFNMADD213SSZrb_Intkz = 9939,
  VFNMADD213SSm = 9940,
  VFNMADD213SSm_Int = 9941,
  VFNMADD213SSr = 9942,
  VFNMADD213SSr_Int = 9943,
  VFNMADD231PDYm = 9944,
  VFNMADD231PDYr = 9945,
  VFNMADD231PDZ128m = 9946,
  VFNMADD231PDZ128mb = 9947,
  VFNMADD231PDZ128mbk = 9948,
  VFNMADD231PDZ128mbkz = 9949,
  VFNMADD231PDZ128mk = 9950,
  VFNMADD231PDZ128mkz = 9951,
  VFNMADD231PDZ128r = 9952,
  VFNMADD231PDZ128rk = 9953,
  VFNMADD231PDZ128rkz = 9954,
  VFNMADD231PDZ256m = 9955,
  VFNMADD231PDZ256mb = 9956,
  VFNMADD231PDZ256mbk = 9957,
  VFNMADD231PDZ256mbkz = 9958,
  VFNMADD231PDZ256mk = 9959,
  VFNMADD231PDZ256mkz = 9960,
  VFNMADD231PDZ256r = 9961,
  VFNMADD231PDZ256rk = 9962,
  VFNMADD231PDZ256rkz = 9963,
  VFNMADD231PDZm = 9964,
  VFNMADD231PDZmb = 9965,
  VFNMADD231PDZmbk = 9966,
  VFNMADD231PDZmbkz = 9967,
  VFNMADD231PDZmk = 9968,
  VFNMADD231PDZmkz = 9969,
  VFNMADD231PDZr = 9970,
  VFNMADD231PDZrb = 9971,
  VFNMADD231PDZrbk = 9972,
  VFNMADD231PDZrbkz = 9973,
  VFNMADD231PDZrk = 9974,
  VFNMADD231PDZrkz = 9975,
  VFNMADD231PDm = 9976,
  VFNMADD231PDr = 9977,
  VFNMADD231PHZ128m = 9978,
  VFNMADD231PHZ128mb = 9979,
  VFNMADD231PHZ128mbk = 9980,
  VFNMADD231PHZ128mbkz = 9981,
  VFNMADD231PHZ128mk = 9982,
  VFNMADD231PHZ128mkz = 9983,
  VFNMADD231PHZ128r = 9984,
  VFNMADD231PHZ128rk = 9985,
  VFNMADD231PHZ128rkz = 9986,
  VFNMADD231PHZ256m = 9987,
  VFNMADD231PHZ256mb = 9988,
  VFNMADD231PHZ256mbk = 9989,
  VFNMADD231PHZ256mbkz = 9990,
  VFNMADD231PHZ256mk = 9991,
  VFNMADD231PHZ256mkz = 9992,
  VFNMADD231PHZ256r = 9993,
  VFNMADD231PHZ256rk = 9994,
  VFNMADD231PHZ256rkz = 9995,
  VFNMADD231PHZm = 9996,
  VFNMADD231PHZmb = 9997,
  VFNMADD231PHZmbk = 9998,
  VFNMADD231PHZmbkz = 9999,
  VFNMADD231PHZmk = 10000,
  VFNMADD231PHZmkz = 10001,
  VFNMADD231PHZr = 10002,
  VFNMADD231PHZrb = 10003,
  VFNMADD231PHZrbk = 10004,
  VFNMADD231PHZrbkz = 10005,
  VFNMADD231PHZrk = 10006,
  VFNMADD231PHZrkz = 10007,
  VFNMADD231PSYm = 10008,
  VFNMADD231PSYr = 10009,
  VFNMADD231PSZ128m = 10010,
  VFNMADD231PSZ128mb = 10011,
  VFNMADD231PSZ128mbk = 10012,
  VFNMADD231PSZ128mbkz = 10013,
  VFNMADD231PSZ128mk = 10014,
  VFNMADD231PSZ128mkz = 10015,
  VFNMADD231PSZ128r = 10016,
  VFNMADD231PSZ128rk = 10017,
  VFNMADD231PSZ128rkz = 10018,
  VFNMADD231PSZ256m = 10019,
  VFNMADD231PSZ256mb = 10020,
  VFNMADD231PSZ256mbk = 10021,
  VFNMADD231PSZ256mbkz = 10022,
  VFNMADD231PSZ256mk = 10023,
  VFNMADD231PSZ256mkz = 10024,
  VFNMADD231PSZ256r = 10025,
  VFNMADD231PSZ256rk = 10026,
  VFNMADD231PSZ256rkz = 10027,
  VFNMADD231PSZm = 10028,
  VFNMADD231PSZmb = 10029,
  VFNMADD231PSZmbk = 10030,
  VFNMADD231PSZmbkz = 10031,
  VFNMADD231PSZmk = 10032,
  VFNMADD231PSZmkz = 10033,
  VFNMADD231PSZr = 10034,
  VFNMADD231PSZrb = 10035,
  VFNMADD231PSZrbk = 10036,
  VFNMADD231PSZrbkz = 10037,
  VFNMADD231PSZrk = 10038,
  VFNMADD231PSZrkz = 10039,
  VFNMADD231PSm = 10040,
  VFNMADD231PSr = 10041,
  VFNMADD231SDZm = 10042,
  VFNMADD231SDZm_Int = 10043,
  VFNMADD231SDZm_Intk = 10044,
  VFNMADD231SDZm_Intkz = 10045,
  VFNMADD231SDZr = 10046,
  VFNMADD231SDZr_Int = 10047,
  VFNMADD231SDZr_Intk = 10048,
  VFNMADD231SDZr_Intkz = 10049,
  VFNMADD231SDZrb = 10050,
  VFNMADD231SDZrb_Int = 10051,
  VFNMADD231SDZrb_Intk = 10052,
  VFNMADD231SDZrb_Intkz = 10053,
  VFNMADD231SDm = 10054,
  VFNMADD231SDm_Int = 10055,
  VFNMADD231SDr = 10056,
  VFNMADD231SDr_Int = 10057,
  VFNMADD231SHZm = 10058,
  VFNMADD231SHZm_Int = 10059,
  VFNMADD231SHZm_Intk = 10060,
  VFNMADD231SHZm_Intkz = 10061,
  VFNMADD231SHZr = 10062,
  VFNMADD231SHZr_Int = 10063,
  VFNMADD231SHZr_Intk = 10064,
  VFNMADD231SHZr_Intkz = 10065,
  VFNMADD231SHZrb = 10066,
  VFNMADD231SHZrb_Int = 10067,
  VFNMADD231SHZrb_Intk = 10068,
  VFNMADD231SHZrb_Intkz = 10069,
  VFNMADD231SSZm = 10070,
  VFNMADD231SSZm_Int = 10071,
  VFNMADD231SSZm_Intk = 10072,
  VFNMADD231SSZm_Intkz = 10073,
  VFNMADD231SSZr = 10074,
  VFNMADD231SSZr_Int = 10075,
  VFNMADD231SSZr_Intk = 10076,
  VFNMADD231SSZr_Intkz = 10077,
  VFNMADD231SSZrb = 10078,
  VFNMADD231SSZrb_Int = 10079,
  VFNMADD231SSZrb_Intk = 10080,
  VFNMADD231SSZrb_Intkz = 10081,
  VFNMADD231SSm = 10082,
  VFNMADD231SSm_Int = 10083,
  VFNMADD231SSr = 10084,
  VFNMADD231SSr_Int = 10085,
  VFNMADDPD4Ymr = 10086,
  VFNMADDPD4Yrm = 10087,
  VFNMADDPD4Yrr = 10088,
  VFNMADDPD4Yrr_REV = 10089,
  VFNMADDPD4mr = 10090,
  VFNMADDPD4rm = 10091,
  VFNMADDPD4rr = 10092,
  VFNMADDPD4rr_REV = 10093,
  VFNMADDPS4Ymr = 10094,
  VFNMADDPS4Yrm = 10095,
  VFNMADDPS4Yrr = 10096,
  VFNMADDPS4Yrr_REV = 10097,
  VFNMADDPS4mr = 10098,
  VFNMADDPS4rm = 10099,
  VFNMADDPS4rr = 10100,
  VFNMADDPS4rr_REV = 10101,
  VFNMADDSD4mr = 10102,
  VFNMADDSD4mr_Int = 10103,
  VFNMADDSD4rm = 10104,
  VFNMADDSD4rm_Int = 10105,
  VFNMADDSD4rr = 10106,
  VFNMADDSD4rr_Int = 10107,
  VFNMADDSD4rr_Int_REV = 10108,
  VFNMADDSD4rr_REV = 10109,
  VFNMADDSS4mr = 10110,
  VFNMADDSS4mr_Int = 10111,
  VFNMADDSS4rm = 10112,
  VFNMADDSS4rm_Int = 10113,
  VFNMADDSS4rr = 10114,
  VFNMADDSS4rr_Int = 10115,
  VFNMADDSS4rr_Int_REV = 10116,
  VFNMADDSS4rr_REV = 10117,
  VFNMSUB132PDYm = 10118,
  VFNMSUB132PDYr = 10119,
  VFNMSUB132PDZ128m = 10120,
  VFNMSUB132PDZ128mb = 10121,
  VFNMSUB132PDZ128mbk = 10122,
  VFNMSUB132PDZ128mbkz = 10123,
  VFNMSUB132PDZ128mk = 10124,
  VFNMSUB132PDZ128mkz = 10125,
  VFNMSUB132PDZ128r = 10126,
  VFNMSUB132PDZ128rk = 10127,
  VFNMSUB132PDZ128rkz = 10128,
  VFNMSUB132PDZ256m = 10129,
  VFNMSUB132PDZ256mb = 10130,
  VFNMSUB132PDZ256mbk = 10131,
  VFNMSUB132PDZ256mbkz = 10132,
  VFNMSUB132PDZ256mk = 10133,
  VFNMSUB132PDZ256mkz = 10134,
  VFNMSUB132PDZ256r = 10135,
  VFNMSUB132PDZ256rk = 10136,
  VFNMSUB132PDZ256rkz = 10137,
  VFNMSUB132PDZm = 10138,
  VFNMSUB132PDZmb = 10139,
  VFNMSUB132PDZmbk = 10140,
  VFNMSUB132PDZmbkz = 10141,
  VFNMSUB132PDZmk = 10142,
  VFNMSUB132PDZmkz = 10143,
  VFNMSUB132PDZr = 10144,
  VFNMSUB132PDZrb = 10145,
  VFNMSUB132PDZrbk = 10146,
  VFNMSUB132PDZrbkz = 10147,
  VFNMSUB132PDZrk = 10148,
  VFNMSUB132PDZrkz = 10149,
  VFNMSUB132PDm = 10150,
  VFNMSUB132PDr = 10151,
  VFNMSUB132PHZ128m = 10152,
  VFNMSUB132PHZ128mb = 10153,
  VFNMSUB132PHZ128mbk = 10154,
  VFNMSUB132PHZ128mbkz = 10155,
  VFNMSUB132PHZ128mk = 10156,
  VFNMSUB132PHZ128mkz = 10157,
  VFNMSUB132PHZ128r = 10158,
  VFNMSUB132PHZ128rk = 10159,
  VFNMSUB132PHZ128rkz = 10160,
  VFNMSUB132PHZ256m = 10161,
  VFNMSUB132PHZ256mb = 10162,
  VFNMSUB132PHZ256mbk = 10163,
  VFNMSUB132PHZ256mbkz = 10164,
  VFNMSUB132PHZ256mk = 10165,
  VFNMSUB132PHZ256mkz = 10166,
  VFNMSUB132PHZ256r = 10167,
  VFNMSUB132PHZ256rk = 10168,
  VFNMSUB132PHZ256rkz = 10169,
  VFNMSUB132PHZm = 10170,
  VFNMSUB132PHZmb = 10171,
  VFNMSUB132PHZmbk = 10172,
  VFNMSUB132PHZmbkz = 10173,
  VFNMSUB132PHZmk = 10174,
  VFNMSUB132PHZmkz = 10175,
  VFNMSUB132PHZr = 10176,
  VFNMSUB132PHZrb = 10177,
  VFNMSUB132PHZrbk = 10178,
  VFNMSUB132PHZrbkz = 10179,
  VFNMSUB132PHZrk = 10180,
  VFNMSUB132PHZrkz = 10181,
  VFNMSUB132PSYm = 10182,
  VFNMSUB132PSYr = 10183,
  VFNMSUB132PSZ128m = 10184,
  VFNMSUB132PSZ128mb = 10185,
  VFNMSUB132PSZ128mbk = 10186,
  VFNMSUB132PSZ128mbkz = 10187,
  VFNMSUB132PSZ128mk = 10188,
  VFNMSUB132PSZ128mkz = 10189,
  VFNMSUB132PSZ128r = 10190,
  VFNMSUB132PSZ128rk = 10191,
  VFNMSUB132PSZ128rkz = 10192,
  VFNMSUB132PSZ256m = 10193,
  VFNMSUB132PSZ256mb = 10194,
  VFNMSUB132PSZ256mbk = 10195,
  VFNMSUB132PSZ256mbkz = 10196,
  VFNMSUB132PSZ256mk = 10197,
  VFNMSUB132PSZ256mkz = 10198,
  VFNMSUB132PSZ256r = 10199,
  VFNMSUB132PSZ256rk = 10200,
  VFNMSUB132PSZ256rkz = 10201,
  VFNMSUB132PSZm = 10202,
  VFNMSUB132PSZmb = 10203,
  VFNMSUB132PSZmbk = 10204,
  VFNMSUB132PSZmbkz = 10205,
  VFNMSUB132PSZmk = 10206,
  VFNMSUB132PSZmkz = 10207,
  VFNMSUB132PSZr = 10208,
  VFNMSUB132PSZrb = 10209,
  VFNMSUB132PSZrbk = 10210,
  VFNMSUB132PSZrbkz = 10211,
  VFNMSUB132PSZrk = 10212,
  VFNMSUB132PSZrkz = 10213,
  VFNMSUB132PSm = 10214,
  VFNMSUB132PSr = 10215,
  VFNMSUB132SDZm = 10216,
  VFNMSUB132SDZm_Int = 10217,
  VFNMSUB132SDZm_Intk = 10218,
  VFNMSUB132SDZm_Intkz = 10219,
  VFNMSUB132SDZr = 10220,
  VFNMSUB132SDZr_Int = 10221,
  VFNMSUB132SDZr_Intk = 10222,
  VFNMSUB132SDZr_Intkz = 10223,
  VFNMSUB132SDZrb = 10224,
  VFNMSUB132SDZrb_Int = 10225,
  VFNMSUB132SDZrb_Intk = 10226,
  VFNMSUB132SDZrb_Intkz = 10227,
  VFNMSUB132SDm = 10228,
  VFNMSUB132SDm_Int = 10229,
  VFNMSUB132SDr = 10230,
  VFNMSUB132SDr_Int = 10231,
  VFNMSUB132SHZm = 10232,
  VFNMSUB132SHZm_Int = 10233,
  VFNMSUB132SHZm_Intk = 10234,
  VFNMSUB132SHZm_Intkz = 10235,
  VFNMSUB132SHZr = 10236,
  VFNMSUB132SHZr_Int = 10237,
  VFNMSUB132SHZr_Intk = 10238,
  VFNMSUB132SHZr_Intkz = 10239,
  VFNMSUB132SHZrb = 10240,
  VFNMSUB132SHZrb_Int = 10241,
  VFNMSUB132SHZrb_Intk = 10242,
  VFNMSUB132SHZrb_Intkz = 10243,
  VFNMSUB132SSZm = 10244,
  VFNMSUB132SSZm_Int = 10245,
  VFNMSUB132SSZm_Intk = 10246,
  VFNMSUB132SSZm_Intkz = 10247,
  VFNMSUB132SSZr = 10248,
  VFNMSUB132SSZr_Int = 10249,
  VFNMSUB132SSZr_Intk = 10250,
  VFNMSUB132SSZr_Intkz = 10251,
  VFNMSUB132SSZrb = 10252,
  VFNMSUB132SSZrb_Int = 10253,
  VFNMSUB132SSZrb_Intk = 10254,
  VFNMSUB132SSZrb_Intkz = 10255,
  VFNMSUB132SSm = 10256,
  VFNMSUB132SSm_Int = 10257,
  VFNMSUB132SSr = 10258,
  VFNMSUB132SSr_Int = 10259,
  VFNMSUB213PDYm = 10260,
  VFNMSUB213PDYr = 10261,
  VFNMSUB213PDZ128m = 10262,
  VFNMSUB213PDZ128mb = 10263,
  VFNMSUB213PDZ128mbk = 10264,
  VFNMSUB213PDZ128mbkz = 10265,
  VFNMSUB213PDZ128mk = 10266,
  VFNMSUB213PDZ128mkz = 10267,
  VFNMSUB213PDZ128r = 10268,
  VFNMSUB213PDZ128rk = 10269,
  VFNMSUB213PDZ128rkz = 10270,
  VFNMSUB213PDZ256m = 10271,
  VFNMSUB213PDZ256mb = 10272,
  VFNMSUB213PDZ256mbk = 10273,
  VFNMSUB213PDZ256mbkz = 10274,
  VFNMSUB213PDZ256mk = 10275,
  VFNMSUB213PDZ256mkz = 10276,
  VFNMSUB213PDZ256r = 10277,
  VFNMSUB213PDZ256rk = 10278,
  VFNMSUB213PDZ256rkz = 10279,
  VFNMSUB213PDZm = 10280,
  VFNMSUB213PDZmb = 10281,
  VFNMSUB213PDZmbk = 10282,
  VFNMSUB213PDZmbkz = 10283,
  VFNMSUB213PDZmk = 10284,
  VFNMSUB213PDZmkz = 10285,
  VFNMSUB213PDZr = 10286,
  VFNMSUB213PDZrb = 10287,
  VFNMSUB213PDZrbk = 10288,
  VFNMSUB213PDZrbkz = 10289,
  VFNMSUB213PDZrk = 10290,
  VFNMSUB213PDZrkz = 10291,
  VFNMSUB213PDm = 10292,
  VFNMSUB213PDr = 10293,
  VFNMSUB213PHZ128m = 10294,
  VFNMSUB213PHZ128mb = 10295,
  VFNMSUB213PHZ128mbk = 10296,
  VFNMSUB213PHZ128mbkz = 10297,
  VFNMSUB213PHZ128mk = 10298,
  VFNMSUB213PHZ128mkz = 10299,
  VFNMSUB213PHZ128r = 10300,
  VFNMSUB213PHZ128rk = 10301,
  VFNMSUB213PHZ128rkz = 10302,
  VFNMSUB213PHZ256m = 10303,
  VFNMSUB213PHZ256mb = 10304,
  VFNMSUB213PHZ256mbk = 10305,
  VFNMSUB213PHZ256mbkz = 10306,
  VFNMSUB213PHZ256mk = 10307,
  VFNMSUB213PHZ256mkz = 10308,
  VFNMSUB213PHZ256r = 10309,
  VFNMSUB213PHZ256rk = 10310,
  VFNMSUB213PHZ256rkz = 10311,
  VFNMSUB213PHZm = 10312,
  VFNMSUB213PHZmb = 10313,
  VFNMSUB213PHZmbk = 10314,
  VFNMSUB213PHZmbkz = 10315,
  VFNMSUB213PHZmk = 10316,
  VFNMSUB213PHZmkz = 10317,
  VFNMSUB213PHZr = 10318,
  VFNMSUB213PHZrb = 10319,
  VFNMSUB213PHZrbk = 10320,
  VFNMSUB213PHZrbkz = 10321,
  VFNMSUB213PHZrk = 10322,
  VFNMSUB213PHZrkz = 10323,
  VFNMSUB213PSYm = 10324,
  VFNMSUB213PSYr = 10325,
  VFNMSUB213PSZ128m = 10326,
  VFNMSUB213PSZ128mb = 10327,
  VFNMSUB213PSZ128mbk = 10328,
  VFNMSUB213PSZ128mbkz = 10329,
  VFNMSUB213PSZ128mk = 10330,
  VFNMSUB213PSZ128mkz = 10331,
  VFNMSUB213PSZ128r = 10332,
  VFNMSUB213PSZ128rk = 10333,
  VFNMSUB213PSZ128rkz = 10334,
  VFNMSUB213PSZ256m = 10335,
  VFNMSUB213PSZ256mb = 10336,
  VFNMSUB213PSZ256mbk = 10337,
  VFNMSUB213PSZ256mbkz = 10338,
  VFNMSUB213PSZ256mk = 10339,
  VFNMSUB213PSZ256mkz = 10340,
  VFNMSUB213PSZ256r = 10341,
  VFNMSUB213PSZ256rk = 10342,
  VFNMSUB213PSZ256rkz = 10343,
  VFNMSUB213PSZm = 10344,
  VFNMSUB213PSZmb = 10345,
  VFNMSUB213PSZmbk = 10346,
  VFNMSUB213PSZmbkz = 10347,
  VFNMSUB213PSZmk = 10348,
  VFNMSUB213PSZmkz = 10349,
  VFNMSUB213PSZr = 10350,
  VFNMSUB213PSZrb = 10351,
  VFNMSUB213PSZrbk = 10352,
  VFNMSUB213PSZrbkz = 10353,
  VFNMSUB213PSZrk = 10354,
  VFNMSUB213PSZrkz = 10355,
  VFNMSUB213PSm = 10356,
  VFNMSUB213PSr = 10357,
  VFNMSUB213SDZm = 10358,
  VFNMSUB213SDZm_Int = 10359,
  VFNMSUB213SDZm_Intk = 10360,
  VFNMSUB213SDZm_Intkz = 10361,
  VFNMSUB213SDZr = 10362,
  VFNMSUB213SDZr_Int = 10363,
  VFNMSUB213SDZr_Intk = 10364,
  VFNMSUB213SDZr_Intkz = 10365,
  VFNMSUB213SDZrb = 10366,
  VFNMSUB213SDZrb_Int = 10367,
  VFNMSUB213SDZrb_Intk = 10368,
  VFNMSUB213SDZrb_Intkz = 10369,
  VFNMSUB213SDm = 10370,
  VFNMSUB213SDm_Int = 10371,
  VFNMSUB213SDr = 10372,
  VFNMSUB213SDr_Int = 10373,
  VFNMSUB213SHZm = 10374,
  VFNMSUB213SHZm_Int = 10375,
  VFNMSUB213SHZm_Intk = 10376,
  VFNMSUB213SHZm_Intkz = 10377,
  VFNMSUB213SHZr = 10378,
  VFNMSUB213SHZr_Int = 10379,
  VFNMSUB213SHZr_Intk = 10380,
  VFNMSUB213SHZr_Intkz = 10381,
  VFNMSUB213SHZrb = 10382,
  VFNMSUB213SHZrb_Int = 10383,
  VFNMSUB213SHZrb_Intk = 10384,
  VFNMSUB213SHZrb_Intkz = 10385,
  VFNMSUB213SSZm = 10386,
  VFNMSUB213SSZm_Int = 10387,
  VFNMSUB213SSZm_Intk = 10388,
  VFNMSUB213SSZm_Intkz = 10389,
  VFNMSUB213SSZr = 10390,
  VFNMSUB213SSZr_Int = 10391,
  VFNMSUB213SSZr_Intk = 10392,
  VFNMSUB213SSZr_Intkz = 10393,
  VFNMSUB213SSZrb = 10394,
  VFNMSUB213SSZrb_Int = 10395,
  VFNMSUB213SSZrb_Intk = 10396,
  VFNMSUB213SSZrb_Intkz = 10397,
  VFNMSUB213SSm = 10398,
  VFNMSUB213SSm_Int = 10399,
  VFNMSUB213SSr = 10400,
  VFNMSUB213SSr_Int = 10401,
  VFNMSUB231PDYm = 10402,
  VFNMSUB231PDYr = 10403,
  VFNMSUB231PDZ128m = 10404,
  VFNMSUB231PDZ128mb = 10405,
  VFNMSUB231PDZ128mbk = 10406,
  VFNMSUB231PDZ128mbkz = 10407,
  VFNMSUB231PDZ128mk = 10408,
  VFNMSUB231PDZ128mkz = 10409,
  VFNMSUB231PDZ128r = 10410,
  VFNMSUB231PDZ128rk = 10411,
  VFNMSUB231PDZ128rkz = 10412,
  VFNMSUB231PDZ256m = 10413,
  VFNMSUB231PDZ256mb = 10414,
  VFNMSUB231PDZ256mbk = 10415,
  VFNMSUB231PDZ256mbkz = 10416,
  VFNMSUB231PDZ256mk = 10417,
  VFNMSUB231PDZ256mkz = 10418,
  VFNMSUB231PDZ256r = 10419,
  VFNMSUB231PDZ256rk = 10420,
  VFNMSUB231PDZ256rkz = 10421,
  VFNMSUB231PDZm = 10422,
  VFNMSUB231PDZmb = 10423,
  VFNMSUB231PDZmbk = 10424,
  VFNMSUB231PDZmbkz = 10425,
  VFNMSUB231PDZmk = 10426,
  VFNMSUB231PDZmkz = 10427,
  VFNMSUB231PDZr = 10428,
  VFNMSUB231PDZrb = 10429,
  VFNMSUB231PDZrbk = 10430,
  VFNMSUB231PDZrbkz = 10431,
  VFNMSUB231PDZrk = 10432,
  VFNMSUB231PDZrkz = 10433,
  VFNMSUB231PDm = 10434,
  VFNMSUB231PDr = 10435,
  VFNMSUB231PHZ128m = 10436,
  VFNMSUB231PHZ128mb = 10437,
  VFNMSUB231PHZ128mbk = 10438,
  VFNMSUB231PHZ128mbkz = 10439,
  VFNMSUB231PHZ128mk = 10440,
  VFNMSUB231PHZ128mkz = 10441,
  VFNMSUB231PHZ128r = 10442,
  VFNMSUB231PHZ128rk = 10443,
  VFNMSUB231PHZ128rkz = 10444,
  VFNMSUB231PHZ256m = 10445,
  VFNMSUB231PHZ256mb = 10446,
  VFNMSUB231PHZ256mbk = 10447,
  VFNMSUB231PHZ256mbkz = 10448,
  VFNMSUB231PHZ256mk = 10449,
  VFNMSUB231PHZ256mkz = 10450,
  VFNMSUB231PHZ256r = 10451,
  VFNMSUB231PHZ256rk = 10452,
  VFNMSUB231PHZ256rkz = 10453,
  VFNMSUB231PHZm = 10454,
  VFNMSUB231PHZmb = 10455,
  VFNMSUB231PHZmbk = 10456,
  VFNMSUB231PHZmbkz = 10457,
  VFNMSUB231PHZmk = 10458,
  VFNMSUB231PHZmkz = 10459,
  VFNMSUB231PHZr = 10460,
  VFNMSUB231PHZrb = 10461,
  VFNMSUB231PHZrbk = 10462,
  VFNMSUB231PHZrbkz = 10463,
  VFNMSUB231PHZrk = 10464,
  VFNMSUB231PHZrkz = 10465,
  VFNMSUB231PSYm = 10466,
  VFNMSUB231PSYr = 10467,
  VFNMSUB231PSZ128m = 10468,
  VFNMSUB231PSZ128mb = 10469,
  VFNMSUB231PSZ128mbk = 10470,
  VFNMSUB231PSZ128mbkz = 10471,
  VFNMSUB231PSZ128mk = 10472,
  VFNMSUB231PSZ128mkz = 10473,
  VFNMSUB231PSZ128r = 10474,
  VFNMSUB231PSZ128rk = 10475,
  VFNMSUB231PSZ128rkz = 10476,
  VFNMSUB231PSZ256m = 10477,
  VFNMSUB231PSZ256mb = 10478,
  VFNMSUB231PSZ256mbk = 10479,
  VFNMSUB231PSZ256mbkz = 10480,
  VFNMSUB231PSZ256mk = 10481,
  VFNMSUB231PSZ256mkz = 10482,
  VFNMSUB231PSZ256r = 10483,
  VFNMSUB231PSZ256rk = 10484,
  VFNMSUB231PSZ256rkz = 10485,
  VFNMSUB231PSZm = 10486,
  VFNMSUB231PSZmb = 10487,
  VFNMSUB231PSZmbk = 10488,
  VFNMSUB231PSZmbkz = 10489,
  VFNMSUB231PSZmk = 10490,
  VFNMSUB231PSZmkz = 10491,
  VFNMSUB231PSZr = 10492,
  VFNMSUB231PSZrb = 10493,
  VFNMSUB231PSZrbk = 10494,
  VFNMSUB231PSZrbkz = 10495,
  VFNMSUB231PSZrk = 10496,
  VFNMSUB231PSZrkz = 10497,
  VFNMSUB231PSm = 10498,
  VFNMSUB231PSr = 10499,
  VFNMSUB231SDZm = 10500,
  VFNMSUB231SDZm_Int = 10501,
  VFNMSUB231SDZm_Intk = 10502,
  VFNMSUB231SDZm_Intkz = 10503,
  VFNMSUB231SDZr = 10504,
  VFNMSUB231SDZr_Int = 10505,
  VFNMSUB231SDZr_Intk = 10506,
  VFNMSUB231SDZr_Intkz = 10507,
  VFNMSUB231SDZrb = 10508,
  VFNMSUB231SDZrb_Int = 10509,
  VFNMSUB231SDZrb_Intk = 10510,
  VFNMSUB231SDZrb_Intkz = 10511,
  VFNMSUB231SDm = 10512,
  VFNMSUB231SDm_Int = 10513,
  VFNMSUB231SDr = 10514,
  VFNMSUB231SDr_Int = 10515,
  VFNMSUB231SHZm = 10516,
  VFNMSUB231SHZm_Int = 10517,
  VFNMSUB231SHZm_Intk = 10518,
  VFNMSUB231SHZm_Intkz = 10519,
  VFNMSUB231SHZr = 10520,
  VFNMSUB231SHZr_Int = 10521,
  VFNMSUB231SHZr_Intk = 10522,
  VFNMSUB231SHZr_Intkz = 10523,
  VFNMSUB231SHZrb = 10524,
  VFNMSUB231SHZrb_Int = 10525,
  VFNMSUB231SHZrb_Intk = 10526,
  VFNMSUB231SHZrb_Intkz = 10527,
  VFNMSUB231SSZm = 10528,
  VFNMSUB231SSZm_Int = 10529,
  VFNMSUB231SSZm_Intk = 10530,
  VFNMSUB231SSZm_Intkz = 10531,
  VFNMSUB231SSZr = 10532,
  VFNMSUB231SSZr_Int = 10533,
  VFNMSUB231SSZr_Intk = 10534,
  VFNMSUB231SSZr_Intkz = 10535,
  VFNMSUB231SSZrb = 10536,
  VFNMSUB231SSZrb_Int = 10537,
  VFNMSUB231SSZrb_Intk = 10538,
  VFNMSUB231SSZrb_Intkz = 10539,
  VFNMSUB231SSm = 10540,
  VFNMSUB231SSm_Int = 10541,
  VFNMSUB231SSr = 10542,
  VFNMSUB231SSr_Int = 10543,
  VFNMSUBPD4Ymr = 10544,
  VFNMSUBPD4Yrm = 10545,
  VFNMSUBPD4Yrr = 10546,
  VFNMSUBPD4Yrr_REV = 10547,
  VFNMSUBPD4mr = 10548,
  VFNMSUBPD4rm = 10549,
  VFNMSUBPD4rr = 10550,
  VFNMSUBPD4rr_REV = 10551,
  VFNMSUBPS4Ymr = 10552,
  VFNMSUBPS4Yrm = 10553,
  VFNMSUBPS4Yrr = 10554,
  VFNMSUBPS4Yrr_REV = 10555,
  VFNMSUBPS4mr = 10556,
  VFNMSUBPS4rm = 10557,
  VFNMSUBPS4rr = 10558,
  VFNMSUBPS4rr_REV = 10559,
  VFNMSUBSD4mr = 10560,
  VFNMSUBSD4mr_Int = 10561,
  VFNMSUBSD4rm = 10562,
  VFNMSUBSD4rm_Int = 10563,
  VFNMSUBSD4rr = 10564,
  VFNMSUBSD4rr_Int = 10565,
  VFNMSUBSD4rr_Int_REV = 10566,
  VFNMSUBSD4rr_REV = 10567,
  VFNMSUBSS4mr = 10568,
  VFNMSUBSS4mr_Int = 10569,
  VFNMSUBSS4rm = 10570,
  VFNMSUBSS4rm_Int = 10571,
  VFNMSUBSS4rr = 10572,
  VFNMSUBSS4rr_Int = 10573,
  VFNMSUBSS4rr_Int_REV = 10574,
  VFNMSUBSS4rr_REV = 10575,
  VFPCLASSPDZ128rm = 10576,
  VFPCLASSPDZ128rmb = 10577,
  VFPCLASSPDZ128rmbk = 10578,
  VFPCLASSPDZ128rmk = 10579,
  VFPCLASSPDZ128rr = 10580,
  VFPCLASSPDZ128rrk = 10581,
  VFPCLASSPDZ256rm = 10582,
  VFPCLASSPDZ256rmb = 10583,
  VFPCLASSPDZ256rmbk = 10584,
  VFPCLASSPDZ256rmk = 10585,
  VFPCLASSPDZ256rr = 10586,
  VFPCLASSPDZ256rrk = 10587,
  VFPCLASSPDZrm = 10588,
  VFPCLASSPDZrmb = 10589,
  VFPCLASSPDZrmbk = 10590,
  VFPCLASSPDZrmk = 10591,
  VFPCLASSPDZrr = 10592,
  VFPCLASSPDZrrk = 10593,
  VFPCLASSPHZ128rm = 10594,
  VFPCLASSPHZ128rmb = 10595,
  VFPCLASSPHZ128rmbk = 10596,
  VFPCLASSPHZ128rmk = 10597,
  VFPCLASSPHZ128rr = 10598,
  VFPCLASSPHZ128rrk = 10599,
  VFPCLASSPHZ256rm = 10600,
  VFPCLASSPHZ256rmb = 10601,
  VFPCLASSPHZ256rmbk = 10602,
  VFPCLASSPHZ256rmk = 10603,
  VFPCLASSPHZ256rr = 10604,
  VFPCLASSPHZ256rrk = 10605,
  VFPCLASSPHZrm = 10606,
  VFPCLASSPHZrmb = 10607,
  VFPCLASSPHZrmbk = 10608,
  VFPCLASSPHZrmk = 10609,
  VFPCLASSPHZrr = 10610,
  VFPCLASSPHZrrk = 10611,
  VFPCLASSPSZ128rm = 10612,
  VFPCLASSPSZ128rmb = 10613,
  VFPCLASSPSZ128rmbk = 10614,
  VFPCLASSPSZ128rmk = 10615,
  VFPCLASSPSZ128rr = 10616,
  VFPCLASSPSZ128rrk = 10617,
  VFPCLASSPSZ256rm = 10618,
  VFPCLASSPSZ256rmb = 10619,
  VFPCLASSPSZ256rmbk = 10620,
  VFPCLASSPSZ256rmk = 10621,
  VFPCLASSPSZ256rr = 10622,
  VFPCLASSPSZ256rrk = 10623,
  VFPCLASSPSZrm = 10624,
  VFPCLASSPSZrmb = 10625,
  VFPCLASSPSZrmbk = 10626,
  VFPCLASSPSZrmk = 10627,
  VFPCLASSPSZrr = 10628,
  VFPCLASSPSZrrk = 10629,
  VFPCLASSSDZrm = 10630,
  VFPCLASSSDZrmk = 10631,
  VFPCLASSSDZrr = 10632,
  VFPCLASSSDZrrk = 10633,
  VFPCLASSSHZrm = 10634,
  VFPCLASSSHZrmk = 10635,
  VFPCLASSSHZrr = 10636,
  VFPCLASSSHZrrk = 10637,
  VFPCLASSSSZrm = 10638,
  VFPCLASSSSZrmk = 10639,
  VFPCLASSSSZrr = 10640,
  VFPCLASSSSZrrk = 10641,
  VFRCZPDYrm = 10642,
  VFRCZPDYrr = 10643,
  VFRCZPDrm = 10644,
  VFRCZPDrr = 10645,
  VFRCZPSYrm = 10646,
  VFRCZPSYrr = 10647,
  VFRCZPSrm = 10648,
  VFRCZPSrr = 10649,
  VFRCZSDrm = 10650,
  VFRCZSDrr = 10651,
  VFRCZSSrm = 10652,
  VFRCZSSrr = 10653,
  VGATHERDPDYrm = 10654,
  VGATHERDPDZ128rm = 10655,
  VGATHERDPDZ256rm = 10656,
  VGATHERDPDZrm = 10657,
  VGATHERDPDrm = 10658,
  VGATHERDPSYrm = 10659,
  VGATHERDPSZ128rm = 10660,
  VGATHERDPSZ256rm = 10661,
  VGATHERDPSZrm = 10662,
  VGATHERDPSrm = 10663,
  VGATHERPF0DPDm = 10664,
  VGATHERPF0DPSm = 10665,
  VGATHERPF0QPDm = 10666,
  VGATHERPF0QPSm = 10667,
  VGATHERPF1DPDm = 10668,
  VGATHERPF1DPSm = 10669,
  VGATHERPF1QPDm = 10670,
  VGATHERPF1QPSm = 10671,
  VGATHERQPDYrm = 10672,
  VGATHERQPDZ128rm = 10673,
  VGATHERQPDZ256rm = 10674,
  VGATHERQPDZrm = 10675,
  VGATHERQPDrm = 10676,
  VGATHERQPSYrm = 10677,
  VGATHERQPSZ128rm = 10678,
  VGATHERQPSZ256rm = 10679,
  VGATHERQPSZrm = 10680,
  VGATHERQPSrm = 10681,
  VGETEXPPDZ128m = 10682,
  VGETEXPPDZ128mb = 10683,
  VGETEXPPDZ128mbk = 10684,
  VGETEXPPDZ128mbkz = 10685,
  VGETEXPPDZ128mk = 10686,
  VGETEXPPDZ128mkz = 10687,
  VGETEXPPDZ128r = 10688,
  VGETEXPPDZ128rk = 10689,
  VGETEXPPDZ128rkz = 10690,
  VGETEXPPDZ256m = 10691,
  VGETEXPPDZ256mb = 10692,
  VGETEXPPDZ256mbk = 10693,
  VGETEXPPDZ256mbkz = 10694,
  VGETEXPPDZ256mk = 10695,
  VGETEXPPDZ256mkz = 10696,
  VGETEXPPDZ256r = 10697,
  VGETEXPPDZ256rk = 10698,
  VGETEXPPDZ256rkz = 10699,
  VGETEXPPDZm = 10700,
  VGETEXPPDZmb = 10701,
  VGETEXPPDZmbk = 10702,
  VGETEXPPDZmbkz = 10703,
  VGETEXPPDZmk = 10704,
  VGETEXPPDZmkz = 10705,
  VGETEXPPDZr = 10706,
  VGETEXPPDZrb = 10707,
  VGETEXPPDZrbk = 10708,
  VGETEXPPDZrbkz = 10709,
  VGETEXPPDZrk = 10710,
  VGETEXPPDZrkz = 10711,
  VGETEXPPHZ128m = 10712,
  VGETEXPPHZ128mb = 10713,
  VGETEXPPHZ128mbk = 10714,
  VGETEXPPHZ128mbkz = 10715,
  VGETEXPPHZ128mk = 10716,
  VGETEXPPHZ128mkz = 10717,
  VGETEXPPHZ128r = 10718,
  VGETEXPPHZ128rk = 10719,
  VGETEXPPHZ128rkz = 10720,
  VGETEXPPHZ256m = 10721,
  VGETEXPPHZ256mb = 10722,
  VGETEXPPHZ256mbk = 10723,
  VGETEXPPHZ256mbkz = 10724,
  VGETEXPPHZ256mk = 10725,
  VGETEXPPHZ256mkz = 10726,
  VGETEXPPHZ256r = 10727,
  VGETEXPPHZ256rk = 10728,
  VGETEXPPHZ256rkz = 10729,
  VGETEXPPHZm = 10730,
  VGETEXPPHZmb = 10731,
  VGETEXPPHZmbk = 10732,
  VGETEXPPHZmbkz = 10733,
  VGETEXPPHZmk = 10734,
  VGETEXPPHZmkz = 10735,
  VGETEXPPHZr = 10736,
  VGETEXPPHZrb = 10737,
  VGETEXPPHZrbk = 10738,
  VGETEXPPHZrbkz = 10739,
  VGETEXPPHZrk = 10740,
  VGETEXPPHZrkz = 10741,
  VGETEXPPSZ128m = 10742,
  VGETEXPPSZ128mb = 10743,
  VGETEXPPSZ128mbk = 10744,
  VGETEXPPSZ128mbkz = 10745,
  VGETEXPPSZ128mk = 10746,
  VGETEXPPSZ128mkz = 10747,
  VGETEXPPSZ128r = 10748,
  VGETEXPPSZ128rk = 10749,
  VGETEXPPSZ128rkz = 10750,
  VGETEXPPSZ256m = 10751,
  VGETEXPPSZ256mb = 10752,
  VGETEXPPSZ256mbk = 10753,
  VGETEXPPSZ256mbkz = 10754,
  VGETEXPPSZ256mk = 10755,
  VGETEXPPSZ256mkz = 10756,
  VGETEXPPSZ256r = 10757,
  VGETEXPPSZ256rk = 10758,
  VGETEXPPSZ256rkz = 10759,
  VGETEXPPSZm = 10760,
  VGETEXPPSZmb = 10761,
  VGETEXPPSZmbk = 10762,
  VGETEXPPSZmbkz = 10763,
  VGETEXPPSZmk = 10764,
  VGETEXPPSZmkz = 10765,
  VGETEXPPSZr = 10766,
  VGETEXPPSZrb = 10767,
  VGETEXPPSZrbk = 10768,
  VGETEXPPSZrbkz = 10769,
  VGETEXPPSZrk = 10770,
  VGETEXPPSZrkz = 10771,
  VGETEXPSDZm = 10772,
  VGETEXPSDZmk = 10773,
  VGETEXPSDZmkz = 10774,
  VGETEXPSDZr = 10775,
  VGETEXPSDZrb = 10776,
  VGETEXPSDZrbk = 10777,
  VGETEXPSDZrbkz = 10778,
  VGETEXPSDZrk = 10779,
  VGETEXPSDZrkz = 10780,
  VGETEXPSHZm = 10781,
  VGETEXPSHZmk = 10782,
  VGETEXPSHZmkz = 10783,
  VGETEXPSHZr = 10784,
  VGETEXPSHZrb = 10785,
  VGETEXPSHZrbk = 10786,
  VGETEXPSHZrbkz = 10787,
  VGETEXPSHZrk = 10788,
  VGETEXPSHZrkz = 10789,
  VGETEXPSSZm = 10790,
  VGETEXPSSZmk = 10791,
  VGETEXPSSZmkz = 10792,
  VGETEXPSSZr = 10793,
  VGETEXPSSZrb = 10794,
  VGETEXPSSZrbk = 10795,
  VGETEXPSSZrbkz = 10796,
  VGETEXPSSZrk = 10797,
  VGETEXPSSZrkz = 10798,
  VGETMANTPDZ128rmbi = 10799,
  VGETMANTPDZ128rmbik = 10800,
  VGETMANTPDZ128rmbikz = 10801,
  VGETMANTPDZ128rmi = 10802,
  VGETMANTPDZ128rmik = 10803,
  VGETMANTPDZ128rmikz = 10804,
  VGETMANTPDZ128rri = 10805,
  VGETMANTPDZ128rrik = 10806,
  VGETMANTPDZ128rrikz = 10807,
  VGETMANTPDZ256rmbi = 10808,
  VGETMANTPDZ256rmbik = 10809,
  VGETMANTPDZ256rmbikz = 10810,
  VGETMANTPDZ256rmi = 10811,
  VGETMANTPDZ256rmik = 10812,
  VGETMANTPDZ256rmikz = 10813,
  VGETMANTPDZ256rri = 10814,
  VGETMANTPDZ256rrik = 10815,
  VGETMANTPDZ256rrikz = 10816,
  VGETMANTPDZrmbi = 10817,
  VGETMANTPDZrmbik = 10818,
  VGETMANTPDZrmbikz = 10819,
  VGETMANTPDZrmi = 10820,
  VGETMANTPDZrmik = 10821,
  VGETMANTPDZrmikz = 10822,
  VGETMANTPDZrri = 10823,
  VGETMANTPDZrrib = 10824,
  VGETMANTPDZrribk = 10825,
  VGETMANTPDZrribkz = 10826,
  VGETMANTPDZrrik = 10827,
  VGETMANTPDZrrikz = 10828,
  VGETMANTPHZ128rmbi = 10829,
  VGETMANTPHZ128rmbik = 10830,
  VGETMANTPHZ128rmbikz = 10831,
  VGETMANTPHZ128rmi = 10832,
  VGETMANTPHZ128rmik = 10833,
  VGETMANTPHZ128rmikz = 10834,
  VGETMANTPHZ128rri = 10835,
  VGETMANTPHZ128rrik = 10836,
  VGETMANTPHZ128rrikz = 10837,
  VGETMANTPHZ256rmbi = 10838,
  VGETMANTPHZ256rmbik = 10839,
  VGETMANTPHZ256rmbikz = 10840,
  VGETMANTPHZ256rmi = 10841,
  VGETMANTPHZ256rmik = 10842,
  VGETMANTPHZ256rmikz = 10843,
  VGETMANTPHZ256rri = 10844,
  VGETMANTPHZ256rrik = 10845,
  VGETMANTPHZ256rrikz = 10846,
  VGETMANTPHZrmbi = 10847,
  VGETMANTPHZrmbik = 10848,
  VGETMANTPHZrmbikz = 10849,
  VGETMANTPHZrmi = 10850,
  VGETMANTPHZrmik = 10851,
  VGETMANTPHZrmikz = 10852,
  VGETMANTPHZrri = 10853,
  VGETMANTPHZrrib = 10854,
  VGETMANTPHZrribk = 10855,
  VGETMANTPHZrribkz = 10856,
  VGETMANTPHZrrik = 10857,
  VGETMANTPHZrrikz = 10858,
  VGETMANTPSZ128rmbi = 10859,
  VGETMANTPSZ128rmbik = 10860,
  VGETMANTPSZ128rmbikz = 10861,
  VGETMANTPSZ128rmi = 10862,
  VGETMANTPSZ128rmik = 10863,
  VGETMANTPSZ128rmikz = 10864,
  VGETMANTPSZ128rri = 10865,
  VGETMANTPSZ128rrik = 10866,
  VGETMANTPSZ128rrikz = 10867,
  VGETMANTPSZ256rmbi = 10868,
  VGETMANTPSZ256rmbik = 10869,
  VGETMANTPSZ256rmbikz = 10870,
  VGETMANTPSZ256rmi = 10871,
  VGETMANTPSZ256rmik = 10872,
  VGETMANTPSZ256rmikz = 10873,
  VGETMANTPSZ256rri = 10874,
  VGETMANTPSZ256rrik = 10875,
  VGETMANTPSZ256rrikz = 10876,
  VGETMANTPSZrmbi = 10877,
  VGETMANTPSZrmbik = 10878,
  VGETMANTPSZrmbikz = 10879,
  VGETMANTPSZrmi = 10880,
  VGETMANTPSZrmik = 10881,
  VGETMANTPSZrmikz = 10882,
  VGETMANTPSZrri = 10883,
  VGETMANTPSZrrib = 10884,
  VGETMANTPSZrribk = 10885,
  VGETMANTPSZrribkz = 10886,
  VGETMANTPSZrrik = 10887,
  VGETMANTPSZrrikz = 10888,
  VGETMANTSDZrmi = 10889,
  VGETMANTSDZrmik = 10890,
  VGETMANTSDZrmikz = 10891,
  VGETMANTSDZrri = 10892,
  VGETMANTSDZrrib = 10893,
  VGETMANTSDZrribk = 10894,
  VGETMANTSDZrribkz = 10895,
  VGETMANTSDZrrik = 10896,
  VGETMANTSDZrrikz = 10897,
  VGETMANTSHZrmi = 10898,
  VGETMANTSHZrmik = 10899,
  VGETMANTSHZrmikz = 10900,
  VGETMANTSHZrri = 10901,
  VGETMANTSHZrrib = 10902,
  VGETMANTSHZrribk = 10903,
  VGETMANTSHZrribkz = 10904,
  VGETMANTSHZrrik = 10905,
  VGETMANTSHZrrikz = 10906,
  VGETMANTSSZrmi = 10907,
  VGETMANTSSZrmik = 10908,
  VGETMANTSSZrmikz = 10909,
  VGETMANTSSZrri = 10910,
  VGETMANTSSZrrib = 10911,
  VGETMANTSSZrribk = 10912,
  VGETMANTSSZrribkz = 10913,
  VGETMANTSSZrrik = 10914,
  VGETMANTSSZrrikz = 10915,
  VGF2P8AFFINEINVQBYrmi = 10916,
  VGF2P8AFFINEINVQBYrri = 10917,
  VGF2P8AFFINEINVQBZ128rmbi = 10918,
  VGF2P8AFFINEINVQBZ128rmbik = 10919,
  VGF2P8AFFINEINVQBZ128rmbikz = 10920,
  VGF2P8AFFINEINVQBZ128rmi = 10921,
  VGF2P8AFFINEINVQBZ128rmik = 10922,
  VGF2P8AFFINEINVQBZ128rmikz = 10923,
  VGF2P8AFFINEINVQBZ128rri = 10924,
  VGF2P8AFFINEINVQBZ128rrik = 10925,
  VGF2P8AFFINEINVQBZ128rrikz = 10926,
  VGF2P8AFFINEINVQBZ256rmbi = 10927,
  VGF2P8AFFINEINVQBZ256rmbik = 10928,
  VGF2P8AFFINEINVQBZ256rmbikz = 10929,
  VGF2P8AFFINEINVQBZ256rmi = 10930,
  VGF2P8AFFINEINVQBZ256rmik = 10931,
  VGF2P8AFFINEINVQBZ256rmikz = 10932,
  VGF2P8AFFINEINVQBZ256rri = 10933,
  VGF2P8AFFINEINVQBZ256rrik = 10934,
  VGF2P8AFFINEINVQBZ256rrikz = 10935,
  VGF2P8AFFINEINVQBZrmbi = 10936,
  VGF2P8AFFINEINVQBZrmbik = 10937,
  VGF2P8AFFINEINVQBZrmbikz = 10938,
  VGF2P8AFFINEINVQBZrmi = 10939,
  VGF2P8AFFINEINVQBZrmik = 10940,
  VGF2P8AFFINEINVQBZrmikz = 10941,
  VGF2P8AFFINEINVQBZrri = 10942,
  VGF2P8AFFINEINVQBZrrik = 10943,
  VGF2P8AFFINEINVQBZrrikz = 10944,
  VGF2P8AFFINEINVQBrmi = 10945,
  VGF2P8AFFINEINVQBrri = 10946,
  VGF2P8AFFINEQBYrmi = 10947,
  VGF2P8AFFINEQBYrri = 10948,
  VGF2P8AFFINEQBZ128rmbi = 10949,
  VGF2P8AFFINEQBZ128rmbik = 10950,
  VGF2P8AFFINEQBZ128rmbikz = 10951,
  VGF2P8AFFINEQBZ128rmi = 10952,
  VGF2P8AFFINEQBZ128rmik = 10953,
  VGF2P8AFFINEQBZ128rmikz = 10954,
  VGF2P8AFFINEQBZ128rri = 10955,
  VGF2P8AFFINEQBZ128rrik = 10956,
  VGF2P8AFFINEQBZ128rrikz = 10957,
  VGF2P8AFFINEQBZ256rmbi = 10958,
  VGF2P8AFFINEQBZ256rmbik = 10959,
  VGF2P8AFFINEQBZ256rmbikz = 10960,
  VGF2P8AFFINEQBZ256rmi = 10961,
  VGF2P8AFFINEQBZ256rmik = 10962,
  VGF2P8AFFINEQBZ256rmikz = 10963,
  VGF2P8AFFINEQBZ256rri = 10964,
  VGF2P8AFFINEQBZ256rrik = 10965,
  VGF2P8AFFINEQBZ256rrikz = 10966,
  VGF2P8AFFINEQBZrmbi = 10967,
  VGF2P8AFFINEQBZrmbik = 10968,
  VGF2P8AFFINEQBZrmbikz = 10969,
  VGF2P8AFFINEQBZrmi = 10970,
  VGF2P8AFFINEQBZrmik = 10971,
  VGF2P8AFFINEQBZrmikz = 10972,
  VGF2P8AFFINEQBZrri = 10973,
  VGF2P8AFFINEQBZrrik = 10974,
  VGF2P8AFFINEQBZrrikz = 10975,
  VGF2P8AFFINEQBrmi = 10976,
  VGF2P8AFFINEQBrri = 10977,
  VGF2P8MULBYrm = 10978,
  VGF2P8MULBYrr = 10979,
  VGF2P8MULBZ128rm = 10980,
  VGF2P8MULBZ128rmk = 10981,
  VGF2P8MULBZ128rmkz = 10982,
  VGF2P8MULBZ128rr = 10983,
  VGF2P8MULBZ128rrk = 10984,
  VGF2P8MULBZ128rrkz = 10985,
  VGF2P8MULBZ256rm = 10986,
  VGF2P8MULBZ256rmk = 10987,
  VGF2P8MULBZ256rmkz = 10988,
  VGF2P8MULBZ256rr = 10989,
  VGF2P8MULBZ256rrk = 10990,
  VGF2P8MULBZ256rrkz = 10991,
  VGF2P8MULBZrm = 10992,
  VGF2P8MULBZrmk = 10993,
  VGF2P8MULBZrmkz = 10994,
  VGF2P8MULBZrr = 10995,
  VGF2P8MULBZrrk = 10996,
  VGF2P8MULBZrrkz = 10997,
  VGF2P8MULBrm = 10998,
  VGF2P8MULBrr = 10999,
  VHADDPDYrm = 11000,
  VHADDPDYrr = 11001,
  VHADDPDrm = 11002,
  VHADDPDrr = 11003,
  VHADDPSYrm = 11004,
  VHADDPSYrr = 11005,
  VHADDPSrm = 11006,
  VHADDPSrr = 11007,
  VHSUBPDYrm = 11008,
  VHSUBPDYrr = 11009,
  VHSUBPDrm = 11010,
  VHSUBPDrr = 11011,
  VHSUBPSYrm = 11012,
  VHSUBPSYrr = 11013,
  VHSUBPSrm = 11014,
  VHSUBPSrr = 11015,
  VINSERTF128rm = 11016,
  VINSERTF128rr = 11017,
  VINSERTF32x4Z256rm = 11018,
  VINSERTF32x4Z256rmk = 11019,
  VINSERTF32x4Z256rmkz = 11020,
  VINSERTF32x4Z256rr = 11021,
  VINSERTF32x4Z256rrk = 11022,
  VINSERTF32x4Z256rrkz = 11023,
  VINSERTF32x4Zrm = 11024,
  VINSERTF32x4Zrmk = 11025,
  VINSERTF32x4Zrmkz = 11026,
  VINSERTF32x4Zrr = 11027,
  VINSERTF32x4Zrrk = 11028,
  VINSERTF32x4Zrrkz = 11029,
  VINSERTF32x8Zrm = 11030,
  VINSERTF32x8Zrmk = 11031,
  VINSERTF32x8Zrmkz = 11032,
  VINSERTF32x8Zrr = 11033,
  VINSERTF32x8Zrrk = 11034,
  VINSERTF32x8Zrrkz = 11035,
  VINSERTF64x2Z256rm = 11036,
  VINSERTF64x2Z256rmk = 11037,
  VINSERTF64x2Z256rmkz = 11038,
  VINSERTF64x2Z256rr = 11039,
  VINSERTF64x2Z256rrk = 11040,
  VINSERTF64x2Z256rrkz = 11041,
  VINSERTF64x2Zrm = 11042,
  VINSERTF64x2Zrmk = 11043,
  VINSERTF64x2Zrmkz = 11044,
  VINSERTF64x2Zrr = 11045,
  VINSERTF64x2Zrrk = 11046,
  VINSERTF64x2Zrrkz = 11047,
  VINSERTF64x4Zrm = 11048,
  VINSERTF64x4Zrmk = 11049,
  VINSERTF64x4Zrmkz = 11050,
  VINSERTF64x4Zrr = 11051,
  VINSERTF64x4Zrrk = 11052,
  VINSERTF64x4Zrrkz = 11053,
  VINSERTI128rm = 11054,
  VINSERTI128rr = 11055,
  VINSERTI32x4Z256rm = 11056,
  VINSERTI32x4Z256rmk = 11057,
  VINSERTI32x4Z256rmkz = 11058,
  VINSERTI32x4Z256rr = 11059,
  VINSERTI32x4Z256rrk = 11060,
  VINSERTI32x4Z256rrkz = 11061,
  VINSERTI32x4Zrm = 11062,
  VINSERTI32x4Zrmk = 11063,
  VINSERTI32x4Zrmkz = 11064,
  VINSERTI32x4Zrr = 11065,
  VINSERTI32x4Zrrk = 11066,
  VINSERTI32x4Zrrkz = 11067,
  VINSERTI32x8Zrm = 11068,
  VINSERTI32x8Zrmk = 11069,
  VINSERTI32x8Zrmkz = 11070,
  VINSERTI32x8Zrr = 11071,
  VINSERTI32x8Zrrk = 11072,
  VINSERTI32x8Zrrkz = 11073,
  VINSERTI64x2Z256rm = 11074,
  VINSERTI64x2Z256rmk = 11075,
  VINSERTI64x2Z256rmkz = 11076,
  VINSERTI64x2Z256rr = 11077,
  VINSERTI64x2Z256rrk = 11078,
  VINSERTI64x2Z256rrkz = 11079,
  VINSERTI64x2Zrm = 11080,
  VINSERTI64x2Zrmk = 11081,
  VINSERTI64x2Zrmkz = 11082,
  VINSERTI64x2Zrr = 11083,
  VINSERTI64x2Zrrk = 11084,
  VINSERTI64x2Zrrkz = 11085,
  VINSERTI64x4Zrm = 11086,
  VINSERTI64x4Zrmk = 11087,
  VINSERTI64x4Zrmkz = 11088,
  VINSERTI64x4Zrr = 11089,
  VINSERTI64x4Zrrk = 11090,
  VINSERTI64x4Zrrkz = 11091,
  VINSERTPSZrm = 11092,
  VINSERTPSZrr = 11093,
  VINSERTPSrm = 11094,
  VINSERTPSrr = 11095,
  VLDDQUYrm = 11096,
  VLDDQUrm = 11097,
  VLDMXCSR = 11098,
  VMASKMOVDQU = 11099,
  VMASKMOVDQU64 = 11100,
  VMASKMOVPDYmr = 11101,
  VMASKMOVPDYrm = 11102,
  VMASKMOVPDmr = 11103,
  VMASKMOVPDrm = 11104,
  VMASKMOVPSYmr = 11105,
  VMASKMOVPSYrm = 11106,
  VMASKMOVPSmr = 11107,
  VMASKMOVPSrm = 11108,
  VMAXCPDYrm = 11109,
  VMAXCPDYrr = 11110,
  VMAXCPDZ128rm = 11111,
  VMAXCPDZ128rmb = 11112,
  VMAXCPDZ128rmbk = 11113,
  VMAXCPDZ128rmbkz = 11114,
  VMAXCPDZ128rmk = 11115,
  VMAXCPDZ128rmkz = 11116,
  VMAXCPDZ128rr = 11117,
  VMAXCPDZ128rrk = 11118,
  VMAXCPDZ128rrkz = 11119,
  VMAXCPDZ256rm = 11120,
  VMAXCPDZ256rmb = 11121,
  VMAXCPDZ256rmbk = 11122,
  VMAXCPDZ256rmbkz = 11123,
  VMAXCPDZ256rmk = 11124,
  VMAXCPDZ256rmkz = 11125,
  VMAXCPDZ256rr = 11126,
  VMAXCPDZ256rrk = 11127,
  VMAXCPDZ256rrkz = 11128,
  VMAXCPDZrm = 11129,
  VMAXCPDZrmb = 11130,
  VMAXCPDZrmbk = 11131,
  VMAXCPDZrmbkz = 11132,
  VMAXCPDZrmk = 11133,
  VMAXCPDZrmkz = 11134,
  VMAXCPDZrr = 11135,
  VMAXCPDZrrk = 11136,
  VMAXCPDZrrkz = 11137,
  VMAXCPDrm = 11138,
  VMAXCPDrr = 11139,
  VMAXCPHZ128rm = 11140,
  VMAXCPHZ128rmb = 11141,
  VMAXCPHZ128rmbk = 11142,
  VMAXCPHZ128rmbkz = 11143,
  VMAXCPHZ128rmk = 11144,
  VMAXCPHZ128rmkz = 11145,
  VMAXCPHZ128rr = 11146,
  VMAXCPHZ128rrk = 11147,
  VMAXCPHZ128rrkz = 11148,
  VMAXCPHZ256rm = 11149,
  VMAXCPHZ256rmb = 11150,
  VMAXCPHZ256rmbk = 11151,
  VMAXCPHZ256rmbkz = 11152,
  VMAXCPHZ256rmk = 11153,
  VMAXCPHZ256rmkz = 11154,
  VMAXCPHZ256rr = 11155,
  VMAXCPHZ256rrk = 11156,
  VMAXCPHZ256rrkz = 11157,
  VMAXCPHZrm = 11158,
  VMAXCPHZrmb = 11159,
  VMAXCPHZrmbk = 11160,
  VMAXCPHZrmbkz = 11161,
  VMAXCPHZrmk = 11162,
  VMAXCPHZrmkz = 11163,
  VMAXCPHZrr = 11164,
  VMAXCPHZrrk = 11165,
  VMAXCPHZrrkz = 11166,
  VMAXCPSYrm = 11167,
  VMAXCPSYrr = 11168,
  VMAXCPSZ128rm = 11169,
  VMAXCPSZ128rmb = 11170,
  VMAXCPSZ128rmbk = 11171,
  VMAXCPSZ128rmbkz = 11172,
  VMAXCPSZ128rmk = 11173,
  VMAXCPSZ128rmkz = 11174,
  VMAXCPSZ128rr = 11175,
  VMAXCPSZ128rrk = 11176,
  VMAXCPSZ128rrkz = 11177,
  VMAXCPSZ256rm = 11178,
  VMAXCPSZ256rmb = 11179,
  VMAXCPSZ256rmbk = 11180,
  VMAXCPSZ256rmbkz = 11181,
  VMAXCPSZ256rmk = 11182,
  VMAXCPSZ256rmkz = 11183,
  VMAXCPSZ256rr = 11184,
  VMAXCPSZ256rrk = 11185,
  VMAXCPSZ256rrkz = 11186,
  VMAXCPSZrm = 11187,
  VMAXCPSZrmb = 11188,
  VMAXCPSZrmbk = 11189,
  VMAXCPSZrmbkz = 11190,
  VMAXCPSZrmk = 11191,
  VMAXCPSZrmkz = 11192,
  VMAXCPSZrr = 11193,
  VMAXCPSZrrk = 11194,
  VMAXCPSZrrkz = 11195,
  VMAXCPSrm = 11196,
  VMAXCPSrr = 11197,
  VMAXCSDZrm = 11198,
  VMAXCSDZrr = 11199,
  VMAXCSDrm = 11200,
  VMAXCSDrr = 11201,
  VMAXCSHZrm = 11202,
  VMAXCSHZrr = 11203,
  VMAXCSSZrm = 11204,
  VMAXCSSZrr = 11205,
  VMAXCSSrm = 11206,
  VMAXCSSrr = 11207,
  VMAXPDYrm = 11208,
  VMAXPDYrr = 11209,
  VMAXPDZ128rm = 11210,
  VMAXPDZ128rmb = 11211,
  VMAXPDZ128rmbk = 11212,
  VMAXPDZ128rmbkz = 11213,
  VMAXPDZ128rmk = 11214,
  VMAXPDZ128rmkz = 11215,
  VMAXPDZ128rr = 11216,
  VMAXPDZ128rrk = 11217,
  VMAXPDZ128rrkz = 11218,
  VMAXPDZ256rm = 11219,
  VMAXPDZ256rmb = 11220,
  VMAXPDZ256rmbk = 11221,
  VMAXPDZ256rmbkz = 11222,
  VMAXPDZ256rmk = 11223,
  VMAXPDZ256rmkz = 11224,
  VMAXPDZ256rr = 11225,
  VMAXPDZ256rrk = 11226,
  VMAXPDZ256rrkz = 11227,
  VMAXPDZrm = 11228,
  VMAXPDZrmb = 11229,
  VMAXPDZrmbk = 11230,
  VMAXPDZrmbkz = 11231,
  VMAXPDZrmk = 11232,
  VMAXPDZrmkz = 11233,
  VMAXPDZrr = 11234,
  VMAXPDZrrb = 11235,
  VMAXPDZrrbk = 11236,
  VMAXPDZrrbkz = 11237,
  VMAXPDZrrk = 11238,
  VMAXPDZrrkz = 11239,
  VMAXPDrm = 11240,
  VMAXPDrr = 11241,
  VMAXPHZ128rm = 11242,
  VMAXPHZ128rmb = 11243,
  VMAXPHZ128rmbk = 11244,
  VMAXPHZ128rmbkz = 11245,
  VMAXPHZ128rmk = 11246,
  VMAXPHZ128rmkz = 11247,
  VMAXPHZ128rr = 11248,
  VMAXPHZ128rrk = 11249,
  VMAXPHZ128rrkz = 11250,
  VMAXPHZ256rm = 11251,
  VMAXPHZ256rmb = 11252,
  VMAXPHZ256rmbk = 11253,
  VMAXPHZ256rmbkz = 11254,
  VMAXPHZ256rmk = 11255,
  VMAXPHZ256rmkz = 11256,
  VMAXPHZ256rr = 11257,
  VMAXPHZ256rrk = 11258,
  VMAXPHZ256rrkz = 11259,
  VMAXPHZrm = 11260,
  VMAXPHZrmb = 11261,
  VMAXPHZrmbk = 11262,
  VMAXPHZrmbkz = 11263,
  VMAXPHZrmk = 11264,
  VMAXPHZrmkz = 11265,
  VMAXPHZrr = 11266,
  VMAXPHZrrb = 11267,
  VMAXPHZrrbk = 11268,
  VMAXPHZrrbkz = 11269,
  VMAXPHZrrk = 11270,
  VMAXPHZrrkz = 11271,
  VMAXPSYrm = 11272,
  VMAXPSYrr = 11273,
  VMAXPSZ128rm = 11274,
  VMAXPSZ128rmb = 11275,
  VMAXPSZ128rmbk = 11276,
  VMAXPSZ128rmbkz = 11277,
  VMAXPSZ128rmk = 11278,
  VMAXPSZ128rmkz = 11279,
  VMAXPSZ128rr = 11280,
  VMAXPSZ128rrk = 11281,
  VMAXPSZ128rrkz = 11282,
  VMAXPSZ256rm = 11283,
  VMAXPSZ256rmb = 11284,
  VMAXPSZ256rmbk = 11285,
  VMAXPSZ256rmbkz = 11286,
  VMAXPSZ256rmk = 11287,
  VMAXPSZ256rmkz = 11288,
  VMAXPSZ256rr = 11289,
  VMAXPSZ256rrk = 11290,
  VMAXPSZ256rrkz = 11291,
  VMAXPSZrm = 11292,
  VMAXPSZrmb = 11293,
  VMAXPSZrmbk = 11294,
  VMAXPSZrmbkz = 11295,
  VMAXPSZrmk = 11296,
  VMAXPSZrmkz = 11297,
  VMAXPSZrr = 11298,
  VMAXPSZrrb = 11299,
  VMAXPSZrrbk = 11300,
  VMAXPSZrrbkz = 11301,
  VMAXPSZrrk = 11302,
  VMAXPSZrrkz = 11303,
  VMAXPSrm = 11304,
  VMAXPSrr = 11305,
  VMAXSDZrm = 11306,
  VMAXSDZrm_Int = 11307,
  VMAXSDZrm_Intk = 11308,
  VMAXSDZrm_Intkz = 11309,
  VMAXSDZrr = 11310,
  VMAXSDZrr_Int = 11311,
  VMAXSDZrr_Intk = 11312,
  VMAXSDZrr_Intkz = 11313,
  VMAXSDZrrb_Int = 11314,
  VMAXSDZrrb_Intk = 11315,
  VMAXSDZrrb_Intkz = 11316,
  VMAXSDrm = 11317,
  VMAXSDrm_Int = 11318,
  VMAXSDrr = 11319,
  VMAXSDrr_Int = 11320,
  VMAXSHZrm = 11321,
  VMAXSHZrm_Int = 11322,
  VMAXSHZrm_Intk = 11323,
  VMAXSHZrm_Intkz = 11324,
  VMAXSHZrr = 11325,
  VMAXSHZrr_Int = 11326,
  VMAXSHZrr_Intk = 11327,
  VMAXSHZrr_Intkz = 11328,
  VMAXSHZrrb_Int = 11329,
  VMAXSHZrrb_Intk = 11330,
  VMAXSHZrrb_Intkz = 11331,
  VMAXSSZrm = 11332,
  VMAXSSZrm_Int = 11333,
  VMAXSSZrm_Intk = 11334,
  VMAXSSZrm_Intkz = 11335,
  VMAXSSZrr = 11336,
  VMAXSSZrr_Int = 11337,
  VMAXSSZrr_Intk = 11338,
  VMAXSSZrr_Intkz = 11339,
  VMAXSSZrrb_Int = 11340,
  VMAXSSZrrb_Intk = 11341,
  VMAXSSZrrb_Intkz = 11342,
  VMAXSSrm = 11343,
  VMAXSSrm_Int = 11344,
  VMAXSSrr = 11345,
  VMAXSSrr_Int = 11346,
  VMCALL = 11347,
  VMCLEARm = 11348,
  VMFUNC = 11349,
  VMINCPDYrm = 11350,
  VMINCPDYrr = 11351,
  VMINCPDZ128rm = 11352,
  VMINCPDZ128rmb = 11353,
  VMINCPDZ128rmbk = 11354,
  VMINCPDZ128rmbkz = 11355,
  VMINCPDZ128rmk = 11356,
  VMINCPDZ128rmkz = 11357,
  VMINCPDZ128rr = 11358,
  VMINCPDZ128rrk = 11359,
  VMINCPDZ128rrkz = 11360,
  VMINCPDZ256rm = 11361,
  VMINCPDZ256rmb = 11362,
  VMINCPDZ256rmbk = 11363,
  VMINCPDZ256rmbkz = 11364,
  VMINCPDZ256rmk = 11365,
  VMINCPDZ256rmkz = 11366,
  VMINCPDZ256rr = 11367,
  VMINCPDZ256rrk = 11368,
  VMINCPDZ256rrkz = 11369,
  VMINCPDZrm = 11370,
  VMINCPDZrmb = 11371,
  VMINCPDZrmbk = 11372,
  VMINCPDZrmbkz = 11373,
  VMINCPDZrmk = 11374,
  VMINCPDZrmkz = 11375,
  VMINCPDZrr = 11376,
  VMINCPDZrrk = 11377,
  VMINCPDZrrkz = 11378,
  VMINCPDrm = 11379,
  VMINCPDrr = 11380,
  VMINCPHZ128rm = 11381,
  VMINCPHZ128rmb = 11382,
  VMINCPHZ128rmbk = 11383,
  VMINCPHZ128rmbkz = 11384,
  VMINCPHZ128rmk = 11385,
  VMINCPHZ128rmkz = 11386,
  VMINCPHZ128rr = 11387,
  VMINCPHZ128rrk = 11388,
  VMINCPHZ128rrkz = 11389,
  VMINCPHZ256rm = 11390,
  VMINCPHZ256rmb = 11391,
  VMINCPHZ256rmbk = 11392,
  VMINCPHZ256rmbkz = 11393,
  VMINCPHZ256rmk = 11394,
  VMINCPHZ256rmkz = 11395,
  VMINCPHZ256rr = 11396,
  VMINCPHZ256rrk = 11397,
  VMINCPHZ256rrkz = 11398,
  VMINCPHZrm = 11399,
  VMINCPHZrmb = 11400,
  VMINCPHZrmbk = 11401,
  VMINCPHZrmbkz = 11402,
  VMINCPHZrmk = 11403,
  VMINCPHZrmkz = 11404,
  VMINCPHZrr = 11405,
  VMINCPHZrrk = 11406,
  VMINCPHZrrkz = 11407,
  VMINCPSYrm = 11408,
  VMINCPSYrr = 11409,
  VMINCPSZ128rm = 11410,
  VMINCPSZ128rmb = 11411,
  VMINCPSZ128rmbk = 11412,
  VMINCPSZ128rmbkz = 11413,
  VMINCPSZ128rmk = 11414,
  VMINCPSZ128rmkz = 11415,
  VMINCPSZ128rr = 11416,
  VMINCPSZ128rrk = 11417,
  VMINCPSZ128rrkz = 11418,
  VMINCPSZ256rm = 11419,
  VMINCPSZ256rmb = 11420,
  VMINCPSZ256rmbk = 11421,
  VMINCPSZ256rmbkz = 11422,
  VMINCPSZ256rmk = 11423,
  VMINCPSZ256rmkz = 11424,
  VMINCPSZ256rr = 11425,
  VMINCPSZ256rrk = 11426,
  VMINCPSZ256rrkz = 11427,
  VMINCPSZrm = 11428,
  VMINCPSZrmb = 11429,
  VMINCPSZrmbk = 11430,
  VMINCPSZrmbkz = 11431,
  VMINCPSZrmk = 11432,
  VMINCPSZrmkz = 11433,
  VMINCPSZrr = 11434,
  VMINCPSZrrk = 11435,
  VMINCPSZrrkz = 11436,
  VMINCPSrm = 11437,
  VMINCPSrr = 11438,
  VMINCSDZrm = 11439,
  VMINCSDZrr = 11440,
  VMINCSDrm = 11441,
  VMINCSDrr = 11442,
  VMINCSHZrm = 11443,
  VMINCSHZrr = 11444,
  VMINCSSZrm = 11445,
  VMINCSSZrr = 11446,
  VMINCSSrm = 11447,
  VMINCSSrr = 11448,
  VMINPDYrm = 11449,
  VMINPDYrr = 11450,
  VMINPDZ128rm = 11451,
  VMINPDZ128rmb = 11452,
  VMINPDZ128rmbk = 11453,
  VMINPDZ128rmbkz = 11454,
  VMINPDZ128rmk = 11455,
  VMINPDZ128rmkz = 11456,
  VMINPDZ128rr = 11457,
  VMINPDZ128rrk = 11458,
  VMINPDZ128rrkz = 11459,
  VMINPDZ256rm = 11460,
  VMINPDZ256rmb = 11461,
  VMINPDZ256rmbk = 11462,
  VMINPDZ256rmbkz = 11463,
  VMINPDZ256rmk = 11464,
  VMINPDZ256rmkz = 11465,
  VMINPDZ256rr = 11466,
  VMINPDZ256rrk = 11467,
  VMINPDZ256rrkz = 11468,
  VMINPDZrm = 11469,
  VMINPDZrmb = 11470,
  VMINPDZrmbk = 11471,
  VMINPDZrmbkz = 11472,
  VMINPDZrmk = 11473,
  VMINPDZrmkz = 11474,
  VMINPDZrr = 11475,
  VMINPDZrrb = 11476,
  VMINPDZrrbk = 11477,
  VMINPDZrrbkz = 11478,
  VMINPDZrrk = 11479,
  VMINPDZrrkz = 11480,
  VMINPDrm = 11481,
  VMINPDrr = 11482,
  VMINPHZ128rm = 11483,
  VMINPHZ128rmb = 11484,
  VMINPHZ128rmbk = 11485,
  VMINPHZ128rmbkz = 11486,
  VMINPHZ128rmk = 11487,
  VMINPHZ128rmkz = 11488,
  VMINPHZ128rr = 11489,
  VMINPHZ128rrk = 11490,
  VMINPHZ128rrkz = 11491,
  VMINPHZ256rm = 11492,
  VMINPHZ256rmb = 11493,
  VMINPHZ256rmbk = 11494,
  VMINPHZ256rmbkz = 11495,
  VMINPHZ256rmk = 11496,
  VMINPHZ256rmkz = 11497,
  VMINPHZ256rr = 11498,
  VMINPHZ256rrk = 11499,
  VMINPHZ256rrkz = 11500,
  VMINPHZrm = 11501,
  VMINPHZrmb = 11502,
  VMINPHZrmbk = 11503,
  VMINPHZrmbkz = 11504,
  VMINPHZrmk = 11505,
  VMINPHZrmkz = 11506,
  VMINPHZrr = 11507,
  VMINPHZrrb = 11508,
  VMINPHZrrbk = 11509,
  VMINPHZrrbkz = 11510,
  VMINPHZrrk = 11511,
  VMINPHZrrkz = 11512,
  VMINPSYrm = 11513,
  VMINPSYrr = 11514,
  VMINPSZ128rm = 11515,
  VMINPSZ128rmb = 11516,
  VMINPSZ128rmbk = 11517,
  VMINPSZ128rmbkz = 11518,
  VMINPSZ128rmk = 11519,
  VMINPSZ128rmkz = 11520,
  VMINPSZ128rr = 11521,
  VMINPSZ128rrk = 11522,
  VMINPSZ128rrkz = 11523,
  VMINPSZ256rm = 11524,
  VMINPSZ256rmb = 11525,
  VMINPSZ256rmbk = 11526,
  VMINPSZ256rmbkz = 11527,
  VMINPSZ256rmk = 11528,
  VMINPSZ256rmkz = 11529,
  VMINPSZ256rr = 11530,
  VMINPSZ256rrk = 11531,
  VMINPSZ256rrkz = 11532,
  VMINPSZrm = 11533,
  VMINPSZrmb = 11534,
  VMINPSZrmbk = 11535,
  VMINPSZrmbkz = 11536,
  VMINPSZrmk = 11537,
  VMINPSZrmkz = 11538,
  VMINPSZrr = 11539,
  VMINPSZrrb = 11540,
  VMINPSZrrbk = 11541,
  VMINPSZrrbkz = 11542,
  VMINPSZrrk = 11543,
  VMINPSZrrkz = 11544,
  VMINPSrm = 11545,
  VMINPSrr = 11546,
  VMINSDZrm = 11547,
  VMINSDZrm_Int = 11548,
  VMINSDZrm_Intk = 11549,
  VMINSDZrm_Intkz = 11550,
  VMINSDZrr = 11551,
  VMINSDZrr_Int = 11552,
  VMINSDZrr_Intk = 11553,
  VMINSDZrr_Intkz = 11554,
  VMINSDZrrb_Int = 11555,
  VMINSDZrrb_Intk = 11556,
  VMINSDZrrb_Intkz = 11557,
  VMINSDrm = 11558,
  VMINSDrm_Int = 11559,
  VMINSDrr = 11560,
  VMINSDrr_Int = 11561,
  VMINSHZrm = 11562,
  VMINSHZrm_Int = 11563,
  VMINSHZrm_Intk = 11564,
  VMINSHZrm_Intkz = 11565,
  VMINSHZrr = 11566,
  VMINSHZrr_Int = 11567,
  VMINSHZrr_Intk = 11568,
  VMINSHZrr_Intkz = 11569,
  VMINSHZrrb_Int = 11570,
  VMINSHZrrb_Intk = 11571,
  VMINSHZrrb_Intkz = 11572,
  VMINSSZrm = 11573,
  VMINSSZrm_Int = 11574,
  VMINSSZrm_Intk = 11575,
  VMINSSZrm_Intkz = 11576,
  VMINSSZrr = 11577,
  VMINSSZrr_Int = 11578,
  VMINSSZrr_Intk = 11579,
  VMINSSZrr_Intkz = 11580,
  VMINSSZrrb_Int = 11581,
  VMINSSZrrb_Intk = 11582,
  VMINSSZrrb_Intkz = 11583,
  VMINSSrm = 11584,
  VMINSSrm_Int = 11585,
  VMINSSrr = 11586,
  VMINSSrr_Int = 11587,
  VMLAUNCH = 11588,
  VMLOAD32 = 11589,
  VMLOAD64 = 11590,
  VMMCALL = 11591,
  VMOV64toPQIZrm = 11592,
  VMOV64toPQIZrr = 11593,
  VMOV64toPQIrm = 11594,
  VMOV64toPQIrr = 11595,
  VMOV64toSDZrr = 11596,
  VMOV64toSDrr = 11597,
  VMOVAPDYmr = 11598,
  VMOVAPDYrm = 11599,
  VMOVAPDYrr = 11600,
  VMOVAPDYrr_REV = 11601,
  VMOVAPDZ128mr = 11602,
  VMOVAPDZ128mrk = 11603,
  VMOVAPDZ128rm = 11604,
  VMOVAPDZ128rmk = 11605,
  VMOVAPDZ128rmkz = 11606,
  VMOVAPDZ128rr = 11607,
  VMOVAPDZ128rr_REV = 11608,
  VMOVAPDZ128rrk = 11609,
  VMOVAPDZ128rrk_REV = 11610,
  VMOVAPDZ128rrkz = 11611,
  VMOVAPDZ128rrkz_REV = 11612,
  VMOVAPDZ256mr = 11613,
  VMOVAPDZ256mrk = 11614,
  VMOVAPDZ256rm = 11615,
  VMOVAPDZ256rmk = 11616,
  VMOVAPDZ256rmkz = 11617,
  VMOVAPDZ256rr = 11618,
  VMOVAPDZ256rr_REV = 11619,
  VMOVAPDZ256rrk = 11620,
  VMOVAPDZ256rrk_REV = 11621,
  VMOVAPDZ256rrkz = 11622,
  VMOVAPDZ256rrkz_REV = 11623,
  VMOVAPDZmr = 11624,
  VMOVAPDZmrk = 11625,
  VMOVAPDZrm = 11626,
  VMOVAPDZrmk = 11627,
  VMOVAPDZrmkz = 11628,
  VMOVAPDZrr = 11629,
  VMOVAPDZrr_REV = 11630,
  VMOVAPDZrrk = 11631,
  VMOVAPDZrrk_REV = 11632,
  VMOVAPDZrrkz = 11633,
  VMOVAPDZrrkz_REV = 11634,
  VMOVAPDmr = 11635,
  VMOVAPDrm = 11636,
  VMOVAPDrr = 11637,
  VMOVAPDrr_REV = 11638,
  VMOVAPSYmr = 11639,
  VMOVAPSYrm = 11640,
  VMOVAPSYrr = 11641,
  VMOVAPSYrr_REV = 11642,
  VMOVAPSZ128mr = 11643,
  VMOVAPSZ128mrk = 11644,
  VMOVAPSZ128rm = 11645,
  VMOVAPSZ128rmk = 11646,
  VMOVAPSZ128rmkz = 11647,
  VMOVAPSZ128rr = 11648,
  VMOVAPSZ128rr_REV = 11649,
  VMOVAPSZ128rrk = 11650,
  VMOVAPSZ128rrk_REV = 11651,
  VMOVAPSZ128rrkz = 11652,
  VMOVAPSZ128rrkz_REV = 11653,
  VMOVAPSZ256mr = 11654,
  VMOVAPSZ256mrk = 11655,
  VMOVAPSZ256rm = 11656,
  VMOVAPSZ256rmk = 11657,
  VMOVAPSZ256rmkz = 11658,
  VMOVAPSZ256rr = 11659,
  VMOVAPSZ256rr_REV = 11660,
  VMOVAPSZ256rrk = 11661,
  VMOVAPSZ256rrk_REV = 11662,
  VMOVAPSZ256rrkz = 11663,
  VMOVAPSZ256rrkz_REV = 11664,
  VMOVAPSZmr = 11665,
  VMOVAPSZmrk = 11666,
  VMOVAPSZrm = 11667,
  VMOVAPSZrmk = 11668,
  VMOVAPSZrmkz = 11669,
  VMOVAPSZrr = 11670,
  VMOVAPSZrr_REV = 11671,
  VMOVAPSZrrk = 11672,
  VMOVAPSZrrk_REV = 11673,
  VMOVAPSZrrkz = 11674,
  VMOVAPSZrrkz_REV = 11675,
  VMOVAPSmr = 11676,
  VMOVAPSrm = 11677,
  VMOVAPSrr = 11678,
  VMOVAPSrr_REV = 11679,
  VMOVDDUPYrm = 11680,
  VMOVDDUPYrr = 11681,
  VMOVDDUPZ128rm = 11682,
  VMOVDDUPZ128rmk = 11683,
  VMOVDDUPZ128rmkz = 11684,
  VMOVDDUPZ128rr = 11685,
  VMOVDDUPZ128rrk = 11686,
  VMOVDDUPZ128rrkz = 11687,
  VMOVDDUPZ256rm = 11688,
  VMOVDDUPZ256rmk = 11689,
  VMOVDDUPZ256rmkz = 11690,
  VMOVDDUPZ256rr = 11691,
  VMOVDDUPZ256rrk = 11692,
  VMOVDDUPZ256rrkz = 11693,
  VMOVDDUPZrm = 11694,
  VMOVDDUPZrmk = 11695,
  VMOVDDUPZrmkz = 11696,
  VMOVDDUPZrr = 11697,
  VMOVDDUPZrrk = 11698,
  VMOVDDUPZrrkz = 11699,
  VMOVDDUPrm = 11700,
  VMOVDDUPrr = 11701,
  VMOVDI2PDIZrm = 11702,
  VMOVDI2PDIZrr = 11703,
  VMOVDI2PDIrm = 11704,
  VMOVDI2PDIrr = 11705,
  VMOVDI2SSZrr = 11706,
  VMOVDI2SSrr = 11707,
  VMOVDQA32Z128mr = 11708,
  VMOVDQA32Z128mrk = 11709,
  VMOVDQA32Z128rm = 11710,
  VMOVDQA32Z128rmk = 11711,
  VMOVDQA32Z128rmkz = 11712,
  VMOVDQA32Z128rr = 11713,
  VMOVDQA32Z128rr_REV = 11714,
  VMOVDQA32Z128rrk = 11715,
  VMOVDQA32Z128rrk_REV = 11716,
  VMOVDQA32Z128rrkz = 11717,
  VMOVDQA32Z128rrkz_REV = 11718,
  VMOVDQA32Z256mr = 11719,
  VMOVDQA32Z256mrk = 11720,
  VMOVDQA32Z256rm = 11721,
  VMOVDQA32Z256rmk = 11722,
  VMOVDQA32Z256rmkz = 11723,
  VMOVDQA32Z256rr = 11724,
  VMOVDQA32Z256rr_REV = 11725,
  VMOVDQA32Z256rrk = 11726,
  VMOVDQA32Z256rrk_REV = 11727,
  VMOVDQA32Z256rrkz = 11728,
  VMOVDQA32Z256rrkz_REV = 11729,
  VMOVDQA32Zmr = 11730,
  VMOVDQA32Zmrk = 11731,
  VMOVDQA32Zrm = 11732,
  VMOVDQA32Zrmk = 11733,
  VMOVDQA32Zrmkz = 11734,
  VMOVDQA32Zrr = 11735,
  VMOVDQA32Zrr_REV = 11736,
  VMOVDQA32Zrrk = 11737,
  VMOVDQA32Zrrk_REV = 11738,
  VMOVDQA32Zrrkz = 11739,
  VMOVDQA32Zrrkz_REV = 11740,
  VMOVDQA64Z128mr = 11741,
  VMOVDQA64Z128mrk = 11742,
  VMOVDQA64Z128rm = 11743,
  VMOVDQA64Z128rmk = 11744,
  VMOVDQA64Z128rmkz = 11745,
  VMOVDQA64Z128rr = 11746,
  VMOVDQA64Z128rr_REV = 11747,
  VMOVDQA64Z128rrk = 11748,
  VMOVDQA64Z128rrk_REV = 11749,
  VMOVDQA64Z128rrkz = 11750,
  VMOVDQA64Z128rrkz_REV = 11751,
  VMOVDQA64Z256mr = 11752,
  VMOVDQA64Z256mrk = 11753,
  VMOVDQA64Z256rm = 11754,
  VMOVDQA64Z256rmk = 11755,
  VMOVDQA64Z256rmkz = 11756,
  VMOVDQA64Z256rr = 11757,
  VMOVDQA64Z256rr_REV = 11758,
  VMOVDQA64Z256rrk = 11759,
  VMOVDQA64Z256rrk_REV = 11760,
  VMOVDQA64Z256rrkz = 11761,
  VMOVDQA64Z256rrkz_REV = 11762,
  VMOVDQA64Zmr = 11763,
  VMOVDQA64Zmrk = 11764,
  VMOVDQA64Zrm = 11765,
  VMOVDQA64Zrmk = 11766,
  VMOVDQA64Zrmkz = 11767,
  VMOVDQA64Zrr = 11768,
  VMOVDQA64Zrr_REV = 11769,
  VMOVDQA64Zrrk = 11770,
  VMOVDQA64Zrrk_REV = 11771,
  VMOVDQA64Zrrkz = 11772,
  VMOVDQA64Zrrkz_REV = 11773,
  VMOVDQAYmr = 11774,
  VMOVDQAYrm = 11775,
  VMOVDQAYrr = 11776,
  VMOVDQAYrr_REV = 11777,
  VMOVDQAmr = 11778,
  VMOVDQArm = 11779,
  VMOVDQArr = 11780,
  VMOVDQArr_REV = 11781,
  VMOVDQU16Z128mr = 11782,
  VMOVDQU16Z128mrk = 11783,
  VMOVDQU16Z128rm = 11784,
  VMOVDQU16Z128rmk = 11785,
  VMOVDQU16Z128rmkz = 11786,
  VMOVDQU16Z128rr = 11787,
  VMOVDQU16Z128rr_REV = 11788,
  VMOVDQU16Z128rrk = 11789,
  VMOVDQU16Z128rrk_REV = 11790,
  VMOVDQU16Z128rrkz = 11791,
  VMOVDQU16Z128rrkz_REV = 11792,
  VMOVDQU16Z256mr = 11793,
  VMOVDQU16Z256mrk = 11794,
  VMOVDQU16Z256rm = 11795,
  VMOVDQU16Z256rmk = 11796,
  VMOVDQU16Z256rmkz = 11797,
  VMOVDQU16Z256rr = 11798,
  VMOVDQU16Z256rr_REV = 11799,
  VMOVDQU16Z256rrk = 11800,
  VMOVDQU16Z256rrk_REV = 11801,
  VMOVDQU16Z256rrkz = 11802,
  VMOVDQU16Z256rrkz_REV = 11803,
  VMOVDQU16Zmr = 11804,
  VMOVDQU16Zmrk = 11805,
  VMOVDQU16Zrm = 11806,
  VMOVDQU16Zrmk = 11807,
  VMOVDQU16Zrmkz = 11808,
  VMOVDQU16Zrr = 11809,
  VMOVDQU16Zrr_REV = 11810,
  VMOVDQU16Zrrk = 11811,
  VMOVDQU16Zrrk_REV = 11812,
  VMOVDQU16Zrrkz = 11813,
  VMOVDQU16Zrrkz_REV = 11814,
  VMOVDQU32Z128mr = 11815,
  VMOVDQU32Z128mrk = 11816,
  VMOVDQU32Z128rm = 11817,
  VMOVDQU32Z128rmk = 11818,
  VMOVDQU32Z128rmkz = 11819,
  VMOVDQU32Z128rr = 11820,
  VMOVDQU32Z128rr_REV = 11821,
  VMOVDQU32Z128rrk = 11822,
  VMOVDQU32Z128rrk_REV = 11823,
  VMOVDQU32Z128rrkz = 11824,
  VMOVDQU32Z128rrkz_REV = 11825,
  VMOVDQU32Z256mr = 11826,
  VMOVDQU32Z256mrk = 11827,
  VMOVDQU32Z256rm = 11828,
  VMOVDQU32Z256rmk = 11829,
  VMOVDQU32Z256rmkz = 11830,
  VMOVDQU32Z256rr = 11831,
  VMOVDQU32Z256rr_REV = 11832,
  VMOVDQU32Z256rrk = 11833,
  VMOVDQU32Z256rrk_REV = 11834,
  VMOVDQU32Z256rrkz = 11835,
  VMOVDQU32Z256rrkz_REV = 11836,
  VMOVDQU32Zmr = 11837,
  VMOVDQU32Zmrk = 11838,
  VMOVDQU32Zrm = 11839,
  VMOVDQU32Zrmk = 11840,
  VMOVDQU32Zrmkz = 11841,
  VMOVDQU32Zrr = 11842,
  VMOVDQU32Zrr_REV = 11843,
  VMOVDQU32Zrrk = 11844,
  VMOVDQU32Zrrk_REV = 11845,
  VMOVDQU32Zrrkz = 11846,
  VMOVDQU32Zrrkz_REV = 11847,
  VMOVDQU64Z128mr = 11848,
  VMOVDQU64Z128mrk = 11849,
  VMOVDQU64Z128rm = 11850,
  VMOVDQU64Z128rmk = 11851,
  VMOVDQU64Z128rmkz = 11852,
  VMOVDQU64Z128rr = 11853,
  VMOVDQU64Z128rr_REV = 11854,
  VMOVDQU64Z128rrk = 11855,
  VMOVDQU64Z128rrk_REV = 11856,
  VMOVDQU64Z128rrkz = 11857,
  VMOVDQU64Z128rrkz_REV = 11858,
  VMOVDQU64Z256mr = 11859,
  VMOVDQU64Z256mrk = 11860,
  VMOVDQU64Z256rm = 11861,
  VMOVDQU64Z256rmk = 11862,
  VMOVDQU64Z256rmkz = 11863,
  VMOVDQU64Z256rr = 11864,
  VMOVDQU64Z256rr_REV = 11865,
  VMOVDQU64Z256rrk = 11866,
  VMOVDQU64Z256rrk_REV = 11867,
  VMOVDQU64Z256rrkz = 11868,
  VMOVDQU64Z256rrkz_REV = 11869,
  VMOVDQU64Zmr = 11870,
  VMOVDQU64Zmrk = 11871,
  VMOVDQU64Zrm = 11872,
  VMOVDQU64Zrmk = 11873,
  VMOVDQU64Zrmkz = 11874,
  VMOVDQU64Zrr = 11875,
  VMOVDQU64Zrr_REV = 11876,
  VMOVDQU64Zrrk = 11877,
  VMOVDQU64Zrrk_REV = 11878,
  VMOVDQU64Zrrkz = 11879,
  VMOVDQU64Zrrkz_REV = 11880,
  VMOVDQU8Z128mr = 11881,
  VMOVDQU8Z128mrk = 11882,
  VMOVDQU8Z128rm = 11883,
  VMOVDQU8Z128rmk = 11884,
  VMOVDQU8Z128rmkz = 11885,
  VMOVDQU8Z128rr = 11886,
  VMOVDQU8Z128rr_REV = 11887,
  VMOVDQU8Z128rrk = 11888,
  VMOVDQU8Z128rrk_REV = 11889,
  VMOVDQU8Z128rrkz = 11890,
  VMOVDQU8Z128rrkz_REV = 11891,
  VMOVDQU8Z256mr = 11892,
  VMOVDQU8Z256mrk = 11893,
  VMOVDQU8Z256rm = 11894,
  VMOVDQU8Z256rmk = 11895,
  VMOVDQU8Z256rmkz = 11896,
  VMOVDQU8Z256rr = 11897,
  VMOVDQU8Z256rr_REV = 11898,
  VMOVDQU8Z256rrk = 11899,
  VMOVDQU8Z256rrk_REV = 11900,
  VMOVDQU8Z256rrkz = 11901,
  VMOVDQU8Z256rrkz_REV = 11902,
  VMOVDQU8Zmr = 11903,
  VMOVDQU8Zmrk = 11904,
  VMOVDQU8Zrm = 11905,
  VMOVDQU8Zrmk = 11906,
  VMOVDQU8Zrmkz = 11907,
  VMOVDQU8Zrr = 11908,
  VMOVDQU8Zrr_REV = 11909,
  VMOVDQU8Zrrk = 11910,
  VMOVDQU8Zrrk_REV = 11911,
  VMOVDQU8Zrrkz = 11912,
  VMOVDQU8Zrrkz_REV = 11913,
  VMOVDQUYmr = 11914,
  VMOVDQUYrm = 11915,
  VMOVDQUYrr = 11916,
  VMOVDQUYrr_REV = 11917,
  VMOVDQUmr = 11918,
  VMOVDQUrm = 11919,
  VMOVDQUrr = 11920,
  VMOVDQUrr_REV = 11921,
  VMOVHLPSZrr = 11922,
  VMOVHLPSrr = 11923,
  VMOVHPDZ128mr = 11924,
  VMOVHPDZ128rm = 11925,
  VMOVHPDmr = 11926,
  VMOVHPDrm = 11927,
  VMOVHPSZ128mr = 11928,
  VMOVHPSZ128rm = 11929,
  VMOVHPSmr = 11930,
  VMOVHPSrm = 11931,
  VMOVLHPSZrr = 11932,
  VMOVLHPSrr = 11933,
  VMOVLPDZ128mr = 11934,
  VMOVLPDZ128rm = 11935,
  VMOVLPDmr = 11936,
  VMOVLPDrm = 11937,
  VMOVLPSZ128mr = 11938,
  VMOVLPSZ128rm = 11939,
  VMOVLPSmr = 11940,
  VMOVLPSrm = 11941,
  VMOVMSKPDYrr = 11942,
  VMOVMSKPDrr = 11943,
  VMOVMSKPSYrr = 11944,
  VMOVMSKPSrr = 11945,
  VMOVNTDQAYrm = 11946,
  VMOVNTDQAZ128rm = 11947,
  VMOVNTDQAZ256rm = 11948,
  VMOVNTDQAZrm = 11949,
  VMOVNTDQArm = 11950,
  VMOVNTDQYmr = 11951,
  VMOVNTDQZ128mr = 11952,
  VMOVNTDQZ256mr = 11953,
  VMOVNTDQZmr = 11954,
  VMOVNTDQmr = 11955,
  VMOVNTPDYmr = 11956,
  VMOVNTPDZ128mr = 11957,
  VMOVNTPDZ256mr = 11958,
  VMOVNTPDZmr = 11959,
  VMOVNTPDmr = 11960,
  VMOVNTPSYmr = 11961,
  VMOVNTPSZ128mr = 11962,
  VMOVNTPSZ256mr = 11963,
  VMOVNTPSZmr = 11964,
  VMOVNTPSmr = 11965,
  VMOVPDI2DIZmr = 11966,
  VMOVPDI2DIZrr = 11967,
  VMOVPDI2DImr = 11968,
  VMOVPDI2DIrr = 11969,
  VMOVPQI2QIZmr = 11970,
  VMOVPQI2QIZrr = 11971,
  VMOVPQI2QImr = 11972,
  VMOVPQI2QIrr = 11973,
  VMOVPQIto64Zmr = 11974,
  VMOVPQIto64Zrr = 11975,
  VMOVPQIto64mr = 11976,
  VMOVPQIto64rr = 11977,
  VMOVQI2PQIZrm = 11978,
  VMOVQI2PQIrm = 11979,
  VMOVSDZmr = 11980,
  VMOVSDZmrk = 11981,
  VMOVSDZrm = 11982,
  VMOVSDZrm_alt = 11983,
  VMOVSDZrmk = 11984,
  VMOVSDZrmkz = 11985,
  VMOVSDZrr = 11986,
  VMOVSDZrr_REV = 11987,
  VMOVSDZrrk = 11988,
  VMOVSDZrrk_REV = 11989,
  VMOVSDZrrkz = 11990,
  VMOVSDZrrkz_REV = 11991,
  VMOVSDmr = 11992,
  VMOVSDrm = 11993,
  VMOVSDrm_alt = 11994,
  VMOVSDrr = 11995,
  VMOVSDrr_REV = 11996,
  VMOVSDto64Zrr = 11997,
  VMOVSDto64rr = 11998,
  VMOVSH2Wrr = 11999,
  VMOVSHDUPYrm = 12000,
  VMOVSHDUPYrr = 12001,
  VMOVSHDUPZ128rm = 12002,
  VMOVSHDUPZ128rmk = 12003,
  VMOVSHDUPZ128rmkz = 12004,
  VMOVSHDUPZ128rr = 12005,
  VMOVSHDUPZ128rrk = 12006,
  VMOVSHDUPZ128rrkz = 12007,
  VMOVSHDUPZ256rm = 12008,
  VMOVSHDUPZ256rmk = 12009,
  VMOVSHDUPZ256rmkz = 12010,
  VMOVSHDUPZ256rr = 12011,
  VMOVSHDUPZ256rrk = 12012,
  VMOVSHDUPZ256rrkz = 12013,
  VMOVSHDUPZrm = 12014,
  VMOVSHDUPZrmk = 12015,
  VMOVSHDUPZrmkz = 12016,
  VMOVSHDUPZrr = 12017,
  VMOVSHDUPZrrk = 12018,
  VMOVSHDUPZrrkz = 12019,
  VMOVSHDUPrm = 12020,
  VMOVSHDUPrr = 12021,
  VMOVSHZmr = 12022,
  VMOVSHZmrk = 12023,
  VMOVSHZrm = 12024,
  VMOVSHZrm_alt = 12025,
  VMOVSHZrmk = 12026,
  VMOVSHZrmkz = 12027,
  VMOVSHZrr = 12028,
  VMOVSHZrr_REV = 12029,
  VMOVSHZrrk = 12030,
  VMOVSHZrrk_REV = 12031,
  VMOVSHZrrkz = 12032,
  VMOVSHZrrkz_REV = 12033,
  VMOVSHtoW64rr = 12034,
  VMOVSLDUPYrm = 12035,
  VMOVSLDUPYrr = 12036,
  VMOVSLDUPZ128rm = 12037,
  VMOVSLDUPZ128rmk = 12038,
  VMOVSLDUPZ128rmkz = 12039,
  VMOVSLDUPZ128rr = 12040,
  VMOVSLDUPZ128rrk = 12041,
  VMOVSLDUPZ128rrkz = 12042,
  VMOVSLDUPZ256rm = 12043,
  VMOVSLDUPZ256rmk = 12044,
  VMOVSLDUPZ256rmkz = 12045,
  VMOVSLDUPZ256rr = 12046,
  VMOVSLDUPZ256rrk = 12047,
  VMOVSLDUPZ256rrkz = 12048,
  VMOVSLDUPZrm = 12049,
  VMOVSLDUPZrmk = 12050,
  VMOVSLDUPZrmkz = 12051,
  VMOVSLDUPZrr = 12052,
  VMOVSLDUPZrrk = 12053,
  VMOVSLDUPZrrkz = 12054,
  VMOVSLDUPrm = 12055,
  VMOVSLDUPrr = 12056,
  VMOVSS2DIZrr = 12057,
  VMOVSS2DIrr = 12058,
  VMOVSSZmr = 12059,
  VMOVSSZmrk = 12060,
  VMOVSSZrm = 12061,
  VMOVSSZrm_alt = 12062,
  VMOVSSZrmk = 12063,
  VMOVSSZrmkz = 12064,
  VMOVSSZrr = 12065,
  VMOVSSZrr_REV = 12066,
  VMOVSSZrrk = 12067,
  VMOVSSZrrk_REV = 12068,
  VMOVSSZrrkz = 12069,
  VMOVSSZrrkz_REV = 12070,
  VMOVSSmr = 12071,
  VMOVSSrm = 12072,
  VMOVSSrm_alt = 12073,
  VMOVSSrr = 12074,
  VMOVSSrr_REV = 12075,
  VMOVUPDYmr = 12076,
  VMOVUPDYrm = 12077,
  VMOVUPDYrr = 12078,
  VMOVUPDYrr_REV = 12079,
  VMOVUPDZ128mr = 12080,
  VMOVUPDZ128mrk = 12081,
  VMOVUPDZ128rm = 12082,
  VMOVUPDZ128rmk = 12083,
  VMOVUPDZ128rmkz = 12084,
  VMOVUPDZ128rr = 12085,
  VMOVUPDZ128rr_REV = 12086,
  VMOVUPDZ128rrk = 12087,
  VMOVUPDZ128rrk_REV = 12088,
  VMOVUPDZ128rrkz = 12089,
  VMOVUPDZ128rrkz_REV = 12090,
  VMOVUPDZ256mr = 12091,
  VMOVUPDZ256mrk = 12092,
  VMOVUPDZ256rm = 12093,
  VMOVUPDZ256rmk = 12094,
  VMOVUPDZ256rmkz = 12095,
  VMOVUPDZ256rr = 12096,
  VMOVUPDZ256rr_REV = 12097,
  VMOVUPDZ256rrk = 12098,
  VMOVUPDZ256rrk_REV = 12099,
  VMOVUPDZ256rrkz = 12100,
  VMOVUPDZ256rrkz_REV = 12101,
  VMOVUPDZmr = 12102,
  VMOVUPDZmrk = 12103,
  VMOVUPDZrm = 12104,
  VMOVUPDZrmk = 12105,
  VMOVUPDZrmkz = 12106,
  VMOVUPDZrr = 12107,
  VMOVUPDZrr_REV = 12108,
  VMOVUPDZrrk = 12109,
  VMOVUPDZrrk_REV = 12110,
  VMOVUPDZrrkz = 12111,
  VMOVUPDZrrkz_REV = 12112,
  VMOVUPDmr = 12113,
  VMOVUPDrm = 12114,
  VMOVUPDrr = 12115,
  VMOVUPDrr_REV = 12116,
  VMOVUPSYmr = 12117,
  VMOVUPSYrm = 12118,
  VMOVUPSYrr = 12119,
  VMOVUPSYrr_REV = 12120,
  VMOVUPSZ128mr = 12121,
  VMOVUPSZ128mrk = 12122,
  VMOVUPSZ128rm = 12123,
  VMOVUPSZ128rmk = 12124,
  VMOVUPSZ128rmkz = 12125,
  VMOVUPSZ128rr = 12126,
  VMOVUPSZ128rr_REV = 12127,
  VMOVUPSZ128rrk = 12128,
  VMOVUPSZ128rrk_REV = 12129,
  VMOVUPSZ128rrkz = 12130,
  VMOVUPSZ128rrkz_REV = 12131,
  VMOVUPSZ256mr = 12132,
  VMOVUPSZ256mrk = 12133,
  VMOVUPSZ256rm = 12134,
  VMOVUPSZ256rmk = 12135,
  VMOVUPSZ256rmkz = 12136,
  VMOVUPSZ256rr = 12137,
  VMOVUPSZ256rr_REV = 12138,
  VMOVUPSZ256rrk = 12139,
  VMOVUPSZ256rrk_REV = 12140,
  VMOVUPSZ256rrkz = 12141,
  VMOVUPSZ256rrkz_REV = 12142,
  VMOVUPSZmr = 12143,
  VMOVUPSZmrk = 12144,
  VMOVUPSZrm = 12145,
  VMOVUPSZrmk = 12146,
  VMOVUPSZrmkz = 12147,
  VMOVUPSZrr = 12148,
  VMOVUPSZrr_REV = 12149,
  VMOVUPSZrrk = 12150,
  VMOVUPSZrrk_REV = 12151,
  VMOVUPSZrrkz = 12152,
  VMOVUPSZrrkz_REV = 12153,
  VMOVUPSmr = 12154,
  VMOVUPSrm = 12155,
  VMOVUPSrr = 12156,
  VMOVUPSrr_REV = 12157,
  VMOVW2SHrr = 12158,
  VMOVW64toSHrr = 12159,
  VMOVWmr = 12160,
  VMOVWrm = 12161,
  VMOVZPQILo2PQIZrr = 12162,
  VMOVZPQILo2PQIrr = 12163,
  VMPSADBWYrmi = 12164,
  VMPSADBWYrri = 12165,
  VMPSADBWrmi = 12166,
  VMPSADBWrri = 12167,
  VMPTRLDm = 12168,
  VMPTRSTm = 12169,
  VMREAD32mr = 12170,
  VMREAD32rr = 12171,
  VMREAD64mr = 12172,
  VMREAD64rr = 12173,
  VMRESUME = 12174,
  VMRUN32 = 12175,
  VMRUN64 = 12176,
  VMSAVE32 = 12177,
  VMSAVE64 = 12178,
  VMULPDYrm = 12179,
  VMULPDYrr = 12180,
  VMULPDZ128rm = 12181,
  VMULPDZ128rmb = 12182,
  VMULPDZ128rmbk = 12183,
  VMULPDZ128rmbkz = 12184,
  VMULPDZ128rmk = 12185,
  VMULPDZ128rmkz = 12186,
  VMULPDZ128rr = 12187,
  VMULPDZ128rrk = 12188,
  VMULPDZ128rrkz = 12189,
  VMULPDZ256rm = 12190,
  VMULPDZ256rmb = 12191,
  VMULPDZ256rmbk = 12192,
  VMULPDZ256rmbkz = 12193,
  VMULPDZ256rmk = 12194,
  VMULPDZ256rmkz = 12195,
  VMULPDZ256rr = 12196,
  VMULPDZ256rrk = 12197,
  VMULPDZ256rrkz = 12198,
  VMULPDZrm = 12199,
  VMULPDZrmb = 12200,
  VMULPDZrmbk = 12201,
  VMULPDZrmbkz = 12202,
  VMULPDZrmk = 12203,
  VMULPDZrmkz = 12204,
  VMULPDZrr = 12205,
  VMULPDZrrb = 12206,
  VMULPDZrrbk = 12207,
  VMULPDZrrbkz = 12208,
  VMULPDZrrk = 12209,
  VMULPDZrrkz = 12210,
  VMULPDrm = 12211,
  VMULPDrr = 12212,
  VMULPHZ128rm = 12213,
  VMULPHZ128rmb = 12214,
  VMULPHZ128rmbk = 12215,
  VMULPHZ128rmbkz = 12216,
  VMULPHZ128rmk = 12217,
  VMULPHZ128rmkz = 12218,
  VMULPHZ128rr = 12219,
  VMULPHZ128rrk = 12220,
  VMULPHZ128rrkz = 12221,
  VMULPHZ256rm = 12222,
  VMULPHZ256rmb = 12223,
  VMULPHZ256rmbk = 12224,
  VMULPHZ256rmbkz = 12225,
  VMULPHZ256rmk = 12226,
  VMULPHZ256rmkz = 12227,
  VMULPHZ256rr = 12228,
  VMULPHZ256rrk = 12229,
  VMULPHZ256rrkz = 12230,
  VMULPHZrm = 12231,
  VMULPHZrmb = 12232,
  VMULPHZrmbk = 12233,
  VMULPHZrmbkz = 12234,
  VMULPHZrmk = 12235,
  VMULPHZrmkz = 12236,
  VMULPHZrr = 12237,
  VMULPHZrrb = 12238,
  VMULPHZrrbk = 12239,
  VMULPHZrrbkz = 12240,
  VMULPHZrrk = 12241,
  VMULPHZrrkz = 12242,
  VMULPSYrm = 12243,
  VMULPSYrr = 12244,
  VMULPSZ128rm = 12245,
  VMULPSZ128rmb = 12246,
  VMULPSZ128rmbk = 12247,
  VMULPSZ128rmbkz = 12248,
  VMULPSZ128rmk = 12249,
  VMULPSZ128rmkz = 12250,
  VMULPSZ128rr = 12251,
  VMULPSZ128rrk = 12252,
  VMULPSZ128rrkz = 12253,
  VMULPSZ256rm = 12254,
  VMULPSZ256rmb = 12255,
  VMULPSZ256rmbk = 12256,
  VMULPSZ256rmbkz = 12257,
  VMULPSZ256rmk = 12258,
  VMULPSZ256rmkz = 12259,
  VMULPSZ256rr = 12260,
  VMULPSZ256rrk = 12261,
  VMULPSZ256rrkz = 12262,
  VMULPSZrm = 12263,
  VMULPSZrmb = 12264,
  VMULPSZrmbk = 12265,
  VMULPSZrmbkz = 12266,
  VMULPSZrmk = 12267,
  VMULPSZrmkz = 12268,
  VMULPSZrr = 12269,
  VMULPSZrrb = 12270,
  VMULPSZrrbk = 12271,
  VMULPSZrrbkz = 12272,
  VMULPSZrrk = 12273,
  VMULPSZrrkz = 12274,
  VMULPSrm = 12275,
  VMULPSrr = 12276,
  VMULSDZrm = 12277,
  VMULSDZrm_Int = 12278,
  VMULSDZrm_Intk = 12279,
  VMULSDZrm_Intkz = 12280,
  VMULSDZrr = 12281,
  VMULSDZrr_Int = 12282,
  VMULSDZrr_Intk = 12283,
  VMULSDZrr_Intkz = 12284,
  VMULSDZrrb_Int = 12285,
  VMULSDZrrb_Intk = 12286,
  VMULSDZrrb_Intkz = 12287,
  VMULSDrm = 12288,
  VMULSDrm_Int = 12289,
  VMULSDrr = 12290,
  VMULSDrr_Int = 12291,
  VMULSHZrm = 12292,
  VMULSHZrm_Int = 12293,
  VMULSHZrm_Intk = 12294,
  VMULSHZrm_Intkz = 12295,
  VMULSHZrr = 12296,
  VMULSHZrr_Int = 12297,
  VMULSHZrr_Intk = 12298,
  VMULSHZrr_Intkz = 12299,
  VMULSHZrrb_Int = 12300,
  VMULSHZrrb_Intk = 12301,
  VMULSHZrrb_Intkz = 12302,
  VMULSSZrm = 12303,
  VMULSSZrm_Int = 12304,
  VMULSSZrm_Intk = 12305,
  VMULSSZrm_Intkz = 12306,
  VMULSSZrr = 12307,
  VMULSSZrr_Int = 12308,
  VMULSSZrr_Intk = 12309,
  VMULSSZrr_Intkz = 12310,
  VMULSSZrrb_Int = 12311,
  VMULSSZrrb_Intk = 12312,
  VMULSSZrrb_Intkz = 12313,
  VMULSSrm = 12314,
  VMULSSrm_Int = 12315,
  VMULSSrr = 12316,
  VMULSSrr_Int = 12317,
  VMWRITE32rm = 12318,
  VMWRITE32rr = 12319,
  VMWRITE64rm = 12320,
  VMWRITE64rr = 12321,
  VMXOFF = 12322,
  VMXON = 12323,
  VORPDYrm = 12324,
  VORPDYrr = 12325,
  VORPDZ128rm = 12326,
  VORPDZ128rmb = 12327,
  VORPDZ128rmbk = 12328,
  VORPDZ128rmbkz = 12329,
  VORPDZ128rmk = 12330,
  VORPDZ128rmkz = 12331,
  VORPDZ128rr = 12332,
  VORPDZ128rrk = 12333,
  VORPDZ128rrkz = 12334,
  VORPDZ256rm = 12335,
  VORPDZ256rmb = 12336,
  VORPDZ256rmbk = 12337,
  VORPDZ256rmbkz = 12338,
  VORPDZ256rmk = 12339,
  VORPDZ256rmkz = 12340,
  VORPDZ256rr = 12341,
  VORPDZ256rrk = 12342,
  VORPDZ256rrkz = 12343,
  VORPDZrm = 12344,
  VORPDZrmb = 12345,
  VORPDZrmbk = 12346,
  VORPDZrmbkz = 12347,
  VORPDZrmk = 12348,
  VORPDZrmkz = 12349,
  VORPDZrr = 12350,
  VORPDZrrk = 12351,
  VORPDZrrkz = 12352,
  VORPDrm = 12353,
  VORPDrr = 12354,
  VORPSYrm = 12355,
  VORPSYrr = 12356,
  VORPSZ128rm = 12357,
  VORPSZ128rmb = 12358,
  VORPSZ128rmbk = 12359,
  VORPSZ128rmbkz = 12360,
  VORPSZ128rmk = 12361,
  VORPSZ128rmkz = 12362,
  VORPSZ128rr = 12363,
  VORPSZ128rrk = 12364,
  VORPSZ128rrkz = 12365,
  VORPSZ256rm = 12366,
  VORPSZ256rmb = 12367,
  VORPSZ256rmbk = 12368,
  VORPSZ256rmbkz = 12369,
  VORPSZ256rmk = 12370,
  VORPSZ256rmkz = 12371,
  VORPSZ256rr = 12372,
  VORPSZ256rrk = 12373,
  VORPSZ256rrkz = 12374,
  VORPSZrm = 12375,
  VORPSZrmb = 12376,
  VORPSZrmbk = 12377,
  VORPSZrmbkz = 12378,
  VORPSZrmk = 12379,
  VORPSZrmkz = 12380,
  VORPSZrr = 12381,
  VORPSZrrk = 12382,
  VORPSZrrkz = 12383,
  VORPSrm = 12384,
  VORPSrr = 12385,
  VP2INTERSECTDZ128rm = 12386,
  VP2INTERSECTDZ128rmb = 12387,
  VP2INTERSECTDZ128rr = 12388,
  VP2INTERSECTDZ256rm = 12389,
  VP2INTERSECTDZ256rmb = 12390,
  VP2INTERSECTDZ256rr = 12391,
  VP2INTERSECTDZrm = 12392,
  VP2INTERSECTDZrmb = 12393,
  VP2INTERSECTDZrr = 12394,
  VP2INTERSECTQZ128rm = 12395,
  VP2INTERSECTQZ128rmb = 12396,
  VP2INTERSECTQZ128rr = 12397,
  VP2INTERSECTQZ256rm = 12398,
  VP2INTERSECTQZ256rmb = 12399,
  VP2INTERSECTQZ256rr = 12400,
  VP2INTERSECTQZrm = 12401,
  VP2INTERSECTQZrmb = 12402,
  VP2INTERSECTQZrr = 12403,
  VP4DPWSSDSrm = 12404,
  VP4DPWSSDSrmk = 12405,
  VP4DPWSSDSrmkz = 12406,
  VP4DPWSSDrm = 12407,
  VP4DPWSSDrmk = 12408,
  VP4DPWSSDrmkz = 12409,
  VPABSBYrm = 12410,
  VPABSBYrr = 12411,
  VPABSBZ128rm = 12412,
  VPABSBZ128rmk = 12413,
  VPABSBZ128rmkz = 12414,
  VPABSBZ128rr = 12415,
  VPABSBZ128rrk = 12416,
  VPABSBZ128rrkz = 12417,
  VPABSBZ256rm = 12418,
  VPABSBZ256rmk = 12419,
  VPABSBZ256rmkz = 12420,
  VPABSBZ256rr = 12421,
  VPABSBZ256rrk = 12422,
  VPABSBZ256rrkz = 12423,
  VPABSBZrm = 12424,
  VPABSBZrmk = 12425,
  VPABSBZrmkz = 12426,
  VPABSBZrr = 12427,
  VPABSBZrrk = 12428,
  VPABSBZrrkz = 12429,
  VPABSBrm = 12430,
  VPABSBrr = 12431,
  VPABSDYrm = 12432,
  VPABSDYrr = 12433,
  VPABSDZ128rm = 12434,
  VPABSDZ128rmb = 12435,
  VPABSDZ128rmbk = 12436,
  VPABSDZ128rmbkz = 12437,
  VPABSDZ128rmk = 12438,
  VPABSDZ128rmkz = 12439,
  VPABSDZ128rr = 12440,
  VPABSDZ128rrk = 12441,
  VPABSDZ128rrkz = 12442,
  VPABSDZ256rm = 12443,
  VPABSDZ256rmb = 12444,
  VPABSDZ256rmbk = 12445,
  VPABSDZ256rmbkz = 12446,
  VPABSDZ256rmk = 12447,
  VPABSDZ256rmkz = 12448,
  VPABSDZ256rr = 12449,
  VPABSDZ256rrk = 12450,
  VPABSDZ256rrkz = 12451,
  VPABSDZrm = 12452,
  VPABSDZrmb = 12453,
  VPABSDZrmbk = 12454,
  VPABSDZrmbkz = 12455,
  VPABSDZrmk = 12456,
  VPABSDZrmkz = 12457,
  VPABSDZrr = 12458,
  VPABSDZrrk = 12459,
  VPABSDZrrkz = 12460,
  VPABSDrm = 12461,
  VPABSDrr = 12462,
  VPABSQZ128rm = 12463,
  VPABSQZ128rmb = 12464,
  VPABSQZ128rmbk = 12465,
  VPABSQZ128rmbkz = 12466,
  VPABSQZ128rmk = 12467,
  VPABSQZ128rmkz = 12468,
  VPABSQZ128rr = 12469,
  VPABSQZ128rrk = 12470,
  VPABSQZ128rrkz = 12471,
  VPABSQZ256rm = 12472,
  VPABSQZ256rmb = 12473,
  VPABSQZ256rmbk = 12474,
  VPABSQZ256rmbkz = 12475,
  VPABSQZ256rmk = 12476,
  VPABSQZ256rmkz = 12477,
  VPABSQZ256rr = 12478,
  VPABSQZ256rrk = 12479,
  VPABSQZ256rrkz = 12480,
  VPABSQZrm = 12481,
  VPABSQZrmb = 12482,
  VPABSQZrmbk = 12483,
  VPABSQZrmbkz = 12484,
  VPABSQZrmk = 12485,
  VPABSQZrmkz = 12486,
  VPABSQZrr = 12487,
  VPABSQZrrk = 12488,
  VPABSQZrrkz = 12489,
  VPABSWYrm = 12490,
  VPABSWYrr = 12491,
  VPABSWZ128rm = 12492,
  VPABSWZ128rmk = 12493,
  VPABSWZ128rmkz = 12494,
  VPABSWZ128rr = 12495,
  VPABSWZ128rrk = 12496,
  VPABSWZ128rrkz = 12497,
  VPABSWZ256rm = 12498,
  VPABSWZ256rmk = 12499,
  VPABSWZ256rmkz = 12500,
  VPABSWZ256rr = 12501,
  VPABSWZ256rrk = 12502,
  VPABSWZ256rrkz = 12503,
  VPABSWZrm = 12504,
  VPABSWZrmk = 12505,
  VPABSWZrmkz = 12506,
  VPABSWZrr = 12507,
  VPABSWZrrk = 12508,
  VPABSWZrrkz = 12509,
  VPABSWrm = 12510,
  VPABSWrr = 12511,
  VPACKSSDWYrm = 12512,
  VPACKSSDWYrr = 12513,
  VPACKSSDWZ128rm = 12514,
  VPACKSSDWZ128rmb = 12515,
  VPACKSSDWZ128rmbk = 12516,
  VPACKSSDWZ128rmbkz = 12517,
  VPACKSSDWZ128rmk = 12518,
  VPACKSSDWZ128rmkz = 12519,
  VPACKSSDWZ128rr = 12520,
  VPACKSSDWZ128rrk = 12521,
  VPACKSSDWZ128rrkz = 12522,
  VPACKSSDWZ256rm = 12523,
  VPACKSSDWZ256rmb = 12524,
  VPACKSSDWZ256rmbk = 12525,
  VPACKSSDWZ256rmbkz = 12526,
  VPACKSSDWZ256rmk = 12527,
  VPACKSSDWZ256rmkz = 12528,
  VPACKSSDWZ256rr = 12529,
  VPACKSSDWZ256rrk = 12530,
  VPACKSSDWZ256rrkz = 12531,
  VPACKSSDWZrm = 12532,
  VPACKSSDWZrmb = 12533,
  VPACKSSDWZrmbk = 12534,
  VPACKSSDWZrmbkz = 12535,
  VPACKSSDWZrmk = 12536,
  VPACKSSDWZrmkz = 12537,
  VPACKSSDWZrr = 12538,
  VPACKSSDWZrrk = 12539,
  VPACKSSDWZrrkz = 12540,
  VPACKSSDWrm = 12541,
  VPACKSSDWrr = 12542,
  VPACKSSWBYrm = 12543,
  VPACKSSWBYrr = 12544,
  VPACKSSWBZ128rm = 12545,
  VPACKSSWBZ128rmk = 12546,
  VPACKSSWBZ128rmkz = 12547,
  VPACKSSWBZ128rr = 12548,
  VPACKSSWBZ128rrk = 12549,
  VPACKSSWBZ128rrkz = 12550,
  VPACKSSWBZ256rm = 12551,
  VPACKSSWBZ256rmk = 12552,
  VPACKSSWBZ256rmkz = 12553,
  VPACKSSWBZ256rr = 12554,
  VPACKSSWBZ256rrk = 12555,
  VPACKSSWBZ256rrkz = 12556,
  VPACKSSWBZrm = 12557,
  VPACKSSWBZrmk = 12558,
  VPACKSSWBZrmkz = 12559,
  VPACKSSWBZrr = 12560,
  VPACKSSWBZrrk = 12561,
  VPACKSSWBZrrkz = 12562,
  VPACKSSWBrm = 12563,
  VPACKSSWBrr = 12564,
  VPACKUSDWYrm = 12565,
  VPACKUSDWYrr = 12566,
  VPACKUSDWZ128rm = 12567,
  VPACKUSDWZ128rmb = 12568,
  VPACKUSDWZ128rmbk = 12569,
  VPACKUSDWZ128rmbkz = 12570,
  VPACKUSDWZ128rmk = 12571,
  VPACKUSDWZ128rmkz = 12572,
  VPACKUSDWZ128rr = 12573,
  VPACKUSDWZ128rrk = 12574,
  VPACKUSDWZ128rrkz = 12575,
  VPACKUSDWZ256rm = 12576,
  VPACKUSDWZ256rmb = 12577,
  VPACKUSDWZ256rmbk = 12578,
  VPACKUSDWZ256rmbkz = 12579,
  VPACKUSDWZ256rmk = 12580,
  VPACKUSDWZ256rmkz = 12581,
  VPACKUSDWZ256rr = 12582,
  VPACKUSDWZ256rrk = 12583,
  VPACKUSDWZ256rrkz = 12584,
  VPACKUSDWZrm = 12585,
  VPACKUSDWZrmb = 12586,
  VPACKUSDWZrmbk = 12587,
  VPACKUSDWZrmbkz = 12588,
  VPACKUSDWZrmk = 12589,
  VPACKUSDWZrmkz = 12590,
  VPACKUSDWZrr = 12591,
  VPACKUSDWZrrk = 12592,
  VPACKUSDWZrrkz = 12593,
  VPACKUSDWrm = 12594,
  VPACKUSDWrr = 12595,
  VPACKUSWBYrm = 12596,
  VPACKUSWBYrr = 12597,
  VPACKUSWBZ128rm = 12598,
  VPACKUSWBZ128rmk = 12599,
  VPACKUSWBZ128rmkz = 12600,
  VPACKUSWBZ128rr = 12601,
  VPACKUSWBZ128rrk = 12602,
  VPACKUSWBZ128rrkz = 12603,
  VPACKUSWBZ256rm = 12604,
  VPACKUSWBZ256rmk = 12605,
  VPACKUSWBZ256rmkz = 12606,
  VPACKUSWBZ256rr = 12607,
  VPACKUSWBZ256rrk = 12608,
  VPACKUSWBZ256rrkz = 12609,
  VPACKUSWBZrm = 12610,
  VPACKUSWBZrmk = 12611,
  VPACKUSWBZrmkz = 12612,
  VPACKUSWBZrr = 12613,
  VPACKUSWBZrrk = 12614,
  VPACKUSWBZrrkz = 12615,
  VPACKUSWBrm = 12616,
  VPACKUSWBrr = 12617,
  VPADDBYrm = 12618,
  VPADDBYrr = 12619,
  VPADDBZ128rm = 12620,
  VPADDBZ128rmk = 12621,
  VPADDBZ128rmkz = 12622,
  VPADDBZ128rr = 12623,
  VPADDBZ128rrk = 12624,
  VPADDBZ128rrkz = 12625,
  VPADDBZ256rm = 12626,
  VPADDBZ256rmk = 12627,
  VPADDBZ256rmkz = 12628,
  VPADDBZ256rr = 12629,
  VPADDBZ256rrk = 12630,
  VPADDBZ256rrkz = 12631,
  VPADDBZrm = 12632,
  VPADDBZrmk = 12633,
  VPADDBZrmkz = 12634,
  VPADDBZrr = 12635,
  VPADDBZrrk = 12636,
  VPADDBZrrkz = 12637,
  VPADDBrm = 12638,
  VPADDBrr = 12639,
  VPADDDYrm = 12640,
  VPADDDYrr = 12641,
  VPADDDZ128rm = 12642,
  VPADDDZ128rmb = 12643,
  VPADDDZ128rmbk = 12644,
  VPADDDZ128rmbkz = 12645,
  VPADDDZ128rmk = 12646,
  VPADDDZ128rmkz = 12647,
  VPADDDZ128rr = 12648,
  VPADDDZ128rrk = 12649,
  VPADDDZ128rrkz = 12650,
  VPADDDZ256rm = 12651,
  VPADDDZ256rmb = 12652,
  VPADDDZ256rmbk = 12653,
  VPADDDZ256rmbkz = 12654,
  VPADDDZ256rmk = 12655,
  VPADDDZ256rmkz = 12656,
  VPADDDZ256rr = 12657,
  VPADDDZ256rrk = 12658,
  VPADDDZ256rrkz = 12659,
  VPADDDZrm = 12660,
  VPADDDZrmb = 12661,
  VPADDDZrmbk = 12662,
  VPADDDZrmbkz = 12663,
  VPADDDZrmk = 12664,
  VPADDDZrmkz = 12665,
  VPADDDZrr = 12666,
  VPADDDZrrk = 12667,
  VPADDDZrrkz = 12668,
  VPADDDrm = 12669,
  VPADDDrr = 12670,
  VPADDQYrm = 12671,
  VPADDQYrr = 12672,
  VPADDQZ128rm = 12673,
  VPADDQZ128rmb = 12674,
  VPADDQZ128rmbk = 12675,
  VPADDQZ128rmbkz = 12676,
  VPADDQZ128rmk = 12677,
  VPADDQZ128rmkz = 12678,
  VPADDQZ128rr = 12679,
  VPADDQZ128rrk = 12680,
  VPADDQZ128rrkz = 12681,
  VPADDQZ256rm = 12682,
  VPADDQZ256rmb = 12683,
  VPADDQZ256rmbk = 12684,
  VPADDQZ256rmbkz = 12685,
  VPADDQZ256rmk = 12686,
  VPADDQZ256rmkz = 12687,
  VPADDQZ256rr = 12688,
  VPADDQZ256rrk = 12689,
  VPADDQZ256rrkz = 12690,
  VPADDQZrm = 12691,
  VPADDQZrmb = 12692,
  VPADDQZrmbk = 12693,
  VPADDQZrmbkz = 12694,
  VPADDQZrmk = 12695,
  VPADDQZrmkz = 12696,
  VPADDQZrr = 12697,
  VPADDQZrrk = 12698,
  VPADDQZrrkz = 12699,
  VPADDQrm = 12700,
  VPADDQrr = 12701,
  VPADDSBYrm = 12702,
  VPADDSBYrr = 12703,
  VPADDSBZ128rm = 12704,
  VPADDSBZ128rmk = 12705,
  VPADDSBZ128rmkz = 12706,
  VPADDSBZ128rr = 12707,
  VPADDSBZ128rrk = 12708,
  VPADDSBZ128rrkz = 12709,
  VPADDSBZ256rm = 12710,
  VPADDSBZ256rmk = 12711,
  VPADDSBZ256rmkz = 12712,
  VPADDSBZ256rr = 12713,
  VPADDSBZ256rrk = 12714,
  VPADDSBZ256rrkz = 12715,
  VPADDSBZrm = 12716,
  VPADDSBZrmk = 12717,
  VPADDSBZrmkz = 12718,
  VPADDSBZrr = 12719,
  VPADDSBZrrk = 12720,
  VPADDSBZrrkz = 12721,
  VPADDSBrm = 12722,
  VPADDSBrr = 12723,
  VPADDSWYrm = 12724,
  VPADDSWYrr = 12725,
  VPADDSWZ128rm = 12726,
  VPADDSWZ128rmk = 12727,
  VPADDSWZ128rmkz = 12728,
  VPADDSWZ128rr = 12729,
  VPADDSWZ128rrk = 12730,
  VPADDSWZ128rrkz = 12731,
  VPADDSWZ256rm = 12732,
  VPADDSWZ256rmk = 12733,
  VPADDSWZ256rmkz = 12734,
  VPADDSWZ256rr = 12735,
  VPADDSWZ256rrk = 12736,
  VPADDSWZ256rrkz = 12737,
  VPADDSWZrm = 12738,
  VPADDSWZrmk = 12739,
  VPADDSWZrmkz = 12740,
  VPADDSWZrr = 12741,
  VPADDSWZrrk = 12742,
  VPADDSWZrrkz = 12743,
  VPADDSWrm = 12744,
  VPADDSWrr = 12745,
  VPADDUSBYrm = 12746,
  VPADDUSBYrr = 12747,
  VPADDUSBZ128rm = 12748,
  VPADDUSBZ128rmk = 12749,
  VPADDUSBZ128rmkz = 12750,
  VPADDUSBZ128rr = 12751,
  VPADDUSBZ128rrk = 12752,
  VPADDUSBZ128rrkz = 12753,
  VPADDUSBZ256rm = 12754,
  VPADDUSBZ256rmk = 12755,
  VPADDUSBZ256rmkz = 12756,
  VPADDUSBZ256rr = 12757,
  VPADDUSBZ256rrk = 12758,
  VPADDUSBZ256rrkz = 12759,
  VPADDUSBZrm = 12760,
  VPADDUSBZrmk = 12761,
  VPADDUSBZrmkz = 12762,
  VPADDUSBZrr = 12763,
  VPADDUSBZrrk = 12764,
  VPADDUSBZrrkz = 12765,
  VPADDUSBrm = 12766,
  VPADDUSBrr = 12767,
  VPADDUSWYrm = 12768,
  VPADDUSWYrr = 12769,
  VPADDUSWZ128rm = 12770,
  VPADDUSWZ128rmk = 12771,
  VPADDUSWZ128rmkz = 12772,
  VPADDUSWZ128rr = 12773,
  VPADDUSWZ128rrk = 12774,
  VPADDUSWZ128rrkz = 12775,
  VPADDUSWZ256rm = 12776,
  VPADDUSWZ256rmk = 12777,
  VPADDUSWZ256rmkz = 12778,
  VPADDUSWZ256rr = 12779,
  VPADDUSWZ256rrk = 12780,
  VPADDUSWZ256rrkz = 12781,
  VPADDUSWZrm = 12782,
  VPADDUSWZrmk = 12783,
  VPADDUSWZrmkz = 12784,
  VPADDUSWZrr = 12785,
  VPADDUSWZrrk = 12786,
  VPADDUSWZrrkz = 12787,
  VPADDUSWrm = 12788,
  VPADDUSWrr = 12789,
  VPADDWYrm = 12790,
  VPADDWYrr = 12791,
  VPADDWZ128rm = 12792,
  VPADDWZ128rmk = 12793,
  VPADDWZ128rmkz = 12794,
  VPADDWZ128rr = 12795,
  VPADDWZ128rrk = 12796,
  VPADDWZ128rrkz = 12797,
  VPADDWZ256rm = 12798,
  VPADDWZ256rmk = 12799,
  VPADDWZ256rmkz = 12800,
  VPADDWZ256rr = 12801,
  VPADDWZ256rrk = 12802,
  VPADDWZ256rrkz = 12803,
  VPADDWZrm = 12804,
  VPADDWZrmk = 12805,
  VPADDWZrmkz = 12806,
  VPADDWZrr = 12807,
  VPADDWZrrk = 12808,
  VPADDWZrrkz = 12809,
  VPADDWrm = 12810,
  VPADDWrr = 12811,
  VPALIGNRYrmi = 12812,
  VPALIGNRYrri = 12813,
  VPALIGNRZ128rmi = 12814,
  VPALIGNRZ128rmik = 12815,
  VPALIGNRZ128rmikz = 12816,
  VPALIGNRZ128rri = 12817,
  VPALIGNRZ128rrik = 12818,
  VPALIGNRZ128rrikz = 12819,
  VPALIGNRZ256rmi = 12820,
  VPALIGNRZ256rmik = 12821,
  VPALIGNRZ256rmikz = 12822,
  VPALIGNRZ256rri = 12823,
  VPALIGNRZ256rrik = 12824,
  VPALIGNRZ256rrikz = 12825,
  VPALIGNRZrmi = 12826,
  VPALIGNRZrmik = 12827,
  VPALIGNRZrmikz = 12828,
  VPALIGNRZrri = 12829,
  VPALIGNRZrrik = 12830,
  VPALIGNRZrrikz = 12831,
  VPALIGNRrmi = 12832,
  VPALIGNRrri = 12833,
  VPANDDZ128rm = 12834,
  VPANDDZ128rmb = 12835,
  VPANDDZ128rmbk = 12836,
  VPANDDZ128rmbkz = 12837,
  VPANDDZ128rmk = 12838,
  VPANDDZ128rmkz = 12839,
  VPANDDZ128rr = 12840,
  VPANDDZ128rrk = 12841,
  VPANDDZ128rrkz = 12842,
  VPANDDZ256rm = 12843,
  VPANDDZ256rmb = 12844,
  VPANDDZ256rmbk = 12845,
  VPANDDZ256rmbkz = 12846,
  VPANDDZ256rmk = 12847,
  VPANDDZ256rmkz = 12848,
  VPANDDZ256rr = 12849,
  VPANDDZ256rrk = 12850,
  VPANDDZ256rrkz = 12851,
  VPANDDZrm = 12852,
  VPANDDZrmb = 12853,
  VPANDDZrmbk = 12854,
  VPANDDZrmbkz = 12855,
  VPANDDZrmk = 12856,
  VPANDDZrmkz = 12857,
  VPANDDZrr = 12858,
  VPANDDZrrk = 12859,
  VPANDDZrrkz = 12860,
  VPANDNDZ128rm = 12861,
  VPANDNDZ128rmb = 12862,
  VPANDNDZ128rmbk = 12863,
  VPANDNDZ128rmbkz = 12864,
  VPANDNDZ128rmk = 12865,
  VPANDNDZ128rmkz = 12866,
  VPANDNDZ128rr = 12867,
  VPANDNDZ128rrk = 12868,
  VPANDNDZ128rrkz = 12869,
  VPANDNDZ256rm = 12870,
  VPANDNDZ256rmb = 12871,
  VPANDNDZ256rmbk = 12872,
  VPANDNDZ256rmbkz = 12873,
  VPANDNDZ256rmk = 12874,
  VPANDNDZ256rmkz = 12875,
  VPANDNDZ256rr = 12876,
  VPANDNDZ256rrk = 12877,
  VPANDNDZ256rrkz = 12878,
  VPANDNDZrm = 12879,
  VPANDNDZrmb = 12880,
  VPANDNDZrmbk = 12881,
  VPANDNDZrmbkz = 12882,
  VPANDNDZrmk = 12883,
  VPANDNDZrmkz = 12884,
  VPANDNDZrr = 12885,
  VPANDNDZrrk = 12886,
  VPANDNDZrrkz = 12887,
  VPANDNQZ128rm = 12888,
  VPANDNQZ128rmb = 12889,
  VPANDNQZ128rmbk = 12890,
  VPANDNQZ128rmbkz = 12891,
  VPANDNQZ128rmk = 12892,
  VPANDNQZ128rmkz = 12893,
  VPANDNQZ128rr = 12894,
  VPANDNQZ128rrk = 12895,
  VPANDNQZ128rrkz = 12896,
  VPANDNQZ256rm = 12897,
  VPANDNQZ256rmb = 12898,
  VPANDNQZ256rmbk = 12899,
  VPANDNQZ256rmbkz = 12900,
  VPANDNQZ256rmk = 12901,
  VPANDNQZ256rmkz = 12902,
  VPANDNQZ256rr = 12903,
  VPANDNQZ256rrk = 12904,
  VPANDNQZ256rrkz = 12905,
  VPANDNQZrm = 12906,
  VPANDNQZrmb = 12907,
  VPANDNQZrmbk = 12908,
  VPANDNQZrmbkz = 12909,
  VPANDNQZrmk = 12910,
  VPANDNQZrmkz = 12911,
  VPANDNQZrr = 12912,
  VPANDNQZrrk = 12913,
  VPANDNQZrrkz = 12914,
  VPANDNYrm = 12915,
  VPANDNYrr = 12916,
  VPANDNrm = 12917,
  VPANDNrr = 12918,
  VPANDQZ128rm = 12919,
  VPANDQZ128rmb = 12920,
  VPANDQZ128rmbk = 12921,
  VPANDQZ128rmbkz = 12922,
  VPANDQZ128rmk = 12923,
  VPANDQZ128rmkz = 12924,
  VPANDQZ128rr = 12925,
  VPANDQZ128rrk = 12926,
  VPANDQZ128rrkz = 12927,
  VPANDQZ256rm = 12928,
  VPANDQZ256rmb = 12929,
  VPANDQZ256rmbk = 12930,
  VPANDQZ256rmbkz = 12931,
  VPANDQZ256rmk = 12932,
  VPANDQZ256rmkz = 12933,
  VPANDQZ256rr = 12934,
  VPANDQZ256rrk = 12935,
  VPANDQZ256rrkz = 12936,
  VPANDQZrm = 12937,
  VPANDQZrmb = 12938,
  VPANDQZrmbk = 12939,
  VPANDQZrmbkz = 12940,
  VPANDQZrmk = 12941,
  VPANDQZrmkz = 12942,
  VPANDQZrr = 12943,
  VPANDQZrrk = 12944,
  VPANDQZrrkz = 12945,
  VPANDYrm = 12946,
  VPANDYrr = 12947,
  VPANDrm = 12948,
  VPANDrr = 12949,
  VPAVGBYrm = 12950,
  VPAVGBYrr = 12951,
  VPAVGBZ128rm = 12952,
  VPAVGBZ128rmk = 12953,
  VPAVGBZ128rmkz = 12954,
  VPAVGBZ128rr = 12955,
  VPAVGBZ128rrk = 12956,
  VPAVGBZ128rrkz = 12957,
  VPAVGBZ256rm = 12958,
  VPAVGBZ256rmk = 12959,
  VPAVGBZ256rmkz = 12960,
  VPAVGBZ256rr = 12961,
  VPAVGBZ256rrk = 12962,
  VPAVGBZ256rrkz = 12963,
  VPAVGBZrm = 12964,
  VPAVGBZrmk = 12965,
  VPAVGBZrmkz = 12966,
  VPAVGBZrr = 12967,
  VPAVGBZrrk = 12968,
  VPAVGBZrrkz = 12969,
  VPAVGBrm = 12970,
  VPAVGBrr = 12971,
  VPAVGWYrm = 12972,
  VPAVGWYrr = 12973,
  VPAVGWZ128rm = 12974,
  VPAVGWZ128rmk = 12975,
  VPAVGWZ128rmkz = 12976,
  VPAVGWZ128rr = 12977,
  VPAVGWZ128rrk = 12978,
  VPAVGWZ128rrkz = 12979,
  VPAVGWZ256rm = 12980,
  VPAVGWZ256rmk = 12981,
  VPAVGWZ256rmkz = 12982,
  VPAVGWZ256rr = 12983,
  VPAVGWZ256rrk = 12984,
  VPAVGWZ256rrkz = 12985,
  VPAVGWZrm = 12986,
  VPAVGWZrmk = 12987,
  VPAVGWZrmkz = 12988,
  VPAVGWZrr = 12989,
  VPAVGWZrrk = 12990,
  VPAVGWZrrkz = 12991,
  VPAVGWrm = 12992,
  VPAVGWrr = 12993,
  VPBLENDDYrmi = 12994,
  VPBLENDDYrri = 12995,
  VPBLENDDrmi = 12996,
  VPBLENDDrri = 12997,
  VPBLENDMBZ128rm = 12998,
  VPBLENDMBZ128rmk = 12999,
  VPBLENDMBZ128rmkz = 13000,
  VPBLENDMBZ128rr = 13001,
  VPBLENDMBZ128rrk = 13002,
  VPBLENDMBZ128rrkz = 13003,
  VPBLENDMBZ256rm = 13004,
  VPBLENDMBZ256rmk = 13005,
  VPBLENDMBZ256rmkz = 13006,
  VPBLENDMBZ256rr = 13007,
  VPBLENDMBZ256rrk = 13008,
  VPBLENDMBZ256rrkz = 13009,
  VPBLENDMBZrm = 13010,
  VPBLENDMBZrmk = 13011,
  VPBLENDMBZrmkz = 13012,
  VPBLENDMBZrr = 13013,
  VPBLENDMBZrrk = 13014,
  VPBLENDMBZrrkz = 13015,
  VPBLENDMDZ128rm = 13016,
  VPBLENDMDZ128rmb = 13017,
  VPBLENDMDZ128rmbk = 13018,
  VPBLENDMDZ128rmbkz = 13019,
  VPBLENDMDZ128rmk = 13020,
  VPBLENDMDZ128rmkz = 13021,
  VPBLENDMDZ128rr = 13022,
  VPBLENDMDZ128rrk = 13023,
  VPBLENDMDZ128rrkz = 13024,
  VPBLENDMDZ256rm = 13025,
  VPBLENDMDZ256rmb = 13026,
  VPBLENDMDZ256rmbk = 13027,
  VPBLENDMDZ256rmbkz = 13028,
  VPBLENDMDZ256rmk = 13029,
  VPBLENDMDZ256rmkz = 13030,
  VPBLENDMDZ256rr = 13031,
  VPBLENDMDZ256rrk = 13032,
  VPBLENDMDZ256rrkz = 13033,
  VPBLENDMDZrm = 13034,
  VPBLENDMDZrmb = 13035,
  VPBLENDMDZrmbk = 13036,
  VPBLENDMDZrmbkz = 13037,
  VPBLENDMDZrmk = 13038,
  VPBLENDMDZrmkz = 13039,
  VPBLENDMDZrr = 13040,
  VPBLENDMDZrrk = 13041,
  VPBLENDMDZrrkz = 13042,
  VPBLENDMQZ128rm = 13043,
  VPBLENDMQZ128rmb = 13044,
  VPBLENDMQZ128rmbk = 13045,
  VPBLENDMQZ128rmbkz = 13046,
  VPBLENDMQZ128rmk = 13047,
  VPBLENDMQZ128rmkz = 13048,
  VPBLENDMQZ128rr = 13049,
  VPBLENDMQZ128rrk = 13050,
  VPBLENDMQZ128rrkz = 13051,
  VPBLENDMQZ256rm = 13052,
  VPBLENDMQZ256rmb = 13053,
  VPBLENDMQZ256rmbk = 13054,
  VPBLENDMQZ256rmbkz = 13055,
  VPBLENDMQZ256rmk = 13056,
  VPBLENDMQZ256rmkz = 13057,
  VPBLENDMQZ256rr = 13058,
  VPBLENDMQZ256rrk = 13059,
  VPBLENDMQZ256rrkz = 13060,
  VPBLENDMQZrm = 13061,
  VPBLENDMQZrmb = 13062,
  VPBLENDMQZrmbk = 13063,
  VPBLENDMQZrmbkz = 13064,
  VPBLENDMQZrmk = 13065,
  VPBLENDMQZrmkz = 13066,
  VPBLENDMQZrr = 13067,
  VPBLENDMQZrrk = 13068,
  VPBLENDMQZrrkz = 13069,
  VPBLENDMWZ128rm = 13070,
  VPBLENDMWZ128rmk = 13071,
  VPBLENDMWZ128rmkz = 13072,
  VPBLENDMWZ128rr = 13073,
  VPBLENDMWZ128rrk = 13074,
  VPBLENDMWZ128rrkz = 13075,
  VPBLENDMWZ256rm = 13076,
  VPBLENDMWZ256rmk = 13077,
  VPBLENDMWZ256rmkz = 13078,
  VPBLENDMWZ256rr = 13079,
  VPBLENDMWZ256rrk = 13080,
  VPBLENDMWZ256rrkz = 13081,
  VPBLENDMWZrm = 13082,
  VPBLENDMWZrmk = 13083,
  VPBLENDMWZrmkz = 13084,
  VPBLENDMWZrr = 13085,
  VPBLENDMWZrrk = 13086,
  VPBLENDMWZrrkz = 13087,
  VPBLENDVBYrmr = 13088,
  VPBLENDVBYrrr = 13089,
  VPBLENDVBrmr = 13090,
  VPBLENDVBrrr = 13091,
  VPBLENDWYrmi = 13092,
  VPBLENDWYrri = 13093,
  VPBLENDWrmi = 13094,
  VPBLENDWrri = 13095,
  VPBROADCASTBYrm = 13096,
  VPBROADCASTBYrr = 13097,
  VPBROADCASTBZ128rm = 13098,
  VPBROADCASTBZ128rmk = 13099,
  VPBROADCASTBZ128rmkz = 13100,
  VPBROADCASTBZ128rr = 13101,
  VPBROADCASTBZ128rrk = 13102,
  VPBROADCASTBZ128rrkz = 13103,
  VPBROADCASTBZ256rm = 13104,
  VPBROADCASTBZ256rmk = 13105,
  VPBROADCASTBZ256rmkz = 13106,
  VPBROADCASTBZ256rr = 13107,
  VPBROADCASTBZ256rrk = 13108,
  VPBROADCASTBZ256rrkz = 13109,
  VPBROADCASTBZrm = 13110,
  VPBROADCASTBZrmk = 13111,
  VPBROADCASTBZrmkz = 13112,
  VPBROADCASTBZrr = 13113,
  VPBROADCASTBZrrk = 13114,
  VPBROADCASTBZrrkz = 13115,
  VPBROADCASTBrZ128rr = 13116,
  VPBROADCASTBrZ128rrk = 13117,
  VPBROADCASTBrZ128rrkz = 13118,
  VPBROADCASTBrZ256rr = 13119,
  VPBROADCASTBrZ256rrk = 13120,
  VPBROADCASTBrZ256rrkz = 13121,
  VPBROADCASTBrZrr = 13122,
  VPBROADCASTBrZrrk = 13123,
  VPBROADCASTBrZrrkz = 13124,
  VPBROADCASTBrm = 13125,
  VPBROADCASTBrr = 13126,
  VPBROADCASTDYrm = 13127,
  VPBROADCASTDYrr = 13128,
  VPBROADCASTDZ128rm = 13129,
  VPBROADCASTDZ128rmk = 13130,
  VPBROADCASTDZ128rmkz = 13131,
  VPBROADCASTDZ128rr = 13132,
  VPBROADCASTDZ128rrk = 13133,
  VPBROADCASTDZ128rrkz = 13134,
  VPBROADCASTDZ256rm = 13135,
  VPBROADCASTDZ256rmk = 13136,
  VPBROADCASTDZ256rmkz = 13137,
  VPBROADCASTDZ256rr = 13138,
  VPBROADCASTDZ256rrk = 13139,
  VPBROADCASTDZ256rrkz = 13140,
  VPBROADCASTDZrm = 13141,
  VPBROADCASTDZrmk = 13142,
  VPBROADCASTDZrmkz = 13143,
  VPBROADCASTDZrr = 13144,
  VPBROADCASTDZrrk = 13145,
  VPBROADCASTDZrrkz = 13146,
  VPBROADCASTDrZ128rr = 13147,
  VPBROADCASTDrZ128rrk = 13148,
  VPBROADCASTDrZ128rrkz = 13149,
  VPBROADCASTDrZ256rr = 13150,
  VPBROADCASTDrZ256rrk = 13151,
  VPBROADCASTDrZ256rrkz = 13152,
  VPBROADCASTDrZrr = 13153,
  VPBROADCASTDrZrrk = 13154,
  VPBROADCASTDrZrrkz = 13155,
  VPBROADCASTDrm = 13156,
  VPBROADCASTDrr = 13157,
  VPBROADCASTMB2QZ128rr = 13158,
  VPBROADCASTMB2QZ256rr = 13159,
  VPBROADCASTMB2QZrr = 13160,
  VPBROADCASTMW2DZ128rr = 13161,
  VPBROADCASTMW2DZ256rr = 13162,
  VPBROADCASTMW2DZrr = 13163,
  VPBROADCASTQYrm = 13164,
  VPBROADCASTQYrr = 13165,
  VPBROADCASTQZ128rm = 13166,
  VPBROADCASTQZ128rmk = 13167,
  VPBROADCASTQZ128rmkz = 13168,
  VPBROADCASTQZ128rr = 13169,
  VPBROADCASTQZ128rrk = 13170,
  VPBROADCASTQZ128rrkz = 13171,
  VPBROADCASTQZ256rm = 13172,
  VPBROADCASTQZ256rmk = 13173,
  VPBROADCASTQZ256rmkz = 13174,
  VPBROADCASTQZ256rr = 13175,
  VPBROADCASTQZ256rrk = 13176,
  VPBROADCASTQZ256rrkz = 13177,
  VPBROADCASTQZrm = 13178,
  VPBROADCASTQZrmk = 13179,
  VPBROADCASTQZrmkz = 13180,
  VPBROADCASTQZrr = 13181,
  VPBROADCASTQZrrk = 13182,
  VPBROADCASTQZrrkz = 13183,
  VPBROADCASTQrZ128rr = 13184,
  VPBROADCASTQrZ128rrk = 13185,
  VPBROADCASTQrZ128rrkz = 13186,
  VPBROADCASTQrZ256rr = 13187,
  VPBROADCASTQrZ256rrk = 13188,
  VPBROADCASTQrZ256rrkz = 13189,
  VPBROADCASTQrZrr = 13190,
  VPBROADCASTQrZrrk = 13191,
  VPBROADCASTQrZrrkz = 13192,
  VPBROADCASTQrm = 13193,
  VPBROADCASTQrr = 13194,
  VPBROADCASTWYrm = 13195,
  VPBROADCASTWYrr = 13196,
  VPBROADCASTWZ128rm = 13197,
  VPBROADCASTWZ128rmk = 13198,
  VPBROADCASTWZ128rmkz = 13199,
  VPBROADCASTWZ128rr = 13200,
  VPBROADCASTWZ128rrk = 13201,
  VPBROADCASTWZ128rrkz = 13202,
  VPBROADCASTWZ256rm = 13203,
  VPBROADCASTWZ256rmk = 13204,
  VPBROADCASTWZ256rmkz = 13205,
  VPBROADCASTWZ256rr = 13206,
  VPBROADCASTWZ256rrk = 13207,
  VPBROADCASTWZ256rrkz = 13208,
  VPBROADCASTWZrm = 13209,
  VPBROADCASTWZrmk = 13210,
  VPBROADCASTWZrmkz = 13211,
  VPBROADCASTWZrr = 13212,
  VPBROADCASTWZrrk = 13213,
  VPBROADCASTWZrrkz = 13214,
  VPBROADCASTWrZ128rr = 13215,
  VPBROADCASTWrZ128rrk = 13216,
  VPBROADCASTWrZ128rrkz = 13217,
  VPBROADCASTWrZ256rr = 13218,
  VPBROADCASTWrZ256rrk = 13219,
  VPBROADCASTWrZ256rrkz = 13220,
  VPBROADCASTWrZrr = 13221,
  VPBROADCASTWrZrrk = 13222,
  VPBROADCASTWrZrrkz = 13223,
  VPBROADCASTWrm = 13224,
  VPBROADCASTWrr = 13225,
  VPCLMULQDQYrmi = 13226,
  VPCLMULQDQYrri = 13227,
  VPCLMULQDQZ128rmi = 13228,
  VPCLMULQDQZ128rri = 13229,
  VPCLMULQDQZ256rmi = 13230,
  VPCLMULQDQZ256rri = 13231,
  VPCLMULQDQZrmi = 13232,
  VPCLMULQDQZrri = 13233,
  VPCLMULQDQrmi = 13234,
  VPCLMULQDQrri = 13235,
  VPCMOVYrmr = 13236,
  VPCMOVYrrm = 13237,
  VPCMOVYrrr = 13238,
  VPCMOVYrrr_REV = 13239,
  VPCMOVrmr = 13240,
  VPCMOVrrm = 13241,
  VPCMOVrrr = 13242,
  VPCMOVrrr_REV = 13243,
  VPCMPBZ128rmi = 13244,
  VPCMPBZ128rmik = 13245,
  VPCMPBZ128rri = 13246,
  VPCMPBZ128rrik = 13247,
  VPCMPBZ256rmi = 13248,
  VPCMPBZ256rmik = 13249,
  VPCMPBZ256rri = 13250,
  VPCMPBZ256rrik = 13251,
  VPCMPBZrmi = 13252,
  VPCMPBZrmik = 13253,
  VPCMPBZrri = 13254,
  VPCMPBZrrik = 13255,
  VPCMPDZ128rmi = 13256,
  VPCMPDZ128rmib = 13257,
  VPCMPDZ128rmibk = 13258,
  VPCMPDZ128rmik = 13259,
  VPCMPDZ128rri = 13260,
  VPCMPDZ128rrik = 13261,
  VPCMPDZ256rmi = 13262,
  VPCMPDZ256rmib = 13263,
  VPCMPDZ256rmibk = 13264,
  VPCMPDZ256rmik = 13265,
  VPCMPDZ256rri = 13266,
  VPCMPDZ256rrik = 13267,
  VPCMPDZrmi = 13268,
  VPCMPDZrmib = 13269,
  VPCMPDZrmibk = 13270,
  VPCMPDZrmik = 13271,
  VPCMPDZrri = 13272,
  VPCMPDZrrik = 13273,
  VPCMPEQBYrm = 13274,
  VPCMPEQBYrr = 13275,
  VPCMPEQBZ128rm = 13276,
  VPCMPEQBZ128rmk = 13277,
  VPCMPEQBZ128rr = 13278,
  VPCMPEQBZ128rrk = 13279,
  VPCMPEQBZ256rm = 13280,
  VPCMPEQBZ256rmk = 13281,
  VPCMPEQBZ256rr = 13282,
  VPCMPEQBZ256rrk = 13283,
  VPCMPEQBZrm = 13284,
  VPCMPEQBZrmk = 13285,
  VPCMPEQBZrr = 13286,
  VPCMPEQBZrrk = 13287,
  VPCMPEQBrm = 13288,
  VPCMPEQBrr = 13289,
  VPCMPEQDYrm = 13290,
  VPCMPEQDYrr = 13291,
  VPCMPEQDZ128rm = 13292,
  VPCMPEQDZ128rmb = 13293,
  VPCMPEQDZ128rmbk = 13294,
  VPCMPEQDZ128rmk = 13295,
  VPCMPEQDZ128rr = 13296,
  VPCMPEQDZ128rrk = 13297,
  VPCMPEQDZ256rm = 13298,
  VPCMPEQDZ256rmb = 13299,
  VPCMPEQDZ256rmbk = 13300,
  VPCMPEQDZ256rmk = 13301,
  VPCMPEQDZ256rr = 13302,
  VPCMPEQDZ256rrk = 13303,
  VPCMPEQDZrm = 13304,
  VPCMPEQDZrmb = 13305,
  VPCMPEQDZrmbk = 13306,
  VPCMPEQDZrmk = 13307,
  VPCMPEQDZrr = 13308,
  VPCMPEQDZrrk = 13309,
  VPCMPEQDrm = 13310,
  VPCMPEQDrr = 13311,
  VPCMPEQQYrm = 13312,
  VPCMPEQQYrr = 13313,
  VPCMPEQQZ128rm = 13314,
  VPCMPEQQZ128rmb = 13315,
  VPCMPEQQZ128rmbk = 13316,
  VPCMPEQQZ128rmk = 13317,
  VPCMPEQQZ128rr = 13318,
  VPCMPEQQZ128rrk = 13319,
  VPCMPEQQZ256rm = 13320,
  VPCMPEQQZ256rmb = 13321,
  VPCMPEQQZ256rmbk = 13322,
  VPCMPEQQZ256rmk = 13323,
  VPCMPEQQZ256rr = 13324,
  VPCMPEQQZ256rrk = 13325,
  VPCMPEQQZrm = 13326,
  VPCMPEQQZrmb = 13327,
  VPCMPEQQZrmbk = 13328,
  VPCMPEQQZrmk = 13329,
  VPCMPEQQZrr = 13330,
  VPCMPEQQZrrk = 13331,
  VPCMPEQQrm = 13332,
  VPCMPEQQrr = 13333,
  VPCMPEQWYrm = 13334,
  VPCMPEQWYrr = 13335,
  VPCMPEQWZ128rm = 13336,
  VPCMPEQWZ128rmk = 13337,
  VPCMPEQWZ128rr = 13338,
  VPCMPEQWZ128rrk = 13339,
  VPCMPEQWZ256rm = 13340,
  VPCMPEQWZ256rmk = 13341,
  VPCMPEQWZ256rr = 13342,
  VPCMPEQWZ256rrk = 13343,
  VPCMPEQWZrm = 13344,
  VPCMPEQWZrmk = 13345,
  VPCMPEQWZrr = 13346,
  VPCMPEQWZrrk = 13347,
  VPCMPEQWrm = 13348,
  VPCMPEQWrr = 13349,
  VPCMPESTRIrmi = 13350,
  VPCMPESTRIrri = 13351,
  VPCMPESTRMrmi = 13352,
  VPCMPESTRMrri = 13353,
  VPCMPGTBYrm = 13354,
  VPCMPGTBYrr = 13355,
  VPCMPGTBZ128rm = 13356,
  VPCMPGTBZ128rmk = 13357,
  VPCMPGTBZ128rr = 13358,
  VPCMPGTBZ128rrk = 13359,
  VPCMPGTBZ256rm = 13360,
  VPCMPGTBZ256rmk = 13361,
  VPCMPGTBZ256rr = 13362,
  VPCMPGTBZ256rrk = 13363,
  VPCMPGTBZrm = 13364,
  VPCMPGTBZrmk = 13365,
  VPCMPGTBZrr = 13366,
  VPCMPGTBZrrk = 13367,
  VPCMPGTBrm = 13368,
  VPCMPGTBrr = 13369,
  VPCMPGTDYrm = 13370,
  VPCMPGTDYrr = 13371,
  VPCMPGTDZ128rm = 13372,
  VPCMPGTDZ128rmb = 13373,
  VPCMPGTDZ128rmbk = 13374,
  VPCMPGTDZ128rmk = 13375,
  VPCMPGTDZ128rr = 13376,
  VPCMPGTDZ128rrk = 13377,
  VPCMPGTDZ256rm = 13378,
  VPCMPGTDZ256rmb = 13379,
  VPCMPGTDZ256rmbk = 13380,
  VPCMPGTDZ256rmk = 13381,
  VPCMPGTDZ256rr = 13382,
  VPCMPGTDZ256rrk = 13383,
  VPCMPGTDZrm = 13384,
  VPCMPGTDZrmb = 13385,
  VPCMPGTDZrmbk = 13386,
  VPCMPGTDZrmk = 13387,
  VPCMPGTDZrr = 13388,
  VPCMPGTDZrrk = 13389,
  VPCMPGTDrm = 13390,
  VPCMPGTDrr = 13391,
  VPCMPGTQYrm = 13392,
  VPCMPGTQYrr = 13393,
  VPCMPGTQZ128rm = 13394,
  VPCMPGTQZ128rmb = 13395,
  VPCMPGTQZ128rmbk = 13396,
  VPCMPGTQZ128rmk = 13397,
  VPCMPGTQZ128rr = 13398,
  VPCMPGTQZ128rrk = 13399,
  VPCMPGTQZ256rm = 13400,
  VPCMPGTQZ256rmb = 13401,
  VPCMPGTQZ256rmbk = 13402,
  VPCMPGTQZ256rmk = 13403,
  VPCMPGTQZ256rr = 13404,
  VPCMPGTQZ256rrk = 13405,
  VPCMPGTQZrm = 13406,
  VPCMPGTQZrmb = 13407,
  VPCMPGTQZrmbk = 13408,
  VPCMPGTQZrmk = 13409,
  VPCMPGTQZrr = 13410,
  VPCMPGTQZrrk = 13411,
  VPCMPGTQrm = 13412,
  VPCMPGTQrr = 13413,
  VPCMPGTWYrm = 13414,
  VPCMPGTWYrr = 13415,
  VPCMPGTWZ128rm = 13416,
  VPCMPGTWZ128rmk = 13417,
  VPCMPGTWZ128rr = 13418,
  VPCMPGTWZ128rrk = 13419,
  VPCMPGTWZ256rm = 13420,
  VPCMPGTWZ256rmk = 13421,
  VPCMPGTWZ256rr = 13422,
  VPCMPGTWZ256rrk = 13423,
  VPCMPGTWZrm = 13424,
  VPCMPGTWZrmk = 13425,
  VPCMPGTWZrr = 13426,
  VPCMPGTWZrrk = 13427,
  VPCMPGTWrm = 13428,
  VPCMPGTWrr = 13429,
  VPCMPISTRIrmi = 13430,
  VPCMPISTRIrri = 13431,
  VPCMPISTRMrmi = 13432,
  VPCMPISTRMrri = 13433,
  VPCMPQZ128rmi = 13434,
  VPCMPQZ128rmib = 13435,
  VPCMPQZ128rmibk = 13436,
  VPCMPQZ128rmik = 13437,
  VPCMPQZ128rri = 13438,
  VPCMPQZ128rrik = 13439,
  VPCMPQZ256rmi = 13440,
  VPCMPQZ256rmib = 13441,
  VPCMPQZ256rmibk = 13442,
  VPCMPQZ256rmik = 13443,
  VPCMPQZ256rri = 13444,
  VPCMPQZ256rrik = 13445,
  VPCMPQZrmi = 13446,
  VPCMPQZrmib = 13447,
  VPCMPQZrmibk = 13448,
  VPCMPQZrmik = 13449,
  VPCMPQZrri = 13450,
  VPCMPQZrrik = 13451,
  VPCMPUBZ128rmi = 13452,
  VPCMPUBZ128rmik = 13453,
  VPCMPUBZ128rri = 13454,
  VPCMPUBZ128rrik = 13455,
  VPCMPUBZ256rmi = 13456,
  VPCMPUBZ256rmik = 13457,
  VPCMPUBZ256rri = 13458,
  VPCMPUBZ256rrik = 13459,
  VPCMPUBZrmi = 13460,
  VPCMPUBZrmik = 13461,
  VPCMPUBZrri = 13462,
  VPCMPUBZrrik = 13463,
  VPCMPUDZ128rmi = 13464,
  VPCMPUDZ128rmib = 13465,
  VPCMPUDZ128rmibk = 13466,
  VPCMPUDZ128rmik = 13467,
  VPCMPUDZ128rri = 13468,
  VPCMPUDZ128rrik = 13469,
  VPCMPUDZ256rmi = 13470,
  VPCMPUDZ256rmib = 13471,
  VPCMPUDZ256rmibk = 13472,
  VPCMPUDZ256rmik = 13473,
  VPCMPUDZ256rri = 13474,
  VPCMPUDZ256rrik = 13475,
  VPCMPUDZrmi = 13476,
  VPCMPUDZrmib = 13477,
  VPCMPUDZrmibk = 13478,
  VPCMPUDZrmik = 13479,
  VPCMPUDZrri = 13480,
  VPCMPUDZrrik = 13481,
  VPCMPUQZ128rmi = 13482,
  VPCMPUQZ128rmib = 13483,
  VPCMPUQZ128rmibk = 13484,
  VPCMPUQZ128rmik = 13485,
  VPCMPUQZ128rri = 13486,
  VPCMPUQZ128rrik = 13487,
  VPCMPUQZ256rmi = 13488,
  VPCMPUQZ256rmib = 13489,
  VPCMPUQZ256rmibk = 13490,
  VPCMPUQZ256rmik = 13491,
  VPCMPUQZ256rri = 13492,
  VPCMPUQZ256rrik = 13493,
  VPCMPUQZrmi = 13494,
  VPCMPUQZrmib = 13495,
  VPCMPUQZrmibk = 13496,
  VPCMPUQZrmik = 13497,
  VPCMPUQZrri = 13498,
  VPCMPUQZrrik = 13499,
  VPCMPUWZ128rmi = 13500,
  VPCMPUWZ128rmik = 13501,
  VPCMPUWZ128rri = 13502,
  VPCMPUWZ128rrik = 13503,
  VPCMPUWZ256rmi = 13504,
  VPCMPUWZ256rmik = 13505,
  VPCMPUWZ256rri = 13506,
  VPCMPUWZ256rrik = 13507,
  VPCMPUWZrmi = 13508,
  VPCMPUWZrmik = 13509,
  VPCMPUWZrri = 13510,
  VPCMPUWZrrik = 13511,
  VPCMPWZ128rmi = 13512,
  VPCMPWZ128rmik = 13513,
  VPCMPWZ128rri = 13514,
  VPCMPWZ128rrik = 13515,
  VPCMPWZ256rmi = 13516,
  VPCMPWZ256rmik = 13517,
  VPCMPWZ256rri = 13518,
  VPCMPWZ256rrik = 13519,
  VPCMPWZrmi = 13520,
  VPCMPWZrmik = 13521,
  VPCMPWZrri = 13522,
  VPCMPWZrrik = 13523,
  VPCOMBmi = 13524,
  VPCOMBri = 13525,
  VPCOMDmi = 13526,
  VPCOMDri = 13527,
  VPCOMPRESSBZ128mr = 13528,
  VPCOMPRESSBZ128mrk = 13529,
  VPCOMPRESSBZ128rr = 13530,
  VPCOMPRESSBZ128rrk = 13531,
  VPCOMPRESSBZ128rrkz = 13532,
  VPCOMPRESSBZ256mr = 13533,
  VPCOMPRESSBZ256mrk = 13534,
  VPCOMPRESSBZ256rr = 13535,
  VPCOMPRESSBZ256rrk = 13536,
  VPCOMPRESSBZ256rrkz = 13537,
  VPCOMPRESSBZmr = 13538,
  VPCOMPRESSBZmrk = 13539,
  VPCOMPRESSBZrr = 13540,
  VPCOMPRESSBZrrk = 13541,
  VPCOMPRESSBZrrkz = 13542,
  VPCOMPRESSDZ128mr = 13543,
  VPCOMPRESSDZ128mrk = 13544,
  VPCOMPRESSDZ128rr = 13545,
  VPCOMPRESSDZ128rrk = 13546,
  VPCOMPRESSDZ128rrkz = 13547,
  VPCOMPRESSDZ256mr = 13548,
  VPCOMPRESSDZ256mrk = 13549,
  VPCOMPRESSDZ256rr = 13550,
  VPCOMPRESSDZ256rrk = 13551,
  VPCOMPRESSDZ256rrkz = 13552,
  VPCOMPRESSDZmr = 13553,
  VPCOMPRESSDZmrk = 13554,
  VPCOMPRESSDZrr = 13555,
  VPCOMPRESSDZrrk = 13556,
  VPCOMPRESSDZrrkz = 13557,
  VPCOMPRESSQZ128mr = 13558,
  VPCOMPRESSQZ128mrk = 13559,
  VPCOMPRESSQZ128rr = 13560,
  VPCOMPRESSQZ128rrk = 13561,
  VPCOMPRESSQZ128rrkz = 13562,
  VPCOMPRESSQZ256mr = 13563,
  VPCOMPRESSQZ256mrk = 13564,
  VPCOMPRESSQZ256rr = 13565,
  VPCOMPRESSQZ256rrk = 13566,
  VPCOMPRESSQZ256rrkz = 13567,
  VPCOMPRESSQZmr = 13568,
  VPCOMPRESSQZmrk = 13569,
  VPCOMPRESSQZrr = 13570,
  VPCOMPRESSQZrrk = 13571,
  VPCOMPRESSQZrrkz = 13572,
  VPCOMPRESSWZ128mr = 13573,
  VPCOMPRESSWZ128mrk = 13574,
  VPCOMPRESSWZ128rr = 13575,
  VPCOMPRESSWZ128rrk = 13576,
  VPCOMPRESSWZ128rrkz = 13577,
  VPCOMPRESSWZ256mr = 13578,
  VPCOMPRESSWZ256mrk = 13579,
  VPCOMPRESSWZ256rr = 13580,
  VPCOMPRESSWZ256rrk = 13581,
  VPCOMPRESSWZ256rrkz = 13582,
  VPCOMPRESSWZmr = 13583,
  VPCOMPRESSWZmrk = 13584,
  VPCOMPRESSWZrr = 13585,
  VPCOMPRESSWZrrk = 13586,
  VPCOMPRESSWZrrkz = 13587,
  VPCOMQmi = 13588,
  VPCOMQri = 13589,
  VPCOMUBmi = 13590,
  VPCOMUBri = 13591,
  VPCOMUDmi = 13592,
  VPCOMUDri = 13593,
  VPCOMUQmi = 13594,
  VPCOMUQri = 13595,
  VPCOMUWmi = 13596,
  VPCOMUWri = 13597,
  VPCOMWmi = 13598,
  VPCOMWri = 13599,
  VPCONFLICTDZ128rm = 13600,
  VPCONFLICTDZ128rmb = 13601,
  VPCONFLICTDZ128rmbk = 13602,
  VPCONFLICTDZ128rmbkz = 13603,
  VPCONFLICTDZ128rmk = 13604,
  VPCONFLICTDZ128rmkz = 13605,
  VPCONFLICTDZ128rr = 13606,
  VPCONFLICTDZ128rrk = 13607,
  VPCONFLICTDZ128rrkz = 13608,
  VPCONFLICTDZ256rm = 13609,
  VPCONFLICTDZ256rmb = 13610,
  VPCONFLICTDZ256rmbk = 13611,
  VPCONFLICTDZ256rmbkz = 13612,
  VPCONFLICTDZ256rmk = 13613,
  VPCONFLICTDZ256rmkz = 13614,
  VPCONFLICTDZ256rr = 13615,
  VPCONFLICTDZ256rrk = 13616,
  VPCONFLICTDZ256rrkz = 13617,
  VPCONFLICTDZrm = 13618,
  VPCONFLICTDZrmb = 13619,
  VPCONFLICTDZrmbk = 13620,
  VPCONFLICTDZrmbkz = 13621,
  VPCONFLICTDZrmk = 13622,
  VPCONFLICTDZrmkz = 13623,
  VPCONFLICTDZrr = 13624,
  VPCONFLICTDZrrk = 13625,
  VPCONFLICTDZrrkz = 13626,
  VPCONFLICTQZ128rm = 13627,
  VPCONFLICTQZ128rmb = 13628,
  VPCONFLICTQZ128rmbk = 13629,
  VPCONFLICTQZ128rmbkz = 13630,
  VPCONFLICTQZ128rmk = 13631,
  VPCONFLICTQZ128rmkz = 13632,
  VPCONFLICTQZ128rr = 13633,
  VPCONFLICTQZ128rrk = 13634,
  VPCONFLICTQZ128rrkz = 13635,
  VPCONFLICTQZ256rm = 13636,
  VPCONFLICTQZ256rmb = 13637,
  VPCONFLICTQZ256rmbk = 13638,
  VPCONFLICTQZ256rmbkz = 13639,
  VPCONFLICTQZ256rmk = 13640,
  VPCONFLICTQZ256rmkz = 13641,
  VPCONFLICTQZ256rr = 13642,
  VPCONFLICTQZ256rrk = 13643,
  VPCONFLICTQZ256rrkz = 13644,
  VPCONFLICTQZrm = 13645,
  VPCONFLICTQZrmb = 13646,
  VPCONFLICTQZrmbk = 13647,
  VPCONFLICTQZrmbkz = 13648,
  VPCONFLICTQZrmk = 13649,
  VPCONFLICTQZrmkz = 13650,
  VPCONFLICTQZrr = 13651,
  VPCONFLICTQZrrk = 13652,
  VPCONFLICTQZrrkz = 13653,
  VPDPBSSDSYrm = 13654,
  VPDPBSSDSYrr = 13655,
  VPDPBSSDSrm = 13656,
  VPDPBSSDSrr = 13657,
  VPDPBSSDYrm = 13658,
  VPDPBSSDYrr = 13659,
  VPDPBSSDrm = 13660,
  VPDPBSSDrr = 13661,
  VPDPBSUDSYrm = 13662,
  VPDPBSUDSYrr = 13663,
  VPDPBSUDSrm = 13664,
  VPDPBSUDSrr = 13665,
  VPDPBSUDYrm = 13666,
  VPDPBSUDYrr = 13667,
  VPDPBSUDrm = 13668,
  VPDPBSUDrr = 13669,
  VPDPBUSDSYrm = 13670,
  VPDPBUSDSYrr = 13671,
  VPDPBUSDSZ128m = 13672,
  VPDPBUSDSZ128mb = 13673,
  VPDPBUSDSZ128mbk = 13674,
  VPDPBUSDSZ128mbkz = 13675,
  VPDPBUSDSZ128mk = 13676,
  VPDPBUSDSZ128mkz = 13677,
  VPDPBUSDSZ128r = 13678,
  VPDPBUSDSZ128rk = 13679,
  VPDPBUSDSZ128rkz = 13680,
  VPDPBUSDSZ256m = 13681,
  VPDPBUSDSZ256mb = 13682,
  VPDPBUSDSZ256mbk = 13683,
  VPDPBUSDSZ256mbkz = 13684,
  VPDPBUSDSZ256mk = 13685,
  VPDPBUSDSZ256mkz = 13686,
  VPDPBUSDSZ256r = 13687,
  VPDPBUSDSZ256rk = 13688,
  VPDPBUSDSZ256rkz = 13689,
  VPDPBUSDSZm = 13690,
  VPDPBUSDSZmb = 13691,
  VPDPBUSDSZmbk = 13692,
  VPDPBUSDSZmbkz = 13693,
  VPDPBUSDSZmk = 13694,
  VPDPBUSDSZmkz = 13695,
  VPDPBUSDSZr = 13696,
  VPDPBUSDSZrk = 13697,
  VPDPBUSDSZrkz = 13698,
  VPDPBUSDSrm = 13699,
  VPDPBUSDSrr = 13700,
  VPDPBUSDYrm = 13701,
  VPDPBUSDYrr = 13702,
  VPDPBUSDZ128m = 13703,
  VPDPBUSDZ128mb = 13704,
  VPDPBUSDZ128mbk = 13705,
  VPDPBUSDZ128mbkz = 13706,
  VPDPBUSDZ128mk = 13707,
  VPDPBUSDZ128mkz = 13708,
  VPDPBUSDZ128r = 13709,
  VPDPBUSDZ128rk = 13710,
  VPDPBUSDZ128rkz = 13711,
  VPDPBUSDZ256m = 13712,
  VPDPBUSDZ256mb = 13713,
  VPDPBUSDZ256mbk = 13714,
  VPDPBUSDZ256mbkz = 13715,
  VPDPBUSDZ256mk = 13716,
  VPDPBUSDZ256mkz = 13717,
  VPDPBUSDZ256r = 13718,
  VPDPBUSDZ256rk = 13719,
  VPDPBUSDZ256rkz = 13720,
  VPDPBUSDZm = 13721,
  VPDPBUSDZmb = 13722,
  VPDPBUSDZmbk = 13723,
  VPDPBUSDZmbkz = 13724,
  VPDPBUSDZmk = 13725,
  VPDPBUSDZmkz = 13726,
  VPDPBUSDZr = 13727,
  VPDPBUSDZrk = 13728,
  VPDPBUSDZrkz = 13729,
  VPDPBUSDrm = 13730,
  VPDPBUSDrr = 13731,
  VPDPBUUDSYrm = 13732,
  VPDPBUUDSYrr = 13733,
  VPDPBUUDSrm = 13734,
  VPDPBUUDSrr = 13735,
  VPDPBUUDYrm = 13736,
  VPDPBUUDYrr = 13737,
  VPDPBUUDrm = 13738,
  VPDPBUUDrr = 13739,
  VPDPWSSDSYrm = 13740,
  VPDPWSSDSYrr = 13741,
  VPDPWSSDSZ128m = 13742,
  VPDPWSSDSZ128mb = 13743,
  VPDPWSSDSZ128mbk = 13744,
  VPDPWSSDSZ128mbkz = 13745,
  VPDPWSSDSZ128mk = 13746,
  VPDPWSSDSZ128mkz = 13747,
  VPDPWSSDSZ128r = 13748,
  VPDPWSSDSZ128rk = 13749,
  VPDPWSSDSZ128rkz = 13750,
  VPDPWSSDSZ256m = 13751,
  VPDPWSSDSZ256mb = 13752,
  VPDPWSSDSZ256mbk = 13753,
  VPDPWSSDSZ256mbkz = 13754,
  VPDPWSSDSZ256mk = 13755,
  VPDPWSSDSZ256mkz = 13756,
  VPDPWSSDSZ256r = 13757,
  VPDPWSSDSZ256rk = 13758,
  VPDPWSSDSZ256rkz = 13759,
  VPDPWSSDSZm = 13760,
  VPDPWSSDSZmb = 13761,
  VPDPWSSDSZmbk = 13762,
  VPDPWSSDSZmbkz = 13763,
  VPDPWSSDSZmk = 13764,
  VPDPWSSDSZmkz = 13765,
  VPDPWSSDSZr = 13766,
  VPDPWSSDSZrk = 13767,
  VPDPWSSDSZrkz = 13768,
  VPDPWSSDSrm = 13769,
  VPDPWSSDSrr = 13770,
  VPDPWSSDYrm = 13771,
  VPDPWSSDYrr = 13772,
  VPDPWSSDZ128m = 13773,
  VPDPWSSDZ128mb = 13774,
  VPDPWSSDZ128mbk = 13775,
  VPDPWSSDZ128mbkz = 13776,
  VPDPWSSDZ128mk = 13777,
  VPDPWSSDZ128mkz = 13778,
  VPDPWSSDZ128r = 13779,
  VPDPWSSDZ128rk = 13780,
  VPDPWSSDZ128rkz = 13781,
  VPDPWSSDZ256m = 13782,
  VPDPWSSDZ256mb = 13783,
  VPDPWSSDZ256mbk = 13784,
  VPDPWSSDZ256mbkz = 13785,
  VPDPWSSDZ256mk = 13786,
  VPDPWSSDZ256mkz = 13787,
  VPDPWSSDZ256r = 13788,
  VPDPWSSDZ256rk = 13789,
  VPDPWSSDZ256rkz = 13790,
  VPDPWSSDZm = 13791,
  VPDPWSSDZmb = 13792,
  VPDPWSSDZmbk = 13793,
  VPDPWSSDZmbkz = 13794,
  VPDPWSSDZmk = 13795,
  VPDPWSSDZmkz = 13796,
  VPDPWSSDZr = 13797,
  VPDPWSSDZrk = 13798,
  VPDPWSSDZrkz = 13799,
  VPDPWSSDrm = 13800,
  VPDPWSSDrr = 13801,
  VPDPWSUDSYrm = 13802,
  VPDPWSUDSYrr = 13803,
  VPDPWSUDSrm = 13804,
  VPDPWSUDSrr = 13805,
  VPDPWSUDYrm = 13806,
  VPDPWSUDYrr = 13807,
  VPDPWSUDrm = 13808,
  VPDPWSUDrr = 13809,
  VPDPWUSDSYrm = 13810,
  VPDPWUSDSYrr = 13811,
  VPDPWUSDSrm = 13812,
  VPDPWUSDSrr = 13813,
  VPDPWUSDYrm = 13814,
  VPDPWUSDYrr = 13815,
  VPDPWUSDrm = 13816,
  VPDPWUSDrr = 13817,
  VPDPWUUDSYrm = 13818,
  VPDPWUUDSYrr = 13819,
  VPDPWUUDSrm = 13820,
  VPDPWUUDSrr = 13821,
  VPDPWUUDYrm = 13822,
  VPDPWUUDYrr = 13823,
  VPDPWUUDrm = 13824,
  VPDPWUUDrr = 13825,
  VPERM2F128rm = 13826,
  VPERM2F128rr = 13827,
  VPERM2I128rm = 13828,
  VPERM2I128rr = 13829,
  VPERMBZ128rm = 13830,
  VPERMBZ128rmk = 13831,
  VPERMBZ128rmkz = 13832,
  VPERMBZ128rr = 13833,
  VPERMBZ128rrk = 13834,
  VPERMBZ128rrkz = 13835,
  VPERMBZ256rm = 13836,
  VPERMBZ256rmk = 13837,
  VPERMBZ256rmkz = 13838,
  VPERMBZ256rr = 13839,
  VPERMBZ256rrk = 13840,
  VPERMBZ256rrkz = 13841,
  VPERMBZrm = 13842,
  VPERMBZrmk = 13843,
  VPERMBZrmkz = 13844,
  VPERMBZrr = 13845,
  VPERMBZrrk = 13846,
  VPERMBZrrkz = 13847,
  VPERMDYrm = 13848,
  VPERMDYrr = 13849,
  VPERMDZ256rm = 13850,
  VPERMDZ256rmb = 13851,
  VPERMDZ256rmbk = 13852,
  VPERMDZ256rmbkz = 13853,
  VPERMDZ256rmk = 13854,
  VPERMDZ256rmkz = 13855,
  VPERMDZ256rr = 13856,
  VPERMDZ256rrk = 13857,
  VPERMDZ256rrkz = 13858,
  VPERMDZrm = 13859,
  VPERMDZrmb = 13860,
  VPERMDZrmbk = 13861,
  VPERMDZrmbkz = 13862,
  VPERMDZrmk = 13863,
  VPERMDZrmkz = 13864,
  VPERMDZrr = 13865,
  VPERMDZrrk = 13866,
  VPERMDZrrkz = 13867,
  VPERMI2BZ128rm = 13868,
  VPERMI2BZ128rmk = 13869,
  VPERMI2BZ128rmkz = 13870,
  VPERMI2BZ128rr = 13871,
  VPERMI2BZ128rrk = 13872,
  VPERMI2BZ128rrkz = 13873,
  VPERMI2BZ256rm = 13874,
  VPERMI2BZ256rmk = 13875,
  VPERMI2BZ256rmkz = 13876,
  VPERMI2BZ256rr = 13877,
  VPERMI2BZ256rrk = 13878,
  VPERMI2BZ256rrkz = 13879,
  VPERMI2BZrm = 13880,
  VPERMI2BZrmk = 13881,
  VPERMI2BZrmkz = 13882,
  VPERMI2BZrr = 13883,
  VPERMI2BZrrk = 13884,
  VPERMI2BZrrkz = 13885,
  VPERMI2DZ128rm = 13886,
  VPERMI2DZ128rmb = 13887,
  VPERMI2DZ128rmbk = 13888,
  VPERMI2DZ128rmbkz = 13889,
  VPERMI2DZ128rmk = 13890,
  VPERMI2DZ128rmkz = 13891,
  VPERMI2DZ128rr = 13892,
  VPERMI2DZ128rrk = 13893,
  VPERMI2DZ128rrkz = 13894,
  VPERMI2DZ256rm = 13895,
  VPERMI2DZ256rmb = 13896,
  VPERMI2DZ256rmbk = 13897,
  VPERMI2DZ256rmbkz = 13898,
  VPERMI2DZ256rmk = 13899,
  VPERMI2DZ256rmkz = 13900,
  VPERMI2DZ256rr = 13901,
  VPERMI2DZ256rrk = 13902,
  VPERMI2DZ256rrkz = 13903,
  VPERMI2DZrm = 13904,
  VPERMI2DZrmb = 13905,
  VPERMI2DZrmbk = 13906,
  VPERMI2DZrmbkz = 13907,
  VPERMI2DZrmk = 13908,
  VPERMI2DZrmkz = 13909,
  VPERMI2DZrr = 13910,
  VPERMI2DZrrk = 13911,
  VPERMI2DZrrkz = 13912,
  VPERMI2PDZ128rm = 13913,
  VPERMI2PDZ128rmb = 13914,
  VPERMI2PDZ128rmbk = 13915,
  VPERMI2PDZ128rmbkz = 13916,
  VPERMI2PDZ128rmk = 13917,
  VPERMI2PDZ128rmkz = 13918,
  VPERMI2PDZ128rr = 13919,
  VPERMI2PDZ128rrk = 13920,
  VPERMI2PDZ128rrkz = 13921,
  VPERMI2PDZ256rm = 13922,
  VPERMI2PDZ256rmb = 13923,
  VPERMI2PDZ256rmbk = 13924,
  VPERMI2PDZ256rmbkz = 13925,
  VPERMI2PDZ256rmk = 13926,
  VPERMI2PDZ256rmkz = 13927,
  VPERMI2PDZ256rr = 13928,
  VPERMI2PDZ256rrk = 13929,
  VPERMI2PDZ256rrkz = 13930,
  VPERMI2PDZrm = 13931,
  VPERMI2PDZrmb = 13932,
  VPERMI2PDZrmbk = 13933,
  VPERMI2PDZrmbkz = 13934,
  VPERMI2PDZrmk = 13935,
  VPERMI2PDZrmkz = 13936,
  VPERMI2PDZrr = 13937,
  VPERMI2PDZrrk = 13938,
  VPERMI2PDZrrkz = 13939,
  VPERMI2PSZ128rm = 13940,
  VPERMI2PSZ128rmb = 13941,
  VPERMI2PSZ128rmbk = 13942,
  VPERMI2PSZ128rmbkz = 13943,
  VPERMI2PSZ128rmk = 13944,
  VPERMI2PSZ128rmkz = 13945,
  VPERMI2PSZ128rr = 13946,
  VPERMI2PSZ128rrk = 13947,
  VPERMI2PSZ128rrkz = 13948,
  VPERMI2PSZ256rm = 13949,
  VPERMI2PSZ256rmb = 13950,
  VPERMI2PSZ256rmbk = 13951,
  VPERMI2PSZ256rmbkz = 13952,
  VPERMI2PSZ256rmk = 13953,
  VPERMI2PSZ256rmkz = 13954,
  VPERMI2PSZ256rr = 13955,
  VPERMI2PSZ256rrk = 13956,
  VPERMI2PSZ256rrkz = 13957,
  VPERMI2PSZrm = 13958,
  VPERMI2PSZrmb = 13959,
  VPERMI2PSZrmbk = 13960,
  VPERMI2PSZrmbkz = 13961,
  VPERMI2PSZrmk = 13962,
  VPERMI2PSZrmkz = 13963,
  VPERMI2PSZrr = 13964,
  VPERMI2PSZrrk = 13965,
  VPERMI2PSZrrkz = 13966,
  VPERMI2QZ128rm = 13967,
  VPERMI2QZ128rmb = 13968,
  VPERMI2QZ128rmbk = 13969,
  VPERMI2QZ128rmbkz = 13970,
  VPERMI2QZ128rmk = 13971,
  VPERMI2QZ128rmkz = 13972,
  VPERMI2QZ128rr = 13973,
  VPERMI2QZ128rrk = 13974,
  VPERMI2QZ128rrkz = 13975,
  VPERMI2QZ256rm = 13976,
  VPERMI2QZ256rmb = 13977,
  VPERMI2QZ256rmbk = 13978,
  VPERMI2QZ256rmbkz = 13979,
  VPERMI2QZ256rmk = 13980,
  VPERMI2QZ256rmkz = 13981,
  VPERMI2QZ256rr = 13982,
  VPERMI2QZ256rrk = 13983,
  VPERMI2QZ256rrkz = 13984,
  VPERMI2QZrm = 13985,
  VPERMI2QZrmb = 13986,
  VPERMI2QZrmbk = 13987,
  VPERMI2QZrmbkz = 13988,
  VPERMI2QZrmk = 13989,
  VPERMI2QZrmkz = 13990,
  VPERMI2QZrr = 13991,
  VPERMI2QZrrk = 13992,
  VPERMI2QZrrkz = 13993,
  VPERMI2WZ128rm = 13994,
  VPERMI2WZ128rmk = 13995,
  VPERMI2WZ128rmkz = 13996,
  VPERMI2WZ128rr = 13997,
  VPERMI2WZ128rrk = 13998,
  VPERMI2WZ128rrkz = 13999,
  VPERMI2WZ256rm = 14000,
  VPERMI2WZ256rmk = 14001,
  VPERMI2WZ256rmkz = 14002,
  VPERMI2WZ256rr = 14003,
  VPERMI2WZ256rrk = 14004,
  VPERMI2WZ256rrkz = 14005,
  VPERMI2WZrm = 14006,
  VPERMI2WZrmk = 14007,
  VPERMI2WZrmkz = 14008,
  VPERMI2WZrr = 14009,
  VPERMI2WZrrk = 14010,
  VPERMI2WZrrkz = 14011,
  VPERMIL2PDYmr = 14012,
  VPERMIL2PDYrm = 14013,
  VPERMIL2PDYrr = 14014,
  VPERMIL2PDYrr_REV = 14015,
  VPERMIL2PDmr = 14016,
  VPERMIL2PDrm = 14017,
  VPERMIL2PDrr = 14018,
  VPERMIL2PDrr_REV = 14019,
  VPERMIL2PSYmr = 14020,
  VPERMIL2PSYrm = 14021,
  VPERMIL2PSYrr = 14022,
  VPERMIL2PSYrr_REV = 14023,
  VPERMIL2PSmr = 14024,
  VPERMIL2PSrm = 14025,
  VPERMIL2PSrr = 14026,
  VPERMIL2PSrr_REV = 14027,
  VPERMILPDYmi = 14028,
  VPERMILPDYri = 14029,
  VPERMILPDYrm = 14030,
  VPERMILPDYrr = 14031,
  VPERMILPDZ128mbi = 14032,
  VPERMILPDZ128mbik = 14033,
  VPERMILPDZ128mbikz = 14034,
  VPERMILPDZ128mi = 14035,
  VPERMILPDZ128mik = 14036,
  VPERMILPDZ128mikz = 14037,
  VPERMILPDZ128ri = 14038,
  VPERMILPDZ128rik = 14039,
  VPERMILPDZ128rikz = 14040,
  VPERMILPDZ128rm = 14041,
  VPERMILPDZ128rmb = 14042,
  VPERMILPDZ128rmbk = 14043,
  VPERMILPDZ128rmbkz = 14044,
  VPERMILPDZ128rmk = 14045,
  VPERMILPDZ128rmkz = 14046,
  VPERMILPDZ128rr = 14047,
  VPERMILPDZ128rrk = 14048,
  VPERMILPDZ128rrkz = 14049,
  VPERMILPDZ256mbi = 14050,
  VPERMILPDZ256mbik = 14051,
  VPERMILPDZ256mbikz = 14052,
  VPERMILPDZ256mi = 14053,
  VPERMILPDZ256mik = 14054,
  VPERMILPDZ256mikz = 14055,
  VPERMILPDZ256ri = 14056,
  VPERMILPDZ256rik = 14057,
  VPERMILPDZ256rikz = 14058,
  VPERMILPDZ256rm = 14059,
  VPERMILPDZ256rmb = 14060,
  VPERMILPDZ256rmbk = 14061,
  VPERMILPDZ256rmbkz = 14062,
  VPERMILPDZ256rmk = 14063,
  VPERMILPDZ256rmkz = 14064,
  VPERMILPDZ256rr = 14065,
  VPERMILPDZ256rrk = 14066,
  VPERMILPDZ256rrkz = 14067,
  VPERMILPDZmbi = 14068,
  VPERMILPDZmbik = 14069,
  VPERMILPDZmbikz = 14070,
  VPERMILPDZmi = 14071,
  VPERMILPDZmik = 14072,
  VPERMILPDZmikz = 14073,
  VPERMILPDZri = 14074,
  VPERMILPDZrik = 14075,
  VPERMILPDZrikz = 14076,
  VPERMILPDZrm = 14077,
  VPERMILPDZrmb = 14078,
  VPERMILPDZrmbk = 14079,
  VPERMILPDZrmbkz = 14080,
  VPERMILPDZrmk = 14081,
  VPERMILPDZrmkz = 14082,
  VPERMILPDZrr = 14083,
  VPERMILPDZrrk = 14084,
  VPERMILPDZrrkz = 14085,
  VPERMILPDmi = 14086,
  VPERMILPDri = 14087,
  VPERMILPDrm = 14088,
  VPERMILPDrr = 14089,
  VPERMILPSYmi = 14090,
  VPERMILPSYri = 14091,
  VPERMILPSYrm = 14092,
  VPERMILPSYrr = 14093,
  VPERMILPSZ128mbi = 14094,
  VPERMILPSZ128mbik = 14095,
  VPERMILPSZ128mbikz = 14096,
  VPERMILPSZ128mi = 14097,
  VPERMILPSZ128mik = 14098,
  VPERMILPSZ128mikz = 14099,
  VPERMILPSZ128ri = 14100,
  VPERMILPSZ128rik = 14101,
  VPERMILPSZ128rikz = 14102,
  VPERMILPSZ128rm = 14103,
  VPERMILPSZ128rmb = 14104,
  VPERMILPSZ128rmbk = 14105,
  VPERMILPSZ128rmbkz = 14106,
  VPERMILPSZ128rmk = 14107,
  VPERMILPSZ128rmkz = 14108,
  VPERMILPSZ128rr = 14109,
  VPERMILPSZ128rrk = 14110,
  VPERMILPSZ128rrkz = 14111,
  VPERMILPSZ256mbi = 14112,
  VPERMILPSZ256mbik = 14113,
  VPERMILPSZ256mbikz = 14114,
  VPERMILPSZ256mi = 14115,
  VPERMILPSZ256mik = 14116,
  VPERMILPSZ256mikz = 14117,
  VPERMILPSZ256ri = 14118,
  VPERMILPSZ256rik = 14119,
  VPERMILPSZ256rikz = 14120,
  VPERMILPSZ256rm = 14121,
  VPERMILPSZ256rmb = 14122,
  VPERMILPSZ256rmbk = 14123,
  VPERMILPSZ256rmbkz = 14124,
  VPERMILPSZ256rmk = 14125,
  VPERMILPSZ256rmkz = 14126,
  VPERMILPSZ256rr = 14127,
  VPERMILPSZ256rrk = 14128,
  VPERMILPSZ256rrkz = 14129,
  VPERMILPSZmbi = 14130,
  VPERMILPSZmbik = 14131,
  VPERMILPSZmbikz = 14132,
  VPERMILPSZmi = 14133,
  VPERMILPSZmik = 14134,
  VPERMILPSZmikz = 14135,
  VPERMILPSZri = 14136,
  VPERMILPSZrik = 14137,
  VPERMILPSZrikz = 14138,
  VPERMILPSZrm = 14139,
  VPERMILPSZrmb = 14140,
  VPERMILPSZrmbk = 14141,
  VPERMILPSZrmbkz = 14142,
  VPERMILPSZrmk = 14143,
  VPERMILPSZrmkz = 14144,
  VPERMILPSZrr = 14145,
  VPERMILPSZrrk = 14146,
  VPERMILPSZrrkz = 14147,
  VPERMILPSmi = 14148,
  VPERMILPSri = 14149,
  VPERMILPSrm = 14150,
  VPERMILPSrr = 14151,
  VPERMPDYmi = 14152,
  VPERMPDYri = 14153,
  VPERMPDZ256mbi = 14154,
  VPERMPDZ256mbik = 14155,
  VPERMPDZ256mbikz = 14156,
  VPERMPDZ256mi = 14157,
  VPERMPDZ256mik = 14158,
  VPERMPDZ256mikz = 14159,
  VPERMPDZ256ri = 14160,
  VPERMPDZ256rik = 14161,
  VPERMPDZ256rikz = 14162,
  VPERMPDZ256rm = 14163,
  VPERMPDZ256rmb = 14164,
  VPERMPDZ256rmbk = 14165,
  VPERMPDZ256rmbkz = 14166,
  VPERMPDZ256rmk = 14167,
  VPERMPDZ256rmkz = 14168,
  VPERMPDZ256rr = 14169,
  VPERMPDZ256rrk = 14170,
  VPERMPDZ256rrkz = 14171,
  VPERMPDZmbi = 14172,
  VPERMPDZmbik = 14173,
  VPERMPDZmbikz = 14174,
  VPERMPDZmi = 14175,
  VPERMPDZmik = 14176,
  VPERMPDZmikz = 14177,
  VPERMPDZri = 14178,
  VPERMPDZrik = 14179,
  VPERMPDZrikz = 14180,
  VPERMPDZrm = 14181,
  VPERMPDZrmb = 14182,
  VPERMPDZrmbk = 14183,
  VPERMPDZrmbkz = 14184,
  VPERMPDZrmk = 14185,
  VPERMPDZrmkz = 14186,
  VPERMPDZrr = 14187,
  VPERMPDZrrk = 14188,
  VPERMPDZrrkz = 14189,
  VPERMPSYrm = 14190,
  VPERMPSYrr = 14191,
  VPERMPSZ256rm = 14192,
  VPERMPSZ256rmb = 14193,
  VPERMPSZ256rmbk = 14194,
  VPERMPSZ256rmbkz = 14195,
  VPERMPSZ256rmk = 14196,
  VPERMPSZ256rmkz = 14197,
  VPERMPSZ256rr = 14198,
  VPERMPSZ256rrk = 14199,
  VPERMPSZ256rrkz = 14200,
  VPERMPSZrm = 14201,
  VPERMPSZrmb = 14202,
  VPERMPSZrmbk = 14203,
  VPERMPSZrmbkz = 14204,
  VPERMPSZrmk = 14205,
  VPERMPSZrmkz = 14206,
  VPERMPSZrr = 14207,
  VPERMPSZrrk = 14208,
  VPERMPSZrrkz = 14209,
  VPERMQYmi = 14210,
  VPERMQYri = 14211,
  VPERMQZ256mbi = 14212,
  VPERMQZ256mbik = 14213,
  VPERMQZ256mbikz = 14214,
  VPERMQZ256mi = 14215,
  VPERMQZ256mik = 14216,
  VPERMQZ256mikz = 14217,
  VPERMQZ256ri = 14218,
  VPERMQZ256rik = 14219,
  VPERMQZ256rikz = 14220,
  VPERMQZ256rm = 14221,
  VPERMQZ256rmb = 14222,
  VPERMQZ256rmbk = 14223,
  VPERMQZ256rmbkz = 14224,
  VPERMQZ256rmk = 14225,
  VPERMQZ256rmkz = 14226,
  VPERMQZ256rr = 14227,
  VPERMQZ256rrk = 14228,
  VPERMQZ256rrkz = 14229,
  VPERMQZmbi = 14230,
  VPERMQZmbik = 14231,
  VPERMQZmbikz = 14232,
  VPERMQZmi = 14233,
  VPERMQZmik = 14234,
  VPERMQZmikz = 14235,
  VPERMQZri = 14236,
  VPERMQZrik = 14237,
  VPERMQZrikz = 14238,
  VPERMQZrm = 14239,
  VPERMQZrmb = 14240,
  VPERMQZrmbk = 14241,
  VPERMQZrmbkz = 14242,
  VPERMQZrmk = 14243,
  VPERMQZrmkz = 14244,
  VPERMQZrr = 14245,
  VPERMQZrrk = 14246,
  VPERMQZrrkz = 14247,
  VPERMT2BZ128rm = 14248,
  VPERMT2BZ128rmk = 14249,
  VPERMT2BZ128rmkz = 14250,
  VPERMT2BZ128rr = 14251,
  VPERMT2BZ128rrk = 14252,
  VPERMT2BZ128rrkz = 14253,
  VPERMT2BZ256rm = 14254,
  VPERMT2BZ256rmk = 14255,
  VPERMT2BZ256rmkz = 14256,
  VPERMT2BZ256rr = 14257,
  VPERMT2BZ256rrk = 14258,
  VPERMT2BZ256rrkz = 14259,
  VPERMT2BZrm = 14260,
  VPERMT2BZrmk = 14261,
  VPERMT2BZrmkz = 14262,
  VPERMT2BZrr = 14263,
  VPERMT2BZrrk = 14264,
  VPERMT2BZrrkz = 14265,
  VPERMT2DZ128rm = 14266,
  VPERMT2DZ128rmb = 14267,
  VPERMT2DZ128rmbk = 14268,
  VPERMT2DZ128rmbkz = 14269,
  VPERMT2DZ128rmk = 14270,
  VPERMT2DZ128rmkz = 14271,
  VPERMT2DZ128rr = 14272,
  VPERMT2DZ128rrk = 14273,
  VPERMT2DZ128rrkz = 14274,
  VPERMT2DZ256rm = 14275,
  VPERMT2DZ256rmb = 14276,
  VPERMT2DZ256rmbk = 14277,
  VPERMT2DZ256rmbkz = 14278,
  VPERMT2DZ256rmk = 14279,
  VPERMT2DZ256rmkz = 14280,
  VPERMT2DZ256rr = 14281,
  VPERMT2DZ256rrk = 14282,
  VPERMT2DZ256rrkz = 14283,
  VPERMT2DZrm = 14284,
  VPERMT2DZrmb = 14285,
  VPERMT2DZrmbk = 14286,
  VPERMT2DZrmbkz = 14287,
  VPERMT2DZrmk = 14288,
  VPERMT2DZrmkz = 14289,
  VPERMT2DZrr = 14290,
  VPERMT2DZrrk = 14291,
  VPERMT2DZrrkz = 14292,
  VPERMT2PDZ128rm = 14293,
  VPERMT2PDZ128rmb = 14294,
  VPERMT2PDZ128rmbk = 14295,
  VPERMT2PDZ128rmbkz = 14296,
  VPERMT2PDZ128rmk = 14297,
  VPERMT2PDZ128rmkz = 14298,
  VPERMT2PDZ128rr = 14299,
  VPERMT2PDZ128rrk = 14300,
  VPERMT2PDZ128rrkz = 14301,
  VPERMT2PDZ256rm = 14302,
  VPERMT2PDZ256rmb = 14303,
  VPERMT2PDZ256rmbk = 14304,
  VPERMT2PDZ256rmbkz = 14305,
  VPERMT2PDZ256rmk = 14306,
  VPERMT2PDZ256rmkz = 14307,
  VPERMT2PDZ256rr = 14308,
  VPERMT2PDZ256rrk = 14309,
  VPERMT2PDZ256rrkz = 14310,
  VPERMT2PDZrm = 14311,
  VPERMT2PDZrmb = 14312,
  VPERMT2PDZrmbk = 14313,
  VPERMT2PDZrmbkz = 14314,
  VPERMT2PDZrmk = 14315,
  VPERMT2PDZrmkz = 14316,
  VPERMT2PDZrr = 14317,
  VPERMT2PDZrrk = 14318,
  VPERMT2PDZrrkz = 14319,
  VPERMT2PSZ128rm = 14320,
  VPERMT2PSZ128rmb = 14321,
  VPERMT2PSZ128rmbk = 14322,
  VPERMT2PSZ128rmbkz = 14323,
  VPERMT2PSZ128rmk = 14324,
  VPERMT2PSZ128rmkz = 14325,
  VPERMT2PSZ128rr = 14326,
  VPERMT2PSZ128rrk = 14327,
  VPERMT2PSZ128rrkz = 14328,
  VPERMT2PSZ256rm = 14329,
  VPERMT2PSZ256rmb = 14330,
  VPERMT2PSZ256rmbk = 14331,
  VPERMT2PSZ256rmbkz = 14332,
  VPERMT2PSZ256rmk = 14333,
  VPERMT2PSZ256rmkz = 14334,
  VPERMT2PSZ256rr = 14335,
  VPERMT2PSZ256rrk = 14336,
  VPERMT2PSZ256rrkz = 14337,
  VPERMT2PSZrm = 14338,
  VPERMT2PSZrmb = 14339,
  VPERMT2PSZrmbk = 14340,
  VPERMT2PSZrmbkz = 14341,
  VPERMT2PSZrmk = 14342,
  VPERMT2PSZrmkz = 14343,
  VPERMT2PSZrr = 14344,
  VPERMT2PSZrrk = 14345,
  VPERMT2PSZrrkz = 14346,
  VPERMT2QZ128rm = 14347,
  VPERMT2QZ128rmb = 14348,
  VPERMT2QZ128rmbk = 14349,
  VPERMT2QZ128rmbkz = 14350,
  VPERMT2QZ128rmk = 14351,
  VPERMT2QZ128rmkz = 14352,
  VPERMT2QZ128rr = 14353,
  VPERMT2QZ128rrk = 14354,
  VPERMT2QZ128rrkz = 14355,
  VPERMT2QZ256rm = 14356,
  VPERMT2QZ256rmb = 14357,
  VPERMT2QZ256rmbk = 14358,
  VPERMT2QZ256rmbkz = 14359,
  VPERMT2QZ256rmk = 14360,
  VPERMT2QZ256rmkz = 14361,
  VPERMT2QZ256rr = 14362,
  VPERMT2QZ256rrk = 14363,
  VPERMT2QZ256rrkz = 14364,
  VPERMT2QZrm = 14365,
  VPERMT2QZrmb = 14366,
  VPERMT2QZrmbk = 14367,
  VPERMT2QZrmbkz = 14368,
  VPERMT2QZrmk = 14369,
  VPERMT2QZrmkz = 14370,
  VPERMT2QZrr = 14371,
  VPERMT2QZrrk = 14372,
  VPERMT2QZrrkz = 14373,
  VPERMT2WZ128rm = 14374,
  VPERMT2WZ128rmk = 14375,
  VPERMT2WZ128rmkz = 14376,
  VPERMT2WZ128rr = 14377,
  VPERMT2WZ128rrk = 14378,
  VPERMT2WZ128rrkz = 14379,
  VPERMT2WZ256rm = 14380,
  VPERMT2WZ256rmk = 14381,
  VPERMT2WZ256rmkz = 14382,
  VPERMT2WZ256rr = 14383,
  VPERMT2WZ256rrk = 14384,
  VPERMT2WZ256rrkz = 14385,
  VPERMT2WZrm = 14386,
  VPERMT2WZrmk = 14387,
  VPERMT2WZrmkz = 14388,
  VPERMT2WZrr = 14389,
  VPERMT2WZrrk = 14390,
  VPERMT2WZrrkz = 14391,
  VPERMWZ128rm = 14392,
  VPERMWZ128rmk = 14393,
  VPERMWZ128rmkz = 14394,
  VPERMWZ128rr = 14395,
  VPERMWZ128rrk = 14396,
  VPERMWZ128rrkz = 14397,
  VPERMWZ256rm = 14398,
  VPERMWZ256rmk = 14399,
  VPERMWZ256rmkz = 14400,
  VPERMWZ256rr = 14401,
  VPERMWZ256rrk = 14402,
  VPERMWZ256rrkz = 14403,
  VPERMWZrm = 14404,
  VPERMWZrmk = 14405,
  VPERMWZrmkz = 14406,
  VPERMWZrr = 14407,
  VPERMWZrrk = 14408,
  VPERMWZrrkz = 14409,
  VPEXPANDBZ128rm = 14410,
  VPEXPANDBZ128rmk = 14411,
  VPEXPANDBZ128rmkz = 14412,
  VPEXPANDBZ128rr = 14413,
  VPEXPANDBZ128rrk = 14414,
  VPEXPANDBZ128rrkz = 14415,
  VPEXPANDBZ256rm = 14416,
  VPEXPANDBZ256rmk = 14417,
  VPEXPANDBZ256rmkz = 14418,
  VPEXPANDBZ256rr = 14419,
  VPEXPANDBZ256rrk = 14420,
  VPEXPANDBZ256rrkz = 14421,
  VPEXPANDBZrm = 14422,
  VPEXPANDBZrmk = 14423,
  VPEXPANDBZrmkz = 14424,
  VPEXPANDBZrr = 14425,
  VPEXPANDBZrrk = 14426,
  VPEXPANDBZrrkz = 14427,
  VPEXPANDDZ128rm = 14428,
  VPEXPANDDZ128rmk = 14429,
  VPEXPANDDZ128rmkz = 14430,
  VPEXPANDDZ128rr = 14431,
  VPEXPANDDZ128rrk = 14432,
  VPEXPANDDZ128rrkz = 14433,
  VPEXPANDDZ256rm = 14434,
  VPEXPANDDZ256rmk = 14435,
  VPEXPANDDZ256rmkz = 14436,
  VPEXPANDDZ256rr = 14437,
  VPEXPANDDZ256rrk = 14438,
  VPEXPANDDZ256rrkz = 14439,
  VPEXPANDDZrm = 14440,
  VPEXPANDDZrmk = 14441,
  VPEXPANDDZrmkz = 14442,
  VPEXPANDDZrr = 14443,
  VPEXPANDDZrrk = 14444,
  VPEXPANDDZrrkz = 14445,
  VPEXPANDQZ128rm = 14446,
  VPEXPANDQZ128rmk = 14447,
  VPEXPANDQZ128rmkz = 14448,
  VPEXPANDQZ128rr = 14449,
  VPEXPANDQZ128rrk = 14450,
  VPEXPANDQZ128rrkz = 14451,
  VPEXPANDQZ256rm = 14452,
  VPEXPANDQZ256rmk = 14453,
  VPEXPANDQZ256rmkz = 14454,
  VPEXPANDQZ256rr = 14455,
  VPEXPANDQZ256rrk = 14456,
  VPEXPANDQZ256rrkz = 14457,
  VPEXPANDQZrm = 14458,
  VPEXPANDQZrmk = 14459,
  VPEXPANDQZrmkz = 14460,
  VPEXPANDQZrr = 14461,
  VPEXPANDQZrrk = 14462,
  VPEXPANDQZrrkz = 14463,
  VPEXPANDWZ128rm = 14464,
  VPEXPANDWZ128rmk = 14465,
  VPEXPANDWZ128rmkz = 14466,
  VPEXPANDWZ128rr = 14467,
  VPEXPANDWZ128rrk = 14468,
  VPEXPANDWZ128rrkz = 14469,
  VPEXPANDWZ256rm = 14470,
  VPEXPANDWZ256rmk = 14471,
  VPEXPANDWZ256rmkz = 14472,
  VPEXPANDWZ256rr = 14473,
  VPEXPANDWZ256rrk = 14474,
  VPEXPANDWZ256rrkz = 14475,
  VPEXPANDWZrm = 14476,
  VPEXPANDWZrmk = 14477,
  VPEXPANDWZrmkz = 14478,
  VPEXPANDWZrr = 14479,
  VPEXPANDWZrrk = 14480,
  VPEXPANDWZrrkz = 14481,
  VPEXTRBZmr = 14482,
  VPEXTRBZrr = 14483,
  VPEXTRBmr = 14484,
  VPEXTRBrr = 14485,
  VPEXTRDZmr = 14486,
  VPEXTRDZrr = 14487,
  VPEXTRDmr = 14488,
  VPEXTRDrr = 14489,
  VPEXTRQZmr = 14490,
  VPEXTRQZrr = 14491,
  VPEXTRQmr = 14492,
  VPEXTRQrr = 14493,
  VPEXTRWZmr = 14494,
  VPEXTRWZrr = 14495,
  VPEXTRWZrr_REV = 14496,
  VPEXTRWmr = 14497,
  VPEXTRWrr = 14498,
  VPEXTRWrr_REV = 14499,
  VPGATHERDDYrm = 14500,
  VPGATHERDDZ128rm = 14501,
  VPGATHERDDZ256rm = 14502,
  VPGATHERDDZrm = 14503,
  VPGATHERDDrm = 14504,
  VPGATHERDQYrm = 14505,
  VPGATHERDQZ128rm = 14506,
  VPGATHERDQZ256rm = 14507,
  VPGATHERDQZrm = 14508,
  VPGATHERDQrm = 14509,
  VPGATHERQDYrm = 14510,
  VPGATHERQDZ128rm = 14511,
  VPGATHERQDZ256rm = 14512,
  VPGATHERQDZrm = 14513,
  VPGATHERQDrm = 14514,
  VPGATHERQQYrm = 14515,
  VPGATHERQQZ128rm = 14516,
  VPGATHERQQZ256rm = 14517,
  VPGATHERQQZrm = 14518,
  VPGATHERQQrm = 14519,
  VPHADDBDrm = 14520,
  VPHADDBDrr = 14521,
  VPHADDBQrm = 14522,
  VPHADDBQrr = 14523,
  VPHADDBWrm = 14524,
  VPHADDBWrr = 14525,
  VPHADDDQrm = 14526,
  VPHADDDQrr = 14527,
  VPHADDDYrm = 14528,
  VPHADDDYrr = 14529,
  VPHADDDrm = 14530,
  VPHADDDrr = 14531,
  VPHADDSWYrm = 14532,
  VPHADDSWYrr = 14533,
  VPHADDSWrm = 14534,
  VPHADDSWrr = 14535,
  VPHADDUBDrm = 14536,
  VPHADDUBDrr = 14537,
  VPHADDUBQrm = 14538,
  VPHADDUBQrr = 14539,
  VPHADDUBWrm = 14540,
  VPHADDUBWrr = 14541,
  VPHADDUDQrm = 14542,
  VPHADDUDQrr = 14543,
  VPHADDUWDrm = 14544,
  VPHADDUWDrr = 14545,
  VPHADDUWQrm = 14546,
  VPHADDUWQrr = 14547,
  VPHADDWDrm = 14548,
  VPHADDWDrr = 14549,
  VPHADDWQrm = 14550,
  VPHADDWQrr = 14551,
  VPHADDWYrm = 14552,
  VPHADDWYrr = 14553,
  VPHADDWrm = 14554,
  VPHADDWrr = 14555,
  VPHMINPOSUWrm = 14556,
  VPHMINPOSUWrr = 14557,
  VPHSUBBWrm = 14558,
  VPHSUBBWrr = 14559,
  VPHSUBDQrm = 14560,
  VPHSUBDQrr = 14561,
  VPHSUBDYrm = 14562,
  VPHSUBDYrr = 14563,
  VPHSUBDrm = 14564,
  VPHSUBDrr = 14565,
  VPHSUBSWYrm = 14566,
  VPHSUBSWYrr = 14567,
  VPHSUBSWrm = 14568,
  VPHSUBSWrr = 14569,
  VPHSUBWDrm = 14570,
  VPHSUBWDrr = 14571,
  VPHSUBWYrm = 14572,
  VPHSUBWYrr = 14573,
  VPHSUBWrm = 14574,
  VPHSUBWrr = 14575,
  VPINSRBZrm = 14576,
  VPINSRBZrr = 14577,
  VPINSRBrm = 14578,
  VPINSRBrr = 14579,
  VPINSRDZrm = 14580,
  VPINSRDZrr = 14581,
  VPINSRDrm = 14582,
  VPINSRDrr = 14583,
  VPINSRQZrm = 14584,
  VPINSRQZrr = 14585,
  VPINSRQrm = 14586,
  VPINSRQrr = 14587,
  VPINSRWZrm = 14588,
  VPINSRWZrr = 14589,
  VPINSRWrm = 14590,
  VPINSRWrr = 14591,
  VPLZCNTDZ128rm = 14592,
  VPLZCNTDZ128rmb = 14593,
  VPLZCNTDZ128rmbk = 14594,
  VPLZCNTDZ128rmbkz = 14595,
  VPLZCNTDZ128rmk = 14596,
  VPLZCNTDZ128rmkz = 14597,
  VPLZCNTDZ128rr = 14598,
  VPLZCNTDZ128rrk = 14599,
  VPLZCNTDZ128rrkz = 14600,
  VPLZCNTDZ256rm = 14601,
  VPLZCNTDZ256rmb = 14602,
  VPLZCNTDZ256rmbk = 14603,
  VPLZCNTDZ256rmbkz = 14604,
  VPLZCNTDZ256rmk = 14605,
  VPLZCNTDZ256rmkz = 14606,
  VPLZCNTDZ256rr = 14607,
  VPLZCNTDZ256rrk = 14608,
  VPLZCNTDZ256rrkz = 14609,
  VPLZCNTDZrm = 14610,
  VPLZCNTDZrmb = 14611,
  VPLZCNTDZrmbk = 14612,
  VPLZCNTDZrmbkz = 14613,
  VPLZCNTDZrmk = 14614,
  VPLZCNTDZrmkz = 14615,
  VPLZCNTDZrr = 14616,
  VPLZCNTDZrrk = 14617,
  VPLZCNTDZrrkz = 14618,
  VPLZCNTQZ128rm = 14619,
  VPLZCNTQZ128rmb = 14620,
  VPLZCNTQZ128rmbk = 14621,
  VPLZCNTQZ128rmbkz = 14622,
  VPLZCNTQZ128rmk = 14623,
  VPLZCNTQZ128rmkz = 14624,
  VPLZCNTQZ128rr = 14625,
  VPLZCNTQZ128rrk = 14626,
  VPLZCNTQZ128rrkz = 14627,
  VPLZCNTQZ256rm = 14628,
  VPLZCNTQZ256rmb = 14629,
  VPLZCNTQZ256rmbk = 14630,
  VPLZCNTQZ256rmbkz = 14631,
  VPLZCNTQZ256rmk = 14632,
  VPLZCNTQZ256rmkz = 14633,
  VPLZCNTQZ256rr = 14634,
  VPLZCNTQZ256rrk = 14635,
  VPLZCNTQZ256rrkz = 14636,
  VPLZCNTQZrm = 14637,
  VPLZCNTQZrmb = 14638,
  VPLZCNTQZrmbk = 14639,
  VPLZCNTQZrmbkz = 14640,
  VPLZCNTQZrmk = 14641,
  VPLZCNTQZrmkz = 14642,
  VPLZCNTQZrr = 14643,
  VPLZCNTQZrrk = 14644,
  VPLZCNTQZrrkz = 14645,
  VPMACSDDrm = 14646,
  VPMACSDDrr = 14647,
  VPMACSDQHrm = 14648,
  VPMACSDQHrr = 14649,
  VPMACSDQLrm = 14650,
  VPMACSDQLrr = 14651,
  VPMACSSDDrm = 14652,
  VPMACSSDDrr = 14653,
  VPMACSSDQHrm = 14654,
  VPMACSSDQHrr = 14655,
  VPMACSSDQLrm = 14656,
  VPMACSSDQLrr = 14657,
  VPMACSSWDrm = 14658,
  VPMACSSWDrr = 14659,
  VPMACSSWWrm = 14660,
  VPMACSSWWrr = 14661,
  VPMACSWDrm = 14662,
  VPMACSWDrr = 14663,
  VPMACSWWrm = 14664,
  VPMACSWWrr = 14665,
  VPMADCSSWDrm = 14666,
  VPMADCSSWDrr = 14667,
  VPMADCSWDrm = 14668,
  VPMADCSWDrr = 14669,
  VPMADD52HUQYrm = 14670,
  VPMADD52HUQYrr = 14671,
  VPMADD52HUQZ128m = 14672,
  VPMADD52HUQZ128mb = 14673,
  VPMADD52HUQZ128mbk = 14674,
  VPMADD52HUQZ128mbkz = 14675,
  VPMADD52HUQZ128mk = 14676,
  VPMADD52HUQZ128mkz = 14677,
  VPMADD52HUQZ128r = 14678,
  VPMADD52HUQZ128rk = 14679,
  VPMADD52HUQZ128rkz = 14680,
  VPMADD52HUQZ256m = 14681,
  VPMADD52HUQZ256mb = 14682,
  VPMADD52HUQZ256mbk = 14683,
  VPMADD52HUQZ256mbkz = 14684,
  VPMADD52HUQZ256mk = 14685,
  VPMADD52HUQZ256mkz = 14686,
  VPMADD52HUQZ256r = 14687,
  VPMADD52HUQZ256rk = 14688,
  VPMADD52HUQZ256rkz = 14689,
  VPMADD52HUQZm = 14690,
  VPMADD52HUQZmb = 14691,
  VPMADD52HUQZmbk = 14692,
  VPMADD52HUQZmbkz = 14693,
  VPMADD52HUQZmk = 14694,
  VPMADD52HUQZmkz = 14695,
  VPMADD52HUQZr = 14696,
  VPMADD52HUQZrk = 14697,
  VPMADD52HUQZrkz = 14698,
  VPMADD52HUQrm = 14699,
  VPMADD52HUQrr = 14700,
  VPMADD52LUQYrm = 14701,
  VPMADD52LUQYrr = 14702,
  VPMADD52LUQZ128m = 14703,
  VPMADD52LUQZ128mb = 14704,
  VPMADD52LUQZ128mbk = 14705,
  VPMADD52LUQZ128mbkz = 14706,
  VPMADD52LUQZ128mk = 14707,
  VPMADD52LUQZ128mkz = 14708,
  VPMADD52LUQZ128r = 14709,
  VPMADD52LUQZ128rk = 14710,
  VPMADD52LUQZ128rkz = 14711,
  VPMADD52LUQZ256m = 14712,
  VPMADD52LUQZ256mb = 14713,
  VPMADD52LUQZ256mbk = 14714,
  VPMADD52LUQZ256mbkz = 14715,
  VPMADD52LUQZ256mk = 14716,
  VPMADD52LUQZ256mkz = 14717,
  VPMADD52LUQZ256r = 14718,
  VPMADD52LUQZ256rk = 14719,
  VPMADD52LUQZ256rkz = 14720,
  VPMADD52LUQZm = 14721,
  VPMADD52LUQZmb = 14722,
  VPMADD52LUQZmbk = 14723,
  VPMADD52LUQZmbkz = 14724,
  VPMADD52LUQZmk = 14725,
  VPMADD52LUQZmkz = 14726,
  VPMADD52LUQZr = 14727,
  VPMADD52LUQZrk = 14728,
  VPMADD52LUQZrkz = 14729,
  VPMADD52LUQrm = 14730,
  VPMADD52LUQrr = 14731,
  VPMADDUBSWYrm = 14732,
  VPMADDUBSWYrr = 14733,
  VPMADDUBSWZ128rm = 14734,
  VPMADDUBSWZ128rmk = 14735,
  VPMADDUBSWZ128rmkz = 14736,
  VPMADDUBSWZ128rr = 14737,
  VPMADDUBSWZ128rrk = 14738,
  VPMADDUBSWZ128rrkz = 14739,
  VPMADDUBSWZ256rm = 14740,
  VPMADDUBSWZ256rmk = 14741,
  VPMADDUBSWZ256rmkz = 14742,
  VPMADDUBSWZ256rr = 14743,
  VPMADDUBSWZ256rrk = 14744,
  VPMADDUBSWZ256rrkz = 14745,
  VPMADDUBSWZrm = 14746,
  VPMADDUBSWZrmk = 14747,
  VPMADDUBSWZrmkz = 14748,
  VPMADDUBSWZrr = 14749,
  VPMADDUBSWZrrk = 14750,
  VPMADDUBSWZrrkz = 14751,
  VPMADDUBSWrm = 14752,
  VPMADDUBSWrr = 14753,
  VPMADDWDYrm = 14754,
  VPMADDWDYrr = 14755,
  VPMADDWDZ128rm = 14756,
  VPMADDWDZ128rmk = 14757,
  VPMADDWDZ128rmkz = 14758,
  VPMADDWDZ128rr = 14759,
  VPMADDWDZ128rrk = 14760,
  VPMADDWDZ128rrkz = 14761,
  VPMADDWDZ256rm = 14762,
  VPMADDWDZ256rmk = 14763,
  VPMADDWDZ256rmkz = 14764,
  VPMADDWDZ256rr = 14765,
  VPMADDWDZ256rrk = 14766,
  VPMADDWDZ256rrkz = 14767,
  VPMADDWDZrm = 14768,
  VPMADDWDZrmk = 14769,
  VPMADDWDZrmkz = 14770,
  VPMADDWDZrr = 14771,
  VPMADDWDZrrk = 14772,
  VPMADDWDZrrkz = 14773,
  VPMADDWDrm = 14774,
  VPMADDWDrr = 14775,
  VPMASKMOVDYmr = 14776,
  VPMASKMOVDYrm = 14777,
  VPMASKMOVDmr = 14778,
  VPMASKMOVDrm = 14779,
  VPMASKMOVQYmr = 14780,
  VPMASKMOVQYrm = 14781,
  VPMASKMOVQmr = 14782,
  VPMASKMOVQrm = 14783,
  VPMAXSBYrm = 14784,
  VPMAXSBYrr = 14785,
  VPMAXSBZ128rm = 14786,
  VPMAXSBZ128rmk = 14787,
  VPMAXSBZ128rmkz = 14788,
  VPMAXSBZ128rr = 14789,
  VPMAXSBZ128rrk = 14790,
  VPMAXSBZ128rrkz = 14791,
  VPMAXSBZ256rm = 14792,
  VPMAXSBZ256rmk = 14793,
  VPMAXSBZ256rmkz = 14794,
  VPMAXSBZ256rr = 14795,
  VPMAXSBZ256rrk = 14796,
  VPMAXSBZ256rrkz = 14797,
  VPMAXSBZrm = 14798,
  VPMAXSBZrmk = 14799,
  VPMAXSBZrmkz = 14800,
  VPMAXSBZrr = 14801,
  VPMAXSBZrrk = 14802,
  VPMAXSBZrrkz = 14803,
  VPMAXSBrm = 14804,
  VPMAXSBrr = 14805,
  VPMAXSDYrm = 14806,
  VPMAXSDYrr = 14807,
  VPMAXSDZ128rm = 14808,
  VPMAXSDZ128rmb = 14809,
  VPMAXSDZ128rmbk = 14810,
  VPMAXSDZ128rmbkz = 14811,
  VPMAXSDZ128rmk = 14812,
  VPMAXSDZ128rmkz = 14813,
  VPMAXSDZ128rr = 14814,
  VPMAXSDZ128rrk = 14815,
  VPMAXSDZ128rrkz = 14816,
  VPMAXSDZ256rm = 14817,
  VPMAXSDZ256rmb = 14818,
  VPMAXSDZ256rmbk = 14819,
  VPMAXSDZ256rmbkz = 14820,
  VPMAXSDZ256rmk = 14821,
  VPMAXSDZ256rmkz = 14822,
  VPMAXSDZ256rr = 14823,
  VPMAXSDZ256rrk = 14824,
  VPMAXSDZ256rrkz = 14825,
  VPMAXSDZrm = 14826,
  VPMAXSDZrmb = 14827,
  VPMAXSDZrmbk = 14828,
  VPMAXSDZrmbkz = 14829,
  VPMAXSDZrmk = 14830,
  VPMAXSDZrmkz = 14831,
  VPMAXSDZrr = 14832,
  VPMAXSDZrrk = 14833,
  VPMAXSDZrrkz = 14834,
  VPMAXSDrm = 14835,
  VPMAXSDrr = 14836,
  VPMAXSQZ128rm = 14837,
  VPMAXSQZ128rmb = 14838,
  VPMAXSQZ128rmbk = 14839,
  VPMAXSQZ128rmbkz = 14840,
  VPMAXSQZ128rmk = 14841,
  VPMAXSQZ128rmkz = 14842,
  VPMAXSQZ128rr = 14843,
  VPMAXSQZ128rrk = 14844,
  VPMAXSQZ128rrkz = 14845,
  VPMAXSQZ256rm = 14846,
  VPMAXSQZ256rmb = 14847,
  VPMAXSQZ256rmbk = 14848,
  VPMAXSQZ256rmbkz = 14849,
  VPMAXSQZ256rmk = 14850,
  VPMAXSQZ256rmkz = 14851,
  VPMAXSQZ256rr = 14852,
  VPMAXSQZ256rrk = 14853,
  VPMAXSQZ256rrkz = 14854,
  VPMAXSQZrm = 14855,
  VPMAXSQZrmb = 14856,
  VPMAXSQZrmbk = 14857,
  VPMAXSQZrmbkz = 14858,
  VPMAXSQZrmk = 14859,
  VPMAXSQZrmkz = 14860,
  VPMAXSQZrr = 14861,
  VPMAXSQZrrk = 14862,
  VPMAXSQZrrkz = 14863,
  VPMAXSWYrm = 14864,
  VPMAXSWYrr = 14865,
  VPMAXSWZ128rm = 14866,
  VPMAXSWZ128rmk = 14867,
  VPMAXSWZ128rmkz = 14868,
  VPMAXSWZ128rr = 14869,
  VPMAXSWZ128rrk = 14870,
  VPMAXSWZ128rrkz = 14871,
  VPMAXSWZ256rm = 14872,
  VPMAXSWZ256rmk = 14873,
  VPMAXSWZ256rmkz = 14874,
  VPMAXSWZ256rr = 14875,
  VPMAXSWZ256rrk = 14876,
  VPMAXSWZ256rrkz = 14877,
  VPMAXSWZrm = 14878,
  VPMAXSWZrmk = 14879,
  VPMAXSWZrmkz = 14880,
  VPMAXSWZrr = 14881,
  VPMAXSWZrrk = 14882,
  VPMAXSWZrrkz = 14883,
  VPMAXSWrm = 14884,
  VPMAXSWrr = 14885,
  VPMAXUBYrm = 14886,
  VPMAXUBYrr = 14887,
  VPMAXUBZ128rm = 14888,
  VPMAXUBZ128rmk = 14889,
  VPMAXUBZ128rmkz = 14890,
  VPMAXUBZ128rr = 14891,
  VPMAXUBZ128rrk = 14892,
  VPMAXUBZ128rrkz = 14893,
  VPMAXUBZ256rm = 14894,
  VPMAXUBZ256rmk = 14895,
  VPMAXUBZ256rmkz = 14896,
  VPMAXUBZ256rr = 14897,
  VPMAXUBZ256rrk = 14898,
  VPMAXUBZ256rrkz = 14899,
  VPMAXUBZrm = 14900,
  VPMAXUBZrmk = 14901,
  VPMAXUBZrmkz = 14902,
  VPMAXUBZrr = 14903,
  VPMAXUBZrrk = 14904,
  VPMAXUBZrrkz = 14905,
  VPMAXUBrm = 14906,
  VPMAXUBrr = 14907,
  VPMAXUDYrm = 14908,
  VPMAXUDYrr = 14909,
  VPMAXUDZ128rm = 14910,
  VPMAXUDZ128rmb = 14911,
  VPMAXUDZ128rmbk = 14912,
  VPMAXUDZ128rmbkz = 14913,
  VPMAXUDZ128rmk = 14914,
  VPMAXUDZ128rmkz = 14915,
  VPMAXUDZ128rr = 14916,
  VPMAXUDZ128rrk = 14917,
  VPMAXUDZ128rrkz = 14918,
  VPMAXUDZ256rm = 14919,
  VPMAXUDZ256rmb = 14920,
  VPMAXUDZ256rmbk = 14921,
  VPMAXUDZ256rmbkz = 14922,
  VPMAXUDZ256rmk = 14923,
  VPMAXUDZ256rmkz = 14924,
  VPMAXUDZ256rr = 14925,
  VPMAXUDZ256rrk = 14926,
  VPMAXUDZ256rrkz = 14927,
  VPMAXUDZrm = 14928,
  VPMAXUDZrmb = 14929,
  VPMAXUDZrmbk = 14930,
  VPMAXUDZrmbkz = 14931,
  VPMAXUDZrmk = 14932,
  VPMAXUDZrmkz = 14933,
  VPMAXUDZrr = 14934,
  VPMAXUDZrrk = 14935,
  VPMAXUDZrrkz = 14936,
  VPMAXUDrm = 14937,
  VPMAXUDrr = 14938,
  VPMAXUQZ128rm = 14939,
  VPMAXUQZ128rmb = 14940,
  VPMAXUQZ128rmbk = 14941,
  VPMAXUQZ128rmbkz = 14942,
  VPMAXUQZ128rmk = 14943,
  VPMAXUQZ128rmkz = 14944,
  VPMAXUQZ128rr = 14945,
  VPMAXUQZ128rrk = 14946,
  VPMAXUQZ128rrkz = 14947,
  VPMAXUQZ256rm = 14948,
  VPMAXUQZ256rmb = 14949,
  VPMAXUQZ256rmbk = 14950,
  VPMAXUQZ256rmbkz = 14951,
  VPMAXUQZ256rmk = 14952,
  VPMAXUQZ256rmkz = 14953,
  VPMAXUQZ256rr = 14954,
  VPMAXUQZ256rrk = 14955,
  VPMAXUQZ256rrkz = 14956,
  VPMAXUQZrm = 14957,
  VPMAXUQZrmb = 14958,
  VPMAXUQZrmbk = 14959,
  VPMAXUQZrmbkz = 14960,
  VPMAXUQZrmk = 14961,
  VPMAXUQZrmkz = 14962,
  VPMAXUQZrr = 14963,
  VPMAXUQZrrk = 14964,
  VPMAXUQZrrkz = 14965,
  VPMAXUWYrm = 14966,
  VPMAXUWYrr = 14967,
  VPMAXUWZ128rm = 14968,
  VPMAXUWZ128rmk = 14969,
  VPMAXUWZ128rmkz = 14970,
  VPMAXUWZ128rr = 14971,
  VPMAXUWZ128rrk = 14972,
  VPMAXUWZ128rrkz = 14973,
  VPMAXUWZ256rm = 14974,
  VPMAXUWZ256rmk = 14975,
  VPMAXUWZ256rmkz = 14976,
  VPMAXUWZ256rr = 14977,
  VPMAXUWZ256rrk = 14978,
  VPMAXUWZ256rrkz = 14979,
  VPMAXUWZrm = 14980,
  VPMAXUWZrmk = 14981,
  VPMAXUWZrmkz = 14982,
  VPMAXUWZrr = 14983,
  VPMAXUWZrrk = 14984,
  VPMAXUWZrrkz = 14985,
  VPMAXUWrm = 14986,
  VPMAXUWrr = 14987,
  VPMINSBYrm = 14988,
  VPMINSBYrr = 14989,
  VPMINSBZ128rm = 14990,
  VPMINSBZ128rmk = 14991,
  VPMINSBZ128rmkz = 14992,
  VPMINSBZ128rr = 14993,
  VPMINSBZ128rrk = 14994,
  VPMINSBZ128rrkz = 14995,
  VPMINSBZ256rm = 14996,
  VPMINSBZ256rmk = 14997,
  VPMINSBZ256rmkz = 14998,
  VPMINSBZ256rr = 14999,
  VPMINSBZ256rrk = 15000,
  VPMINSBZ256rrkz = 15001,
  VPMINSBZrm = 15002,
  VPMINSBZrmk = 15003,
  VPMINSBZrmkz = 15004,
  VPMINSBZrr = 15005,
  VPMINSBZrrk = 15006,
  VPMINSBZrrkz = 15007,
  VPMINSBrm = 15008,
  VPMINSBrr = 15009,
  VPMINSDYrm = 15010,
  VPMINSDYrr = 15011,
  VPMINSDZ128rm = 15012,
  VPMINSDZ128rmb = 15013,
  VPMINSDZ128rmbk = 15014,
  VPMINSDZ128rmbkz = 15015,
  VPMINSDZ128rmk = 15016,
  VPMINSDZ128rmkz = 15017,
  VPMINSDZ128rr = 15018,
  VPMINSDZ128rrk = 15019,
  VPMINSDZ128rrkz = 15020,
  VPMINSDZ256rm = 15021,
  VPMINSDZ256rmb = 15022,
  VPMINSDZ256rmbk = 15023,
  VPMINSDZ256rmbkz = 15024,
  VPMINSDZ256rmk = 15025,
  VPMINSDZ256rmkz = 15026,
  VPMINSDZ256rr = 15027,
  VPMINSDZ256rrk = 15028,
  VPMINSDZ256rrkz = 15029,
  VPMINSDZrm = 15030,
  VPMINSDZrmb = 15031,
  VPMINSDZrmbk = 15032,
  VPMINSDZrmbkz = 15033,
  VPMINSDZrmk = 15034,
  VPMINSDZrmkz = 15035,
  VPMINSDZrr = 15036,
  VPMINSDZrrk = 15037,
  VPMINSDZrrkz = 15038,
  VPMINSDrm = 15039,
  VPMINSDrr = 15040,
  VPMINSQZ128rm = 15041,
  VPMINSQZ128rmb = 15042,
  VPMINSQZ128rmbk = 15043,
  VPMINSQZ128rmbkz = 15044,
  VPMINSQZ128rmk = 15045,
  VPMINSQZ128rmkz = 15046,
  VPMINSQZ128rr = 15047,
  VPMINSQZ128rrk = 15048,
  VPMINSQZ128rrkz = 15049,
  VPMINSQZ256rm = 15050,
  VPMINSQZ256rmb = 15051,
  VPMINSQZ256rmbk = 15052,
  VPMINSQZ256rmbkz = 15053,
  VPMINSQZ256rmk = 15054,
  VPMINSQZ256rmkz = 15055,
  VPMINSQZ256rr = 15056,
  VPMINSQZ256rrk = 15057,
  VPMINSQZ256rrkz = 15058,
  VPMINSQZrm = 15059,
  VPMINSQZrmb = 15060,
  VPMINSQZrmbk = 15061,
  VPMINSQZrmbkz = 15062,
  VPMINSQZrmk = 15063,
  VPMINSQZrmkz = 15064,
  VPMINSQZrr = 15065,
  VPMINSQZrrk = 15066,
  VPMINSQZrrkz = 15067,
  VPMINSWYrm = 15068,
  VPMINSWYrr = 15069,
  VPMINSWZ128rm = 15070,
  VPMINSWZ128rmk = 15071,
  VPMINSWZ128rmkz = 15072,
  VPMINSWZ128rr = 15073,
  VPMINSWZ128rrk = 15074,
  VPMINSWZ128rrkz = 15075,
  VPMINSWZ256rm = 15076,
  VPMINSWZ256rmk = 15077,
  VPMINSWZ256rmkz = 15078,
  VPMINSWZ256rr = 15079,
  VPMINSWZ256rrk = 15080,
  VPMINSWZ256rrkz = 15081,
  VPMINSWZrm = 15082,
  VPMINSWZrmk = 15083,
  VPMINSWZrmkz = 15084,
  VPMINSWZrr = 15085,
  VPMINSWZrrk = 15086,
  VPMINSWZrrkz = 15087,
  VPMINSWrm = 15088,
  VPMINSWrr = 15089,
  VPMINUBYrm = 15090,
  VPMINUBYrr = 15091,
  VPMINUBZ128rm = 15092,
  VPMINUBZ128rmk = 15093,
  VPMINUBZ128rmkz = 15094,
  VPMINUBZ128rr = 15095,
  VPMINUBZ128rrk = 15096,
  VPMINUBZ128rrkz = 15097,
  VPMINUBZ256rm = 15098,
  VPMINUBZ256rmk = 15099,
  VPMINUBZ256rmkz = 15100,
  VPMINUBZ256rr = 15101,
  VPMINUBZ256rrk = 15102,
  VPMINUBZ256rrkz = 15103,
  VPMINUBZrm = 15104,
  VPMINUBZrmk = 15105,
  VPMINUBZrmkz = 15106,
  VPMINUBZrr = 15107,
  VPMINUBZrrk = 15108,
  VPMINUBZrrkz = 15109,
  VPMINUBrm = 15110,
  VPMINUBrr = 15111,
  VPMINUDYrm = 15112,
  VPMINUDYrr = 15113,
  VPMINUDZ128rm = 15114,
  VPMINUDZ128rmb = 15115,
  VPMINUDZ128rmbk = 15116,
  VPMINUDZ128rmbkz = 15117,
  VPMINUDZ128rmk = 15118,
  VPMINUDZ128rmkz = 15119,
  VPMINUDZ128rr = 15120,
  VPMINUDZ128rrk = 15121,
  VPMINUDZ128rrkz = 15122,
  VPMINUDZ256rm = 15123,
  VPMINUDZ256rmb = 15124,
  VPMINUDZ256rmbk = 15125,
  VPMINUDZ256rmbkz = 15126,
  VPMINUDZ256rmk = 15127,
  VPMINUDZ256rmkz = 15128,
  VPMINUDZ256rr = 15129,
  VPMINUDZ256rrk = 15130,
  VPMINUDZ256rrkz = 15131,
  VPMINUDZrm = 15132,
  VPMINUDZrmb = 15133,
  VPMINUDZrmbk = 15134,
  VPMINUDZrmbkz = 15135,
  VPMINUDZrmk = 15136,
  VPMINUDZrmkz = 15137,
  VPMINUDZrr = 15138,
  VPMINUDZrrk = 15139,
  VPMINUDZrrkz = 15140,
  VPMINUDrm = 15141,
  VPMINUDrr = 15142,
  VPMINUQZ128rm = 15143,
  VPMINUQZ128rmb = 15144,
  VPMINUQZ128rmbk = 15145,
  VPMINUQZ128rmbkz = 15146,
  VPMINUQZ128rmk = 15147,
  VPMINUQZ128rmkz = 15148,
  VPMINUQZ128rr = 15149,
  VPMINUQZ128rrk = 15150,
  VPMINUQZ128rrkz = 15151,
  VPMINUQZ256rm = 15152,
  VPMINUQZ256rmb = 15153,
  VPMINUQZ256rmbk = 15154,
  VPMINUQZ256rmbkz = 15155,
  VPMINUQZ256rmk = 15156,
  VPMINUQZ256rmkz = 15157,
  VPMINUQZ256rr = 15158,
  VPMINUQZ256rrk = 15159,
  VPMINUQZ256rrkz = 15160,
  VPMINUQZrm = 15161,
  VPMINUQZrmb = 15162,
  VPMINUQZrmbk = 15163,
  VPMINUQZrmbkz = 15164,
  VPMINUQZrmk = 15165,
  VPMINUQZrmkz = 15166,
  VPMINUQZrr = 15167,
  VPMINUQZrrk = 15168,
  VPMINUQZrrkz = 15169,
  VPMINUWYrm = 15170,
  VPMINUWYrr = 15171,
  VPMINUWZ128rm = 15172,
  VPMINUWZ128rmk = 15173,
  VPMINUWZ128rmkz = 15174,
  VPMINUWZ128rr = 15175,
  VPMINUWZ128rrk = 15176,
  VPMINUWZ128rrkz = 15177,
  VPMINUWZ256rm = 15178,
  VPMINUWZ256rmk = 15179,
  VPMINUWZ256rmkz = 15180,
  VPMINUWZ256rr = 15181,
  VPMINUWZ256rrk = 15182,
  VPMINUWZ256rrkz = 15183,
  VPMINUWZrm = 15184,
  VPMINUWZrmk = 15185,
  VPMINUWZrmkz = 15186,
  VPMINUWZrr = 15187,
  VPMINUWZrrk = 15188,
  VPMINUWZrrkz = 15189,
  VPMINUWrm = 15190,
  VPMINUWrr = 15191,
  VPMOVB2MZ128rr = 15192,
  VPMOVB2MZ256rr = 15193,
  VPMOVB2MZrr = 15194,
  VPMOVD2MZ128rr = 15195,
  VPMOVD2MZ256rr = 15196,
  VPMOVD2MZrr = 15197,
  VPMOVDBZ128mr = 15198,
  VPMOVDBZ128mrk = 15199,
  VPMOVDBZ128rr = 15200,
  VPMOVDBZ128rrk = 15201,
  VPMOVDBZ128rrkz = 15202,
  VPMOVDBZ256mr = 15203,
  VPMOVDBZ256mrk = 15204,
  VPMOVDBZ256rr = 15205,
  VPMOVDBZ256rrk = 15206,
  VPMOVDBZ256rrkz = 15207,
  VPMOVDBZmr = 15208,
  VPMOVDBZmrk = 15209,
  VPMOVDBZrr = 15210,
  VPMOVDBZrrk = 15211,
  VPMOVDBZrrkz = 15212,
  VPMOVDWZ128mr = 15213,
  VPMOVDWZ128mrk = 15214,
  VPMOVDWZ128rr = 15215,
  VPMOVDWZ128rrk = 15216,
  VPMOVDWZ128rrkz = 15217,
  VPMOVDWZ256mr = 15218,
  VPMOVDWZ256mrk = 15219,
  VPMOVDWZ256rr = 15220,
  VPMOVDWZ256rrk = 15221,
  VPMOVDWZ256rrkz = 15222,
  VPMOVDWZmr = 15223,
  VPMOVDWZmrk = 15224,
  VPMOVDWZrr = 15225,
  VPMOVDWZrrk = 15226,
  VPMOVDWZrrkz = 15227,
  VPMOVM2BZ128rr = 15228,
  VPMOVM2BZ256rr = 15229,
  VPMOVM2BZrr = 15230,
  VPMOVM2DZ128rr = 15231,
  VPMOVM2DZ256rr = 15232,
  VPMOVM2DZrr = 15233,
  VPMOVM2QZ128rr = 15234,
  VPMOVM2QZ256rr = 15235,
  VPMOVM2QZrr = 15236,
  VPMOVM2WZ128rr = 15237,
  VPMOVM2WZ256rr = 15238,
  VPMOVM2WZrr = 15239,
  VPMOVMSKBYrr = 15240,
  VPMOVMSKBrr = 15241,
  VPMOVQ2MZ128rr = 15242,
  VPMOVQ2MZ256rr = 15243,
  VPMOVQ2MZrr = 15244,
  VPMOVQBZ128mr = 15245,
  VPMOVQBZ128mrk = 15246,
  VPMOVQBZ128rr = 15247,
  VPMOVQBZ128rrk = 15248,
  VPMOVQBZ128rrkz = 15249,
  VPMOVQBZ256mr = 15250,
  VPMOVQBZ256mrk = 15251,
  VPMOVQBZ256rr = 15252,
  VPMOVQBZ256rrk = 15253,
  VPMOVQBZ256rrkz = 15254,
  VPMOVQBZmr = 15255,
  VPMOVQBZmrk = 15256,
  VPMOVQBZrr = 15257,
  VPMOVQBZrrk = 15258,
  VPMOVQBZrrkz = 15259,
  VPMOVQDZ128mr = 15260,
  VPMOVQDZ128mrk = 15261,
  VPMOVQDZ128rr = 15262,
  VPMOVQDZ128rrk = 15263,
  VPMOVQDZ128rrkz = 15264,
  VPMOVQDZ256mr = 15265,
  VPMOVQDZ256mrk = 15266,
  VPMOVQDZ256rr = 15267,
  VPMOVQDZ256rrk = 15268,
  VPMOVQDZ256rrkz = 15269,
  VPMOVQDZmr = 15270,
  VPMOVQDZmrk = 15271,
  VPMOVQDZrr = 15272,
  VPMOVQDZrrk = 15273,
  VPMOVQDZrrkz = 15274,
  VPMOVQWZ128mr = 15275,
  VPMOVQWZ128mrk = 15276,
  VPMOVQWZ128rr = 15277,
  VPMOVQWZ128rrk = 15278,
  VPMOVQWZ128rrkz = 15279,
  VPMOVQWZ256mr = 15280,
  VPMOVQWZ256mrk = 15281,
  VPMOVQWZ256rr = 15282,
  VPMOVQWZ256rrk = 15283,
  VPMOVQWZ256rrkz = 15284,
  VPMOVQWZmr = 15285,
  VPMOVQWZmrk = 15286,
  VPMOVQWZrr = 15287,
  VPMOVQWZrrk = 15288,
  VPMOVQWZrrkz = 15289,
  VPMOVSDBZ128mr = 15290,
  VPMOVSDBZ128mrk = 15291,
  VPMOVSDBZ128rr = 15292,
  VPMOVSDBZ128rrk = 15293,
  VPMOVSDBZ128rrkz = 15294,
  VPMOVSDBZ256mr = 15295,
  VPMOVSDBZ256mrk = 15296,
  VPMOVSDBZ256rr = 15297,
  VPMOVSDBZ256rrk = 15298,
  VPMOVSDBZ256rrkz = 15299,
  VPMOVSDBZmr = 15300,
  VPMOVSDBZmrk = 15301,
  VPMOVSDBZrr = 15302,
  VPMOVSDBZrrk = 15303,
  VPMOVSDBZrrkz = 15304,
  VPMOVSDWZ128mr = 15305,
  VPMOVSDWZ128mrk = 15306,
  VPMOVSDWZ128rr = 15307,
  VPMOVSDWZ128rrk = 15308,
  VPMOVSDWZ128rrkz = 15309,
  VPMOVSDWZ256mr = 15310,
  VPMOVSDWZ256mrk = 15311,
  VPMOVSDWZ256rr = 15312,
  VPMOVSDWZ256rrk = 15313,
  VPMOVSDWZ256rrkz = 15314,
  VPMOVSDWZmr = 15315,
  VPMOVSDWZmrk = 15316,
  VPMOVSDWZrr = 15317,
  VPMOVSDWZrrk = 15318,
  VPMOVSDWZrrkz = 15319,
  VPMOVSQBZ128mr = 15320,
  VPMOVSQBZ128mrk = 15321,
  VPMOVSQBZ128rr = 15322,
  VPMOVSQBZ128rrk = 15323,
  VPMOVSQBZ128rrkz = 15324,
  VPMOVSQBZ256mr = 15325,
  VPMOVSQBZ256mrk = 15326,
  VPMOVSQBZ256rr = 15327,
  VPMOVSQBZ256rrk = 15328,
  VPMOVSQBZ256rrkz = 15329,
  VPMOVSQBZmr = 15330,
  VPMOVSQBZmrk = 15331,
  VPMOVSQBZrr = 15332,
  VPMOVSQBZrrk = 15333,
  VPMOVSQBZrrkz = 15334,
  VPMOVSQDZ128mr = 15335,
  VPMOVSQDZ128mrk = 15336,
  VPMOVSQDZ128rr = 15337,
  VPMOVSQDZ128rrk = 15338,
  VPMOVSQDZ128rrkz = 15339,
  VPMOVSQDZ256mr = 15340,
  VPMOVSQDZ256mrk = 15341,
  VPMOVSQDZ256rr = 15342,
  VPMOVSQDZ256rrk = 15343,
  VPMOVSQDZ256rrkz = 15344,
  VPMOVSQDZmr = 15345,
  VPMOVSQDZmrk = 15346,
  VPMOVSQDZrr = 15347,
  VPMOVSQDZrrk = 15348,
  VPMOVSQDZrrkz = 15349,
  VPMOVSQWZ128mr = 15350,
  VPMOVSQWZ128mrk = 15351,
  VPMOVSQWZ128rr = 15352,
  VPMOVSQWZ128rrk = 15353,
  VPMOVSQWZ128rrkz = 15354,
  VPMOVSQWZ256mr = 15355,
  VPMOVSQWZ256mrk = 15356,
  VPMOVSQWZ256rr = 15357,
  VPMOVSQWZ256rrk = 15358,
  VPMOVSQWZ256rrkz = 15359,
  VPMOVSQWZmr = 15360,
  VPMOVSQWZmrk = 15361,
  VPMOVSQWZrr = 15362,
  VPMOVSQWZrrk = 15363,
  VPMOVSQWZrrkz = 15364,
  VPMOVSWBZ128mr = 15365,
  VPMOVSWBZ128mrk = 15366,
  VPMOVSWBZ128rr = 15367,
  VPMOVSWBZ128rrk = 15368,
  VPMOVSWBZ128rrkz = 15369,
  VPMOVSWBZ256mr = 15370,
  VPMOVSWBZ256mrk = 15371,
  VPMOVSWBZ256rr = 15372,
  VPMOVSWBZ256rrk = 15373,
  VPMOVSWBZ256rrkz = 15374,
  VPMOVSWBZmr = 15375,
  VPMOVSWBZmrk = 15376,
  VPMOVSWBZrr = 15377,
  VPMOVSWBZrrk = 15378,
  VPMOVSWBZrrkz = 15379,
  VPMOVSXBDYrm = 15380,
  VPMOVSXBDYrr = 15381,
  VPMOVSXBDZ128rm = 15382,
  VPMOVSXBDZ128rmk = 15383,
  VPMOVSXBDZ128rmkz = 15384,
  VPMOVSXBDZ128rr = 15385,
  VPMOVSXBDZ128rrk = 15386,
  VPMOVSXBDZ128rrkz = 15387,
  VPMOVSXBDZ256rm = 15388,
  VPMOVSXBDZ256rmk = 15389,
  VPMOVSXBDZ256rmkz = 15390,
  VPMOVSXBDZ256rr = 15391,
  VPMOVSXBDZ256rrk = 15392,
  VPMOVSXBDZ256rrkz = 15393,
  VPMOVSXBDZrm = 15394,
  VPMOVSXBDZrmk = 15395,
  VPMOVSXBDZrmkz = 15396,
  VPMOVSXBDZrr = 15397,
  VPMOVSXBDZrrk = 15398,
  VPMOVSXBDZrrkz = 15399,
  VPMOVSXBDrm = 15400,
  VPMOVSXBDrr = 15401,
  VPMOVSXBQYrm = 15402,
  VPMOVSXBQYrr = 15403,
  VPMOVSXBQZ128rm = 15404,
  VPMOVSXBQZ128rmk = 15405,
  VPMOVSXBQZ128rmkz = 15406,
  VPMOVSXBQZ128rr = 15407,
  VPMOVSXBQZ128rrk = 15408,
  VPMOVSXBQZ128rrkz = 15409,
  VPMOVSXBQZ256rm = 15410,
  VPMOVSXBQZ256rmk = 15411,
  VPMOVSXBQZ256rmkz = 15412,
  VPMOVSXBQZ256rr = 15413,
  VPMOVSXBQZ256rrk = 15414,
  VPMOVSXBQZ256rrkz = 15415,
  VPMOVSXBQZrm = 15416,
  VPMOVSXBQZrmk = 15417,
  VPMOVSXBQZrmkz = 15418,
  VPMOVSXBQZrr = 15419,
  VPMOVSXBQZrrk = 15420,
  VPMOVSXBQZrrkz = 15421,
  VPMOVSXBQrm = 15422,
  VPMOVSXBQrr = 15423,
  VPMOVSXBWYrm = 15424,
  VPMOVSXBWYrr = 15425,
  VPMOVSXBWZ128rm = 15426,
  VPMOVSXBWZ128rmk = 15427,
  VPMOVSXBWZ128rmkz = 15428,
  VPMOVSXBWZ128rr = 15429,
  VPMOVSXBWZ128rrk = 15430,
  VPMOVSXBWZ128rrkz = 15431,
  VPMOVSXBWZ256rm = 15432,
  VPMOVSXBWZ256rmk = 15433,
  VPMOVSXBWZ256rmkz = 15434,
  VPMOVSXBWZ256rr = 15435,
  VPMOVSXBWZ256rrk = 15436,
  VPMOVSXBWZ256rrkz = 15437,
  VPMOVSXBWZrm = 15438,
  VPMOVSXBWZrmk = 15439,
  VPMOVSXBWZrmkz = 15440,
  VPMOVSXBWZrr = 15441,
  VPMOVSXBWZrrk = 15442,
  VPMOVSXBWZrrkz = 15443,
  VPMOVSXBWrm = 15444,
  VPMOVSXBWrr = 15445,
  VPMOVSXDQYrm = 15446,
  VPMOVSXDQYrr = 15447,
  VPMOVSXDQZ128rm = 15448,
  VPMOVSXDQZ128rmk = 15449,
  VPMOVSXDQZ128rmkz = 15450,
  VPMOVSXDQZ128rr = 15451,
  VPMOVSXDQZ128rrk = 15452,
  VPMOVSXDQZ128rrkz = 15453,
  VPMOVSXDQZ256rm = 15454,
  VPMOVSXDQZ256rmk = 15455,
  VPMOVSXDQZ256rmkz = 15456,
  VPMOVSXDQZ256rr = 15457,
  VPMOVSXDQZ256rrk = 15458,
  VPMOVSXDQZ256rrkz = 15459,
  VPMOVSXDQZrm = 15460,
  VPMOVSXDQZrmk = 15461,
  VPMOVSXDQZrmkz = 15462,
  VPMOVSXDQZrr = 15463,
  VPMOVSXDQZrrk = 15464,
  VPMOVSXDQZrrkz = 15465,
  VPMOVSXDQrm = 15466,
  VPMOVSXDQrr = 15467,
  VPMOVSXWDYrm = 15468,
  VPMOVSXWDYrr = 15469,
  VPMOVSXWDZ128rm = 15470,
  VPMOVSXWDZ128rmk = 15471,
  VPMOVSXWDZ128rmkz = 15472,
  VPMOVSXWDZ128rr = 15473,
  VPMOVSXWDZ128rrk = 15474,
  VPMOVSXWDZ128rrkz = 15475,
  VPMOVSXWDZ256rm = 15476,
  VPMOVSXWDZ256rmk = 15477,
  VPMOVSXWDZ256rmkz = 15478,
  VPMOVSXWDZ256rr = 15479,
  VPMOVSXWDZ256rrk = 15480,
  VPMOVSXWDZ256rrkz = 15481,
  VPMOVSXWDZrm = 15482,
  VPMOVSXWDZrmk = 15483,
  VPMOVSXWDZrmkz = 15484,
  VPMOVSXWDZrr = 15485,
  VPMOVSXWDZrrk = 15486,
  VPMOVSXWDZrrkz = 15487,
  VPMOVSXWDrm = 15488,
  VPMOVSXWDrr = 15489,
  VPMOVSXWQYrm = 15490,
  VPMOVSXWQYrr = 15491,
  VPMOVSXWQZ128rm = 15492,
  VPMOVSXWQZ128rmk = 15493,
  VPMOVSXWQZ128rmkz = 15494,
  VPMOVSXWQZ128rr = 15495,
  VPMOVSXWQZ128rrk = 15496,
  VPMOVSXWQZ128rrkz = 15497,
  VPMOVSXWQZ256rm = 15498,
  VPMOVSXWQZ256rmk = 15499,
  VPMOVSXWQZ256rmkz = 15500,
  VPMOVSXWQZ256rr = 15501,
  VPMOVSXWQZ256rrk = 15502,
  VPMOVSXWQZ256rrkz = 15503,
  VPMOVSXWQZrm = 15504,
  VPMOVSXWQZrmk = 15505,
  VPMOVSXWQZrmkz = 15506,
  VPMOVSXWQZrr = 15507,
  VPMOVSXWQZrrk = 15508,
  VPMOVSXWQZrrkz = 15509,
  VPMOVSXWQrm = 15510,
  VPMOVSXWQrr = 15511,
  VPMOVUSDBZ128mr = 15512,
  VPMOVUSDBZ128mrk = 15513,
  VPMOVUSDBZ128rr = 15514,
  VPMOVUSDBZ128rrk = 15515,
  VPMOVUSDBZ128rrkz = 15516,
  VPMOVUSDBZ256mr = 15517,
  VPMOVUSDBZ256mrk = 15518,
  VPMOVUSDBZ256rr = 15519,
  VPMOVUSDBZ256rrk = 15520,
  VPMOVUSDBZ256rrkz = 15521,
  VPMOVUSDBZmr = 15522,
  VPMOVUSDBZmrk = 15523,
  VPMOVUSDBZrr = 15524,
  VPMOVUSDBZrrk = 15525,
  VPMOVUSDBZrrkz = 15526,
  VPMOVUSDWZ128mr = 15527,
  VPMOVUSDWZ128mrk = 15528,
  VPMOVUSDWZ128rr = 15529,
  VPMOVUSDWZ128rrk = 15530,
  VPMOVUSDWZ128rrkz = 15531,
  VPMOVUSDWZ256mr = 15532,
  VPMOVUSDWZ256mrk = 15533,
  VPMOVUSDWZ256rr = 15534,
  VPMOVUSDWZ256rrk = 15535,
  VPMOVUSDWZ256rrkz = 15536,
  VPMOVUSDWZmr = 15537,
  VPMOVUSDWZmrk = 15538,
  VPMOVUSDWZrr = 15539,
  VPMOVUSDWZrrk = 15540,
  VPMOVUSDWZrrkz = 15541,
  VPMOVUSQBZ128mr = 15542,
  VPMOVUSQBZ128mrk = 15543,
  VPMOVUSQBZ128rr = 15544,
  VPMOVUSQBZ128rrk = 15545,
  VPMOVUSQBZ128rrkz = 15546,
  VPMOVUSQBZ256mr = 15547,
  VPMOVUSQBZ256mrk = 15548,
  VPMOVUSQBZ256rr = 15549,
  VPMOVUSQBZ256rrk = 15550,
  VPMOVUSQBZ256rrkz = 15551,
  VPMOVUSQBZmr = 15552,
  VPMOVUSQBZmrk = 15553,
  VPMOVUSQBZrr = 15554,
  VPMOVUSQBZrrk = 15555,
  VPMOVUSQBZrrkz = 15556,
  VPMOVUSQDZ128mr = 15557,
  VPMOVUSQDZ128mrk = 15558,
  VPMOVUSQDZ128rr = 15559,
  VPMOVUSQDZ128rrk = 15560,
  VPMOVUSQDZ128rrkz = 15561,
  VPMOVUSQDZ256mr = 15562,
  VPMOVUSQDZ256mrk = 15563,
  VPMOVUSQDZ256rr = 15564,
  VPMOVUSQDZ256rrk = 15565,
  VPMOVUSQDZ256rrkz = 15566,
  VPMOVUSQDZmr = 15567,
  VPMOVUSQDZmrk = 15568,
  VPMOVUSQDZrr = 15569,
  VPMOVUSQDZrrk = 15570,
  VPMOVUSQDZrrkz = 15571,
  VPMOVUSQWZ128mr = 15572,
  VPMOVUSQWZ128mrk = 15573,
  VPMOVUSQWZ128rr = 15574,
  VPMOVUSQWZ128rrk = 15575,
  VPMOVUSQWZ128rrkz = 15576,
  VPMOVUSQWZ256mr = 15577,
  VPMOVUSQWZ256mrk = 15578,
  VPMOVUSQWZ256rr = 15579,
  VPMOVUSQWZ256rrk = 15580,
  VPMOVUSQWZ256rrkz = 15581,
  VPMOVUSQWZmr = 15582,
  VPMOVUSQWZmrk = 15583,
  VPMOVUSQWZrr = 15584,
  VPMOVUSQWZrrk = 15585,
  VPMOVUSQWZrrkz = 15586,
  VPMOVUSWBZ128mr = 15587,
  VPMOVUSWBZ128mrk = 15588,
  VPMOVUSWBZ128rr = 15589,
  VPMOVUSWBZ128rrk = 15590,
  VPMOVUSWBZ128rrkz = 15591,
  VPMOVUSWBZ256mr = 15592,
  VPMOVUSWBZ256mrk = 15593,
  VPMOVUSWBZ256rr = 15594,
  VPMOVUSWBZ256rrk = 15595,
  VPMOVUSWBZ256rrkz = 15596,
  VPMOVUSWBZmr = 15597,
  VPMOVUSWBZmrk = 15598,
  VPMOVUSWBZrr = 15599,
  VPMOVUSWBZrrk = 15600,
  VPMOVUSWBZrrkz = 15601,
  VPMOVW2MZ128rr = 15602,
  VPMOVW2MZ256rr = 15603,
  VPMOVW2MZrr = 15604,
  VPMOVWBZ128mr = 15605,
  VPMOVWBZ128mrk = 15606,
  VPMOVWBZ128rr = 15607,
  VPMOVWBZ128rrk = 15608,
  VPMOVWBZ128rrkz = 15609,
  VPMOVWBZ256mr = 15610,
  VPMOVWBZ256mrk = 15611,
  VPMOVWBZ256rr = 15612,
  VPMOVWBZ256rrk = 15613,
  VPMOVWBZ256rrkz = 15614,
  VPMOVWBZmr = 15615,
  VPMOVWBZmrk = 15616,
  VPMOVWBZrr = 15617,
  VPMOVWBZrrk = 15618,
  VPMOVWBZrrkz = 15619,
  VPMOVZXBDYrm = 15620,
  VPMOVZXBDYrr = 15621,
  VPMOVZXBDZ128rm = 15622,
  VPMOVZXBDZ128rmk = 15623,
  VPMOVZXBDZ128rmkz = 15624,
  VPMOVZXBDZ128rr = 15625,
  VPMOVZXBDZ128rrk = 15626,
  VPMOVZXBDZ128rrkz = 15627,
  VPMOVZXBDZ256rm = 15628,
  VPMOVZXBDZ256rmk = 15629,
  VPMOVZXBDZ256rmkz = 15630,
  VPMOVZXBDZ256rr = 15631,
  VPMOVZXBDZ256rrk = 15632,
  VPMOVZXBDZ256rrkz = 15633,
  VPMOVZXBDZrm = 15634,
  VPMOVZXBDZrmk = 15635,
  VPMOVZXBDZrmkz = 15636,
  VPMOVZXBDZrr = 15637,
  VPMOVZXBDZrrk = 15638,
  VPMOVZXBDZrrkz = 15639,
  VPMOVZXBDrm = 15640,
  VPMOVZXBDrr = 15641,
  VPMOVZXBQYrm = 15642,
  VPMOVZXBQYrr = 15643,
  VPMOVZXBQZ128rm = 15644,
  VPMOVZXBQZ128rmk = 15645,
  VPMOVZXBQZ128rmkz = 15646,
  VPMOVZXBQZ128rr = 15647,
  VPMOVZXBQZ128rrk = 15648,
  VPMOVZXBQZ128rrkz = 15649,
  VPMOVZXBQZ256rm = 15650,
  VPMOVZXBQZ256rmk = 15651,
  VPMOVZXBQZ256rmkz = 15652,
  VPMOVZXBQZ256rr = 15653,
  VPMOVZXBQZ256rrk = 15654,
  VPMOVZXBQZ256rrkz = 15655,
  VPMOVZXBQZrm = 15656,
  VPMOVZXBQZrmk = 15657,
  VPMOVZXBQZrmkz = 15658,
  VPMOVZXBQZrr = 15659,
  VPMOVZXBQZrrk = 15660,
  VPMOVZXBQZrrkz = 15661,
  VPMOVZXBQrm = 15662,
  VPMOVZXBQrr = 15663,
  VPMOVZXBWYrm = 15664,
  VPMOVZXBWYrr = 15665,
  VPMOVZXBWZ128rm = 15666,
  VPMOVZXBWZ128rmk = 15667,
  VPMOVZXBWZ128rmkz = 15668,
  VPMOVZXBWZ128rr = 15669,
  VPMOVZXBWZ128rrk = 15670,
  VPMOVZXBWZ128rrkz = 15671,
  VPMOVZXBWZ256rm = 15672,
  VPMOVZXBWZ256rmk = 15673,
  VPMOVZXBWZ256rmkz = 15674,
  VPMOVZXBWZ256rr = 15675,
  VPMOVZXBWZ256rrk = 15676,
  VPMOVZXBWZ256rrkz = 15677,
  VPMOVZXBWZrm = 15678,
  VPMOVZXBWZrmk = 15679,
  VPMOVZXBWZrmkz = 15680,
  VPMOVZXBWZrr = 15681,
  VPMOVZXBWZrrk = 15682,
  VPMOVZXBWZrrkz = 15683,
  VPMOVZXBWrm = 15684,
  VPMOVZXBWrr = 15685,
  VPMOVZXDQYrm = 15686,
  VPMOVZXDQYrr = 15687,
  VPMOVZXDQZ128rm = 15688,
  VPMOVZXDQZ128rmk = 15689,
  VPMOVZXDQZ128rmkz = 15690,
  VPMOVZXDQZ128rr = 15691,
  VPMOVZXDQZ128rrk = 15692,
  VPMOVZXDQZ128rrkz = 15693,
  VPMOVZXDQZ256rm = 15694,
  VPMOVZXDQZ256rmk = 15695,
  VPMOVZXDQZ256rmkz = 15696,
  VPMOVZXDQZ256rr = 15697,
  VPMOVZXDQZ256rrk = 15698,
  VPMOVZXDQZ256rrkz = 15699,
  VPMOVZXDQZrm = 15700,
  VPMOVZXDQZrmk = 15701,
  VPMOVZXDQZrmkz = 15702,
  VPMOVZXDQZrr = 15703,
  VPMOVZXDQZrrk = 15704,
  VPMOVZXDQZrrkz = 15705,
  VPMOVZXDQrm = 15706,
  VPMOVZXDQrr = 15707,
  VPMOVZXWDYrm = 15708,
  VPMOVZXWDYrr = 15709,
  VPMOVZXWDZ128rm = 15710,
  VPMOVZXWDZ128rmk = 15711,
  VPMOVZXWDZ128rmkz = 15712,
  VPMOVZXWDZ128rr = 15713,
  VPMOVZXWDZ128rrk = 15714,
  VPMOVZXWDZ128rrkz = 15715,
  VPMOVZXWDZ256rm = 15716,
  VPMOVZXWDZ256rmk = 15717,
  VPMOVZXWDZ256rmkz = 15718,
  VPMOVZXWDZ256rr = 15719,
  VPMOVZXWDZ256rrk = 15720,
  VPMOVZXWDZ256rrkz = 15721,
  VPMOVZXWDZrm = 15722,
  VPMOVZXWDZrmk = 15723,
  VPMOVZXWDZrmkz = 15724,
  VPMOVZXWDZrr = 15725,
  VPMOVZXWDZrrk = 15726,
  VPMOVZXWDZrrkz = 15727,
  VPMOVZXWDrm = 15728,
  VPMOVZXWDrr = 15729,
  VPMOVZXWQYrm = 15730,
  VPMOVZXWQYrr = 15731,
  VPMOVZXWQZ128rm = 15732,
  VPMOVZXWQZ128rmk = 15733,
  VPMOVZXWQZ128rmkz = 15734,
  VPMOVZXWQZ128rr = 15735,
  VPMOVZXWQZ128rrk = 15736,
  VPMOVZXWQZ128rrkz = 15737,
  VPMOVZXWQZ256rm = 15738,
  VPMOVZXWQZ256rmk = 15739,
  VPMOVZXWQZ256rmkz = 15740,
  VPMOVZXWQZ256rr = 15741,
  VPMOVZXWQZ256rrk = 15742,
  VPMOVZXWQZ256rrkz = 15743,
  VPMOVZXWQZrm = 15744,
  VPMOVZXWQZrmk = 15745,
  VPMOVZXWQZrmkz = 15746,
  VPMOVZXWQZrr = 15747,
  VPMOVZXWQZrrk = 15748,
  VPMOVZXWQZrrkz = 15749,
  VPMOVZXWQrm = 15750,
  VPMOVZXWQrr = 15751,
  VPMULDQYrm = 15752,
  VPMULDQYrr = 15753,
  VPMULDQZ128rm = 15754,
  VPMULDQZ128rmb = 15755,
  VPMULDQZ128rmbk = 15756,
  VPMULDQZ128rmbkz = 15757,
  VPMULDQZ128rmk = 15758,
  VPMULDQZ128rmkz = 15759,
  VPMULDQZ128rr = 15760,
  VPMULDQZ128rrk = 15761,
  VPMULDQZ128rrkz = 15762,
  VPMULDQZ256rm = 15763,
  VPMULDQZ256rmb = 15764,
  VPMULDQZ256rmbk = 15765,
  VPMULDQZ256rmbkz = 15766,
  VPMULDQZ256rmk = 15767,
  VPMULDQZ256rmkz = 15768,
  VPMULDQZ256rr = 15769,
  VPMULDQZ256rrk = 15770,
  VPMULDQZ256rrkz = 15771,
  VPMULDQZrm = 15772,
  VPMULDQZrmb = 15773,
  VPMULDQZrmbk = 15774,
  VPMULDQZrmbkz = 15775,
  VPMULDQZrmk = 15776,
  VPMULDQZrmkz = 15777,
  VPMULDQZrr = 15778,
  VPMULDQZrrk = 15779,
  VPMULDQZrrkz = 15780,
  VPMULDQrm = 15781,
  VPMULDQrr = 15782,
  VPMULHRSWYrm = 15783,
  VPMULHRSWYrr = 15784,
  VPMULHRSWZ128rm = 15785,
  VPMULHRSWZ128rmk = 15786,
  VPMULHRSWZ128rmkz = 15787,
  VPMULHRSWZ128rr = 15788,
  VPMULHRSWZ128rrk = 15789,
  VPMULHRSWZ128rrkz = 15790,
  VPMULHRSWZ256rm = 15791,
  VPMULHRSWZ256rmk = 15792,
  VPMULHRSWZ256rmkz = 15793,
  VPMULHRSWZ256rr = 15794,
  VPMULHRSWZ256rrk = 15795,
  VPMULHRSWZ256rrkz = 15796,
  VPMULHRSWZrm = 15797,
  VPMULHRSWZrmk = 15798,
  VPMULHRSWZrmkz = 15799,
  VPMULHRSWZrr = 15800,
  VPMULHRSWZrrk = 15801,
  VPMULHRSWZrrkz = 15802,
  VPMULHRSWrm = 15803,
  VPMULHRSWrr = 15804,
  VPMULHUWYrm = 15805,
  VPMULHUWYrr = 15806,
  VPMULHUWZ128rm = 15807,
  VPMULHUWZ128rmk = 15808,
  VPMULHUWZ128rmkz = 15809,
  VPMULHUWZ128rr = 15810,
  VPMULHUWZ128rrk = 15811,
  VPMULHUWZ128rrkz = 15812,
  VPMULHUWZ256rm = 15813,
  VPMULHUWZ256rmk = 15814,
  VPMULHUWZ256rmkz = 15815,
  VPMULHUWZ256rr = 15816,
  VPMULHUWZ256rrk = 15817,
  VPMULHUWZ256rrkz = 15818,
  VPMULHUWZrm = 15819,
  VPMULHUWZrmk = 15820,
  VPMULHUWZrmkz = 15821,
  VPMULHUWZrr = 15822,
  VPMULHUWZrrk = 15823,
  VPMULHUWZrrkz = 15824,
  VPMULHUWrm = 15825,
  VPMULHUWrr = 15826,
  VPMULHWYrm = 15827,
  VPMULHWYrr = 15828,
  VPMULHWZ128rm = 15829,
  VPMULHWZ128rmk = 15830,
  VPMULHWZ128rmkz = 15831,
  VPMULHWZ128rr = 15832,
  VPMULHWZ128rrk = 15833,
  VPMULHWZ128rrkz = 15834,
  VPMULHWZ256rm = 15835,
  VPMULHWZ256rmk = 15836,
  VPMULHWZ256rmkz = 15837,
  VPMULHWZ256rr = 15838,
  VPMULHWZ256rrk = 15839,
  VPMULHWZ256rrkz = 15840,
  VPMULHWZrm = 15841,
  VPMULHWZrmk = 15842,
  VPMULHWZrmkz = 15843,
  VPMULHWZrr = 15844,
  VPMULHWZrrk = 15845,
  VPMULHWZrrkz = 15846,
  VPMULHWrm = 15847,
  VPMULHWrr = 15848,
  VPMULLDYrm = 15849,
  VPMULLDYrr = 15850,
  VPMULLDZ128rm = 15851,
  VPMULLDZ128rmb = 15852,
  VPMULLDZ128rmbk = 15853,
  VPMULLDZ128rmbkz = 15854,
  VPMULLDZ128rmk = 15855,
  VPMULLDZ128rmkz = 15856,
  VPMULLDZ128rr = 15857,
  VPMULLDZ128rrk = 15858,
  VPMULLDZ128rrkz = 15859,
  VPMULLDZ256rm = 15860,
  VPMULLDZ256rmb = 15861,
  VPMULLDZ256rmbk = 15862,
  VPMULLDZ256rmbkz = 15863,
  VPMULLDZ256rmk = 15864,
  VPMULLDZ256rmkz = 15865,
  VPMULLDZ256rr = 15866,
  VPMULLDZ256rrk = 15867,
  VPMULLDZ256rrkz = 15868,
  VPMULLDZrm = 15869,
  VPMULLDZrmb = 15870,
  VPMULLDZrmbk = 15871,
  VPMULLDZrmbkz = 15872,
  VPMULLDZrmk = 15873,
  VPMULLDZrmkz = 15874,
  VPMULLDZrr = 15875,
  VPMULLDZrrk = 15876,
  VPMULLDZrrkz = 15877,
  VPMULLDrm = 15878,
  VPMULLDrr = 15879,
  VPMULLQZ128rm = 15880,
  VPMULLQZ128rmb = 15881,
  VPMULLQZ128rmbk = 15882,
  VPMULLQZ128rmbkz = 15883,
  VPMULLQZ128rmk = 15884,
  VPMULLQZ128rmkz = 15885,
  VPMULLQZ128rr = 15886,
  VPMULLQZ128rrk = 15887,
  VPMULLQZ128rrkz = 15888,
  VPMULLQZ256rm = 15889,
  VPMULLQZ256rmb = 15890,
  VPMULLQZ256rmbk = 15891,
  VPMULLQZ256rmbkz = 15892,
  VPMULLQZ256rmk = 15893,
  VPMULLQZ256rmkz = 15894,
  VPMULLQZ256rr = 15895,
  VPMULLQZ256rrk = 15896,
  VPMULLQZ256rrkz = 15897,
  VPMULLQZrm = 15898,
  VPMULLQZrmb = 15899,
  VPMULLQZrmbk = 15900,
  VPMULLQZrmbkz = 15901,
  VPMULLQZrmk = 15902,
  VPMULLQZrmkz = 15903,
  VPMULLQZrr = 15904,
  VPMULLQZrrk = 15905,
  VPMULLQZrrkz = 15906,
  VPMULLWYrm = 15907,
  VPMULLWYrr = 15908,
  VPMULLWZ128rm = 15909,
  VPMULLWZ128rmk = 15910,
  VPMULLWZ128rmkz = 15911,
  VPMULLWZ128rr = 15912,
  VPMULLWZ128rrk = 15913,
  VPMULLWZ128rrkz = 15914,
  VPMULLWZ256rm = 15915,
  VPMULLWZ256rmk = 15916,
  VPMULLWZ256rmkz = 15917,
  VPMULLWZ256rr = 15918,
  VPMULLWZ256rrk = 15919,
  VPMULLWZ256rrkz = 15920,
  VPMULLWZrm = 15921,
  VPMULLWZrmk = 15922,
  VPMULLWZrmkz = 15923,
  VPMULLWZrr = 15924,
  VPMULLWZrrk = 15925,
  VPMULLWZrrkz = 15926,
  VPMULLWrm = 15927,
  VPMULLWrr = 15928,
  VPMULTISHIFTQBZ128rm = 15929,
  VPMULTISHIFTQBZ128rmb = 15930,
  VPMULTISHIFTQBZ128rmbk = 15931,
  VPMULTISHIFTQBZ128rmbkz = 15932,
  VPMULTISHIFTQBZ128rmk = 15933,
  VPMULTISHIFTQBZ128rmkz = 15934,
  VPMULTISHIFTQBZ128rr = 15935,
  VPMULTISHIFTQBZ128rrk = 15936,
  VPMULTISHIFTQBZ128rrkz = 15937,
  VPMULTISHIFTQBZ256rm = 15938,
  VPMULTISHIFTQBZ256rmb = 15939,
  VPMULTISHIFTQBZ256rmbk = 15940,
  VPMULTISHIFTQBZ256rmbkz = 15941,
  VPMULTISHIFTQBZ256rmk = 15942,
  VPMULTISHIFTQBZ256rmkz = 15943,
  VPMULTISHIFTQBZ256rr = 15944,
  VPMULTISHIFTQBZ256rrk = 15945,
  VPMULTISHIFTQBZ256rrkz = 15946,
  VPMULTISHIFTQBZrm = 15947,
  VPMULTISHIFTQBZrmb = 15948,
  VPMULTISHIFTQBZrmbk = 15949,
  VPMULTISHIFTQBZrmbkz = 15950,
  VPMULTISHIFTQBZrmk = 15951,
  VPMULTISHIFTQBZrmkz = 15952,
  VPMULTISHIFTQBZrr = 15953,
  VPMULTISHIFTQBZrrk = 15954,
  VPMULTISHIFTQBZrrkz = 15955,
  VPMULUDQYrm = 15956,
  VPMULUDQYrr = 15957,
  VPMULUDQZ128rm = 15958,
  VPMULUDQZ128rmb = 15959,
  VPMULUDQZ128rmbk = 15960,
  VPMULUDQZ128rmbkz = 15961,
  VPMULUDQZ128rmk = 15962,
  VPMULUDQZ128rmkz = 15963,
  VPMULUDQZ128rr = 15964,
  VPMULUDQZ128rrk = 15965,
  VPMULUDQZ128rrkz = 15966,
  VPMULUDQZ256rm = 15967,
  VPMULUDQZ256rmb = 15968,
  VPMULUDQZ256rmbk = 15969,
  VPMULUDQZ256rmbkz = 15970,
  VPMULUDQZ256rmk = 15971,
  VPMULUDQZ256rmkz = 15972,
  VPMULUDQZ256rr = 15973,
  VPMULUDQZ256rrk = 15974,
  VPMULUDQZ256rrkz = 15975,
  VPMULUDQZrm = 15976,
  VPMULUDQZrmb = 15977,
  VPMULUDQZrmbk = 15978,
  VPMULUDQZrmbkz = 15979,
  VPMULUDQZrmk = 15980,
  VPMULUDQZrmkz = 15981,
  VPMULUDQZrr = 15982,
  VPMULUDQZrrk = 15983,
  VPMULUDQZrrkz = 15984,
  VPMULUDQrm = 15985,
  VPMULUDQrr = 15986,
  VPOPCNTBZ128rm = 15987,
  VPOPCNTBZ128rmk = 15988,
  VPOPCNTBZ128rmkz = 15989,
  VPOPCNTBZ128rr = 15990,
  VPOPCNTBZ128rrk = 15991,
  VPOPCNTBZ128rrkz = 15992,
  VPOPCNTBZ256rm = 15993,
  VPOPCNTBZ256rmk = 15994,
  VPOPCNTBZ256rmkz = 15995,
  VPOPCNTBZ256rr = 15996,
  VPOPCNTBZ256rrk = 15997,
  VPOPCNTBZ256rrkz = 15998,
  VPOPCNTBZrm = 15999,
  VPOPCNTBZrmk = 16000,
  VPOPCNTBZrmkz = 16001,
  VPOPCNTBZrr = 16002,
  VPOPCNTBZrrk = 16003,
  VPOPCNTBZrrkz = 16004,
  VPOPCNTDZ128rm = 16005,
  VPOPCNTDZ128rmb = 16006,
  VPOPCNTDZ128rmbk = 16007,
  VPOPCNTDZ128rmbkz = 16008,
  VPOPCNTDZ128rmk = 16009,
  VPOPCNTDZ128rmkz = 16010,
  VPOPCNTDZ128rr = 16011,
  VPOPCNTDZ128rrk = 16012,
  VPOPCNTDZ128rrkz = 16013,
  VPOPCNTDZ256rm = 16014,
  VPOPCNTDZ256rmb = 16015,
  VPOPCNTDZ256rmbk = 16016,
  VPOPCNTDZ256rmbkz = 16017,
  VPOPCNTDZ256rmk = 16018,
  VPOPCNTDZ256rmkz = 16019,
  VPOPCNTDZ256rr = 16020,
  VPOPCNTDZ256rrk = 16021,
  VPOPCNTDZ256rrkz = 16022,
  VPOPCNTDZrm = 16023,
  VPOPCNTDZrmb = 16024,
  VPOPCNTDZrmbk = 16025,
  VPOPCNTDZrmbkz = 16026,
  VPOPCNTDZrmk = 16027,
  VPOPCNTDZrmkz = 16028,
  VPOPCNTDZrr = 16029,
  VPOPCNTDZrrk = 16030,
  VPOPCNTDZrrkz = 16031,
  VPOPCNTQZ128rm = 16032,
  VPOPCNTQZ128rmb = 16033,
  VPOPCNTQZ128rmbk = 16034,
  VPOPCNTQZ128rmbkz = 16035,
  VPOPCNTQZ128rmk = 16036,
  VPOPCNTQZ128rmkz = 16037,
  VPOPCNTQZ128rr = 16038,
  VPOPCNTQZ128rrk = 16039,
  VPOPCNTQZ128rrkz = 16040,
  VPOPCNTQZ256rm = 16041,
  VPOPCNTQZ256rmb = 16042,
  VPOPCNTQZ256rmbk = 16043,
  VPOPCNTQZ256rmbkz = 16044,
  VPOPCNTQZ256rmk = 16045,
  VPOPCNTQZ256rmkz = 16046,
  VPOPCNTQZ256rr = 16047,
  VPOPCNTQZ256rrk = 16048,
  VPOPCNTQZ256rrkz = 16049,
  VPOPCNTQZrm = 16050,
  VPOPCNTQZrmb = 16051,
  VPOPCNTQZrmbk = 16052,
  VPOPCNTQZrmbkz = 16053,
  VPOPCNTQZrmk = 16054,
  VPOPCNTQZrmkz = 16055,
  VPOPCNTQZrr = 16056,
  VPOPCNTQZrrk = 16057,
  VPOPCNTQZrrkz = 16058,
  VPOPCNTWZ128rm = 16059,
  VPOPCNTWZ128rmk = 16060,
  VPOPCNTWZ128rmkz = 16061,
  VPOPCNTWZ128rr = 16062,
  VPOPCNTWZ128rrk = 16063,
  VPOPCNTWZ128rrkz = 16064,
  VPOPCNTWZ256rm = 16065,
  VPOPCNTWZ256rmk = 16066,
  VPOPCNTWZ256rmkz = 16067,
  VPOPCNTWZ256rr = 16068,
  VPOPCNTWZ256rrk = 16069,
  VPOPCNTWZ256rrkz = 16070,
  VPOPCNTWZrm = 16071,
  VPOPCNTWZrmk = 16072,
  VPOPCNTWZrmkz = 16073,
  VPOPCNTWZrr = 16074,
  VPOPCNTWZrrk = 16075,
  VPOPCNTWZrrkz = 16076,
  VPORDZ128rm = 16077,
  VPORDZ128rmb = 16078,
  VPORDZ128rmbk = 16079,
  VPORDZ128rmbkz = 16080,
  VPORDZ128rmk = 16081,
  VPORDZ128rmkz = 16082,
  VPORDZ128rr = 16083,
  VPORDZ128rrk = 16084,
  VPORDZ128rrkz = 16085,
  VPORDZ256rm = 16086,
  VPORDZ256rmb = 16087,
  VPORDZ256rmbk = 16088,
  VPORDZ256rmbkz = 16089,
  VPORDZ256rmk = 16090,
  VPORDZ256rmkz = 16091,
  VPORDZ256rr = 16092,
  VPORDZ256rrk = 16093,
  VPORDZ256rrkz = 16094,
  VPORDZrm = 16095,
  VPORDZrmb = 16096,
  VPORDZrmbk = 16097,
  VPORDZrmbkz = 16098,
  VPORDZrmk = 16099,
  VPORDZrmkz = 16100,
  VPORDZrr = 16101,
  VPORDZrrk = 16102,
  VPORDZrrkz = 16103,
  VPORQZ128rm = 16104,
  VPORQZ128rmb = 16105,
  VPORQZ128rmbk = 16106,
  VPORQZ128rmbkz = 16107,
  VPORQZ128rmk = 16108,
  VPORQZ128rmkz = 16109,
  VPORQZ128rr = 16110,
  VPORQZ128rrk = 16111,
  VPORQZ128rrkz = 16112,
  VPORQZ256rm = 16113,
  VPORQZ256rmb = 16114,
  VPORQZ256rmbk = 16115,
  VPORQZ256rmbkz = 16116,
  VPORQZ256rmk = 16117,
  VPORQZ256rmkz = 16118,
  VPORQZ256rr = 16119,
  VPORQZ256rrk = 16120,
  VPORQZ256rrkz = 16121,
  VPORQZrm = 16122,
  VPORQZrmb = 16123,
  VPORQZrmbk = 16124,
  VPORQZrmbkz = 16125,
  VPORQZrmk = 16126,
  VPORQZrmkz = 16127,
  VPORQZrr = 16128,
  VPORQZrrk = 16129,
  VPORQZrrkz = 16130,
  VPORYrm = 16131,
  VPORYrr = 16132,
  VPORrm = 16133,
  VPORrr = 16134,
  VPPERMrmr = 16135,
  VPPERMrrm = 16136,
  VPPERMrrr = 16137,
  VPPERMrrr_REV = 16138,
  VPROLDZ128mbi = 16139,
  VPROLDZ128mbik = 16140,
  VPROLDZ128mbikz = 16141,
  VPROLDZ128mi = 16142,
  VPROLDZ128mik = 16143,
  VPROLDZ128mikz = 16144,
  VPROLDZ128ri = 16145,
  VPROLDZ128rik = 16146,
  VPROLDZ128rikz = 16147,
  VPROLDZ256mbi = 16148,
  VPROLDZ256mbik = 16149,
  VPROLDZ256mbikz = 16150,
  VPROLDZ256mi = 16151,
  VPROLDZ256mik = 16152,
  VPROLDZ256mikz = 16153,
  VPROLDZ256ri = 16154,
  VPROLDZ256rik = 16155,
  VPROLDZ256rikz = 16156,
  VPROLDZmbi = 16157,
  VPROLDZmbik = 16158,
  VPROLDZmbikz = 16159,
  VPROLDZmi = 16160,
  VPROLDZmik = 16161,
  VPROLDZmikz = 16162,
  VPROLDZri = 16163,
  VPROLDZrik = 16164,
  VPROLDZrikz = 16165,
  VPROLQZ128mbi = 16166,
  VPROLQZ128mbik = 16167,
  VPROLQZ128mbikz = 16168,
  VPROLQZ128mi = 16169,
  VPROLQZ128mik = 16170,
  VPROLQZ128mikz = 16171,
  VPROLQZ128ri = 16172,
  VPROLQZ128rik = 16173,
  VPROLQZ128rikz = 16174,
  VPROLQZ256mbi = 16175,
  VPROLQZ256mbik = 16176,
  VPROLQZ256mbikz = 16177,
  VPROLQZ256mi = 16178,
  VPROLQZ256mik = 16179,
  VPROLQZ256mikz = 16180,
  VPROLQZ256ri = 16181,
  VPROLQZ256rik = 16182,
  VPROLQZ256rikz = 16183,
  VPROLQZmbi = 16184,
  VPROLQZmbik = 16185,
  VPROLQZmbikz = 16186,
  VPROLQZmi = 16187,
  VPROLQZmik = 16188,
  VPROLQZmikz = 16189,
  VPROLQZri = 16190,
  VPROLQZrik = 16191,
  VPROLQZrikz = 16192,
  VPROLVDZ128rm = 16193,
  VPROLVDZ128rmb = 16194,
  VPROLVDZ128rmbk = 16195,
  VPROLVDZ128rmbkz = 16196,
  VPROLVDZ128rmk = 16197,
  VPROLVDZ128rmkz = 16198,
  VPROLVDZ128rr = 16199,
  VPROLVDZ128rrk = 16200,
  VPROLVDZ128rrkz = 16201,
  VPROLVDZ256rm = 16202,
  VPROLVDZ256rmb = 16203,
  VPROLVDZ256rmbk = 16204,
  VPROLVDZ256rmbkz = 16205,
  VPROLVDZ256rmk = 16206,
  VPROLVDZ256rmkz = 16207,
  VPROLVDZ256rr = 16208,
  VPROLVDZ256rrk = 16209,
  VPROLVDZ256rrkz = 16210,
  VPROLVDZrm = 16211,
  VPROLVDZrmb = 16212,
  VPROLVDZrmbk = 16213,
  VPROLVDZrmbkz = 16214,
  VPROLVDZrmk = 16215,
  VPROLVDZrmkz = 16216,
  VPROLVDZrr = 16217,
  VPROLVDZrrk = 16218,
  VPROLVDZrrkz = 16219,
  VPROLVQZ128rm = 16220,
  VPROLVQZ128rmb = 16221,
  VPROLVQZ128rmbk = 16222,
  VPROLVQZ128rmbkz = 16223,
  VPROLVQZ128rmk = 16224,
  VPROLVQZ128rmkz = 16225,
  VPROLVQZ128rr = 16226,
  VPROLVQZ128rrk = 16227,
  VPROLVQZ128rrkz = 16228,
  VPROLVQZ256rm = 16229,
  VPROLVQZ256rmb = 16230,
  VPROLVQZ256rmbk = 16231,
  VPROLVQZ256rmbkz = 16232,
  VPROLVQZ256rmk = 16233,
  VPROLVQZ256rmkz = 16234,
  VPROLVQZ256rr = 16235,
  VPROLVQZ256rrk = 16236,
  VPROLVQZ256rrkz = 16237,
  VPROLVQZrm = 16238,
  VPROLVQZrmb = 16239,
  VPROLVQZrmbk = 16240,
  VPROLVQZrmbkz = 16241,
  VPROLVQZrmk = 16242,
  VPROLVQZrmkz = 16243,
  VPROLVQZrr = 16244,
  VPROLVQZrrk = 16245,
  VPROLVQZrrkz = 16246,
  VPRORDZ128mbi = 16247,
  VPRORDZ128mbik = 16248,
  VPRORDZ128mbikz = 16249,
  VPRORDZ128mi = 16250,
  VPRORDZ128mik = 16251,
  VPRORDZ128mikz = 16252,
  VPRORDZ128ri = 16253,
  VPRORDZ128rik = 16254,
  VPRORDZ128rikz = 16255,
  VPRORDZ256mbi = 16256,
  VPRORDZ256mbik = 16257,
  VPRORDZ256mbikz = 16258,
  VPRORDZ256mi = 16259,
  VPRORDZ256mik = 16260,
  VPRORDZ256mikz = 16261,
  VPRORDZ256ri = 16262,
  VPRORDZ256rik = 16263,
  VPRORDZ256rikz = 16264,
  VPRORDZmbi = 16265,
  VPRORDZmbik = 16266,
  VPRORDZmbikz = 16267,
  VPRORDZmi = 16268,
  VPRORDZmik = 16269,
  VPRORDZmikz = 16270,
  VPRORDZri = 16271,
  VPRORDZrik = 16272,
  VPRORDZrikz = 16273,
  VPRORQZ128mbi = 16274,
  VPRORQZ128mbik = 16275,
  VPRORQZ128mbikz = 16276,
  VPRORQZ128mi = 16277,
  VPRORQZ128mik = 16278,
  VPRORQZ128mikz = 16279,
  VPRORQZ128ri = 16280,
  VPRORQZ128rik = 16281,
  VPRORQZ128rikz = 16282,
  VPRORQZ256mbi = 16283,
  VPRORQZ256mbik = 16284,
  VPRORQZ256mbikz = 16285,
  VPRORQZ256mi = 16286,
  VPRORQZ256mik = 16287,
  VPRORQZ256mikz = 16288,
  VPRORQZ256ri = 16289,
  VPRORQZ256rik = 16290,
  VPRORQZ256rikz = 16291,
  VPRORQZmbi = 16292,
  VPRORQZmbik = 16293,
  VPRORQZmbikz = 16294,
  VPRORQZmi = 16295,
  VPRORQZmik = 16296,
  VPRORQZmikz = 16297,
  VPRORQZri = 16298,
  VPRORQZrik = 16299,
  VPRORQZrikz = 16300,
  VPRORVDZ128rm = 16301,
  VPRORVDZ128rmb = 16302,
  VPRORVDZ128rmbk = 16303,
  VPRORVDZ128rmbkz = 16304,
  VPRORVDZ128rmk = 16305,
  VPRORVDZ128rmkz = 16306,
  VPRORVDZ128rr = 16307,
  VPRORVDZ128rrk = 16308,
  VPRORVDZ128rrkz = 16309,
  VPRORVDZ256rm = 16310,
  VPRORVDZ256rmb = 16311,
  VPRORVDZ256rmbk = 16312,
  VPRORVDZ256rmbkz = 16313,
  VPRORVDZ256rmk = 16314,
  VPRORVDZ256rmkz = 16315,
  VPRORVDZ256rr = 16316,
  VPRORVDZ256rrk = 16317,
  VPRORVDZ256rrkz = 16318,
  VPRORVDZrm = 16319,
  VPRORVDZrmb = 16320,
  VPRORVDZrmbk = 16321,
  VPRORVDZrmbkz = 16322,
  VPRORVDZrmk = 16323,
  VPRORVDZrmkz = 16324,
  VPRORVDZrr = 16325,
  VPRORVDZrrk = 16326,
  VPRORVDZrrkz = 16327,
  VPRORVQZ128rm = 16328,
  VPRORVQZ128rmb = 16329,
  VPRORVQZ128rmbk = 16330,
  VPRORVQZ128rmbkz = 16331,
  VPRORVQZ128rmk = 16332,
  VPRORVQZ128rmkz = 16333,
  VPRORVQZ128rr = 16334,
  VPRORVQZ128rrk = 16335,
  VPRORVQZ128rrkz = 16336,
  VPRORVQZ256rm = 16337,
  VPRORVQZ256rmb = 16338,
  VPRORVQZ256rmbk = 16339,
  VPRORVQZ256rmbkz = 16340,
  VPRORVQZ256rmk = 16341,
  VPRORVQZ256rmkz = 16342,
  VPRORVQZ256rr = 16343,
  VPRORVQZ256rrk = 16344,
  VPRORVQZ256rrkz = 16345,
  VPRORVQZrm = 16346,
  VPRORVQZrmb = 16347,
  VPRORVQZrmbk = 16348,
  VPRORVQZrmbkz = 16349,
  VPRORVQZrmk = 16350,
  VPRORVQZrmkz = 16351,
  VPRORVQZrr = 16352,
  VPRORVQZrrk = 16353,
  VPRORVQZrrkz = 16354,
  VPROTBmi = 16355,
  VPROTBmr = 16356,
  VPROTBri = 16357,
  VPROTBrm = 16358,
  VPROTBrr = 16359,
  VPROTBrr_REV = 16360,
  VPROTDmi = 16361,
  VPROTDmr = 16362,
  VPROTDri = 16363,
  VPROTDrm = 16364,
  VPROTDrr = 16365,
  VPROTDrr_REV = 16366,
  VPROTQmi = 16367,
  VPROTQmr = 16368,
  VPROTQri = 16369,
  VPROTQrm = 16370,
  VPROTQrr = 16371,
  VPROTQrr_REV = 16372,
  VPROTWmi = 16373,
  VPROTWmr = 16374,
  VPROTWri = 16375,
  VPROTWrm = 16376,
  VPROTWrr = 16377,
  VPROTWrr_REV = 16378,
  VPSADBWYrm = 16379,
  VPSADBWYrr = 16380,
  VPSADBWZ128rm = 16381,
  VPSADBWZ128rr = 16382,
  VPSADBWZ256rm = 16383,
  VPSADBWZ256rr = 16384,
  VPSADBWZrm = 16385,
  VPSADBWZrr = 16386,
  VPSADBWrm = 16387,
  VPSADBWrr = 16388,
  VPSCATTERDDZ128mr = 16389,
  VPSCATTERDDZ256mr = 16390,
  VPSCATTERDDZmr = 16391,
  VPSCATTERDQZ128mr = 16392,
  VPSCATTERDQZ256mr = 16393,
  VPSCATTERDQZmr = 16394,
  VPSCATTERQDZ128mr = 16395,
  VPSCATTERQDZ256mr = 16396,
  VPSCATTERQDZmr = 16397,
  VPSCATTERQQZ128mr = 16398,
  VPSCATTERQQZ256mr = 16399,
  VPSCATTERQQZmr = 16400,
  VPSHABmr = 16401,
  VPSHABrm = 16402,
  VPSHABrr = 16403,
  VPSHABrr_REV = 16404,
  VPSHADmr = 16405,
  VPSHADrm = 16406,
  VPSHADrr = 16407,
  VPSHADrr_REV = 16408,
  VPSHAQmr = 16409,
  VPSHAQrm = 16410,
  VPSHAQrr = 16411,
  VPSHAQrr_REV = 16412,
  VPSHAWmr = 16413,
  VPSHAWrm = 16414,
  VPSHAWrr = 16415,
  VPSHAWrr_REV = 16416,
  VPSHLBmr = 16417,
  VPSHLBrm = 16418,
  VPSHLBrr = 16419,
  VPSHLBrr_REV = 16420,
  VPSHLDDZ128rmbi = 16421,
  VPSHLDDZ128rmbik = 16422,
  VPSHLDDZ128rmbikz = 16423,
  VPSHLDDZ128rmi = 16424,
  VPSHLDDZ128rmik = 16425,
  VPSHLDDZ128rmikz = 16426,
  VPSHLDDZ128rri = 16427,
  VPSHLDDZ128rrik = 16428,
  VPSHLDDZ128rrikz = 16429,
  VPSHLDDZ256rmbi = 16430,
  VPSHLDDZ256rmbik = 16431,
  VPSHLDDZ256rmbikz = 16432,
  VPSHLDDZ256rmi = 16433,
  VPSHLDDZ256rmik = 16434,
  VPSHLDDZ256rmikz = 16435,
  VPSHLDDZ256rri = 16436,
  VPSHLDDZ256rrik = 16437,
  VPSHLDDZ256rrikz = 16438,
  VPSHLDDZrmbi = 16439,
  VPSHLDDZrmbik = 16440,
  VPSHLDDZrmbikz = 16441,
  VPSHLDDZrmi = 16442,
  VPSHLDDZrmik = 16443,
  VPSHLDDZrmikz = 16444,
  VPSHLDDZrri = 16445,
  VPSHLDDZrrik = 16446,
  VPSHLDDZrrikz = 16447,
  VPSHLDQZ128rmbi = 16448,
  VPSHLDQZ128rmbik = 16449,
  VPSHLDQZ128rmbikz = 16450,
  VPSHLDQZ128rmi = 16451,
  VPSHLDQZ128rmik = 16452,
  VPSHLDQZ128rmikz = 16453,
  VPSHLDQZ128rri = 16454,
  VPSHLDQZ128rrik = 16455,
  VPSHLDQZ128rrikz = 16456,
  VPSHLDQZ256rmbi = 16457,
  VPSHLDQZ256rmbik = 16458,
  VPSHLDQZ256rmbikz = 16459,
  VPSHLDQZ256rmi = 16460,
  VPSHLDQZ256rmik = 16461,
  VPSHLDQZ256rmikz = 16462,
  VPSHLDQZ256rri = 16463,
  VPSHLDQZ256rrik = 16464,
  VPSHLDQZ256rrikz = 16465,
  VPSHLDQZrmbi = 16466,
  VPSHLDQZrmbik = 16467,
  VPSHLDQZrmbikz = 16468,
  VPSHLDQZrmi = 16469,
  VPSHLDQZrmik = 16470,
  VPSHLDQZrmikz = 16471,
  VPSHLDQZrri = 16472,
  VPSHLDQZrrik = 16473,
  VPSHLDQZrrikz = 16474,
  VPSHLDVDZ128m = 16475,
  VPSHLDVDZ128mb = 16476,
  VPSHLDVDZ128mbk = 16477,
  VPSHLDVDZ128mbkz = 16478,
  VPSHLDVDZ128mk = 16479,
  VPSHLDVDZ128mkz = 16480,
  VPSHLDVDZ128r = 16481,
  VPSHLDVDZ128rk = 16482,
  VPSHLDVDZ128rkz = 16483,
  VPSHLDVDZ256m = 16484,
  VPSHLDVDZ256mb = 16485,
  VPSHLDVDZ256mbk = 16486,
  VPSHLDVDZ256mbkz = 16487,
  VPSHLDVDZ256mk = 16488,
  VPSHLDVDZ256mkz = 16489,
  VPSHLDVDZ256r = 16490,
  VPSHLDVDZ256rk = 16491,
  VPSHLDVDZ256rkz = 16492,
  VPSHLDVDZm = 16493,
  VPSHLDVDZmb = 16494,
  VPSHLDVDZmbk = 16495,
  VPSHLDVDZmbkz = 16496,
  VPSHLDVDZmk = 16497,
  VPSHLDVDZmkz = 16498,
  VPSHLDVDZr = 16499,
  VPSHLDVDZrk = 16500,
  VPSHLDVDZrkz = 16501,
  VPSHLDVQZ128m = 16502,
  VPSHLDVQZ128mb = 16503,
  VPSHLDVQZ128mbk = 16504,
  VPSHLDVQZ128mbkz = 16505,
  VPSHLDVQZ128mk = 16506,
  VPSHLDVQZ128mkz = 16507,
  VPSHLDVQZ128r = 16508,
  VPSHLDVQZ128rk = 16509,
  VPSHLDVQZ128rkz = 16510,
  VPSHLDVQZ256m = 16511,
  VPSHLDVQZ256mb = 16512,
  VPSHLDVQZ256mbk = 16513,
  VPSHLDVQZ256mbkz = 16514,
  VPSHLDVQZ256mk = 16515,
  VPSHLDVQZ256mkz = 16516,
  VPSHLDVQZ256r = 16517,
  VPSHLDVQZ256rk = 16518,
  VPSHLDVQZ256rkz = 16519,
  VPSHLDVQZm = 16520,
  VPSHLDVQZmb = 16521,
  VPSHLDVQZmbk = 16522,
  VPSHLDVQZmbkz = 16523,
  VPSHLDVQZmk = 16524,
  VPSHLDVQZmkz = 16525,
  VPSHLDVQZr = 16526,
  VPSHLDVQZrk = 16527,
  VPSHLDVQZrkz = 16528,
  VPSHLDVWZ128m = 16529,
  VPSHLDVWZ128mk = 16530,
  VPSHLDVWZ128mkz = 16531,
  VPSHLDVWZ128r = 16532,
  VPSHLDVWZ128rk = 16533,
  VPSHLDVWZ128rkz = 16534,
  VPSHLDVWZ256m = 16535,
  VPSHLDVWZ256mk = 16536,
  VPSHLDVWZ256mkz = 16537,
  VPSHLDVWZ256r = 16538,
  VPSHLDVWZ256rk = 16539,
  VPSHLDVWZ256rkz = 16540,
  VPSHLDVWZm = 16541,
  VPSHLDVWZmk = 16542,
  VPSHLDVWZmkz = 16543,
  VPSHLDVWZr = 16544,
  VPSHLDVWZrk = 16545,
  VPSHLDVWZrkz = 16546,
  VPSHLDWZ128rmi = 16547,
  VPSHLDWZ128rmik = 16548,
  VPSHLDWZ128rmikz = 16549,
  VPSHLDWZ128rri = 16550,
  VPSHLDWZ128rrik = 16551,
  VPSHLDWZ128rrikz = 16552,
  VPSHLDWZ256rmi = 16553,
  VPSHLDWZ256rmik = 16554,
  VPSHLDWZ256rmikz = 16555,
  VPSHLDWZ256rri = 16556,
  VPSHLDWZ256rrik = 16557,
  VPSHLDWZ256rrikz = 16558,
  VPSHLDWZrmi = 16559,
  VPSHLDWZrmik = 16560,
  VPSHLDWZrmikz = 16561,
  VPSHLDWZrri = 16562,
  VPSHLDWZrrik = 16563,
  VPSHLDWZrrikz = 16564,
  VPSHLDmr = 16565,
  VPSHLDrm = 16566,
  VPSHLDrr = 16567,
  VPSHLDrr_REV = 16568,
  VPSHLQmr = 16569,
  VPSHLQrm = 16570,
  VPSHLQrr = 16571,
  VPSHLQrr_REV = 16572,
  VPSHLWmr = 16573,
  VPSHLWrm = 16574,
  VPSHLWrr = 16575,
  VPSHLWrr_REV = 16576,
  VPSHRDDZ128rmbi = 16577,
  VPSHRDDZ128rmbik = 16578,
  VPSHRDDZ128rmbikz = 16579,
  VPSHRDDZ128rmi = 16580,
  VPSHRDDZ128rmik = 16581,
  VPSHRDDZ128rmikz = 16582,
  VPSHRDDZ128rri = 16583,
  VPSHRDDZ128rrik = 16584,
  VPSHRDDZ128rrikz = 16585,
  VPSHRDDZ256rmbi = 16586,
  VPSHRDDZ256rmbik = 16587,
  VPSHRDDZ256rmbikz = 16588,
  VPSHRDDZ256rmi = 16589,
  VPSHRDDZ256rmik = 16590,
  VPSHRDDZ256rmikz = 16591,
  VPSHRDDZ256rri = 16592,
  VPSHRDDZ256rrik = 16593,
  VPSHRDDZ256rrikz = 16594,
  VPSHRDDZrmbi = 16595,
  VPSHRDDZrmbik = 16596,
  VPSHRDDZrmbikz = 16597,
  VPSHRDDZrmi = 16598,
  VPSHRDDZrmik = 16599,
  VPSHRDDZrmikz = 16600,
  VPSHRDDZrri = 16601,
  VPSHRDDZrrik = 16602,
  VPSHRDDZrrikz = 16603,
  VPSHRDQZ128rmbi = 16604,
  VPSHRDQZ128rmbik = 16605,
  VPSHRDQZ128rmbikz = 16606,
  VPSHRDQZ128rmi = 16607,
  VPSHRDQZ128rmik = 16608,
  VPSHRDQZ128rmikz = 16609,
  VPSHRDQZ128rri = 16610,
  VPSHRDQZ128rrik = 16611,
  VPSHRDQZ128rrikz = 16612,
  VPSHRDQZ256rmbi = 16613,
  VPSHRDQZ256rmbik = 16614,
  VPSHRDQZ256rmbikz = 16615,
  VPSHRDQZ256rmi = 16616,
  VPSHRDQZ256rmik = 16617,
  VPSHRDQZ256rmikz = 16618,
  VPSHRDQZ256rri = 16619,
  VPSHRDQZ256rrik = 16620,
  VPSHRDQZ256rrikz = 16621,
  VPSHRDQZrmbi = 16622,
  VPSHRDQZrmbik = 16623,
  VPSHRDQZrmbikz = 16624,
  VPSHRDQZrmi = 16625,
  VPSHRDQZrmik = 16626,
  VPSHRDQZrmikz = 16627,
  VPSHRDQZrri = 16628,
  VPSHRDQZrrik = 16629,
  VPSHRDQZrrikz = 16630,
  VPSHRDVDZ128m = 16631,
  VPSHRDVDZ128mb = 16632,
  VPSHRDVDZ128mbk = 16633,
  VPSHRDVDZ128mbkz = 16634,
  VPSHRDVDZ128mk = 16635,
  VPSHRDVDZ128mkz = 16636,
  VPSHRDVDZ128r = 16637,
  VPSHRDVDZ128rk = 16638,
  VPSHRDVDZ128rkz = 16639,
  VPSHRDVDZ256m = 16640,
  VPSHRDVDZ256mb = 16641,
  VPSHRDVDZ256mbk = 16642,
  VPSHRDVDZ256mbkz = 16643,
  VPSHRDVDZ256mk = 16644,
  VPSHRDVDZ256mkz = 16645,
  VPSHRDVDZ256r = 16646,
  VPSHRDVDZ256rk = 16647,
  VPSHRDVDZ256rkz = 16648,
  VPSHRDVDZm = 16649,
  VPSHRDVDZmb = 16650,
  VPSHRDVDZmbk = 16651,
  VPSHRDVDZmbkz = 16652,
  VPSHRDVDZmk = 16653,
  VPSHRDVDZmkz = 16654,
  VPSHRDVDZr = 16655,
  VPSHRDVDZrk = 16656,
  VPSHRDVDZrkz = 16657,
  VPSHRDVQZ128m = 16658,
  VPSHRDVQZ128mb = 16659,
  VPSHRDVQZ128mbk = 16660,
  VPSHRDVQZ128mbkz = 16661,
  VPSHRDVQZ128mk = 16662,
  VPSHRDVQZ128mkz = 16663,
  VPSHRDVQZ128r = 16664,
  VPSHRDVQZ128rk = 16665,
  VPSHRDVQZ128rkz = 16666,
  VPSHRDVQZ256m = 16667,
  VPSHRDVQZ256mb = 16668,
  VPSHRDVQZ256mbk = 16669,
  VPSHRDVQZ256mbkz = 16670,
  VPSHRDVQZ256mk = 16671,
  VPSHRDVQZ256mkz = 16672,
  VPSHRDVQZ256r = 16673,
  VPSHRDVQZ256rk = 16674,
  VPSHRDVQZ256rkz = 16675,
  VPSHRDVQZm = 16676,
  VPSHRDVQZmb = 16677,
  VPSHRDVQZmbk = 16678,
  VPSHRDVQZmbkz = 16679,
  VPSHRDVQZmk = 16680,
  VPSHRDVQZmkz = 16681,
  VPSHRDVQZr = 16682,
  VPSHRDVQZrk = 16683,
  VPSHRDVQZrkz = 16684,
  VPSHRDVWZ128m = 16685,
  VPSHRDVWZ128mk = 16686,
  VPSHRDVWZ128mkz = 16687,
  VPSHRDVWZ128r = 16688,
  VPSHRDVWZ128rk = 16689,
  VPSHRDVWZ128rkz = 16690,
  VPSHRDVWZ256m = 16691,
  VPSHRDVWZ256mk = 16692,
  VPSHRDVWZ256mkz = 16693,
  VPSHRDVWZ256r = 16694,
  VPSHRDVWZ256rk = 16695,
  VPSHRDVWZ256rkz = 16696,
  VPSHRDVWZm = 16697,
  VPSHRDVWZmk = 16698,
  VPSHRDVWZmkz = 16699,
  VPSHRDVWZr = 16700,
  VPSHRDVWZrk = 16701,
  VPSHRDVWZrkz = 16702,
  VPSHRDWZ128rmi = 16703,
  VPSHRDWZ128rmik = 16704,
  VPSHRDWZ128rmikz = 16705,
  VPSHRDWZ128rri = 16706,
  VPSHRDWZ128rrik = 16707,
  VPSHRDWZ128rrikz = 16708,
  VPSHRDWZ256rmi = 16709,
  VPSHRDWZ256rmik = 16710,
  VPSHRDWZ256rmikz = 16711,
  VPSHRDWZ256rri = 16712,
  VPSHRDWZ256rrik = 16713,
  VPSHRDWZ256rrikz = 16714,
  VPSHRDWZrmi = 16715,
  VPSHRDWZrmik = 16716,
  VPSHRDWZrmikz = 16717,
  VPSHRDWZrri = 16718,
  VPSHRDWZrrik = 16719,
  VPSHRDWZrrikz = 16720,
  VPSHUFBITQMBZ128rm = 16721,
  VPSHUFBITQMBZ128rmk = 16722,
  VPSHUFBITQMBZ128rr = 16723,
  VPSHUFBITQMBZ128rrk = 16724,
  VPSHUFBITQMBZ256rm = 16725,
  VPSHUFBITQMBZ256rmk = 16726,
  VPSHUFBITQMBZ256rr = 16727,
  VPSHUFBITQMBZ256rrk = 16728,
  VPSHUFBITQMBZrm = 16729,
  VPSHUFBITQMBZrmk = 16730,
  VPSHUFBITQMBZrr = 16731,
  VPSHUFBITQMBZrrk = 16732,
  VPSHUFBYrm = 16733,
  VPSHUFBYrr = 16734,
  VPSHUFBZ128rm = 16735,
  VPSHUFBZ128rmk = 16736,
  VPSHUFBZ128rmkz = 16737,
  VPSHUFBZ128rr = 16738,
  VPSHUFBZ128rrk = 16739,
  VPSHUFBZ128rrkz = 16740,
  VPSHUFBZ256rm = 16741,
  VPSHUFBZ256rmk = 16742,
  VPSHUFBZ256rmkz = 16743,
  VPSHUFBZ256rr = 16744,
  VPSHUFBZ256rrk = 16745,
  VPSHUFBZ256rrkz = 16746,
  VPSHUFBZrm = 16747,
  VPSHUFBZrmk = 16748,
  VPSHUFBZrmkz = 16749,
  VPSHUFBZrr = 16750,
  VPSHUFBZrrk = 16751,
  VPSHUFBZrrkz = 16752,
  VPSHUFBrm = 16753,
  VPSHUFBrr = 16754,
  VPSHUFDYmi = 16755,
  VPSHUFDYri = 16756,
  VPSHUFDZ128mbi = 16757,
  VPSHUFDZ128mbik = 16758,
  VPSHUFDZ128mbikz = 16759,
  VPSHUFDZ128mi = 16760,
  VPSHUFDZ128mik = 16761,
  VPSHUFDZ128mikz = 16762,
  VPSHUFDZ128ri = 16763,
  VPSHUFDZ128rik = 16764,
  VPSHUFDZ128rikz = 16765,
  VPSHUFDZ256mbi = 16766,
  VPSHUFDZ256mbik = 16767,
  VPSHUFDZ256mbikz = 16768,
  VPSHUFDZ256mi = 16769,
  VPSHUFDZ256mik = 16770,
  VPSHUFDZ256mikz = 16771,
  VPSHUFDZ256ri = 16772,
  VPSHUFDZ256rik = 16773,
  VPSHUFDZ256rikz = 16774,
  VPSHUFDZmbi = 16775,
  VPSHUFDZmbik = 16776,
  VPSHUFDZmbikz = 16777,
  VPSHUFDZmi = 16778,
  VPSHUFDZmik = 16779,
  VPSHUFDZmikz = 16780,
  VPSHUFDZri = 16781,
  VPSHUFDZrik = 16782,
  VPSHUFDZrikz = 16783,
  VPSHUFDmi = 16784,
  VPSHUFDri = 16785,
  VPSHUFHWYmi = 16786,
  VPSHUFHWYri = 16787,
  VPSHUFHWZ128mi = 16788,
  VPSHUFHWZ128mik = 16789,
  VPSHUFHWZ128mikz = 16790,
  VPSHUFHWZ128ri = 16791,
  VPSHUFHWZ128rik = 16792,
  VPSHUFHWZ128rikz = 16793,
  VPSHUFHWZ256mi = 16794,
  VPSHUFHWZ256mik = 16795,
  VPSHUFHWZ256mikz = 16796,
  VPSHUFHWZ256ri = 16797,
  VPSHUFHWZ256rik = 16798,
  VPSHUFHWZ256rikz = 16799,
  VPSHUFHWZmi = 16800,
  VPSHUFHWZmik = 16801,
  VPSHUFHWZmikz = 16802,
  VPSHUFHWZri = 16803,
  VPSHUFHWZrik = 16804,
  VPSHUFHWZrikz = 16805,
  VPSHUFHWmi = 16806,
  VPSHUFHWri = 16807,
  VPSHUFLWYmi = 16808,
  VPSHUFLWYri = 16809,
  VPSHUFLWZ128mi = 16810,
  VPSHUFLWZ128mik = 16811,
  VPSHUFLWZ128mikz = 16812,
  VPSHUFLWZ128ri = 16813,
  VPSHUFLWZ128rik = 16814,
  VPSHUFLWZ128rikz = 16815,
  VPSHUFLWZ256mi = 16816,
  VPSHUFLWZ256mik = 16817,
  VPSHUFLWZ256mikz = 16818,
  VPSHUFLWZ256ri = 16819,
  VPSHUFLWZ256rik = 16820,
  VPSHUFLWZ256rikz = 16821,
  VPSHUFLWZmi = 16822,
  VPSHUFLWZmik = 16823,
  VPSHUFLWZmikz = 16824,
  VPSHUFLWZri = 16825,
  VPSHUFLWZrik = 16826,
  VPSHUFLWZrikz = 16827,
  VPSHUFLWmi = 16828,
  VPSHUFLWri = 16829,
  VPSIGNBYrm = 16830,
  VPSIGNBYrr = 16831,
  VPSIGNBrm = 16832,
  VPSIGNBrr = 16833,
  VPSIGNDYrm = 16834,
  VPSIGNDYrr = 16835,
  VPSIGNDrm = 16836,
  VPSIGNDrr = 16837,
  VPSIGNWYrm = 16838,
  VPSIGNWYrr = 16839,
  VPSIGNWrm = 16840,
  VPSIGNWrr = 16841,
  VPSLLDQYri = 16842,
  VPSLLDQZ128mi = 16843,
  VPSLLDQZ128ri = 16844,
  VPSLLDQZ256mi = 16845,
  VPSLLDQZ256ri = 16846,
  VPSLLDQZmi = 16847,
  VPSLLDQZri = 16848,
  VPSLLDQri = 16849,
  VPSLLDYri = 16850,
  VPSLLDYrm = 16851,
  VPSLLDYrr = 16852,
  VPSLLDZ128mbi = 16853,
  VPSLLDZ128mbik = 16854,
  VPSLLDZ128mbikz = 16855,
  VPSLLDZ128mi = 16856,
  VPSLLDZ128mik = 16857,
  VPSLLDZ128mikz = 16858,
  VPSLLDZ128ri = 16859,
  VPSLLDZ128rik = 16860,
  VPSLLDZ128rikz = 16861,
  VPSLLDZ128rm = 16862,
  VPSLLDZ128rmk = 16863,
  VPSLLDZ128rmkz = 16864,
  VPSLLDZ128rr = 16865,
  VPSLLDZ128rrk = 16866,
  VPSLLDZ128rrkz = 16867,
  VPSLLDZ256mbi = 16868,
  VPSLLDZ256mbik = 16869,
  VPSLLDZ256mbikz = 16870,
  VPSLLDZ256mi = 16871,
  VPSLLDZ256mik = 16872,
  VPSLLDZ256mikz = 16873,
  VPSLLDZ256ri = 16874,
  VPSLLDZ256rik = 16875,
  VPSLLDZ256rikz = 16876,
  VPSLLDZ256rm = 16877,
  VPSLLDZ256rmk = 16878,
  VPSLLDZ256rmkz = 16879,
  VPSLLDZ256rr = 16880,
  VPSLLDZ256rrk = 16881,
  VPSLLDZ256rrkz = 16882,
  VPSLLDZmbi = 16883,
  VPSLLDZmbik = 16884,
  VPSLLDZmbikz = 16885,
  VPSLLDZmi = 16886,
  VPSLLDZmik = 16887,
  VPSLLDZmikz = 16888,
  VPSLLDZri = 16889,
  VPSLLDZrik = 16890,
  VPSLLDZrikz = 16891,
  VPSLLDZrm = 16892,
  VPSLLDZrmk = 16893,
  VPSLLDZrmkz = 16894,
  VPSLLDZrr = 16895,
  VPSLLDZrrk = 16896,
  VPSLLDZrrkz = 16897,
  VPSLLDri = 16898,
  VPSLLDrm = 16899,
  VPSLLDrr = 16900,
  VPSLLQYri = 16901,
  VPSLLQYrm = 16902,
  VPSLLQYrr = 16903,
  VPSLLQZ128mbi = 16904,
  VPSLLQZ128mbik = 16905,
  VPSLLQZ128mbikz = 16906,
  VPSLLQZ128mi = 16907,
  VPSLLQZ128mik = 16908,
  VPSLLQZ128mikz = 16909,
  VPSLLQZ128ri = 16910,
  VPSLLQZ128rik = 16911,
  VPSLLQZ128rikz = 16912,
  VPSLLQZ128rm = 16913,
  VPSLLQZ128rmk = 16914,
  VPSLLQZ128rmkz = 16915,
  VPSLLQZ128rr = 16916,
  VPSLLQZ128rrk = 16917,
  VPSLLQZ128rrkz = 16918,
  VPSLLQZ256mbi = 16919,
  VPSLLQZ256mbik = 16920,
  VPSLLQZ256mbikz = 16921,
  VPSLLQZ256mi = 16922,
  VPSLLQZ256mik = 16923,
  VPSLLQZ256mikz = 16924,
  VPSLLQZ256ri = 16925,
  VPSLLQZ256rik = 16926,
  VPSLLQZ256rikz = 16927,
  VPSLLQZ256rm = 16928,
  VPSLLQZ256rmk = 16929,
  VPSLLQZ256rmkz = 16930,
  VPSLLQZ256rr = 16931,
  VPSLLQZ256rrk = 16932,
  VPSLLQZ256rrkz = 16933,
  VPSLLQZmbi = 16934,
  VPSLLQZmbik = 16935,
  VPSLLQZmbikz = 16936,
  VPSLLQZmi = 16937,
  VPSLLQZmik = 16938,
  VPSLLQZmikz = 16939,
  VPSLLQZri = 16940,
  VPSLLQZrik = 16941,
  VPSLLQZrikz = 16942,
  VPSLLQZrm = 16943,
  VPSLLQZrmk = 16944,
  VPSLLQZrmkz = 16945,
  VPSLLQZrr = 16946,
  VPSLLQZrrk = 16947,
  VPSLLQZrrkz = 16948,
  VPSLLQri = 16949,
  VPSLLQrm = 16950,
  VPSLLQrr = 16951,
  VPSLLVDYrm = 16952,
  VPSLLVDYrr = 16953,
  VPSLLVDZ128rm = 16954,
  VPSLLVDZ128rmb = 16955,
  VPSLLVDZ128rmbk = 16956,
  VPSLLVDZ128rmbkz = 16957,
  VPSLLVDZ128rmk = 16958,
  VPSLLVDZ128rmkz = 16959,
  VPSLLVDZ128rr = 16960,
  VPSLLVDZ128rrk = 16961,
  VPSLLVDZ128rrkz = 16962,
  VPSLLVDZ256rm = 16963,
  VPSLLVDZ256rmb = 16964,
  VPSLLVDZ256rmbk = 16965,
  VPSLLVDZ256rmbkz = 16966,
  VPSLLVDZ256rmk = 16967,
  VPSLLVDZ256rmkz = 16968,
  VPSLLVDZ256rr = 16969,
  VPSLLVDZ256rrk = 16970,
  VPSLLVDZ256rrkz = 16971,
  VPSLLVDZrm = 16972,
  VPSLLVDZrmb = 16973,
  VPSLLVDZrmbk = 16974,
  VPSLLVDZrmbkz = 16975,
  VPSLLVDZrmk = 16976,
  VPSLLVDZrmkz = 16977,
  VPSLLVDZrr = 16978,
  VPSLLVDZrrk = 16979,
  VPSLLVDZrrkz = 16980,
  VPSLLVDrm = 16981,
  VPSLLVDrr = 16982,
  VPSLLVQYrm = 16983,
  VPSLLVQYrr = 16984,
  VPSLLVQZ128rm = 16985,
  VPSLLVQZ128rmb = 16986,
  VPSLLVQZ128rmbk = 16987,
  VPSLLVQZ128rmbkz = 16988,
  VPSLLVQZ128rmk = 16989,
  VPSLLVQZ128rmkz = 16990,
  VPSLLVQZ128rr = 16991,
  VPSLLVQZ128rrk = 16992,
  VPSLLVQZ128rrkz = 16993,
  VPSLLVQZ256rm = 16994,
  VPSLLVQZ256rmb = 16995,
  VPSLLVQZ256rmbk = 16996,
  VPSLLVQZ256rmbkz = 16997,
  VPSLLVQZ256rmk = 16998,
  VPSLLVQZ256rmkz = 16999,
  VPSLLVQZ256rr = 17000,
  VPSLLVQZ256rrk = 17001,
  VPSLLVQZ256rrkz = 17002,
  VPSLLVQZrm = 17003,
  VPSLLVQZrmb = 17004,
  VPSLLVQZrmbk = 17005,
  VPSLLVQZrmbkz = 17006,
  VPSLLVQZrmk = 17007,
  VPSLLVQZrmkz = 17008,
  VPSLLVQZrr = 17009,
  VPSLLVQZrrk = 17010,
  VPSLLVQZrrkz = 17011,
  VPSLLVQrm = 17012,
  VPSLLVQrr = 17013,
  VPSLLVWZ128rm = 17014,
  VPSLLVWZ128rmk = 17015,
  VPSLLVWZ128rmkz = 17016,
  VPSLLVWZ128rr = 17017,
  VPSLLVWZ128rrk = 17018,
  VPSLLVWZ128rrkz = 17019,
  VPSLLVWZ256rm = 17020,
  VPSLLVWZ256rmk = 17021,
  VPSLLVWZ256rmkz = 17022,
  VPSLLVWZ256rr = 17023,
  VPSLLVWZ256rrk = 17024,
  VPSLLVWZ256rrkz = 17025,
  VPSLLVWZrm = 17026,
  VPSLLVWZrmk = 17027,
  VPSLLVWZrmkz = 17028,
  VPSLLVWZrr = 17029,
  VPSLLVWZrrk = 17030,
  VPSLLVWZrrkz = 17031,
  VPSLLWYri = 17032,
  VPSLLWYrm = 17033,
  VPSLLWYrr = 17034,
  VPSLLWZ128mi = 17035,
  VPSLLWZ128mik = 17036,
  VPSLLWZ128mikz = 17037,
  VPSLLWZ128ri = 17038,
  VPSLLWZ128rik = 17039,
  VPSLLWZ128rikz = 17040,
  VPSLLWZ128rm = 17041,
  VPSLLWZ128rmk = 17042,
  VPSLLWZ128rmkz = 17043,
  VPSLLWZ128rr = 17044,
  VPSLLWZ128rrk = 17045,
  VPSLLWZ128rrkz = 17046,
  VPSLLWZ256mi = 17047,
  VPSLLWZ256mik = 17048,
  VPSLLWZ256mikz = 17049,
  VPSLLWZ256ri = 17050,
  VPSLLWZ256rik = 17051,
  VPSLLWZ256rikz = 17052,
  VPSLLWZ256rm = 17053,
  VPSLLWZ256rmk = 17054,
  VPSLLWZ256rmkz = 17055,
  VPSLLWZ256rr = 17056,
  VPSLLWZ256rrk = 17057,
  VPSLLWZ256rrkz = 17058,
  VPSLLWZmi = 17059,
  VPSLLWZmik = 17060,
  VPSLLWZmikz = 17061,
  VPSLLWZri = 17062,
  VPSLLWZrik = 17063,
  VPSLLWZrikz = 17064,
  VPSLLWZrm = 17065,
  VPSLLWZrmk = 17066,
  VPSLLWZrmkz = 17067,
  VPSLLWZrr = 17068,
  VPSLLWZrrk = 17069,
  VPSLLWZrrkz = 17070,
  VPSLLWri = 17071,
  VPSLLWrm = 17072,
  VPSLLWrr = 17073,
  VPSRADYri = 17074,
  VPSRADYrm = 17075,
  VPSRADYrr = 17076,
  VPSRADZ128mbi = 17077,
  VPSRADZ128mbik = 17078,
  VPSRADZ128mbikz = 17079,
  VPSRADZ128mi = 17080,
  VPSRADZ128mik = 17081,
  VPSRADZ128mikz = 17082,
  VPSRADZ128ri = 17083,
  VPSRADZ128rik = 17084,
  VPSRADZ128rikz = 17085,
  VPSRADZ128rm = 17086,
  VPSRADZ128rmk = 17087,
  VPSRADZ128rmkz = 17088,
  VPSRADZ128rr = 17089,
  VPSRADZ128rrk = 17090,
  VPSRADZ128rrkz = 17091,
  VPSRADZ256mbi = 17092,
  VPSRADZ256mbik = 17093,
  VPSRADZ256mbikz = 17094,
  VPSRADZ256mi = 17095,
  VPSRADZ256mik = 17096,
  VPSRADZ256mikz = 17097,
  VPSRADZ256ri = 17098,
  VPSRADZ256rik = 17099,
  VPSRADZ256rikz = 17100,
  VPSRADZ256rm = 17101,
  VPSRADZ256rmk = 17102,
  VPSRADZ256rmkz = 17103,
  VPSRADZ256rr = 17104,
  VPSRADZ256rrk = 17105,
  VPSRADZ256rrkz = 17106,
  VPSRADZmbi = 17107,
  VPSRADZmbik = 17108,
  VPSRADZmbikz = 17109,
  VPSRADZmi = 17110,
  VPSRADZmik = 17111,
  VPSRADZmikz = 17112,
  VPSRADZri = 17113,
  VPSRADZrik = 17114,
  VPSRADZrikz = 17115,
  VPSRADZrm = 17116,
  VPSRADZrmk = 17117,
  VPSRADZrmkz = 17118,
  VPSRADZrr = 17119,
  VPSRADZrrk = 17120,
  VPSRADZrrkz = 17121,
  VPSRADri = 17122,
  VPSRADrm = 17123,
  VPSRADrr = 17124,
  VPSRAQZ128mbi = 17125,
  VPSRAQZ128mbik = 17126,
  VPSRAQZ128mbikz = 17127,
  VPSRAQZ128mi = 17128,
  VPSRAQZ128mik = 17129,
  VPSRAQZ128mikz = 17130,
  VPSRAQZ128ri = 17131,
  VPSRAQZ128rik = 17132,
  VPSRAQZ128rikz = 17133,
  VPSRAQZ128rm = 17134,
  VPSRAQZ128rmk = 17135,
  VPSRAQZ128rmkz = 17136,
  VPSRAQZ128rr = 17137,
  VPSRAQZ128rrk = 17138,
  VPSRAQZ128rrkz = 17139,
  VPSRAQZ256mbi = 17140,
  VPSRAQZ256mbik = 17141,
  VPSRAQZ256mbikz = 17142,
  VPSRAQZ256mi = 17143,
  VPSRAQZ256mik = 17144,
  VPSRAQZ256mikz = 17145,
  VPSRAQZ256ri = 17146,
  VPSRAQZ256rik = 17147,
  VPSRAQZ256rikz = 17148,
  VPSRAQZ256rm = 17149,
  VPSRAQZ256rmk = 17150,
  VPSRAQZ256rmkz = 17151,
  VPSRAQZ256rr = 17152,
  VPSRAQZ256rrk = 17153,
  VPSRAQZ256rrkz = 17154,
  VPSRAQZmbi = 17155,
  VPSRAQZmbik = 17156,
  VPSRAQZmbikz = 17157,
  VPSRAQZmi = 17158,
  VPSRAQZmik = 17159,
  VPSRAQZmikz = 17160,
  VPSRAQZri = 17161,
  VPSRAQZrik = 17162,
  VPSRAQZrikz = 17163,
  VPSRAQZrm = 17164,
  VPSRAQZrmk = 17165,
  VPSRAQZrmkz = 17166,
  VPSRAQZrr = 17167,
  VPSRAQZrrk = 17168,
  VPSRAQZrrkz = 17169,
  VPSRAVDYrm = 17170,
  VPSRAVDYrr = 17171,
  VPSRAVDZ128rm = 17172,
  VPSRAVDZ128rmb = 17173,
  VPSRAVDZ128rmbk = 17174,
  VPSRAVDZ128rmbkz = 17175,
  VPSRAVDZ128rmk = 17176,
  VPSRAVDZ128rmkz = 17177,
  VPSRAVDZ128rr = 17178,
  VPSRAVDZ128rrk = 17179,
  VPSRAVDZ128rrkz = 17180,
  VPSRAVDZ256rm = 17181,
  VPSRAVDZ256rmb = 17182,
  VPSRAVDZ256rmbk = 17183,
  VPSRAVDZ256rmbkz = 17184,
  VPSRAVDZ256rmk = 17185,
  VPSRAVDZ256rmkz = 17186,
  VPSRAVDZ256rr = 17187,
  VPSRAVDZ256rrk = 17188,
  VPSRAVDZ256rrkz = 17189,
  VPSRAVDZrm = 17190,
  VPSRAVDZrmb = 17191,
  VPSRAVDZrmbk = 17192,
  VPSRAVDZrmbkz = 17193,
  VPSRAVDZrmk = 17194,
  VPSRAVDZrmkz = 17195,
  VPSRAVDZrr = 17196,
  VPSRAVDZrrk = 17197,
  VPSRAVDZrrkz = 17198,
  VPSRAVDrm = 17199,
  VPSRAVDrr = 17200,
  VPSRAVQZ128rm = 17201,
  VPSRAVQZ128rmb = 17202,
  VPSRAVQZ128rmbk = 17203,
  VPSRAVQZ128rmbkz = 17204,
  VPSRAVQZ128rmk = 17205,
  VPSRAVQZ128rmkz = 17206,
  VPSRAVQZ128rr = 17207,
  VPSRAVQZ128rrk = 17208,
  VPSRAVQZ128rrkz = 17209,
  VPSRAVQZ256rm = 17210,
  VPSRAVQZ256rmb = 17211,
  VPSRAVQZ256rmbk = 17212,
  VPSRAVQZ256rmbkz = 17213,
  VPSRAVQZ256rmk = 17214,
  VPSRAVQZ256rmkz = 17215,
  VPSRAVQZ256rr = 17216,
  VPSRAVQZ256rrk = 17217,
  VPSRAVQZ256rrkz = 17218,
  VPSRAVQZrm = 17219,
  VPSRAVQZrmb = 17220,
  VPSRAVQZrmbk = 17221,
  VPSRAVQZrmbkz = 17222,
  VPSRAVQZrmk = 17223,
  VPSRAVQZrmkz = 17224,
  VPSRAVQZrr = 17225,
  VPSRAVQZrrk = 17226,
  VPSRAVQZrrkz = 17227,
  VPSRAVWZ128rm = 17228,
  VPSRAVWZ128rmk = 17229,
  VPSRAVWZ128rmkz = 17230,
  VPSRAVWZ128rr = 17231,
  VPSRAVWZ128rrk = 17232,
  VPSRAVWZ128rrkz = 17233,
  VPSRAVWZ256rm = 17234,
  VPSRAVWZ256rmk = 17235,
  VPSRAVWZ256rmkz = 17236,
  VPSRAVWZ256rr = 17237,
  VPSRAVWZ256rrk = 17238,
  VPSRAVWZ256rrkz = 17239,
  VPSRAVWZrm = 17240,
  VPSRAVWZrmk = 17241,
  VPSRAVWZrmkz = 17242,
  VPSRAVWZrr = 17243,
  VPSRAVWZrrk = 17244,
  VPSRAVWZrrkz = 17245,
  VPSRAWYri = 17246,
  VPSRAWYrm = 17247,
  VPSRAWYrr = 17248,
  VPSRAWZ128mi = 17249,
  VPSRAWZ128mik = 17250,
  VPSRAWZ128mikz = 17251,
  VPSRAWZ128ri = 17252,
  VPSRAWZ128rik = 17253,
  VPSRAWZ128rikz = 17254,
  VPSRAWZ128rm = 17255,
  VPSRAWZ128rmk = 17256,
  VPSRAWZ128rmkz = 17257,
  VPSRAWZ128rr = 17258,
  VPSRAWZ128rrk = 17259,
  VPSRAWZ128rrkz = 17260,
  VPSRAWZ256mi = 17261,
  VPSRAWZ256mik = 17262,
  VPSRAWZ256mikz = 17263,
  VPSRAWZ256ri = 17264,
  VPSRAWZ256rik = 17265,
  VPSRAWZ256rikz = 17266,
  VPSRAWZ256rm = 17267,
  VPSRAWZ256rmk = 17268,
  VPSRAWZ256rmkz = 17269,
  VPSRAWZ256rr = 17270,
  VPSRAWZ256rrk = 17271,
  VPSRAWZ256rrkz = 17272,
  VPSRAWZmi = 17273,
  VPSRAWZmik = 17274,
  VPSRAWZmikz = 17275,
  VPSRAWZri = 17276,
  VPSRAWZrik = 17277,
  VPSRAWZrikz = 17278,
  VPSRAWZrm = 17279,
  VPSRAWZrmk = 17280,
  VPSRAWZrmkz = 17281,
  VPSRAWZrr = 17282,
  VPSRAWZrrk = 17283,
  VPSRAWZrrkz = 17284,
  VPSRAWri = 17285,
  VPSRAWrm = 17286,
  VPSRAWrr = 17287,
  VPSRLDQYri = 17288,
  VPSRLDQZ128mi = 17289,
  VPSRLDQZ128ri = 17290,
  VPSRLDQZ256mi = 17291,
  VPSRLDQZ256ri = 17292,
  VPSRLDQZmi = 17293,
  VPSRLDQZri = 17294,
  VPSRLDQri = 17295,
  VPSRLDYri = 17296,
  VPSRLDYrm = 17297,
  VPSRLDYrr = 17298,
  VPSRLDZ128mbi = 17299,
  VPSRLDZ128mbik = 17300,
  VPSRLDZ128mbikz = 17301,
  VPSRLDZ128mi = 17302,
  VPSRLDZ128mik = 17303,
  VPSRLDZ128mikz = 17304,
  VPSRLDZ128ri = 17305,
  VPSRLDZ128rik = 17306,
  VPSRLDZ128rikz = 17307,
  VPSRLDZ128rm = 17308,
  VPSRLDZ128rmk = 17309,
  VPSRLDZ128rmkz = 17310,
  VPSRLDZ128rr = 17311,
  VPSRLDZ128rrk = 17312,
  VPSRLDZ128rrkz = 17313,
  VPSRLDZ256mbi = 17314,
  VPSRLDZ256mbik = 17315,
  VPSRLDZ256mbikz = 17316,
  VPSRLDZ256mi = 17317,
  VPSRLDZ256mik = 17318,
  VPSRLDZ256mikz = 17319,
  VPSRLDZ256ri = 17320,
  VPSRLDZ256rik = 17321,
  VPSRLDZ256rikz = 17322,
  VPSRLDZ256rm = 17323,
  VPSRLDZ256rmk = 17324,
  VPSRLDZ256rmkz = 17325,
  VPSRLDZ256rr = 17326,
  VPSRLDZ256rrk = 17327,
  VPSRLDZ256rrkz = 17328,
  VPSRLDZmbi = 17329,
  VPSRLDZmbik = 17330,
  VPSRLDZmbikz = 17331,
  VPSRLDZmi = 17332,
  VPSRLDZmik = 17333,
  VPSRLDZmikz = 17334,
  VPSRLDZri = 17335,
  VPSRLDZrik = 17336,
  VPSRLDZrikz = 17337,
  VPSRLDZrm = 17338,
  VPSRLDZrmk = 17339,
  VPSRLDZrmkz = 17340,
  VPSRLDZrr = 17341,
  VPSRLDZrrk = 17342,
  VPSRLDZrrkz = 17343,
  VPSRLDri = 17344,
  VPSRLDrm = 17345,
  VPSRLDrr = 17346,
  VPSRLQYri = 17347,
  VPSRLQYrm = 17348,
  VPSRLQYrr = 17349,
  VPSRLQZ128mbi = 17350,
  VPSRLQZ128mbik = 17351,
  VPSRLQZ128mbikz = 17352,
  VPSRLQZ128mi = 17353,
  VPSRLQZ128mik = 17354,
  VPSRLQZ128mikz = 17355,
  VPSRLQZ128ri = 17356,
  VPSRLQZ128rik = 17357,
  VPSRLQZ128rikz = 17358,
  VPSRLQZ128rm = 17359,
  VPSRLQZ128rmk = 17360,
  VPSRLQZ128rmkz = 17361,
  VPSRLQZ128rr = 17362,
  VPSRLQZ128rrk = 17363,
  VPSRLQZ128rrkz = 17364,
  VPSRLQZ256mbi = 17365,
  VPSRLQZ256mbik = 17366,
  VPSRLQZ256mbikz = 17367,
  VPSRLQZ256mi = 17368,
  VPSRLQZ256mik = 17369,
  VPSRLQZ256mikz = 17370,
  VPSRLQZ256ri = 17371,
  VPSRLQZ256rik = 17372,
  VPSRLQZ256rikz = 17373,
  VPSRLQZ256rm = 17374,
  VPSRLQZ256rmk = 17375,
  VPSRLQZ256rmkz = 17376,
  VPSRLQZ256rr = 17377,
  VPSRLQZ256rrk = 17378,
  VPSRLQZ256rrkz = 17379,
  VPSRLQZmbi = 17380,
  VPSRLQZmbik = 17381,
  VPSRLQZmbikz = 17382,
  VPSRLQZmi = 17383,
  VPSRLQZmik = 17384,
  VPSRLQZmikz = 17385,
  VPSRLQZri = 17386,
  VPSRLQZrik = 17387,
  VPSRLQZrikz = 17388,
  VPSRLQZrm = 17389,
  VPSRLQZrmk = 17390,
  VPSRLQZrmkz = 17391,
  VPSRLQZrr = 17392,
  VPSRLQZrrk = 17393,
  VPSRLQZrrkz = 17394,
  VPSRLQri = 17395,
  VPSRLQrm = 17396,
  VPSRLQrr = 17397,
  VPSRLVDYrm = 17398,
  VPSRLVDYrr = 17399,
  VPSRLVDZ128rm = 17400,
  VPSRLVDZ128rmb = 17401,
  VPSRLVDZ128rmbk = 17402,
  VPSRLVDZ128rmbkz = 17403,
  VPSRLVDZ128rmk = 17404,
  VPSRLVDZ128rmkz = 17405,
  VPSRLVDZ128rr = 17406,
  VPSRLVDZ128rrk = 17407,
  VPSRLVDZ128rrkz = 17408,
  VPSRLVDZ256rm = 17409,
  VPSRLVDZ256rmb = 17410,
  VPSRLVDZ256rmbk = 17411,
  VPSRLVDZ256rmbkz = 17412,
  VPSRLVDZ256rmk = 17413,
  VPSRLVDZ256rmkz = 17414,
  VPSRLVDZ256rr = 17415,
  VPSRLVDZ256rrk = 17416,
  VPSRLVDZ256rrkz = 17417,
  VPSRLVDZrm = 17418,
  VPSRLVDZrmb = 17419,
  VPSRLVDZrmbk = 17420,
  VPSRLVDZrmbkz = 17421,
  VPSRLVDZrmk = 17422,
  VPSRLVDZrmkz = 17423,
  VPSRLVDZrr = 17424,
  VPSRLVDZrrk = 17425,
  VPSRLVDZrrkz = 17426,
  VPSRLVDrm = 17427,
  VPSRLVDrr = 17428,
  VPSRLVQYrm = 17429,
  VPSRLVQYrr = 17430,
  VPSRLVQZ128rm = 17431,
  VPSRLVQZ128rmb = 17432,
  VPSRLVQZ128rmbk = 17433,
  VPSRLVQZ128rmbkz = 17434,
  VPSRLVQZ128rmk = 17435,
  VPSRLVQZ128rmkz = 17436,
  VPSRLVQZ128rr = 17437,
  VPSRLVQZ128rrk = 17438,
  VPSRLVQZ128rrkz = 17439,
  VPSRLVQZ256rm = 17440,
  VPSRLVQZ256rmb = 17441,
  VPSRLVQZ256rmbk = 17442,
  VPSRLVQZ256rmbkz = 17443,
  VPSRLVQZ256rmk = 17444,
  VPSRLVQZ256rmkz = 17445,
  VPSRLVQZ256rr = 17446,
  VPSRLVQZ256rrk = 17447,
  VPSRLVQZ256rrkz = 17448,
  VPSRLVQZrm = 17449,
  VPSRLVQZrmb = 17450,
  VPSRLVQZrmbk = 17451,
  VPSRLVQZrmbkz = 17452,
  VPSRLVQZrmk = 17453,
  VPSRLVQZrmkz = 17454,
  VPSRLVQZrr = 17455,
  VPSRLVQZrrk = 17456,
  VPSRLVQZrrkz = 17457,
  VPSRLVQrm = 17458,
  VPSRLVQrr = 17459,
  VPSRLVWZ128rm = 17460,
  VPSRLVWZ128rmk = 17461,
  VPSRLVWZ128rmkz = 17462,
  VPSRLVWZ128rr = 17463,
  VPSRLVWZ128rrk = 17464,
  VPSRLVWZ128rrkz = 17465,
  VPSRLVWZ256rm = 17466,
  VPSRLVWZ256rmk = 17467,
  VPSRLVWZ256rmkz = 17468,
  VPSRLVWZ256rr = 17469,
  VPSRLVWZ256rrk = 17470,
  VPSRLVWZ256rrkz = 17471,
  VPSRLVWZrm = 17472,
  VPSRLVWZrmk = 17473,
  VPSRLVWZrmkz = 17474,
  VPSRLVWZrr = 17475,
  VPSRLVWZrrk = 17476,
  VPSRLVWZrrkz = 17477,
  VPSRLWYri = 17478,
  VPSRLWYrm = 17479,
  VPSRLWYrr = 17480,
  VPSRLWZ128mi = 17481,
  VPSRLWZ128mik = 17482,
  VPSRLWZ128mikz = 17483,
  VPSRLWZ128ri = 17484,
  VPSRLWZ128rik = 17485,
  VPSRLWZ128rikz = 17486,
  VPSRLWZ128rm = 17487,
  VPSRLWZ128rmk = 17488,
  VPSRLWZ128rmkz = 17489,
  VPSRLWZ128rr = 17490,
  VPSRLWZ128rrk = 17491,
  VPSRLWZ128rrkz = 17492,
  VPSRLWZ256mi = 17493,
  VPSRLWZ256mik = 17494,
  VPSRLWZ256mikz = 17495,
  VPSRLWZ256ri = 17496,
  VPSRLWZ256rik = 17497,
  VPSRLWZ256rikz = 17498,
  VPSRLWZ256rm = 17499,
  VPSRLWZ256rmk = 17500,
  VPSRLWZ256rmkz = 17501,
  VPSRLWZ256rr = 17502,
  VPSRLWZ256rrk = 17503,
  VPSRLWZ256rrkz = 17504,
  VPSRLWZmi = 17505,
  VPSRLWZmik = 17506,
  VPSRLWZmikz = 17507,
  VPSRLWZri = 17508,
  VPSRLWZrik = 17509,
  VPSRLWZrikz = 17510,
  VPSRLWZrm = 17511,
  VPSRLWZrmk = 17512,
  VPSRLWZrmkz = 17513,
  VPSRLWZrr = 17514,
  VPSRLWZrrk = 17515,
  VPSRLWZrrkz = 17516,
  VPSRLWri = 17517,
  VPSRLWrm = 17518,
  VPSRLWrr = 17519,
  VPSUBBYrm = 17520,
  VPSUBBYrr = 17521,
  VPSUBBZ128rm = 17522,
  VPSUBBZ128rmk = 17523,
  VPSUBBZ128rmkz = 17524,
  VPSUBBZ128rr = 17525,
  VPSUBBZ128rrk = 17526,
  VPSUBBZ128rrkz = 17527,
  VPSUBBZ256rm = 17528,
  VPSUBBZ256rmk = 17529,
  VPSUBBZ256rmkz = 17530,
  VPSUBBZ256rr = 17531,
  VPSUBBZ256rrk = 17532,
  VPSUBBZ256rrkz = 17533,
  VPSUBBZrm = 17534,
  VPSUBBZrmk = 17535,
  VPSUBBZrmkz = 17536,
  VPSUBBZrr = 17537,
  VPSUBBZrrk = 17538,
  VPSUBBZrrkz = 17539,
  VPSUBBrm = 17540,
  VPSUBBrr = 17541,
  VPSUBDYrm = 17542,
  VPSUBDYrr = 17543,
  VPSUBDZ128rm = 17544,
  VPSUBDZ128rmb = 17545,
  VPSUBDZ128rmbk = 17546,
  VPSUBDZ128rmbkz = 17547,
  VPSUBDZ128rmk = 17548,
  VPSUBDZ128rmkz = 17549,
  VPSUBDZ128rr = 17550,
  VPSUBDZ128rrk = 17551,
  VPSUBDZ128rrkz = 17552,
  VPSUBDZ256rm = 17553,
  VPSUBDZ256rmb = 17554,
  VPSUBDZ256rmbk = 17555,
  VPSUBDZ256rmbkz = 17556,
  VPSUBDZ256rmk = 17557,
  VPSUBDZ256rmkz = 17558,
  VPSUBDZ256rr = 17559,
  VPSUBDZ256rrk = 17560,
  VPSUBDZ256rrkz = 17561,
  VPSUBDZrm = 17562,
  VPSUBDZrmb = 17563,
  VPSUBDZrmbk = 17564,
  VPSUBDZrmbkz = 17565,
  VPSUBDZrmk = 17566,
  VPSUBDZrmkz = 17567,
  VPSUBDZrr = 17568,
  VPSUBDZrrk = 17569,
  VPSUBDZrrkz = 17570,
  VPSUBDrm = 17571,
  VPSUBDrr = 17572,
  VPSUBQYrm = 17573,
  VPSUBQYrr = 17574,
  VPSUBQZ128rm = 17575,
  VPSUBQZ128rmb = 17576,
  VPSUBQZ128rmbk = 17577,
  VPSUBQZ128rmbkz = 17578,
  VPSUBQZ128rmk = 17579,
  VPSUBQZ128rmkz = 17580,
  VPSUBQZ128rr = 17581,
  VPSUBQZ128rrk = 17582,
  VPSUBQZ128rrkz = 17583,
  VPSUBQZ256rm = 17584,
  VPSUBQZ256rmb = 17585,
  VPSUBQZ256rmbk = 17586,
  VPSUBQZ256rmbkz = 17587,
  VPSUBQZ256rmk = 17588,
  VPSUBQZ256rmkz = 17589,
  VPSUBQZ256rr = 17590,
  VPSUBQZ256rrk = 17591,
  VPSUBQZ256rrkz = 17592,
  VPSUBQZrm = 17593,
  VPSUBQZrmb = 17594,
  VPSUBQZrmbk = 17595,
  VPSUBQZrmbkz = 17596,
  VPSUBQZrmk = 17597,
  VPSUBQZrmkz = 17598,
  VPSUBQZrr = 17599,
  VPSUBQZrrk = 17600,
  VPSUBQZrrkz = 17601,
  VPSUBQrm = 17602,
  VPSUBQrr = 17603,
  VPSUBSBYrm = 17604,
  VPSUBSBYrr = 17605,
  VPSUBSBZ128rm = 17606,
  VPSUBSBZ128rmk = 17607,
  VPSUBSBZ128rmkz = 17608,
  VPSUBSBZ128rr = 17609,
  VPSUBSBZ128rrk = 17610,
  VPSUBSBZ128rrkz = 17611,
  VPSUBSBZ256rm = 17612,
  VPSUBSBZ256rmk = 17613,
  VPSUBSBZ256rmkz = 17614,
  VPSUBSBZ256rr = 17615,
  VPSUBSBZ256rrk = 17616,
  VPSUBSBZ256rrkz = 17617,
  VPSUBSBZrm = 17618,
  VPSUBSBZrmk = 17619,
  VPSUBSBZrmkz = 17620,
  VPSUBSBZrr = 17621,
  VPSUBSBZrrk = 17622,
  VPSUBSBZrrkz = 17623,
  VPSUBSBrm = 17624,
  VPSUBSBrr = 17625,
  VPSUBSWYrm = 17626,
  VPSUBSWYrr = 17627,
  VPSUBSWZ128rm = 17628,
  VPSUBSWZ128rmk = 17629,
  VPSUBSWZ128rmkz = 17630,
  VPSUBSWZ128rr = 17631,
  VPSUBSWZ128rrk = 17632,
  VPSUBSWZ128rrkz = 17633,
  VPSUBSWZ256rm = 17634,
  VPSUBSWZ256rmk = 17635,
  VPSUBSWZ256rmkz = 17636,
  VPSUBSWZ256rr = 17637,
  VPSUBSWZ256rrk = 17638,
  VPSUBSWZ256rrkz = 17639,
  VPSUBSWZrm = 17640,
  VPSUBSWZrmk = 17641,
  VPSUBSWZrmkz = 17642,
  VPSUBSWZrr = 17643,
  VPSUBSWZrrk = 17644,
  VPSUBSWZrrkz = 17645,
  VPSUBSWrm = 17646,
  VPSUBSWrr = 17647,
  VPSUBUSBYrm = 17648,
  VPSUBUSBYrr = 17649,
  VPSUBUSBZ128rm = 17650,
  VPSUBUSBZ128rmk = 17651,
  VPSUBUSBZ128rmkz = 17652,
  VPSUBUSBZ128rr = 17653,
  VPSUBUSBZ128rrk = 17654,
  VPSUBUSBZ128rrkz = 17655,
  VPSUBUSBZ256rm = 17656,
  VPSUBUSBZ256rmk = 17657,
  VPSUBUSBZ256rmkz = 17658,
  VPSUBUSBZ256rr = 17659,
  VPSUBUSBZ256rrk = 17660,
  VPSUBUSBZ256rrkz = 17661,
  VPSUBUSBZrm = 17662,
  VPSUBUSBZrmk = 17663,
  VPSUBUSBZrmkz = 17664,
  VPSUBUSBZrr = 17665,
  VPSUBUSBZrrk = 17666,
  VPSUBUSBZrrkz = 17667,
  VPSUBUSBrm = 17668,
  VPSUBUSBrr = 17669,
  VPSUBUSWYrm = 17670,
  VPSUBUSWYrr = 17671,
  VPSUBUSWZ128rm = 17672,
  VPSUBUSWZ128rmk = 17673,
  VPSUBUSWZ128rmkz = 17674,
  VPSUBUSWZ128rr = 17675,
  VPSUBUSWZ128rrk = 17676,
  VPSUBUSWZ128rrkz = 17677,
  VPSUBUSWZ256rm = 17678,
  VPSUBUSWZ256rmk = 17679,
  VPSUBUSWZ256rmkz = 17680,
  VPSUBUSWZ256rr = 17681,
  VPSUBUSWZ256rrk = 17682,
  VPSUBUSWZ256rrkz = 17683,
  VPSUBUSWZrm = 17684,
  VPSUBUSWZrmk = 17685,
  VPSUBUSWZrmkz = 17686,
  VPSUBUSWZrr = 17687,
  VPSUBUSWZrrk = 17688,
  VPSUBUSWZrrkz = 17689,
  VPSUBUSWrm = 17690,
  VPSUBUSWrr = 17691,
  VPSUBWYrm = 17692,
  VPSUBWYrr = 17693,
  VPSUBWZ128rm = 17694,
  VPSUBWZ128rmk = 17695,
  VPSUBWZ128rmkz = 17696,
  VPSUBWZ128rr = 17697,
  VPSUBWZ128rrk = 17698,
  VPSUBWZ128rrkz = 17699,
  VPSUBWZ256rm = 17700,
  VPSUBWZ256rmk = 17701,
  VPSUBWZ256rmkz = 17702,
  VPSUBWZ256rr = 17703,
  VPSUBWZ256rrk = 17704,
  VPSUBWZ256rrkz = 17705,
  VPSUBWZrm = 17706,
  VPSUBWZrmk = 17707,
  VPSUBWZrmkz = 17708,
  VPSUBWZrr = 17709,
  VPSUBWZrrk = 17710,
  VPSUBWZrrkz = 17711,
  VPSUBWrm = 17712,
  VPSUBWrr = 17713,
  VPTERNLOGDZ128rmbi = 17714,
  VPTERNLOGDZ128rmbik = 17715,
  VPTERNLOGDZ128rmbikz = 17716,
  VPTERNLOGDZ128rmi = 17717,
  VPTERNLOGDZ128rmik = 17718,
  VPTERNLOGDZ128rmikz = 17719,
  VPTERNLOGDZ128rri = 17720,
  VPTERNLOGDZ128rrik = 17721,
  VPTERNLOGDZ128rrikz = 17722,
  VPTERNLOGDZ256rmbi = 17723,
  VPTERNLOGDZ256rmbik = 17724,
  VPTERNLOGDZ256rmbikz = 17725,
  VPTERNLOGDZ256rmi = 17726,
  VPTERNLOGDZ256rmik = 17727,
  VPTERNLOGDZ256rmikz = 17728,
  VPTERNLOGDZ256rri = 17729,
  VPTERNLOGDZ256rrik = 17730,
  VPTERNLOGDZ256rrikz = 17731,
  VPTERNLOGDZrmbi = 17732,
  VPTERNLOGDZrmbik = 17733,
  VPTERNLOGDZrmbikz = 17734,
  VPTERNLOGDZrmi = 17735,
  VPTERNLOGDZrmik = 17736,
  VPTERNLOGDZrmikz = 17737,
  VPTERNLOGDZrri = 17738,
  VPTERNLOGDZrrik = 17739,
  VPTERNLOGDZrrikz = 17740,
  VPTERNLOGQZ128rmbi = 17741,
  VPTERNLOGQZ128rmbik = 17742,
  VPTERNLOGQZ128rmbikz = 17743,
  VPTERNLOGQZ128rmi = 17744,
  VPTERNLOGQZ128rmik = 17745,
  VPTERNLOGQZ128rmikz = 17746,
  VPTERNLOGQZ128rri = 17747,
  VPTERNLOGQZ128rrik = 17748,
  VPTERNLOGQZ128rrikz = 17749,
  VPTERNLOGQZ256rmbi = 17750,
  VPTERNLOGQZ256rmbik = 17751,
  VPTERNLOGQZ256rmbikz = 17752,
  VPTERNLOGQZ256rmi = 17753,
  VPTERNLOGQZ256rmik = 17754,
  VPTERNLOGQZ256rmikz = 17755,
  VPTERNLOGQZ256rri = 17756,
  VPTERNLOGQZ256rrik = 17757,
  VPTERNLOGQZ256rrikz = 17758,
  VPTERNLOGQZrmbi = 17759,
  VPTERNLOGQZrmbik = 17760,
  VPTERNLOGQZrmbikz = 17761,
  VPTERNLOGQZrmi = 17762,
  VPTERNLOGQZrmik = 17763,
  VPTERNLOGQZrmikz = 17764,
  VPTERNLOGQZrri = 17765,
  VPTERNLOGQZrrik = 17766,
  VPTERNLOGQZrrikz = 17767,
  VPTESTMBZ128rm = 17768,
  VPTESTMBZ128rmk = 17769,
  VPTESTMBZ128rr = 17770,
  VPTESTMBZ128rrk = 17771,
  VPTESTMBZ256rm = 17772,
  VPTESTMBZ256rmk = 17773,
  VPTESTMBZ256rr = 17774,
  VPTESTMBZ256rrk = 17775,
  VPTESTMBZrm = 17776,
  VPTESTMBZrmk = 17777,
  VPTESTMBZrr = 17778,
  VPTESTMBZrrk = 17779,
  VPTESTMDZ128rm = 17780,
  VPTESTMDZ128rmb = 17781,
  VPTESTMDZ128rmbk = 17782,
  VPTESTMDZ128rmk = 17783,
  VPTESTMDZ128rr = 17784,
  VPTESTMDZ128rrk = 17785,
  VPTESTMDZ256rm = 17786,
  VPTESTMDZ256rmb = 17787,
  VPTESTMDZ256rmbk = 17788,
  VPTESTMDZ256rmk = 17789,
  VPTESTMDZ256rr = 17790,
  VPTESTMDZ256rrk = 17791,
  VPTESTMDZrm = 17792,
  VPTESTMDZrmb = 17793,
  VPTESTMDZrmbk = 17794,
  VPTESTMDZrmk = 17795,
  VPTESTMDZrr = 17796,
  VPTESTMDZrrk = 17797,
  VPTESTMQZ128rm = 17798,
  VPTESTMQZ128rmb = 17799,
  VPTESTMQZ128rmbk = 17800,
  VPTESTMQZ128rmk = 17801,
  VPTESTMQZ128rr = 17802,
  VPTESTMQZ128rrk = 17803,
  VPTESTMQZ256rm = 17804,
  VPTESTMQZ256rmb = 17805,
  VPTESTMQZ256rmbk = 17806,
  VPTESTMQZ256rmk = 17807,
  VPTESTMQZ256rr = 17808,
  VPTESTMQZ256rrk = 17809,
  VPTESTMQZrm = 17810,
  VPTESTMQZrmb = 17811,
  VPTESTMQZrmbk = 17812,
  VPTESTMQZrmk = 17813,
  VPTESTMQZrr = 17814,
  VPTESTMQZrrk = 17815,
  VPTESTMWZ128rm = 17816,
  VPTESTMWZ128rmk = 17817,
  VPTESTMWZ128rr = 17818,
  VPTESTMWZ128rrk = 17819,
  VPTESTMWZ256rm = 17820,
  VPTESTMWZ256rmk = 17821,
  VPTESTMWZ256rr = 17822,
  VPTESTMWZ256rrk = 17823,
  VPTESTMWZrm = 17824,
  VPTESTMWZrmk = 17825,
  VPTESTMWZrr = 17826,
  VPTESTMWZrrk = 17827,
  VPTESTNMBZ128rm = 17828,
  VPTESTNMBZ128rmk = 17829,
  VPTESTNMBZ128rr = 17830,
  VPTESTNMBZ128rrk = 17831,
  VPTESTNMBZ256rm = 17832,
  VPTESTNMBZ256rmk = 17833,
  VPTESTNMBZ256rr = 17834,
  VPTESTNMBZ256rrk = 17835,
  VPTESTNMBZrm = 17836,
  VPTESTNMBZrmk = 17837,
  VPTESTNMBZrr = 17838,
  VPTESTNMBZrrk = 17839,
  VPTESTNMDZ128rm = 17840,
  VPTESTNMDZ128rmb = 17841,
  VPTESTNMDZ128rmbk = 17842,
  VPTESTNMDZ128rmk = 17843,
  VPTESTNMDZ128rr = 17844,
  VPTESTNMDZ128rrk = 17845,
  VPTESTNMDZ256rm = 17846,
  VPTESTNMDZ256rmb = 17847,
  VPTESTNMDZ256rmbk = 17848,
  VPTESTNMDZ256rmk = 17849,
  VPTESTNMDZ256rr = 17850,
  VPTESTNMDZ256rrk = 17851,
  VPTESTNMDZrm = 17852,
  VPTESTNMDZrmb = 17853,
  VPTESTNMDZrmbk = 17854,
  VPTESTNMDZrmk = 17855,
  VPTESTNMDZrr = 17856,
  VPTESTNMDZrrk = 17857,
  VPTESTNMQZ128rm = 17858,
  VPTESTNMQZ128rmb = 17859,
  VPTESTNMQZ128rmbk = 17860,
  VPTESTNMQZ128rmk = 17861,
  VPTESTNMQZ128rr = 17862,
  VPTESTNMQZ128rrk = 17863,
  VPTESTNMQZ256rm = 17864,
  VPTESTNMQZ256rmb = 17865,
  VPTESTNMQZ256rmbk = 17866,
  VPTESTNMQZ256rmk = 17867,
  VPTESTNMQZ256rr = 17868,
  VPTESTNMQZ256rrk = 17869,
  VPTESTNMQZrm = 17870,
  VPTESTNMQZrmb = 17871,
  VPTESTNMQZrmbk = 17872,
  VPTESTNMQZrmk = 17873,
  VPTESTNMQZrr = 17874,
  VPTESTNMQZrrk = 17875,
  VPTESTNMWZ128rm = 17876,
  VPTESTNMWZ128rmk = 17877,
  VPTESTNMWZ128rr = 17878,
  VPTESTNMWZ128rrk = 17879,
  VPTESTNMWZ256rm = 17880,
  VPTESTNMWZ256rmk = 17881,
  VPTESTNMWZ256rr = 17882,
  VPTESTNMWZ256rrk = 17883,
  VPTESTNMWZrm = 17884,
  VPTESTNMWZrmk = 17885,
  VPTESTNMWZrr = 17886,
  VPTESTNMWZrrk = 17887,
  VPTESTYrm = 17888,
  VPTESTYrr = 17889,
  VPTESTrm = 17890,
  VPTESTrr = 17891,
  VPUNPCKHBWYrm = 17892,
  VPUNPCKHBWYrr = 17893,
  VPUNPCKHBWZ128rm = 17894,
  VPUNPCKHBWZ128rmk = 17895,
  VPUNPCKHBWZ128rmkz = 17896,
  VPUNPCKHBWZ128rr = 17897,
  VPUNPCKHBWZ128rrk = 17898,
  VPUNPCKHBWZ128rrkz = 17899,
  VPUNPCKHBWZ256rm = 17900,
  VPUNPCKHBWZ256rmk = 17901,
  VPUNPCKHBWZ256rmkz = 17902,
  VPUNPCKHBWZ256rr = 17903,
  VPUNPCKHBWZ256rrk = 17904,
  VPUNPCKHBWZ256rrkz = 17905,
  VPUNPCKHBWZrm = 17906,
  VPUNPCKHBWZrmk = 17907,
  VPUNPCKHBWZrmkz = 17908,
  VPUNPCKHBWZrr = 17909,
  VPUNPCKHBWZrrk = 17910,
  VPUNPCKHBWZrrkz = 17911,
  VPUNPCKHBWrm = 17912,
  VPUNPCKHBWrr = 17913,
  VPUNPCKHDQYrm = 17914,
  VPUNPCKHDQYrr = 17915,
  VPUNPCKHDQZ128rm = 17916,
  VPUNPCKHDQZ128rmb = 17917,
  VPUNPCKHDQZ128rmbk = 17918,
  VPUNPCKHDQZ128rmbkz = 17919,
  VPUNPCKHDQZ128rmk = 17920,
  VPUNPCKHDQZ128rmkz = 17921,
  VPUNPCKHDQZ128rr = 17922,
  VPUNPCKHDQZ128rrk = 17923,
  VPUNPCKHDQZ128rrkz = 17924,
  VPUNPCKHDQZ256rm = 17925,
  VPUNPCKHDQZ256rmb = 17926,
  VPUNPCKHDQZ256rmbk = 17927,
  VPUNPCKHDQZ256rmbkz = 17928,
  VPUNPCKHDQZ256rmk = 17929,
  VPUNPCKHDQZ256rmkz = 17930,
  VPUNPCKHDQZ256rr = 17931,
  VPUNPCKHDQZ256rrk = 17932,
  VPUNPCKHDQZ256rrkz = 17933,
  VPUNPCKHDQZrm = 17934,
  VPUNPCKHDQZrmb = 17935,
  VPUNPCKHDQZrmbk = 17936,
  VPUNPCKHDQZrmbkz = 17937,
  VPUNPCKHDQZrmk = 17938,
  VPUNPCKHDQZrmkz = 17939,
  VPUNPCKHDQZrr = 17940,
  VPUNPCKHDQZrrk = 17941,
  VPUNPCKHDQZrrkz = 17942,
  VPUNPCKHDQrm = 17943,
  VPUNPCKHDQrr = 17944,
  VPUNPCKHQDQYrm = 17945,
  VPUNPCKHQDQYrr = 17946,
  VPUNPCKHQDQZ128rm = 17947,
  VPUNPCKHQDQZ128rmb = 17948,
  VPUNPCKHQDQZ128rmbk = 17949,
  VPUNPCKHQDQZ128rmbkz = 17950,
  VPUNPCKHQDQZ128rmk = 17951,
  VPUNPCKHQDQZ128rmkz = 17952,
  VPUNPCKHQDQZ128rr = 17953,
  VPUNPCKHQDQZ128rrk = 17954,
  VPUNPCKHQDQZ128rrkz = 17955,
  VPUNPCKHQDQZ256rm = 17956,
  VPUNPCKHQDQZ256rmb = 17957,
  VPUNPCKHQDQZ256rmbk = 17958,
  VPUNPCKHQDQZ256rmbkz = 17959,
  VPUNPCKHQDQZ256rmk = 17960,
  VPUNPCKHQDQZ256rmkz = 17961,
  VPUNPCKHQDQZ256rr = 17962,
  VPUNPCKHQDQZ256rrk = 17963,
  VPUNPCKHQDQZ256rrkz = 17964,
  VPUNPCKHQDQZrm = 17965,
  VPUNPCKHQDQZrmb = 17966,
  VPUNPCKHQDQZrmbk = 17967,
  VPUNPCKHQDQZrmbkz = 17968,
  VPUNPCKHQDQZrmk = 17969,
  VPUNPCKHQDQZrmkz = 17970,
  VPUNPCKHQDQZrr = 17971,
  VPUNPCKHQDQZrrk = 17972,
  VPUNPCKHQDQZrrkz = 17973,
  VPUNPCKHQDQrm = 17974,
  VPUNPCKHQDQrr = 17975,
  VPUNPCKHWDYrm = 17976,
  VPUNPCKHWDYrr = 17977,
  VPUNPCKHWDZ128rm = 17978,
  VPUNPCKHWDZ128rmk = 17979,
  VPUNPCKHWDZ128rmkz = 17980,
  VPUNPCKHWDZ128rr = 17981,
  VPUNPCKHWDZ128rrk = 17982,
  VPUNPCKHWDZ128rrkz = 17983,
  VPUNPCKHWDZ256rm = 17984,
  VPUNPCKHWDZ256rmk = 17985,
  VPUNPCKHWDZ256rmkz = 17986,
  VPUNPCKHWDZ256rr = 17987,
  VPUNPCKHWDZ256rrk = 17988,
  VPUNPCKHWDZ256rrkz = 17989,
  VPUNPCKHWDZrm = 17990,
  VPUNPCKHWDZrmk = 17991,
  VPUNPCKHWDZrmkz = 17992,
  VPUNPCKHWDZrr = 17993,
  VPUNPCKHWDZrrk = 17994,
  VPUNPCKHWDZrrkz = 17995,
  VPUNPCKHWDrm = 17996,
  VPUNPCKHWDrr = 17997,
  VPUNPCKLBWYrm = 17998,
  VPUNPCKLBWYrr = 17999,
  VPUNPCKLBWZ128rm = 18000,
  VPUNPCKLBWZ128rmk = 18001,
  VPUNPCKLBWZ128rmkz = 18002,
  VPUNPCKLBWZ128rr = 18003,
  VPUNPCKLBWZ128rrk = 18004,
  VPUNPCKLBWZ128rrkz = 18005,
  VPUNPCKLBWZ256rm = 18006,
  VPUNPCKLBWZ256rmk = 18007,
  VPUNPCKLBWZ256rmkz = 18008,
  VPUNPCKLBWZ256rr = 18009,
  VPUNPCKLBWZ256rrk = 18010,
  VPUNPCKLBWZ256rrkz = 18011,
  VPUNPCKLBWZrm = 18012,
  VPUNPCKLBWZrmk = 18013,
  VPUNPCKLBWZrmkz = 18014,
  VPUNPCKLBWZrr = 18015,
  VPUNPCKLBWZrrk = 18016,
  VPUNPCKLBWZrrkz = 18017,
  VPUNPCKLBWrm = 18018,
  VPUNPCKLBWrr = 18019,
  VPUNPCKLDQYrm = 18020,
  VPUNPCKLDQYrr = 18021,
  VPUNPCKLDQZ128rm = 18022,
  VPUNPCKLDQZ128rmb = 18023,
  VPUNPCKLDQZ128rmbk = 18024,
  VPUNPCKLDQZ128rmbkz = 18025,
  VPUNPCKLDQZ128rmk = 18026,
  VPUNPCKLDQZ128rmkz = 18027,
  VPUNPCKLDQZ128rr = 18028,
  VPUNPCKLDQZ128rrk = 18029,
  VPUNPCKLDQZ128rrkz = 18030,
  VPUNPCKLDQZ256rm = 18031,
  VPUNPCKLDQZ256rmb = 18032,
  VPUNPCKLDQZ256rmbk = 18033,
  VPUNPCKLDQZ256rmbkz = 18034,
  VPUNPCKLDQZ256rmk = 18035,
  VPUNPCKLDQZ256rmkz = 18036,
  VPUNPCKLDQZ256rr = 18037,
  VPUNPCKLDQZ256rrk = 18038,
  VPUNPCKLDQZ256rrkz = 18039,
  VPUNPCKLDQZrm = 18040,
  VPUNPCKLDQZrmb = 18041,
  VPUNPCKLDQZrmbk = 18042,
  VPUNPCKLDQZrmbkz = 18043,
  VPUNPCKLDQZrmk = 18044,
  VPUNPCKLDQZrmkz = 18045,
  VPUNPCKLDQZrr = 18046,
  VPUNPCKLDQZrrk = 18047,
  VPUNPCKLDQZrrkz = 18048,
  VPUNPCKLDQrm = 18049,
  VPUNPCKLDQrr = 18050,
  VPUNPCKLQDQYrm = 18051,
  VPUNPCKLQDQYrr = 18052,
  VPUNPCKLQDQZ128rm = 18053,
  VPUNPCKLQDQZ128rmb = 18054,
  VPUNPCKLQDQZ128rmbk = 18055,
  VPUNPCKLQDQZ128rmbkz = 18056,
  VPUNPCKLQDQZ128rmk = 18057,
  VPUNPCKLQDQZ128rmkz = 18058,
  VPUNPCKLQDQZ128rr = 18059,
  VPUNPCKLQDQZ128rrk = 18060,
  VPUNPCKLQDQZ128rrkz = 18061,
  VPUNPCKLQDQZ256rm = 18062,
  VPUNPCKLQDQZ256rmb = 18063,
  VPUNPCKLQDQZ256rmbk = 18064,
  VPUNPCKLQDQZ256rmbkz = 18065,
  VPUNPCKLQDQZ256rmk = 18066,
  VPUNPCKLQDQZ256rmkz = 18067,
  VPUNPCKLQDQZ256rr = 18068,
  VPUNPCKLQDQZ256rrk = 18069,
  VPUNPCKLQDQZ256rrkz = 18070,
  VPUNPCKLQDQZrm = 18071,
  VPUNPCKLQDQZrmb = 18072,
  VPUNPCKLQDQZrmbk = 18073,
  VPUNPCKLQDQZrmbkz = 18074,
  VPUNPCKLQDQZrmk = 18075,
  VPUNPCKLQDQZrmkz = 18076,
  VPUNPCKLQDQZrr = 18077,
  VPUNPCKLQDQZrrk = 18078,
  VPUNPCKLQDQZrrkz = 18079,
  VPUNPCKLQDQrm = 18080,
  VPUNPCKLQDQrr = 18081,
  VPUNPCKLWDYrm = 18082,
  VPUNPCKLWDYrr = 18083,
  VPUNPCKLWDZ128rm = 18084,
  VPUNPCKLWDZ128rmk = 18085,
  VPUNPCKLWDZ128rmkz = 18086,
  VPUNPCKLWDZ128rr = 18087,
  VPUNPCKLWDZ128rrk = 18088,
  VPUNPCKLWDZ128rrkz = 18089,
  VPUNPCKLWDZ256rm = 18090,
  VPUNPCKLWDZ256rmk = 18091,
  VPUNPCKLWDZ256rmkz = 18092,
  VPUNPCKLWDZ256rr = 18093,
  VPUNPCKLWDZ256rrk = 18094,
  VPUNPCKLWDZ256rrkz = 18095,
  VPUNPCKLWDZrm = 18096,
  VPUNPCKLWDZrmk = 18097,
  VPUNPCKLWDZrmkz = 18098,
  VPUNPCKLWDZrr = 18099,
  VPUNPCKLWDZrrk = 18100,
  VPUNPCKLWDZrrkz = 18101,
  VPUNPCKLWDrm = 18102,
  VPUNPCKLWDrr = 18103,
  VPXORDZ128rm = 18104,
  VPXORDZ128rmb = 18105,
  VPXORDZ128rmbk = 18106,
  VPXORDZ128rmbkz = 18107,
  VPXORDZ128rmk = 18108,
  VPXORDZ128rmkz = 18109,
  VPXORDZ128rr = 18110,
  VPXORDZ128rrk = 18111,
  VPXORDZ128rrkz = 18112,
  VPXORDZ256rm = 18113,
  VPXORDZ256rmb = 18114,
  VPXORDZ256rmbk = 18115,
  VPXORDZ256rmbkz = 18116,
  VPXORDZ256rmk = 18117,
  VPXORDZ256rmkz = 18118,
  VPXORDZ256rr = 18119,
  VPXORDZ256rrk = 18120,
  VPXORDZ256rrkz = 18121,
  VPXORDZrm = 18122,
  VPXORDZrmb = 18123,
  VPXORDZrmbk = 18124,
  VPXORDZrmbkz = 18125,
  VPXORDZrmk = 18126,
  VPXORDZrmkz = 18127,
  VPXORDZrr = 18128,
  VPXORDZrrk = 18129,
  VPXORDZrrkz = 18130,
  VPXORQZ128rm = 18131,
  VPXORQZ128rmb = 18132,
  VPXORQZ128rmbk = 18133,
  VPXORQZ128rmbkz = 18134,
  VPXORQZ128rmk = 18135,
  VPXORQZ128rmkz = 18136,
  VPXORQZ128rr = 18137,
  VPXORQZ128rrk = 18138,
  VPXORQZ128rrkz = 18139,
  VPXORQZ256rm = 18140,
  VPXORQZ256rmb = 18141,
  VPXORQZ256rmbk = 18142,
  VPXORQZ256rmbkz = 18143,
  VPXORQZ256rmk = 18144,
  VPXORQZ256rmkz = 18145,
  VPXORQZ256rr = 18146,
  VPXORQZ256rrk = 18147,
  VPXORQZ256rrkz = 18148,
  VPXORQZrm = 18149,
  VPXORQZrmb = 18150,
  VPXORQZrmbk = 18151,
  VPXORQZrmbkz = 18152,
  VPXORQZrmk = 18153,
  VPXORQZrmkz = 18154,
  VPXORQZrr = 18155,
  VPXORQZrrk = 18156,
  VPXORQZrrkz = 18157,
  VPXORYrm = 18158,
  VPXORYrr = 18159,
  VPXORrm = 18160,
  VPXORrr = 18161,
  VRANGEPDZ128rmbi = 18162,
  VRANGEPDZ128rmbik = 18163,
  VRANGEPDZ128rmbikz = 18164,
  VRANGEPDZ128rmi = 18165,
  VRANGEPDZ128rmik = 18166,
  VRANGEPDZ128rmikz = 18167,
  VRANGEPDZ128rri = 18168,
  VRANGEPDZ128rrik = 18169,
  VRANGEPDZ128rrikz = 18170,
  VRANGEPDZ256rmbi = 18171,
  VRANGEPDZ256rmbik = 18172,
  VRANGEPDZ256rmbikz = 18173,
  VRANGEPDZ256rmi = 18174,
  VRANGEPDZ256rmik = 18175,
  VRANGEPDZ256rmikz = 18176,
  VRANGEPDZ256rri = 18177,
  VRANGEPDZ256rrik = 18178,
  VRANGEPDZ256rrikz = 18179,
  VRANGEPDZrmbi = 18180,
  VRANGEPDZrmbik = 18181,
  VRANGEPDZrmbikz = 18182,
  VRANGEPDZrmi = 18183,
  VRANGEPDZrmik = 18184,
  VRANGEPDZrmikz = 18185,
  VRANGEPDZrri = 18186,
  VRANGEPDZrrib = 18187,
  VRANGEPDZrribk = 18188,
  VRANGEPDZrribkz = 18189,
  VRANGEPDZrrik = 18190,
  VRANGEPDZrrikz = 18191,
  VRANGEPSZ128rmbi = 18192,
  VRANGEPSZ128rmbik = 18193,
  VRANGEPSZ128rmbikz = 18194,
  VRANGEPSZ128rmi = 18195,
  VRANGEPSZ128rmik = 18196,
  VRANGEPSZ128rmikz = 18197,
  VRANGEPSZ128rri = 18198,
  VRANGEPSZ128rrik = 18199,
  VRANGEPSZ128rrikz = 18200,
  VRANGEPSZ256rmbi = 18201,
  VRANGEPSZ256rmbik = 18202,
  VRANGEPSZ256rmbikz = 18203,
  VRANGEPSZ256rmi = 18204,
  VRANGEPSZ256rmik = 18205,
  VRANGEPSZ256rmikz = 18206,
  VRANGEPSZ256rri = 18207,
  VRANGEPSZ256rrik = 18208,
  VRANGEPSZ256rrikz = 18209,
  VRANGEPSZrmbi = 18210,
  VRANGEPSZrmbik = 18211,
  VRANGEPSZrmbikz = 18212,
  VRANGEPSZrmi = 18213,
  VRANGEPSZrmik = 18214,
  VRANGEPSZrmikz = 18215,
  VRANGEPSZrri = 18216,
  VRANGEPSZrrib = 18217,
  VRANGEPSZrribk = 18218,
  VRANGEPSZrribkz = 18219,
  VRANGEPSZrrik = 18220,
  VRANGEPSZrrikz = 18221,
  VRANGESDZrmi = 18222,
  VRANGESDZrmik = 18223,
  VRANGESDZrmikz = 18224,
  VRANGESDZrri = 18225,
  VRANGESDZrrib = 18226,
  VRANGESDZrribk = 18227,
  VRANGESDZrribkz = 18228,
  VRANGESDZrrik = 18229,
  VRANGESDZrrikz = 18230,
  VRANGESSZrmi = 18231,
  VRANGESSZrmik = 18232,
  VRANGESSZrmikz = 18233,
  VRANGESSZrri = 18234,
  VRANGESSZrrib = 18235,
  VRANGESSZrribk = 18236,
  VRANGESSZrribkz = 18237,
  VRANGESSZrrik = 18238,
  VRANGESSZrrikz = 18239,
  VRCP14PDZ128m = 18240,
  VRCP14PDZ128mb = 18241,
  VRCP14PDZ128mbk = 18242,
  VRCP14PDZ128mbkz = 18243,
  VRCP14PDZ128mk = 18244,
  VRCP14PDZ128mkz = 18245,
  VRCP14PDZ128r = 18246,
  VRCP14PDZ128rk = 18247,
  VRCP14PDZ128rkz = 18248,
  VRCP14PDZ256m = 18249,
  VRCP14PDZ256mb = 18250,
  VRCP14PDZ256mbk = 18251,
  VRCP14PDZ256mbkz = 18252,
  VRCP14PDZ256mk = 18253,
  VRCP14PDZ256mkz = 18254,
  VRCP14PDZ256r = 18255,
  VRCP14PDZ256rk = 18256,
  VRCP14PDZ256rkz = 18257,
  VRCP14PDZm = 18258,
  VRCP14PDZmb = 18259,
  VRCP14PDZmbk = 18260,
  VRCP14PDZmbkz = 18261,
  VRCP14PDZmk = 18262,
  VRCP14PDZmkz = 18263,
  VRCP14PDZr = 18264,
  VRCP14PDZrk = 18265,
  VRCP14PDZrkz = 18266,
  VRCP14PSZ128m = 18267,
  VRCP14PSZ128mb = 18268,
  VRCP14PSZ128mbk = 18269,
  VRCP14PSZ128mbkz = 18270,
  VRCP14PSZ128mk = 18271,
  VRCP14PSZ128mkz = 18272,
  VRCP14PSZ128r = 18273,
  VRCP14PSZ128rk = 18274,
  VRCP14PSZ128rkz = 18275,
  VRCP14PSZ256m = 18276,
  VRCP14PSZ256mb = 18277,
  VRCP14PSZ256mbk = 18278,
  VRCP14PSZ256mbkz = 18279,
  VRCP14PSZ256mk = 18280,
  VRCP14PSZ256mkz = 18281,
  VRCP14PSZ256r = 18282,
  VRCP14PSZ256rk = 18283,
  VRCP14PSZ256rkz = 18284,
  VRCP14PSZm = 18285,
  VRCP14PSZmb = 18286,
  VRCP14PSZmbk = 18287,
  VRCP14PSZmbkz = 18288,
  VRCP14PSZmk = 18289,
  VRCP14PSZmkz = 18290,
  VRCP14PSZr = 18291,
  VRCP14PSZrk = 18292,
  VRCP14PSZrkz = 18293,
  VRCP14SDZrm = 18294,
  VRCP14SDZrmk = 18295,
  VRCP14SDZrmkz = 18296,
  VRCP14SDZrr = 18297,
  VRCP14SDZrrk = 18298,
  VRCP14SDZrrkz = 18299,
  VRCP14SSZrm = 18300,
  VRCP14SSZrmk = 18301,
  VRCP14SSZrmkz = 18302,
  VRCP14SSZrr = 18303,
  VRCP14SSZrrk = 18304,
  VRCP14SSZrrkz = 18305,
  VRCP28PDZm = 18306,
  VRCP28PDZmb = 18307,
  VRCP28PDZmbk = 18308,
  VRCP28PDZmbkz = 18309,
  VRCP28PDZmk = 18310,
  VRCP28PDZmkz = 18311,
  VRCP28PDZr = 18312,
  VRCP28PDZrb = 18313,
  VRCP28PDZrbk = 18314,
  VRCP28PDZrbkz = 18315,
  VRCP28PDZrk = 18316,
  VRCP28PDZrkz = 18317,
  VRCP28PSZm = 18318,
  VRCP28PSZmb = 18319,
  VRCP28PSZmbk = 18320,
  VRCP28PSZmbkz = 18321,
  VRCP28PSZmk = 18322,
  VRCP28PSZmkz = 18323,
  VRCP28PSZr = 18324,
  VRCP28PSZrb = 18325,
  VRCP28PSZrbk = 18326,
  VRCP28PSZrbkz = 18327,
  VRCP28PSZrk = 18328,
  VRCP28PSZrkz = 18329,
  VRCP28SDZm = 18330,
  VRCP28SDZmk = 18331,
  VRCP28SDZmkz = 18332,
  VRCP28SDZr = 18333,
  VRCP28SDZrb = 18334,
  VRCP28SDZrbk = 18335,
  VRCP28SDZrbkz = 18336,
  VRCP28SDZrk = 18337,
  VRCP28SDZrkz = 18338,
  VRCP28SSZm = 18339,
  VRCP28SSZmk = 18340,
  VRCP28SSZmkz = 18341,
  VRCP28SSZr = 18342,
  VRCP28SSZrb = 18343,
  VRCP28SSZrbk = 18344,
  VRCP28SSZrbkz = 18345,
  VRCP28SSZrk = 18346,
  VRCP28SSZrkz = 18347,
  VRCPPHZ128m = 18348,
  VRCPPHZ128mb = 18349,
  VRCPPHZ128mbk = 18350,
  VRCPPHZ128mbkz = 18351,
  VRCPPHZ128mk = 18352,
  VRCPPHZ128mkz = 18353,
  VRCPPHZ128r = 18354,
  VRCPPHZ128rk = 18355,
  VRCPPHZ128rkz = 18356,
  VRCPPHZ256m = 18357,
  VRCPPHZ256mb = 18358,
  VRCPPHZ256mbk = 18359,
  VRCPPHZ256mbkz = 18360,
  VRCPPHZ256mk = 18361,
  VRCPPHZ256mkz = 18362,
  VRCPPHZ256r = 18363,
  VRCPPHZ256rk = 18364,
  VRCPPHZ256rkz = 18365,
  VRCPPHZm = 18366,
  VRCPPHZmb = 18367,
  VRCPPHZmbk = 18368,
  VRCPPHZmbkz = 18369,
  VRCPPHZmk = 18370,
  VRCPPHZmkz = 18371,
  VRCPPHZr = 18372,
  VRCPPHZrk = 18373,
  VRCPPHZrkz = 18374,
  VRCPPSYm = 18375,
  VRCPPSYr = 18376,
  VRCPPSm = 18377,
  VRCPPSr = 18378,
  VRCPSHZrm = 18379,
  VRCPSHZrmk = 18380,
  VRCPSHZrmkz = 18381,
  VRCPSHZrr = 18382,
  VRCPSHZrrk = 18383,
  VRCPSHZrrkz = 18384,
  VRCPSSm = 18385,
  VRCPSSm_Int = 18386,
  VRCPSSr = 18387,
  VRCPSSr_Int = 18388,
  VREDUCEPDZ128rmbi = 18389,
  VREDUCEPDZ128rmbik = 18390,
  VREDUCEPDZ128rmbikz = 18391,
  VREDUCEPDZ128rmi = 18392,
  VREDUCEPDZ128rmik = 18393,
  VREDUCEPDZ128rmikz = 18394,
  VREDUCEPDZ128rri = 18395,
  VREDUCEPDZ128rrik = 18396,
  VREDUCEPDZ128rrikz = 18397,
  VREDUCEPDZ256rmbi = 18398,
  VREDUCEPDZ256rmbik = 18399,
  VREDUCEPDZ256rmbikz = 18400,
  VREDUCEPDZ256rmi = 18401,
  VREDUCEPDZ256rmik = 18402,
  VREDUCEPDZ256rmikz = 18403,
  VREDUCEPDZ256rri = 18404,
  VREDUCEPDZ256rrik = 18405,
  VREDUCEPDZ256rrikz = 18406,
  VREDUCEPDZrmbi = 18407,
  VREDUCEPDZrmbik = 18408,
  VREDUCEPDZrmbikz = 18409,
  VREDUCEPDZrmi = 18410,
  VREDUCEPDZrmik = 18411,
  VREDUCEPDZrmikz = 18412,
  VREDUCEPDZrri = 18413,
  VREDUCEPDZrrib = 18414,
  VREDUCEPDZrribk = 18415,
  VREDUCEPDZrribkz = 18416,
  VREDUCEPDZrrik = 18417,
  VREDUCEPDZrrikz = 18418,
  VREDUCEPHZ128rmbi = 18419,
  VREDUCEPHZ128rmbik = 18420,
  VREDUCEPHZ128rmbikz = 18421,
  VREDUCEPHZ128rmi = 18422,
  VREDUCEPHZ128rmik = 18423,
  VREDUCEPHZ128rmikz = 18424,
  VREDUCEPHZ128rri = 18425,
  VREDUCEPHZ128rrik = 18426,
  VREDUCEPHZ128rrikz = 18427,
  VREDUCEPHZ256rmbi = 18428,
  VREDUCEPHZ256rmbik = 18429,
  VREDUCEPHZ256rmbikz = 18430,
  VREDUCEPHZ256rmi = 18431,
  VREDUCEPHZ256rmik = 18432,
  VREDUCEPHZ256rmikz = 18433,
  VREDUCEPHZ256rri = 18434,
  VREDUCEPHZ256rrik = 18435,
  VREDUCEPHZ256rrikz = 18436,
  VREDUCEPHZrmbi = 18437,
  VREDUCEPHZrmbik = 18438,
  VREDUCEPHZrmbikz = 18439,
  VREDUCEPHZrmi = 18440,
  VREDUCEPHZrmik = 18441,
  VREDUCEPHZrmikz = 18442,
  VREDUCEPHZrri = 18443,
  VREDUCEPHZrrib = 18444,
  VREDUCEPHZrribk = 18445,
  VREDUCEPHZrribkz = 18446,
  VREDUCEPHZrrik = 18447,
  VREDUCEPHZrrikz = 18448,
  VREDUCEPSZ128rmbi = 18449,
  VREDUCEPSZ128rmbik = 18450,
  VREDUCEPSZ128rmbikz = 18451,
  VREDUCEPSZ128rmi = 18452,
  VREDUCEPSZ128rmik = 18453,
  VREDUCEPSZ128rmikz = 18454,
  VREDUCEPSZ128rri = 18455,
  VREDUCEPSZ128rrik = 18456,
  VREDUCEPSZ128rrikz = 18457,
  VREDUCEPSZ256rmbi = 18458,
  VREDUCEPSZ256rmbik = 18459,
  VREDUCEPSZ256rmbikz = 18460,
  VREDUCEPSZ256rmi = 18461,
  VREDUCEPSZ256rmik = 18462,
  VREDUCEPSZ256rmikz = 18463,
  VREDUCEPSZ256rri = 18464,
  VREDUCEPSZ256rrik = 18465,
  VREDUCEPSZ256rrikz = 18466,
  VREDUCEPSZrmbi = 18467,
  VREDUCEPSZrmbik = 18468,
  VREDUCEPSZrmbikz = 18469,
  VREDUCEPSZrmi = 18470,
  VREDUCEPSZrmik = 18471,
  VREDUCEPSZrmikz = 18472,
  VREDUCEPSZrri = 18473,
  VREDUCEPSZrrib = 18474,
  VREDUCEPSZrribk = 18475,
  VREDUCEPSZrribkz = 18476,
  VREDUCEPSZrrik = 18477,
  VREDUCEPSZrrikz = 18478,
  VREDUCESDZrmi = 18479,
  VREDUCESDZrmik = 18480,
  VREDUCESDZrmikz = 18481,
  VREDUCESDZrri = 18482,
  VREDUCESDZrrib = 18483,
  VREDUCESDZrribk = 18484,
  VREDUCESDZrribkz = 18485,
  VREDUCESDZrrik = 18486,
  VREDUCESDZrrikz = 18487,
  VREDUCESHZrmi = 18488,
  VREDUCESHZrmik = 18489,
  VREDUCESHZrmikz = 18490,
  VREDUCESHZrri = 18491,
  VREDUCESHZrrib = 18492,
  VREDUCESHZrribk = 18493,
  VREDUCESHZrribkz = 18494,
  VREDUCESHZrrik = 18495,
  VREDUCESHZrrikz = 18496,
  VREDUCESSZrmi = 18497,
  VREDUCESSZrmik = 18498,
  VREDUCESSZrmikz = 18499,
  VREDUCESSZrri = 18500,
  VREDUCESSZrrib = 18501,
  VREDUCESSZrribk = 18502,
  VREDUCESSZrribkz = 18503,
  VREDUCESSZrrik = 18504,
  VREDUCESSZrrikz = 18505,
  VRNDSCALEPDZ128rmbi = 18506,
  VRNDSCALEPDZ128rmbik = 18507,
  VRNDSCALEPDZ128rmbikz = 18508,
  VRNDSCALEPDZ128rmi = 18509,
  VRNDSCALEPDZ128rmik = 18510,
  VRNDSCALEPDZ128rmikz = 18511,
  VRNDSCALEPDZ128rri = 18512,
  VRNDSCALEPDZ128rrik = 18513,
  VRNDSCALEPDZ128rrikz = 18514,
  VRNDSCALEPDZ256rmbi = 18515,
  VRNDSCALEPDZ256rmbik = 18516,
  VRNDSCALEPDZ256rmbikz = 18517,
  VRNDSCALEPDZ256rmi = 18518,
  VRNDSCALEPDZ256rmik = 18519,
  VRNDSCALEPDZ256rmikz = 18520,
  VRNDSCALEPDZ256rri = 18521,
  VRNDSCALEPDZ256rrik = 18522,
  VRNDSCALEPDZ256rrikz = 18523,
  VRNDSCALEPDZrmbi = 18524,
  VRNDSCALEPDZrmbik = 18525,
  VRNDSCALEPDZrmbikz = 18526,
  VRNDSCALEPDZrmi = 18527,
  VRNDSCALEPDZrmik = 18528,
  VRNDSCALEPDZrmikz = 18529,
  VRNDSCALEPDZrri = 18530,
  VRNDSCALEPDZrrib = 18531,
  VRNDSCALEPDZrribk = 18532,
  VRNDSCALEPDZrribkz = 18533,
  VRNDSCALEPDZrrik = 18534,
  VRNDSCALEPDZrrikz = 18535,
  VRNDSCALEPHZ128rmbi = 18536,
  VRNDSCALEPHZ128rmbik = 18537,
  VRNDSCALEPHZ128rmbikz = 18538,
  VRNDSCALEPHZ128rmi = 18539,
  VRNDSCALEPHZ128rmik = 18540,
  VRNDSCALEPHZ128rmikz = 18541,
  VRNDSCALEPHZ128rri = 18542,
  VRNDSCALEPHZ128rrik = 18543,
  VRNDSCALEPHZ128rrikz = 18544,
  VRNDSCALEPHZ256rmbi = 18545,
  VRNDSCALEPHZ256rmbik = 18546,
  VRNDSCALEPHZ256rmbikz = 18547,
  VRNDSCALEPHZ256rmi = 18548,
  VRNDSCALEPHZ256rmik = 18549,
  VRNDSCALEPHZ256rmikz = 18550,
  VRNDSCALEPHZ256rri = 18551,
  VRNDSCALEPHZ256rrik = 18552,
  VRNDSCALEPHZ256rrikz = 18553,
  VRNDSCALEPHZrmbi = 18554,
  VRNDSCALEPHZrmbik = 18555,
  VRNDSCALEPHZrmbikz = 18556,
  VRNDSCALEPHZrmi = 18557,
  VRNDSCALEPHZrmik = 18558,
  VRNDSCALEPHZrmikz = 18559,
  VRNDSCALEPHZrri = 18560,
  VRNDSCALEPHZrrib = 18561,
  VRNDSCALEPHZrribk = 18562,
  VRNDSCALEPHZrribkz = 18563,
  VRNDSCALEPHZrrik = 18564,
  VRNDSCALEPHZrrikz = 18565,
  VRNDSCALEPSZ128rmbi = 18566,
  VRNDSCALEPSZ128rmbik = 18567,
  VRNDSCALEPSZ128rmbikz = 18568,
  VRNDSCALEPSZ128rmi = 18569,
  VRNDSCALEPSZ128rmik = 18570,
  VRNDSCALEPSZ128rmikz = 18571,
  VRNDSCALEPSZ128rri = 18572,
  VRNDSCALEPSZ128rrik = 18573,
  VRNDSCALEPSZ128rrikz = 18574,
  VRNDSCALEPSZ256rmbi = 18575,
  VRNDSCALEPSZ256rmbik = 18576,
  VRNDSCALEPSZ256rmbikz = 18577,
  VRNDSCALEPSZ256rmi = 18578,
  VRNDSCALEPSZ256rmik = 18579,
  VRNDSCALEPSZ256rmikz = 18580,
  VRNDSCALEPSZ256rri = 18581,
  VRNDSCALEPSZ256rrik = 18582,
  VRNDSCALEPSZ256rrikz = 18583,
  VRNDSCALEPSZrmbi = 18584,
  VRNDSCALEPSZrmbik = 18585,
  VRNDSCALEPSZrmbikz = 18586,
  VRNDSCALEPSZrmi = 18587,
  VRNDSCALEPSZrmik = 18588,
  VRNDSCALEPSZrmikz = 18589,
  VRNDSCALEPSZrri = 18590,
  VRNDSCALEPSZrrib = 18591,
  VRNDSCALEPSZrribk = 18592,
  VRNDSCALEPSZrribkz = 18593,
  VRNDSCALEPSZrrik = 18594,
  VRNDSCALEPSZrrikz = 18595,
  VRNDSCALESDZm = 18596,
  VRNDSCALESDZm_Int = 18597,
  VRNDSCALESDZm_Intk = 18598,
  VRNDSCALESDZm_Intkz = 18599,
  VRNDSCALESDZr = 18600,
  VRNDSCALESDZr_Int = 18601,
  VRNDSCALESDZr_Intk = 18602,
  VRNDSCALESDZr_Intkz = 18603,
  VRNDSCALESDZrb_Int = 18604,
  VRNDSCALESDZrb_Intk = 18605,
  VRNDSCALESDZrb_Intkz = 18606,
  VRNDSCALESHZm = 18607,
  VRNDSCALESHZm_Int = 18608,
  VRNDSCALESHZm_Intk = 18609,
  VRNDSCALESHZm_Intkz = 18610,
  VRNDSCALESHZr = 18611,
  VRNDSCALESHZr_Int = 18612,
  VRNDSCALESHZr_Intk = 18613,
  VRNDSCALESHZr_Intkz = 18614,
  VRNDSCALESHZrb_Int = 18615,
  VRNDSCALESHZrb_Intk = 18616,
  VRNDSCALESHZrb_Intkz = 18617,
  VRNDSCALESSZm = 18618,
  VRNDSCALESSZm_Int = 18619,
  VRNDSCALESSZm_Intk = 18620,
  VRNDSCALESSZm_Intkz = 18621,
  VRNDSCALESSZr = 18622,
  VRNDSCALESSZr_Int = 18623,
  VRNDSCALESSZr_Intk = 18624,
  VRNDSCALESSZr_Intkz = 18625,
  VRNDSCALESSZrb_Int = 18626,
  VRNDSCALESSZrb_Intk = 18627,
  VRNDSCALESSZrb_Intkz = 18628,
  VROUNDPDYmi = 18629,
  VROUNDPDYri = 18630,
  VROUNDPDmi = 18631,
  VROUNDPDri = 18632,
  VROUNDPSYmi = 18633,
  VROUNDPSYri = 18634,
  VROUNDPSmi = 18635,
  VROUNDPSri = 18636,
  VROUNDSDmi = 18637,
  VROUNDSDmi_Int = 18638,
  VROUNDSDri = 18639,
  VROUNDSDri_Int = 18640,
  VROUNDSSmi = 18641,
  VROUNDSSmi_Int = 18642,
  VROUNDSSri = 18643,
  VROUNDSSri_Int = 18644,
  VRSQRT14PDZ128m = 18645,
  VRSQRT14PDZ128mb = 18646,
  VRSQRT14PDZ128mbk = 18647,
  VRSQRT14PDZ128mbkz = 18648,
  VRSQRT14PDZ128mk = 18649,
  VRSQRT14PDZ128mkz = 18650,
  VRSQRT14PDZ128r = 18651,
  VRSQRT14PDZ128rk = 18652,
  VRSQRT14PDZ128rkz = 18653,
  VRSQRT14PDZ256m = 18654,
  VRSQRT14PDZ256mb = 18655,
  VRSQRT14PDZ256mbk = 18656,
  VRSQRT14PDZ256mbkz = 18657,
  VRSQRT14PDZ256mk = 18658,
  VRSQRT14PDZ256mkz = 18659,
  VRSQRT14PDZ256r = 18660,
  VRSQRT14PDZ256rk = 18661,
  VRSQRT14PDZ256rkz = 18662,
  VRSQRT14PDZm = 18663,
  VRSQRT14PDZmb = 18664,
  VRSQRT14PDZmbk = 18665,
  VRSQRT14PDZmbkz = 18666,
  VRSQRT14PDZmk = 18667,
  VRSQRT14PDZmkz = 18668,
  VRSQRT14PDZr = 18669,
  VRSQRT14PDZrk = 18670,
  VRSQRT14PDZrkz = 18671,
  VRSQRT14PSZ128m = 18672,
  VRSQRT14PSZ128mb = 18673,
  VRSQRT14PSZ128mbk = 18674,
  VRSQRT14PSZ128mbkz = 18675,
  VRSQRT14PSZ128mk = 18676,
  VRSQRT14PSZ128mkz = 18677,
  VRSQRT14PSZ128r = 18678,
  VRSQRT14PSZ128rk = 18679,
  VRSQRT14PSZ128rkz = 18680,
  VRSQRT14PSZ256m = 18681,
  VRSQRT14PSZ256mb = 18682,
  VRSQRT14PSZ256mbk = 18683,
  VRSQRT14PSZ256mbkz = 18684,
  VRSQRT14PSZ256mk = 18685,
  VRSQRT14PSZ256mkz = 18686,
  VRSQRT14PSZ256r = 18687,
  VRSQRT14PSZ256rk = 18688,
  VRSQRT14PSZ256rkz = 18689,
  VRSQRT14PSZm = 18690,
  VRSQRT14PSZmb = 18691,
  VRSQRT14PSZmbk = 18692,
  VRSQRT14PSZmbkz = 18693,
  VRSQRT14PSZmk = 18694,
  VRSQRT14PSZmkz = 18695,
  VRSQRT14PSZr = 18696,
  VRSQRT14PSZrk = 18697,
  VRSQRT14PSZrkz = 18698,
  VRSQRT14SDZrm = 18699,
  VRSQRT14SDZrmk = 18700,
  VRSQRT14SDZrmkz = 18701,
  VRSQRT14SDZrr = 18702,
  VRSQRT14SDZrrk = 18703,
  VRSQRT14SDZrrkz = 18704,
  VRSQRT14SSZrm = 18705,
  VRSQRT14SSZrmk = 18706,
  VRSQRT14SSZrmkz = 18707,
  VRSQRT14SSZrr = 18708,
  VRSQRT14SSZrrk = 18709,
  VRSQRT14SSZrrkz = 18710,
  VRSQRT28PDZm = 18711,
  VRSQRT28PDZmb = 18712,
  VRSQRT28PDZmbk = 18713,
  VRSQRT28PDZmbkz = 18714,
  VRSQRT28PDZmk = 18715,
  VRSQRT28PDZmkz = 18716,
  VRSQRT28PDZr = 18717,
  VRSQRT28PDZrb = 18718,
  VRSQRT28PDZrbk = 18719,
  VRSQRT28PDZrbkz = 18720,
  VRSQRT28PDZrk = 18721,
  VRSQRT28PDZrkz = 18722,
  VRSQRT28PSZm = 18723,
  VRSQRT28PSZmb = 18724,
  VRSQRT28PSZmbk = 18725,
  VRSQRT28PSZmbkz = 18726,
  VRSQRT28PSZmk = 18727,
  VRSQRT28PSZmkz = 18728,
  VRSQRT28PSZr = 18729,
  VRSQRT28PSZrb = 18730,
  VRSQRT28PSZrbk = 18731,
  VRSQRT28PSZrbkz = 18732,
  VRSQRT28PSZrk = 18733,
  VRSQRT28PSZrkz = 18734,
  VRSQRT28SDZm = 18735,
  VRSQRT28SDZmk = 18736,
  VRSQRT28SDZmkz = 18737,
  VRSQRT28SDZr = 18738,
  VRSQRT28SDZrb = 18739,
  VRSQRT28SDZrbk = 18740,
  VRSQRT28SDZrbkz = 18741,
  VRSQRT28SDZrk = 18742,
  VRSQRT28SDZrkz = 18743,
  VRSQRT28SSZm = 18744,
  VRSQRT28SSZmk = 18745,
  VRSQRT28SSZmkz = 18746,
  VRSQRT28SSZr = 18747,
  VRSQRT28SSZrb = 18748,
  VRSQRT28SSZrbk = 18749,
  VRSQRT28SSZrbkz = 18750,
  VRSQRT28SSZrk = 18751,
  VRSQRT28SSZrkz = 18752,
  VRSQRTPHZ128m = 18753,
  VRSQRTPHZ128mb = 18754,
  VRSQRTPHZ128mbk = 18755,
  VRSQRTPHZ128mbkz = 18756,
  VRSQRTPHZ128mk = 18757,
  VRSQRTPHZ128mkz = 18758,
  VRSQRTPHZ128r = 18759,
  VRSQRTPHZ128rk = 18760,
  VRSQRTPHZ128rkz = 18761,
  VRSQRTPHZ256m = 18762,
  VRSQRTPHZ256mb = 18763,
  VRSQRTPHZ256mbk = 18764,
  VRSQRTPHZ256mbkz = 18765,
  VRSQRTPHZ256mk = 18766,
  VRSQRTPHZ256mkz = 18767,
  VRSQRTPHZ256r = 18768,
  VRSQRTPHZ256rk = 18769,
  VRSQRTPHZ256rkz = 18770,
  VRSQRTPHZm = 18771,
  VRSQRTPHZmb = 18772,
  VRSQRTPHZmbk = 18773,
  VRSQRTPHZmbkz = 18774,
  VRSQRTPHZmk = 18775,
  VRSQRTPHZmkz = 18776,
  VRSQRTPHZr = 18777,
  VRSQRTPHZrk = 18778,
  VRSQRTPHZrkz = 18779,
  VRSQRTPSYm = 18780,
  VRSQRTPSYr = 18781,
  VRSQRTPSm = 18782,
  VRSQRTPSr = 18783,
  VRSQRTSHZrm = 18784,
  VRSQRTSHZrmk = 18785,
  VRSQRTSHZrmkz = 18786,
  VRSQRTSHZrr = 18787,
  VRSQRTSHZrrk = 18788,
  VRSQRTSHZrrkz = 18789,
  VRSQRTSSm = 18790,
  VRSQRTSSm_Int = 18791,
  VRSQRTSSr = 18792,
  VRSQRTSSr_Int = 18793,
  VSCALEFPDZ128rm = 18794,
  VSCALEFPDZ128rmb = 18795,
  VSCALEFPDZ128rmbk = 18796,
  VSCALEFPDZ128rmbkz = 18797,
  VSCALEFPDZ128rmk = 18798,
  VSCALEFPDZ128rmkz = 18799,
  VSCALEFPDZ128rr = 18800,
  VSCALEFPDZ128rrk = 18801,
  VSCALEFPDZ128rrkz = 18802,
  VSCALEFPDZ256rm = 18803,
  VSCALEFPDZ256rmb = 18804,
  VSCALEFPDZ256rmbk = 18805,
  VSCALEFPDZ256rmbkz = 18806,
  VSCALEFPDZ256rmk = 18807,
  VSCALEFPDZ256rmkz = 18808,
  VSCALEFPDZ256rr = 18809,
  VSCALEFPDZ256rrk = 18810,
  VSCALEFPDZ256rrkz = 18811,
  VSCALEFPDZrm = 18812,
  VSCALEFPDZrmb = 18813,
  VSCALEFPDZrmbk = 18814,
  VSCALEFPDZrmbkz = 18815,
  VSCALEFPDZrmk = 18816,
  VSCALEFPDZrmkz = 18817,
  VSCALEFPDZrr = 18818,
  VSCALEFPDZrrb = 18819,
  VSCALEFPDZrrbk = 18820,
  VSCALEFPDZrrbkz = 18821,
  VSCALEFPDZrrk = 18822,
  VSCALEFPDZrrkz = 18823,
  VSCALEFPHZ128rm = 18824,
  VSCALEFPHZ128rmb = 18825,
  VSCALEFPHZ128rmbk = 18826,
  VSCALEFPHZ128rmbkz = 18827,
  VSCALEFPHZ128rmk = 18828,
  VSCALEFPHZ128rmkz = 18829,
  VSCALEFPHZ128rr = 18830,
  VSCALEFPHZ128rrk = 18831,
  VSCALEFPHZ128rrkz = 18832,
  VSCALEFPHZ256rm = 18833,
  VSCALEFPHZ256rmb = 18834,
  VSCALEFPHZ256rmbk = 18835,
  VSCALEFPHZ256rmbkz = 18836,
  VSCALEFPHZ256rmk = 18837,
  VSCALEFPHZ256rmkz = 18838,
  VSCALEFPHZ256rr = 18839,
  VSCALEFPHZ256rrk = 18840,
  VSCALEFPHZ256rrkz = 18841,
  VSCALEFPHZrm = 18842,
  VSCALEFPHZrmb = 18843,
  VSCALEFPHZrmbk = 18844,
  VSCALEFPHZrmbkz = 18845,
  VSCALEFPHZrmk = 18846,
  VSCALEFPHZrmkz = 18847,
  VSCALEFPHZrr = 18848,
  VSCALEFPHZrrb = 18849,
  VSCALEFPHZrrbk = 18850,
  VSCALEFPHZrrbkz = 18851,
  VSCALEFPHZrrk = 18852,
  VSCALEFPHZrrkz = 18853,
  VSCALEFPSZ128rm = 18854,
  VSCALEFPSZ128rmb = 18855,
  VSCALEFPSZ128rmbk = 18856,
  VSCALEFPSZ128rmbkz = 18857,
  VSCALEFPSZ128rmk = 18858,
  VSCALEFPSZ128rmkz = 18859,
  VSCALEFPSZ128rr = 18860,
  VSCALEFPSZ128rrk = 18861,
  VSCALEFPSZ128rrkz = 18862,
  VSCALEFPSZ256rm = 18863,
  VSCALEFPSZ256rmb = 18864,
  VSCALEFPSZ256rmbk = 18865,
  VSCALEFPSZ256rmbkz = 18866,
  VSCALEFPSZ256rmk = 18867,
  VSCALEFPSZ256rmkz = 18868,
  VSCALEFPSZ256rr = 18869,
  VSCALEFPSZ256rrk = 18870,
  VSCALEFPSZ256rrkz = 18871,
  VSCALEFPSZrm = 18872,
  VSCALEFPSZrmb = 18873,
  VSCALEFPSZrmbk = 18874,
  VSCALEFPSZrmbkz = 18875,
  VSCALEFPSZrmk = 18876,
  VSCALEFPSZrmkz = 18877,
  VSCALEFPSZrr = 18878,
  VSCALEFPSZrrb = 18879,
  VSCALEFPSZrrbk = 18880,
  VSCALEFPSZrrbkz = 18881,
  VSCALEFPSZrrk = 18882,
  VSCALEFPSZrrkz = 18883,
  VSCALEFSDZrm = 18884,
  VSCALEFSDZrmk = 18885,
  VSCALEFSDZrmkz = 18886,
  VSCALEFSDZrr = 18887,
  VSCALEFSDZrrb_Int = 18888,
  VSCALEFSDZrrb_Intk = 18889,
  VSCALEFSDZrrb_Intkz = 18890,
  VSCALEFSDZrrk = 18891,
  VSCALEFSDZrrkz = 18892,
  VSCALEFSHZrm = 18893,
  VSCALEFSHZrmk = 18894,
  VSCALEFSHZrmkz = 18895,
  VSCALEFSHZrr = 18896,
  VSCALEFSHZrrb_Int = 18897,
  VSCALEFSHZrrb_Intk = 18898,
  VSCALEFSHZrrb_Intkz = 18899,
  VSCALEFSHZrrk = 18900,
  VSCALEFSHZrrkz = 18901,
  VSCALEFSSZrm = 18902,
  VSCALEFSSZrmk = 18903,
  VSCALEFSSZrmkz = 18904,
  VSCALEFSSZrr = 18905,
  VSCALEFSSZrrb_Int = 18906,
  VSCALEFSSZrrb_Intk = 18907,
  VSCALEFSSZrrb_Intkz = 18908,
  VSCALEFSSZrrk = 18909,
  VSCALEFSSZrrkz = 18910,
  VSCATTERDPDZ128mr = 18911,
  VSCATTERDPDZ256mr = 18912,
  VSCATTERDPDZmr = 18913,
  VSCATTERDPSZ128mr = 18914,
  VSCATTERDPSZ256mr = 18915,
  VSCATTERDPSZmr = 18916,
  VSCATTERPF0DPDm = 18917,
  VSCATTERPF0DPSm = 18918,
  VSCATTERPF0QPDm = 18919,
  VSCATTERPF0QPSm = 18920,
  VSCATTERPF1DPDm = 18921,
  VSCATTERPF1DPSm = 18922,
  VSCATTERPF1QPDm = 18923,
  VSCATTERPF1QPSm = 18924,
  VSCATTERQPDZ128mr = 18925,
  VSCATTERQPDZ256mr = 18926,
  VSCATTERQPDZmr = 18927,
  VSCATTERQPSZ128mr = 18928,
  VSCATTERQPSZ256mr = 18929,
  VSCATTERQPSZmr = 18930,
  VSHA512MSG1rr = 18931,
  VSHA512MSG2rr = 18932,
  VSHA512RNDS2rr = 18933,
  VSHUFF32X4Z256rmbi = 18934,
  VSHUFF32X4Z256rmbik = 18935,
  VSHUFF32X4Z256rmbikz = 18936,
  VSHUFF32X4Z256rmi = 18937,
  VSHUFF32X4Z256rmik = 18938,
  VSHUFF32X4Z256rmikz = 18939,
  VSHUFF32X4Z256rri = 18940,
  VSHUFF32X4Z256rrik = 18941,
  VSHUFF32X4Z256rrikz = 18942,
  VSHUFF32X4Zrmbi = 18943,
  VSHUFF32X4Zrmbik = 18944,
  VSHUFF32X4Zrmbikz = 18945,
  VSHUFF32X4Zrmi = 18946,
  VSHUFF32X4Zrmik = 18947,
  VSHUFF32X4Zrmikz = 18948,
  VSHUFF32X4Zrri = 18949,
  VSHUFF32X4Zrrik = 18950,
  VSHUFF32X4Zrrikz = 18951,
  VSHUFF64X2Z256rmbi = 18952,
  VSHUFF64X2Z256rmbik = 18953,
  VSHUFF64X2Z256rmbikz = 18954,
  VSHUFF64X2Z256rmi = 18955,
  VSHUFF64X2Z256rmik = 18956,
  VSHUFF64X2Z256rmikz = 18957,
  VSHUFF64X2Z256rri = 18958,
  VSHUFF64X2Z256rrik = 18959,
  VSHUFF64X2Z256rrikz = 18960,
  VSHUFF64X2Zrmbi = 18961,
  VSHUFF64X2Zrmbik = 18962,
  VSHUFF64X2Zrmbikz = 18963,
  VSHUFF64X2Zrmi = 18964,
  VSHUFF64X2Zrmik = 18965,
  VSHUFF64X2Zrmikz = 18966,
  VSHUFF64X2Zrri = 18967,
  VSHUFF64X2Zrrik = 18968,
  VSHUFF64X2Zrrikz = 18969,
  VSHUFI32X4Z256rmbi = 18970,
  VSHUFI32X4Z256rmbik = 18971,
  VSHUFI32X4Z256rmbikz = 18972,
  VSHUFI32X4Z256rmi = 18973,
  VSHUFI32X4Z256rmik = 18974,
  VSHUFI32X4Z256rmikz = 18975,
  VSHUFI32X4Z256rri = 18976,
  VSHUFI32X4Z256rrik = 18977,
  VSHUFI32X4Z256rrikz = 18978,
  VSHUFI32X4Zrmbi = 18979,
  VSHUFI32X4Zrmbik = 18980,
  VSHUFI32X4Zrmbikz = 18981,
  VSHUFI32X4Zrmi = 18982,
  VSHUFI32X4Zrmik = 18983,
  VSHUFI32X4Zrmikz = 18984,
  VSHUFI32X4Zrri = 18985,
  VSHUFI32X4Zrrik = 18986,
  VSHUFI32X4Zrrikz = 18987,
  VSHUFI64X2Z256rmbi = 18988,
  VSHUFI64X2Z256rmbik = 18989,
  VSHUFI64X2Z256rmbikz = 18990,
  VSHUFI64X2Z256rmi = 18991,
  VSHUFI64X2Z256rmik = 18992,
  VSHUFI64X2Z256rmikz = 18993,
  VSHUFI64X2Z256rri = 18994,
  VSHUFI64X2Z256rrik = 18995,
  VSHUFI64X2Z256rrikz = 18996,
  VSHUFI64X2Zrmbi = 18997,
  VSHUFI64X2Zrmbik = 18998,
  VSHUFI64X2Zrmbikz = 18999,
  VSHUFI64X2Zrmi = 19000,
  VSHUFI64X2Zrmik = 19001,
  VSHUFI64X2Zrmikz = 19002,
  VSHUFI64X2Zrri = 19003,
  VSHUFI64X2Zrrik = 19004,
  VSHUFI64X2Zrrikz = 19005,
  VSHUFPDYrmi = 19006,
  VSHUFPDYrri = 19007,
  VSHUFPDZ128rmbi = 19008,
  VSHUFPDZ128rmbik = 19009,
  VSHUFPDZ128rmbikz = 19010,
  VSHUFPDZ128rmi = 19011,
  VSHUFPDZ128rmik = 19012,
  VSHUFPDZ128rmikz = 19013,
  VSHUFPDZ128rri = 19014,
  VSHUFPDZ128rrik = 19015,
  VSHUFPDZ128rrikz = 19016,
  VSHUFPDZ256rmbi = 19017,
  VSHUFPDZ256rmbik = 19018,
  VSHUFPDZ256rmbikz = 19019,
  VSHUFPDZ256rmi = 19020,
  VSHUFPDZ256rmik = 19021,
  VSHUFPDZ256rmikz = 19022,
  VSHUFPDZ256rri = 19023,
  VSHUFPDZ256rrik = 19024,
  VSHUFPDZ256rrikz = 19025,
  VSHUFPDZrmbi = 19026,
  VSHUFPDZrmbik = 19027,
  VSHUFPDZrmbikz = 19028,
  VSHUFPDZrmi = 19029,
  VSHUFPDZrmik = 19030,
  VSHUFPDZrmikz = 19031,
  VSHUFPDZrri = 19032,
  VSHUFPDZrrik = 19033,
  VSHUFPDZrrikz = 19034,
  VSHUFPDrmi = 19035,
  VSHUFPDrri = 19036,
  VSHUFPSYrmi = 19037,
  VSHUFPSYrri = 19038,
  VSHUFPSZ128rmbi = 19039,
  VSHUFPSZ128rmbik = 19040,
  VSHUFPSZ128rmbikz = 19041,
  VSHUFPSZ128rmi = 19042,
  VSHUFPSZ128rmik = 19043,
  VSHUFPSZ128rmikz = 19044,
  VSHUFPSZ128rri = 19045,
  VSHUFPSZ128rrik = 19046,
  VSHUFPSZ128rrikz = 19047,
  VSHUFPSZ256rmbi = 19048,
  VSHUFPSZ256rmbik = 19049,
  VSHUFPSZ256rmbikz = 19050,
  VSHUFPSZ256rmi = 19051,
  VSHUFPSZ256rmik = 19052,
  VSHUFPSZ256rmikz = 19053,
  VSHUFPSZ256rri = 19054,
  VSHUFPSZ256rrik = 19055,
  VSHUFPSZ256rrikz = 19056,
  VSHUFPSZrmbi = 19057,
  VSHUFPSZrmbik = 19058,
  VSHUFPSZrmbikz = 19059,
  VSHUFPSZrmi = 19060,
  VSHUFPSZrmik = 19061,
  VSHUFPSZrmikz = 19062,
  VSHUFPSZrri = 19063,
  VSHUFPSZrrik = 19064,
  VSHUFPSZrrikz = 19065,
  VSHUFPSrmi = 19066,
  VSHUFPSrri = 19067,
  VSM3MSG1rm = 19068,
  VSM3MSG1rr = 19069,
  VSM3MSG2rm = 19070,
  VSM3MSG2rr = 19071,
  VSM3RNDS2rm = 19072,
  VSM3RNDS2rr = 19073,
  VSM4KEY4Yrm = 19074,
  VSM4KEY4Yrr = 19075,
  VSM4KEY4rm = 19076,
  VSM4KEY4rr = 19077,
  VSM4RNDS4Yrm = 19078,
  VSM4RNDS4Yrr = 19079,
  VSM4RNDS4rm = 19080,
  VSM4RNDS4rr = 19081,
  VSQRTPDYm = 19082,
  VSQRTPDYr = 19083,
  VSQRTPDZ128m = 19084,
  VSQRTPDZ128mb = 19085,
  VSQRTPDZ128mbk = 19086,
  VSQRTPDZ128mbkz = 19087,
  VSQRTPDZ128mk = 19088,
  VSQRTPDZ128mkz = 19089,
  VSQRTPDZ128r = 19090,
  VSQRTPDZ128rk = 19091,
  VSQRTPDZ128rkz = 19092,
  VSQRTPDZ256m = 19093,
  VSQRTPDZ256mb = 19094,
  VSQRTPDZ256mbk = 19095,
  VSQRTPDZ256mbkz = 19096,
  VSQRTPDZ256mk = 19097,
  VSQRTPDZ256mkz = 19098,
  VSQRTPDZ256r = 19099,
  VSQRTPDZ256rk = 19100,
  VSQRTPDZ256rkz = 19101,
  VSQRTPDZm = 19102,
  VSQRTPDZmb = 19103,
  VSQRTPDZmbk = 19104,
  VSQRTPDZmbkz = 19105,
  VSQRTPDZmk = 19106,
  VSQRTPDZmkz = 19107,
  VSQRTPDZr = 19108,
  VSQRTPDZrb = 19109,
  VSQRTPDZrbk = 19110,
  VSQRTPDZrbkz = 19111,
  VSQRTPDZrk = 19112,
  VSQRTPDZrkz = 19113,
  VSQRTPDm = 19114,
  VSQRTPDr = 19115,
  VSQRTPHZ128m = 19116,
  VSQRTPHZ128mb = 19117,
  VSQRTPHZ128mbk = 19118,
  VSQRTPHZ128mbkz = 19119,
  VSQRTPHZ128mk = 19120,
  VSQRTPHZ128mkz = 19121,
  VSQRTPHZ128r = 19122,
  VSQRTPHZ128rk = 19123,
  VSQRTPHZ128rkz = 19124,
  VSQRTPHZ256m = 19125,
  VSQRTPHZ256mb = 19126,
  VSQRTPHZ256mbk = 19127,
  VSQRTPHZ256mbkz = 19128,
  VSQRTPHZ256mk = 19129,
  VSQRTPHZ256mkz = 19130,
  VSQRTPHZ256r = 19131,
  VSQRTPHZ256rk = 19132,
  VSQRTPHZ256rkz = 19133,
  VSQRTPHZm = 19134,
  VSQRTPHZmb = 19135,
  VSQRTPHZmbk = 19136,
  VSQRTPHZmbkz = 19137,
  VSQRTPHZmk = 19138,
  VSQRTPHZmkz = 19139,
  VSQRTPHZr = 19140,
  VSQRTPHZrb = 19141,
  VSQRTPHZrbk = 19142,
  VSQRTPHZrbkz = 19143,
  VSQRTPHZrk = 19144,
  VSQRTPHZrkz = 19145,
  VSQRTPSYm = 19146,
  VSQRTPSYr = 19147,
  VSQRTPSZ128m = 19148,
  VSQRTPSZ128mb = 19149,
  VSQRTPSZ128mbk = 19150,
  VSQRTPSZ128mbkz = 19151,
  VSQRTPSZ128mk = 19152,
  VSQRTPSZ128mkz = 19153,
  VSQRTPSZ128r = 19154,
  VSQRTPSZ128rk = 19155,
  VSQRTPSZ128rkz = 19156,
  VSQRTPSZ256m = 19157,
  VSQRTPSZ256mb = 19158,
  VSQRTPSZ256mbk = 19159,
  VSQRTPSZ256mbkz = 19160,
  VSQRTPSZ256mk = 19161,
  VSQRTPSZ256mkz = 19162,
  VSQRTPSZ256r = 19163,
  VSQRTPSZ256rk = 19164,
  VSQRTPSZ256rkz = 19165,
  VSQRTPSZm = 19166,
  VSQRTPSZmb = 19167,
  VSQRTPSZmbk = 19168,
  VSQRTPSZmbkz = 19169,
  VSQRTPSZmk = 19170,
  VSQRTPSZmkz = 19171,
  VSQRTPSZr = 19172,
  VSQRTPSZrb = 19173,
  VSQRTPSZrbk = 19174,
  VSQRTPSZrbkz = 19175,
  VSQRTPSZrk = 19176,
  VSQRTPSZrkz = 19177,
  VSQRTPSm = 19178,
  VSQRTPSr = 19179,
  VSQRTSDZm = 19180,
  VSQRTSDZm_Int = 19181,
  VSQRTSDZm_Intk = 19182,
  VSQRTSDZm_Intkz = 19183,
  VSQRTSDZr = 19184,
  VSQRTSDZr_Int = 19185,
  VSQRTSDZr_Intk = 19186,
  VSQRTSDZr_Intkz = 19187,
  VSQRTSDZrb_Int = 19188,
  VSQRTSDZrb_Intk = 19189,
  VSQRTSDZrb_Intkz = 19190,
  VSQRTSDm = 19191,
  VSQRTSDm_Int = 19192,
  VSQRTSDr = 19193,
  VSQRTSDr_Int = 19194,
  VSQRTSHZm = 19195,
  VSQRTSHZm_Int = 19196,
  VSQRTSHZm_Intk = 19197,
  VSQRTSHZm_Intkz = 19198,
  VSQRTSHZr = 19199,
  VSQRTSHZr_Int = 19200,
  VSQRTSHZr_Intk = 19201,
  VSQRTSHZr_Intkz = 19202,
  VSQRTSHZrb_Int = 19203,
  VSQRTSHZrb_Intk = 19204,
  VSQRTSHZrb_Intkz = 19205,
  VSQRTSSZm = 19206,
  VSQRTSSZm_Int = 19207,
  VSQRTSSZm_Intk = 19208,
  VSQRTSSZm_Intkz = 19209,
  VSQRTSSZr = 19210,
  VSQRTSSZr_Int = 19211,
  VSQRTSSZr_Intk = 19212,
  VSQRTSSZr_Intkz = 19213,
  VSQRTSSZrb_Int = 19214,
  VSQRTSSZrb_Intk = 19215,
  VSQRTSSZrb_Intkz = 19216,
  VSQRTSSm = 19217,
  VSQRTSSm_Int = 19218,
  VSQRTSSr = 19219,
  VSQRTSSr_Int = 19220,
  VSTMXCSR = 19221,
  VSUBPDYrm = 19222,
  VSUBPDYrr = 19223,
  VSUBPDZ128rm = 19224,
  VSUBPDZ128rmb = 19225,
  VSUBPDZ128rmbk = 19226,
  VSUBPDZ128rmbkz = 19227,
  VSUBPDZ128rmk = 19228,
  VSUBPDZ128rmkz = 19229,
  VSUBPDZ128rr = 19230,
  VSUBPDZ128rrk = 19231,
  VSUBPDZ128rrkz = 19232,
  VSUBPDZ256rm = 19233,
  VSUBPDZ256rmb = 19234,
  VSUBPDZ256rmbk = 19235,
  VSUBPDZ256rmbkz = 19236,
  VSUBPDZ256rmk = 19237,
  VSUBPDZ256rmkz = 19238,
  VSUBPDZ256rr = 19239,
  VSUBPDZ256rrk = 19240,
  VSUBPDZ256rrkz = 19241,
  VSUBPDZrm = 19242,
  VSUBPDZrmb = 19243,
  VSUBPDZrmbk = 19244,
  VSUBPDZrmbkz = 19245,
  VSUBPDZrmk = 19246,
  VSUBPDZrmkz = 19247,
  VSUBPDZrr = 19248,
  VSUBPDZrrb = 19249,
  VSUBPDZrrbk = 19250,
  VSUBPDZrrbkz = 19251,
  VSUBPDZrrk = 19252,
  VSUBPDZrrkz = 19253,
  VSUBPDrm = 19254,
  VSUBPDrr = 19255,
  VSUBPHZ128rm = 19256,
  VSUBPHZ128rmb = 19257,
  VSUBPHZ128rmbk = 19258,
  VSUBPHZ128rmbkz = 19259,
  VSUBPHZ128rmk = 19260,
  VSUBPHZ128rmkz = 19261,
  VSUBPHZ128rr = 19262,
  VSUBPHZ128rrk = 19263,
  VSUBPHZ128rrkz = 19264,
  VSUBPHZ256rm = 19265,
  VSUBPHZ256rmb = 19266,
  VSUBPHZ256rmbk = 19267,
  VSUBPHZ256rmbkz = 19268,
  VSUBPHZ256rmk = 19269,
  VSUBPHZ256rmkz = 19270,
  VSUBPHZ256rr = 19271,
  VSUBPHZ256rrk = 19272,
  VSUBPHZ256rrkz = 19273,
  VSUBPHZrm = 19274,
  VSUBPHZrmb = 19275,
  VSUBPHZrmbk = 19276,
  VSUBPHZrmbkz = 19277,
  VSUBPHZrmk = 19278,
  VSUBPHZrmkz = 19279,
  VSUBPHZrr = 19280,
  VSUBPHZrrb = 19281,
  VSUBPHZrrbk = 19282,
  VSUBPHZrrbkz = 19283,
  VSUBPHZrrk = 19284,
  VSUBPHZrrkz = 19285,
  VSUBPSYrm = 19286,
  VSUBPSYrr = 19287,
  VSUBPSZ128rm = 19288,
  VSUBPSZ128rmb = 19289,
  VSUBPSZ128rmbk = 19290,
  VSUBPSZ128rmbkz = 19291,
  VSUBPSZ128rmk = 19292,
  VSUBPSZ128rmkz = 19293,
  VSUBPSZ128rr = 19294,
  VSUBPSZ128rrk = 19295,
  VSUBPSZ128rrkz = 19296,
  VSUBPSZ256rm = 19297,
  VSUBPSZ256rmb = 19298,
  VSUBPSZ256rmbk = 19299,
  VSUBPSZ256rmbkz = 19300,
  VSUBPSZ256rmk = 19301,
  VSUBPSZ256rmkz = 19302,
  VSUBPSZ256rr = 19303,
  VSUBPSZ256rrk = 19304,
  VSUBPSZ256rrkz = 19305,
  VSUBPSZrm = 19306,
  VSUBPSZrmb = 19307,
  VSUBPSZrmbk = 19308,
  VSUBPSZrmbkz = 19309,
  VSUBPSZrmk = 19310,
  VSUBPSZrmkz = 19311,
  VSUBPSZrr = 19312,
  VSUBPSZrrb = 19313,
  VSUBPSZrrbk = 19314,
  VSUBPSZrrbkz = 19315,
  VSUBPSZrrk = 19316,
  VSUBPSZrrkz = 19317,
  VSUBPSrm = 19318,
  VSUBPSrr = 19319,
  VSUBSDZrm = 19320,
  VSUBSDZrm_Int = 19321,
  VSUBSDZrm_Intk = 19322,
  VSUBSDZrm_Intkz = 19323,
  VSUBSDZrr = 19324,
  VSUBSDZrr_Int = 19325,
  VSUBSDZrr_Intk = 19326,
  VSUBSDZrr_Intkz = 19327,
  VSUBSDZrrb_Int = 19328,
  VSUBSDZrrb_Intk = 19329,
  VSUBSDZrrb_Intkz = 19330,
  VSUBSDrm = 19331,
  VSUBSDrm_Int = 19332,
  VSUBSDrr = 19333,
  VSUBSDrr_Int = 19334,
  VSUBSHZrm = 19335,
  VSUBSHZrm_Int = 19336,
  VSUBSHZrm_Intk = 19337,
  VSUBSHZrm_Intkz = 19338,
  VSUBSHZrr = 19339,
  VSUBSHZrr_Int = 19340,
  VSUBSHZrr_Intk = 19341,
  VSUBSHZrr_Intkz = 19342,
  VSUBSHZrrb_Int = 19343,
  VSUBSHZrrb_Intk = 19344,
  VSUBSHZrrb_Intkz = 19345,
  VSUBSSZrm = 19346,
  VSUBSSZrm_Int = 19347,
  VSUBSSZrm_Intk = 19348,
  VSUBSSZrm_Intkz = 19349,
  VSUBSSZrr = 19350,
  VSUBSSZrr_Int = 19351,
  VSUBSSZrr_Intk = 19352,
  VSUBSSZrr_Intkz = 19353,
  VSUBSSZrrb_Int = 19354,
  VSUBSSZrrb_Intk = 19355,
  VSUBSSZrrb_Intkz = 19356,
  VSUBSSrm = 19357,
  VSUBSSrm_Int = 19358,
  VSUBSSrr = 19359,
  VSUBSSrr_Int = 19360,
  VTESTPDYrm = 19361,
  VTESTPDYrr = 19362,
  VTESTPDrm = 19363,
  VTESTPDrr = 19364,
  VTESTPSYrm = 19365,
  VTESTPSYrr = 19366,
  VTESTPSrm = 19367,
  VTESTPSrr = 19368,
  VUCOMISDZrm = 19369,
  VUCOMISDZrm_Int = 19370,
  VUCOMISDZrr = 19371,
  VUCOMISDZrr_Int = 19372,
  VUCOMISDZrrb = 19373,
  VUCOMISDrm = 19374,
  VUCOMISDrm_Int = 19375,
  VUCOMISDrr = 19376,
  VUCOMISDrr_Int = 19377,
  VUCOMISHZrm = 19378,
  VUCOMISHZrm_Int = 19379,
  VUCOMISHZrr = 19380,
  VUCOMISHZrr_Int = 19381,
  VUCOMISHZrrb = 19382,
  VUCOMISSZrm = 19383,
  VUCOMISSZrm_Int = 19384,
  VUCOMISSZrr = 19385,
  VUCOMISSZrr_Int = 19386,
  VUCOMISSZrrb = 19387,
  VUCOMISSrm = 19388,
  VUCOMISSrm_Int = 19389,
  VUCOMISSrr = 19390,
  VUCOMISSrr_Int = 19391,
  VUNPCKHPDYrm = 19392,
  VUNPCKHPDYrr = 19393,
  VUNPCKHPDZ128rm = 19394,
  VUNPCKHPDZ128rmb = 19395,
  VUNPCKHPDZ128rmbk = 19396,
  VUNPCKHPDZ128rmbkz = 19397,
  VUNPCKHPDZ128rmk = 19398,
  VUNPCKHPDZ128rmkz = 19399,
  VUNPCKHPDZ128rr = 19400,
  VUNPCKHPDZ128rrk = 19401,
  VUNPCKHPDZ128rrkz = 19402,
  VUNPCKHPDZ256rm = 19403,
  VUNPCKHPDZ256rmb = 19404,
  VUNPCKHPDZ256rmbk = 19405,
  VUNPCKHPDZ256rmbkz = 19406,
  VUNPCKHPDZ256rmk = 19407,
  VUNPCKHPDZ256rmkz = 19408,
  VUNPCKHPDZ256rr = 19409,
  VUNPCKHPDZ256rrk = 19410,
  VUNPCKHPDZ256rrkz = 19411,
  VUNPCKHPDZrm = 19412,
  VUNPCKHPDZrmb = 19413,
  VUNPCKHPDZrmbk = 19414,
  VUNPCKHPDZrmbkz = 19415,
  VUNPCKHPDZrmk = 19416,
  VUNPCKHPDZrmkz = 19417,
  VUNPCKHPDZrr = 19418,
  VUNPCKHPDZrrk = 19419,
  VUNPCKHPDZrrkz = 19420,
  VUNPCKHPDrm = 19421,
  VUNPCKHPDrr = 19422,
  VUNPCKHPSYrm = 19423,
  VUNPCKHPSYrr = 19424,
  VUNPCKHPSZ128rm = 19425,
  VUNPCKHPSZ128rmb = 19426,
  VUNPCKHPSZ128rmbk = 19427,
  VUNPCKHPSZ128rmbkz = 19428,
  VUNPCKHPSZ128rmk = 19429,
  VUNPCKHPSZ128rmkz = 19430,
  VUNPCKHPSZ128rr = 19431,
  VUNPCKHPSZ128rrk = 19432,
  VUNPCKHPSZ128rrkz = 19433,
  VUNPCKHPSZ256rm = 19434,
  VUNPCKHPSZ256rmb = 19435,
  VUNPCKHPSZ256rmbk = 19436,
  VUNPCKHPSZ256rmbkz = 19437,
  VUNPCKHPSZ256rmk = 19438,
  VUNPCKHPSZ256rmkz = 19439,
  VUNPCKHPSZ256rr = 19440,
  VUNPCKHPSZ256rrk = 19441,
  VUNPCKHPSZ256rrkz = 19442,
  VUNPCKHPSZrm = 19443,
  VUNPCKHPSZrmb = 19444,
  VUNPCKHPSZrmbk = 19445,
  VUNPCKHPSZrmbkz = 19446,
  VUNPCKHPSZrmk = 19447,
  VUNPCKHPSZrmkz = 19448,
  VUNPCKHPSZrr = 19449,
  VUNPCKHPSZrrk = 19450,
  VUNPCKHPSZrrkz = 19451,
  VUNPCKHPSrm = 19452,
  VUNPCKHPSrr = 19453,
  VUNPCKLPDYrm = 19454,
  VUNPCKLPDYrr = 19455,
  VUNPCKLPDZ128rm = 19456,
  VUNPCKLPDZ128rmb = 19457,
  VUNPCKLPDZ128rmbk = 19458,
  VUNPCKLPDZ128rmbkz = 19459,
  VUNPCKLPDZ128rmk = 19460,
  VUNPCKLPDZ128rmkz = 19461,
  VUNPCKLPDZ128rr = 19462,
  VUNPCKLPDZ128rrk = 19463,
  VUNPCKLPDZ128rrkz = 19464,
  VUNPCKLPDZ256rm = 19465,
  VUNPCKLPDZ256rmb = 19466,
  VUNPCKLPDZ256rmbk = 19467,
  VUNPCKLPDZ256rmbkz = 19468,
  VUNPCKLPDZ256rmk = 19469,
  VUNPCKLPDZ256rmkz = 19470,
  VUNPCKLPDZ256rr = 19471,
  VUNPCKLPDZ256rrk = 19472,
  VUNPCKLPDZ256rrkz = 19473,
  VUNPCKLPDZrm = 19474,
  VUNPCKLPDZrmb = 19475,
  VUNPCKLPDZrmbk = 19476,
  VUNPCKLPDZrmbkz = 19477,
  VUNPCKLPDZrmk = 19478,
  VUNPCKLPDZrmkz = 19479,
  VUNPCKLPDZrr = 19480,
  VUNPCKLPDZrrk = 19481,
  VUNPCKLPDZrrkz = 19482,
  VUNPCKLPDrm = 19483,
  VUNPCKLPDrr = 19484,
  VUNPCKLPSYrm = 19485,
  VUNPCKLPSYrr = 19486,
  VUNPCKLPSZ128rm = 19487,
  VUNPCKLPSZ128rmb = 19488,
  VUNPCKLPSZ128rmbk = 19489,
  VUNPCKLPSZ128rmbkz = 19490,
  VUNPCKLPSZ128rmk = 19491,
  VUNPCKLPSZ128rmkz = 19492,
  VUNPCKLPSZ128rr = 19493,
  VUNPCKLPSZ128rrk = 19494,
  VUNPCKLPSZ128rrkz = 19495,
  VUNPCKLPSZ256rm = 19496,
  VUNPCKLPSZ256rmb = 19497,
  VUNPCKLPSZ256rmbk = 19498,
  VUNPCKLPSZ256rmbkz = 19499,
  VUNPCKLPSZ256rmk = 19500,
  VUNPCKLPSZ256rmkz = 19501,
  VUNPCKLPSZ256rr = 19502,
  VUNPCKLPSZ256rrk = 19503,
  VUNPCKLPSZ256rrkz = 19504,
  VUNPCKLPSZrm = 19505,
  VUNPCKLPSZrmb = 19506,
  VUNPCKLPSZrmbk = 19507,
  VUNPCKLPSZrmbkz = 19508,
  VUNPCKLPSZrmk = 19509,
  VUNPCKLPSZrmkz = 19510,
  VUNPCKLPSZrr = 19511,
  VUNPCKLPSZrrk = 19512,
  VUNPCKLPSZrrkz = 19513,
  VUNPCKLPSrm = 19514,
  VUNPCKLPSrr = 19515,
  VXORPDYrm = 19516,
  VXORPDYrr = 19517,
  VXORPDZ128rm = 19518,
  VXORPDZ128rmb = 19519,
  VXORPDZ128rmbk = 19520,
  VXORPDZ128rmbkz = 19521,
  VXORPDZ128rmk = 19522,
  VXORPDZ128rmkz = 19523,
  VXORPDZ128rr = 19524,
  VXORPDZ128rrk = 19525,
  VXORPDZ128rrkz = 19526,
  VXORPDZ256rm = 19527,
  VXORPDZ256rmb = 19528,
  VXORPDZ256rmbk = 19529,
  VXORPDZ256rmbkz = 19530,
  VXORPDZ256rmk = 19531,
  VXORPDZ256rmkz = 19532,
  VXORPDZ256rr = 19533,
  VXORPDZ256rrk = 19534,
  VXORPDZ256rrkz = 19535,
  VXORPDZrm = 19536,
  VXORPDZrmb = 19537,
  VXORPDZrmbk = 19538,
  VXORPDZrmbkz = 19539,
  VXORPDZrmk = 19540,
  VXORPDZrmkz = 19541,
  VXORPDZrr = 19542,
  VXORPDZrrk = 19543,
  VXORPDZrrkz = 19544,
  VXORPDrm = 19545,
  VXORPDrr = 19546,
  VXORPSYrm = 19547,
  VXORPSYrr = 19548,
  VXORPSZ128rm = 19549,
  VXORPSZ128rmb = 19550,
  VXORPSZ128rmbk = 19551,
  VXORPSZ128rmbkz = 19552,
  VXORPSZ128rmk = 19553,
  VXORPSZ128rmkz = 19554,
  VXORPSZ128rr = 19555,
  VXORPSZ128rrk = 19556,
  VXORPSZ128rrkz = 19557,
  VXORPSZ256rm = 19558,
  VXORPSZ256rmb = 19559,
  VXORPSZ256rmbk = 19560,
  VXORPSZ256rmbkz = 19561,
  VXORPSZ256rmk = 19562,
  VXORPSZ256rmkz = 19563,
  VXORPSZ256rr = 19564,
  VXORPSZ256rrk = 19565,
  VXORPSZ256rrkz = 19566,
  VXORPSZrm = 19567,
  VXORPSZrmb = 19568,
  VXORPSZrmbk = 19569,
  VXORPSZrmbkz = 19570,
  VXORPSZrmk = 19571,
  VXORPSZrmkz = 19572,
  VXORPSZrr = 19573,
  VXORPSZrrk = 19574,
  VXORPSZrrkz = 19575,
  VXORPSrm = 19576,
  VXORPSrr = 19577,
  VZEROALL = 19578,
  VZEROUPPER = 19579,
  WAIT = 19580,
  WBINVD = 19581,
  WBNOINVD = 19582,
  WRFSBASE = 19583,
  WRFSBASE64 = 19584,
  WRGSBASE = 19585,
  WRGSBASE64 = 19586,
  WRMSR = 19587,
  WRMSRLIST = 19588,
  WRMSRNS = 19589,
  WRPKRUr = 19590,
  WRSSD = 19591,
  WRSSD_EVEX = 19592,
  WRSSQ = 19593,
  WRSSQ_EVEX = 19594,
  WRUSSD = 19595,
  WRUSSD_EVEX = 19596,
  WRUSSQ = 19597,
  WRUSSQ_EVEX = 19598,
  XABORT = 19599,
  XACQUIRE_PREFIX = 19600,
  XADD16rm = 19601,
  XADD16rr = 19602,
  XADD32rm = 19603,
  XADD32rr = 19604,
  XADD64rm = 19605,
  XADD64rr = 19606,
  XADD8rm = 19607,
  XADD8rr = 19608,
  XAM_F = 19609,
  XAM_Fp32 = 19610,
  XAM_Fp64 = 19611,
  XAM_Fp80 = 19612,
  XBEGIN = 19613,
  XBEGIN_2 = 19614,
  XBEGIN_4 = 19615,
  XCHG16ar = 19616,
  XCHG16rm = 19617,
  XCHG16rr = 19618,
  XCHG32ar = 19619,
  XCHG32rm = 19620,
  XCHG32rr = 19621,
  XCHG64ar = 19622,
  XCHG64rm = 19623,
  XCHG64rr = 19624,
  XCHG8rm = 19625,
  XCHG8rr = 19626,
  XCH_F = 19627,
  XCRYPTCBC = 19628,
  XCRYPTCFB = 19629,
  XCRYPTCTR = 19630,
  XCRYPTECB = 19631,
  XCRYPTOFB = 19632,
  XEND = 19633,
  XGETBV = 19634,
  XLAT = 19635,
  XOR16i16 = 19636,
  XOR16mi = 19637,
  XOR16mi8 = 19638,
  XOR16mi8_EVEX = 19639,
  XOR16mi8_ND = 19640,
  XOR16mi8_NF = 19641,
  XOR16mi8_NF_ND = 19642,
  XOR16mi_EVEX = 19643,
  XOR16mi_ND = 19644,
  XOR16mi_NF = 19645,
  XOR16mi_NF_ND = 19646,
  XOR16mr = 19647,
  XOR16mr_EVEX = 19648,
  XOR16mr_ND = 19649,
  XOR16mr_NF = 19650,
  XOR16mr_NF_ND = 19651,
  XOR16ri = 19652,
  XOR16ri8 = 19653,
  XOR16ri8_EVEX = 19654,
  XOR16ri8_ND = 19655,
  XOR16ri8_NF = 19656,
  XOR16ri8_NF_ND = 19657,
  XOR16ri_EVEX = 19658,
  XOR16ri_ND = 19659,
  XOR16ri_NF = 19660,
  XOR16ri_NF_ND = 19661,
  XOR16rm = 19662,
  XOR16rm_EVEX = 19663,
  XOR16rm_ND = 19664,
  XOR16rm_NF = 19665,
  XOR16rm_NF_ND = 19666,
  XOR16rr = 19667,
  XOR16rr_EVEX = 19668,
  XOR16rr_EVEX_REV = 19669,
  XOR16rr_ND = 19670,
  XOR16rr_ND_REV = 19671,
  XOR16rr_NF = 19672,
  XOR16rr_NF_ND = 19673,
  XOR16rr_NF_ND_REV = 19674,
  XOR16rr_NF_REV = 19675,
  XOR16rr_REV = 19676,
  XOR32i32 = 19677,
  XOR32mi = 19678,
  XOR32mi8 = 19679,
  XOR32mi8_EVEX = 19680,
  XOR32mi8_ND = 19681,
  XOR32mi8_NF = 19682,
  XOR32mi8_NF_ND = 19683,
  XOR32mi_EVEX = 19684,
  XOR32mi_ND = 19685,
  XOR32mi_NF = 19686,
  XOR32mi_NF_ND = 19687,
  XOR32mr = 19688,
  XOR32mr_EVEX = 19689,
  XOR32mr_ND = 19690,
  XOR32mr_NF = 19691,
  XOR32mr_NF_ND = 19692,
  XOR32ri = 19693,
  XOR32ri8 = 19694,
  XOR32ri8_EVEX = 19695,
  XOR32ri8_ND = 19696,
  XOR32ri8_NF = 19697,
  XOR32ri8_NF_ND = 19698,
  XOR32ri_EVEX = 19699,
  XOR32ri_ND = 19700,
  XOR32ri_NF = 19701,
  XOR32ri_NF_ND = 19702,
  XOR32rm = 19703,
  XOR32rm_EVEX = 19704,
  XOR32rm_ND = 19705,
  XOR32rm_NF = 19706,
  XOR32rm_NF_ND = 19707,
  XOR32rr = 19708,
  XOR32rr_EVEX = 19709,
  XOR32rr_EVEX_REV = 19710,
  XOR32rr_ND = 19711,
  XOR32rr_ND_REV = 19712,
  XOR32rr_NF = 19713,
  XOR32rr_NF_ND = 19714,
  XOR32rr_NF_ND_REV = 19715,
  XOR32rr_NF_REV = 19716,
  XOR32rr_REV = 19717,
  XOR64i32 = 19718,
  XOR64mi32 = 19719,
  XOR64mi32_EVEX = 19720,
  XOR64mi32_ND = 19721,
  XOR64mi32_NF = 19722,
  XOR64mi32_NF_ND = 19723,
  XOR64mi8 = 19724,
  XOR64mi8_EVEX = 19725,
  XOR64mi8_ND = 19726,
  XOR64mi8_NF = 19727,
  XOR64mi8_NF_ND = 19728,
  XOR64mr = 19729,
  XOR64mr_EVEX = 19730,
  XOR64mr_ND = 19731,
  XOR64mr_NF = 19732,
  XOR64mr_NF_ND = 19733,
  XOR64ri32 = 19734,
  XOR64ri32_EVEX = 19735,
  XOR64ri32_ND = 19736,
  XOR64ri32_NF = 19737,
  XOR64ri32_NF_ND = 19738,
  XOR64ri8 = 19739,
  XOR64ri8_EVEX = 19740,
  XOR64ri8_ND = 19741,
  XOR64ri8_NF = 19742,
  XOR64ri8_NF_ND = 19743,
  XOR64rm = 19744,
  XOR64rm_EVEX = 19745,
  XOR64rm_ND = 19746,
  XOR64rm_NF = 19747,
  XOR64rm_NF_ND = 19748,
  XOR64rr = 19749,
  XOR64rr_EVEX = 19750,
  XOR64rr_EVEX_REV = 19751,
  XOR64rr_ND = 19752,
  XOR64rr_ND_REV = 19753,
  XOR64rr_NF = 19754,
  XOR64rr_NF_ND = 19755,
  XOR64rr_NF_ND_REV = 19756,
  XOR64rr_NF_REV = 19757,
  XOR64rr_REV = 19758,
  XOR8i8 = 19759,
  XOR8mi = 19760,
  XOR8mi8 = 19761,
  XOR8mi_EVEX = 19762,
  XOR8mi_ND = 19763,
  XOR8mi_NF = 19764,
  XOR8mi_NF_ND = 19765,
  XOR8mr = 19766,
  XOR8mr_EVEX = 19767,
  XOR8mr_ND = 19768,
  XOR8mr_NF = 19769,
  XOR8mr_NF_ND = 19770,
  XOR8ri = 19771,
  XOR8ri8 = 19772,
  XOR8ri_EVEX = 19773,
  XOR8ri_ND = 19774,
  XOR8ri_NF = 19775,
  XOR8ri_NF_ND = 19776,
  XOR8rm = 19777,
  XOR8rm_EVEX = 19778,
  XOR8rm_ND = 19779,
  XOR8rm_NF = 19780,
  XOR8rm_NF_ND = 19781,
  XOR8rr = 19782,
  XOR8rr_EVEX = 19783,
  XOR8rr_EVEX_REV = 19784,
  XOR8rr_ND = 19785,
  XOR8rr_ND_REV = 19786,
  XOR8rr_NF = 19787,
  XOR8rr_NF_ND = 19788,
  XOR8rr_NF_ND_REV = 19789,
  XOR8rr_NF_REV = 19790,
  XOR8rr_NOREX = 19791,
  XOR8rr_REV = 19792,
  XORPDrm = 19793,
  XORPDrr = 19794,
  XORPSrm = 19795,
  XORPSrr = 19796,
  XRELEASE_PREFIX = 19797,
  XRESLDTRK = 19798,
  XRSTOR = 19799,
  XRSTOR64 = 19800,
  XRSTORS = 19801,
  XRSTORS64 = 19802,
  XSAVE = 19803,
  XSAVE64 = 19804,
  XSAVEC = 19805,
  XSAVEC64 = 19806,
  XSAVEOPT = 19807,
  XSAVEOPT64 = 19808,
  XSAVES = 19809,
  XSAVES64 = 19810,
  XSETBV = 19811,
  XSHA1 = 19812,
  XSHA256 = 19813,
  XSTORE = 19814,
  XSUSLDTRK = 19815,
  XTEST = 19816,
  INSTRUCTION_LIST_END = 19817,
};
}
}
}
#endif
